/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 4329
#define LARGE_STATE_COUNT 257
#define SYMBOL_COUNT 307
#define ALIAS_COUNT 10
#define TOKEN_COUNT 142
#define EXTERNAL_TOKEN_COUNT 10
#define FIELD_COUNT 27
#define MAX_ALIAS_SEQUENCE_LENGTH 14
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 124
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_identifier = 1,
  aux_sym_block_token1 = 2,
  anon_sym_RPAREN = 3,
  anon_sym_LPAREN = 4,
  anon_sym_LBRACE = 5,
  anon_sym_RBRACE = 6,
  aux_sym_subroutine_block_token1 = 7,
  aux_sym_if_block_token1 = 8,
  aux_sym_elif_block_token1 = 9,
  aux_sym_while_block_token1 = 10,
  aux_sym_while_block_token2 = 11,
  aux_sym__repeat_block_pre_condition_format_token1 = 12,
  anon_sym_EQ = 13,
  anon_sym_PLUS = 14,
  anon_sym_DASH = 15,
  anon_sym_TILDE = 16,
  anon_sym_BANG = 17,
  anon_sym_PLUS_PLUS = 18,
  anon_sym_DASH_DASH = 19,
  anon_sym_CARET_CARET = 20,
  anon_sym_PIPE_PIPE = 21,
  anon_sym_STAR = 22,
  anon_sym_SLASH = 23,
  anon_sym_PERCENT = 24,
  anon_sym_PIPE = 25,
  anon_sym_CARET = 26,
  anon_sym_EQ_EQ = 27,
  anon_sym_BANG_EQ = 28,
  anon_sym_GT = 29,
  anon_sym_GT_EQ = 30,
  anon_sym_LT_EQ = 31,
  anon_sym_LT = 32,
  anon_sym_LT_LT = 33,
  anon_sym_GT_GT = 34,
  anon_sym_DOT_DOT = 35,
  anon_sym_AMP_AMP = 36,
  anon_sym_AMP = 37,
  anon_sym_COLON = 38,
  aux_sym_macro_definition_token1 = 39,
  aux_sym_parameter_declaration_token1 = 40,
  aux_sym_parameter_declaration_token2 = 41,
  aux_sym_parameter_declaration_token3 = 42,
  aux_sym_parameter_declaration_token4 = 43,
  aux_sym_subroutine_call_expression_token1 = 44,
  aux_sym_macro_definition_command_token1 = 45,
  aux_sym_macro_definition_command_token2 = 46,
  aux_sym_macro_definition_command_token3 = 47,
  aux_sym__host_command_with_default_format_token1 = 48,
  anon_sym_DOT = 49,
  anon_sym_COMMA = 50,
  aux_sym__host_command_argument_list_default_format_token1 = 51,
  aux_sym__hll_non_default_format_var_command_token1 = 52,
  aux_sym__hll_non_default_format_var_command_token2 = 53,
  aux_sym__hll_non_default_format_var_command_token3 = 54,
  aux_sym__hll_non_default_format_var_command_token4 = 55,
  aux_sym__hll_non_default_format_var_command_token5 = 56,
  aux_sym__hll_var_definition_command_token1 = 57,
  aux_sym__var_command_with_non_hll_format_token1 = 58,
  aux_sym__var_command_with_non_hll_format_token2 = 59,
  aux_sym__var_command_with_non_hll_format_token3 = 60,
  aux_sym__hll_var_definition_command_expression_token1 = 61,
  aux_sym__hll_var_definition_command_expression_token2 = 62,
  anon_sym_QMARK = 63,
  anon_sym_DASH_GT = 64,
  anon_sym_LBRACK = 65,
  anon_sym_RBRACK = 66,
  anon_sym_sizeof = 67,
  anon_sym_STAR_EQ = 68,
  anon_sym_SLASH_EQ = 69,
  anon_sym_PERCENT_EQ = 70,
  anon_sym_PLUS_EQ = 71,
  anon_sym_DASH_EQ = 72,
  anon_sym_LT_LT_EQ = 73,
  anon_sym_GT_GT_EQ = 74,
  anon_sym_AMP_EQ = 75,
  anon_sym_CARET_EQ = 76,
  anon_sym_PIPE_EQ = 77,
  anon_sym_L_SQUOTE = 78,
  anon_sym_u_SQUOTE = 79,
  anon_sym_U_SQUOTE = 80,
  anon_sym_u8_SQUOTE = 81,
  anon_sym_SQUOTE = 82,
  aux_sym_hll_char_literal_token1 = 83,
  anon_sym_L_DQUOTE = 84,
  anon_sym_u_DQUOTE = 85,
  anon_sym_U_DQUOTE = 86,
  anon_sym_u8_DQUOTE = 87,
  anon_sym_DQUOTE = 88,
  aux_sym_hll_string_literal_token1 = 89,
  anon_sym_const = 90,
  anon_sym_volatile = 91,
  anon_sym_struct = 92,
  anon_sym_union = 93,
  anon_sym_enum = 94,
  anon_sym_signed = 95,
  anon_sym_unsigned = 96,
  anon_sym_long = 97,
  anon_sym_short = 98,
  sym_hll_primitive_type = 99,
  sym_hll_escape_sequence = 100,
  aux_sym__hll_expression_separator_token1 = 101,
  aux_sym__hll_expression_separator_token2 = 102,
  anon_sym_COLON_COLON_COLON = 103,
  anon_sym_COLON_COLON = 104,
  sym_access_class = 105,
  aux_sym_integer_token1 = 106,
  aux_sym_integer_token2 = 107,
  sym_float = 108,
  aux_sym_bitmask_token1 = 109,
  aux_sym_bitmask_token2 = 110,
  aux_sym_string_token1 = 111,
  aux_sym_string_token2 = 112,
  aux_sym_character_token1 = 113,
  aux_sym_character_token2 = 114,
  sym__line_specifier = 115,
  anon_sym_BSLASH_BSLASH_BSLASH = 116,
  aux_sym_symbol_token1 = 117,
  aux_sym_symbol_token2 = 118,
  anon_sym_BSLASH_BSLASH = 119,
  anon_sym_BSLASH = 120,
  aux_sym_symbol_token3 = 121,
  aux_sym_symbol_token4 = 122,
  aux_sym_symbol_token5 = 123,
  sym__composed_name = 124,
  sym_time = 125,
  sym_frequency = 126,
  sym_percentage = 127,
  anon_sym_POUND = 128,
  aux_sym_file_handle_token1 = 129,
  sym_comment = 130,
  sym__blank_line = 131,
  sym__line_continuation = 132,
  sym__blank = 133,
  sym_label_identifier = 134,
  sym__and_operator_pre_hook = 135,
  sym__decimal_number = 136,
  sym__decimal_number_pre_hook = 137,
  sym_hll_number_literal = 138,
  sym__hll_number_literal_pre_hook = 139,
  sym_path = 140,
  sym__ampersand_char = 141,
  sym_script = 142,
  sym_block = 143,
  sym__statement = 144,
  sym__non_labeled_statement = 145,
  sym__parenthesized_expression = 146,
  sym__path_expression = 147,
  sym_labeled_expression = 148,
  sym_subroutine_block = 149,
  sym_if_block = 150,
  sym_elif_block = 151,
  sym_else_block = 152,
  sym_while_block = 153,
  sym_repeat_block = 154,
  sym__repeat_block_pre_condition_format = 155,
  sym__repeat_block_post_condition_format = 156,
  sym_macro_assignment_expression = 157,
  sym_unary_expression = 158,
  sym__unary_expression = 159,
  sym__prefix_postfix_expression = 160,
  sym_binary_expression = 161,
  sym__binary_expression = 162,
  sym__and_expression = 163,
  sym_assignment_expression = 164,
  sym__label = 165,
  sym_macro_definition = 166,
  sym_parameter_declaration = 167,
  sym_subroutine_call_expression = 168,
  sym_macro = 169,
  sym_recursive_macro_expansion = 170,
  sym_macro_text_expansion = 171,
  sym_macro_definition_command = 172,
  sym_command_expression = 173,
  sym__host_command = 174,
  sym__host_command_with_default_format = 175,
  sym__other_command = 176,
  sym__command_identifier = 177,
  sym__command_arguments = 178,
  sym__host_command_argument_list_default_format = 179,
  sym__command_argument = 180,
  sym__option_value = 181,
  sym__parenthesized_option_value = 182,
  sym_option_expression = 183,
  sym_format_expression = 184,
  sym_call_expression = 185,
  sym__function_identifier = 186,
  sym_argument_list = 187,
  sym__var_command = 188,
  sym__hll_var_command = 189,
  sym__hll_default_format_var_command = 190,
  sym__hll_non_default_format_var_command = 191,
  sym__non_hll_var_command = 192,
  sym__hll_var_definition_command = 193,
  sym__hll_var_command_with_default_format = 194,
  sym__var_command_with_non_hll_format = 195,
  sym__hll_var_definition_command_expression = 196,
  sym__hll_var_if_command = 197,
  sym__hll_var_command_argument_list_default_format = 198,
  sym__hll_var_command_argument_list_non_default_format = 199,
  sym__hll_var_pattern_command_argument_list_format = 200,
  sym__var_command_argument_list_non_hll_format = 201,
  sym__var_definition_command_argument_list_format = 202,
  sym__hll_var_call_expression_function = 203,
  sym__hll_var_call_expression = 204,
  sym_hll_var_call_expression_argument_list = 205,
  sym_hll_type_pattern = 206,
  sym__hll_option_value = 207,
  sym__hll_parenthesized_option_value = 208,
  sym_hll_option_expression = 209,
  sym__hll_expression = 210,
  sym_hll_call_expression = 211,
  sym_hll_field_expression = 212,
  sym_hll_subscript_expression = 213,
  sym_hll_cast_expression = 214,
  sym_hll_sizeof_expression = 215,
  sym_hll_pointer_expression = 216,
  sym_hll_comma_expression = 217,
  sym_hll_update_expression = 218,
  sym_hll_unary_expression = 219,
  sym_hll_binary_expression = 220,
  sym_hll_range_expression = 221,
  sym_hll_assignment_expression = 222,
  sym__hll_assignment_left_expression = 223,
  sym_hll_conditional_expression = 224,
  sym_hll_char_literal = 225,
  sym_hll_string_literal = 226,
  sym_hll_parenthesized_expression = 227,
  sym_hll_type_descriptor = 228,
  sym_hll_type_qualifier = 229,
  sym__hll_declaration_modifiers = 230,
  sym__hll_type_specifier = 231,
  sym_hll_struct_specifier = 232,
  sym_hll_union_specifier = 233,
  sym_hll_enum_specifier = 234,
  sym_hll_sized_type_specifier = 235,
  sym_hll_declaration = 236,
  sym__hll_declaration_specifiers = 237,
  sym__hll_declarator = 238,
  sym_hll_pointer_declarator = 239,
  sym_hll_function_declarator = 240,
  sym_hll_array_declarator = 241,
  sym_hll_parenthesized_declarator = 242,
  sym__hll_pointer_declarator_specifier = 243,
  sym__hll_abstract_declarator = 244,
  sym_hll_abstract_pointer_declarator = 245,
  sym_hll_abstract_function_declarator = 246,
  sym_hll_abstract_array_declarator = 247,
  sym_hll_abstract_parenthesized_declarator = 248,
  sym_hll_parameter_list = 249,
  sym_hll_parameter_declaration = 250,
  sym_hll_argument_list = 251,
  sym__hll_type_identifier = 252,
  sym__hll_field_identifier = 253,
  sym__literal = 254,
  sym__address_expression = 255,
  sym_memory_space = 256,
  sym_address = 257,
  sym__parenthesized_address_expression = 258,
  sym__address_binary_expression = 259,
  sym_integer = 260,
  sym_bitmask = 261,
  sym_string = 262,
  sym_character = 263,
  sym_symbol = 264,
  sym__special_command_operator = 265,
  sym__file_dialog = 266,
  sym_file_handle = 267,
  sym__expression = 268,
  aux_sym_script_repeat1 = 269,
  aux_sym_block_repeat1 = 270,
  aux_sym_block_repeat2 = 271,
  aux_sym__path_expression_repeat1 = 272,
  aux_sym__path_expression_repeat2 = 273,
  aux_sym_labeled_expression_repeat1 = 274,
  aux_sym_subroutine_block_repeat1 = 275,
  aux_sym_if_block_repeat1 = 276,
  aux_sym_macro_definition_repeat1 = 277,
  aux_sym_macro_text_expansion_repeat1 = 278,
  aux_sym__command_identifier_repeat1 = 279,
  aux_sym__command_arguments_repeat1 = 280,
  aux_sym__command_arguments_repeat2 = 281,
  aux_sym__command_arguments_repeat3 = 282,
  aux_sym__host_command_argument_list_default_format_repeat1 = 283,
  aux_sym__host_command_argument_list_default_format_repeat2 = 284,
  aux_sym_format_expression_repeat1 = 285,
  aux_sym__function_identifier_repeat1 = 286,
  aux_sym_argument_list_repeat1 = 287,
  aux_sym__hll_var_command_argument_list_default_format_repeat1 = 288,
  aux_sym__hll_var_command_argument_list_default_format_repeat2 = 289,
  aux_sym__hll_var_command_argument_list_default_format_repeat3 = 290,
  aux_sym__hll_var_pattern_command_argument_list_format_repeat1 = 291,
  aux_sym__hll_var_pattern_command_argument_list_format_repeat2 = 292,
  aux_sym__var_command_argument_list_non_hll_format_repeat1 = 293,
  aux_sym_hll_type_pattern_repeat1 = 294,
  aux_sym_hll_string_literal_repeat1 = 295,
  aux_sym_hll_type_descriptor_repeat1 = 296,
  aux_sym_hll_type_descriptor_repeat2 = 297,
  aux_sym_hll_sized_type_specifier_repeat1 = 298,
  aux_sym__hll_declaration_specifiers_repeat1 = 299,
  aux_sym__hll_declaration_specifiers_repeat2 = 300,
  aux_sym__hll_pointer_declarator_specifier_repeat1 = 301,
  aux_sym_hll_parameter_list_repeat1 = 302,
  aux_sym_hll_argument_list_repeat1 = 303,
  aux_sym_string_repeat1 = 304,
  aux_sym_symbol_repeat1 = 305,
  aux_sym_file_handle_repeat1 = 306,
  anon_alias_sym_IF = 307,
  anon_alias_sym_command = 308,
  anon_alias_sym_fragment = 309,
  anon_alias_sym_function = 310,
  alias_sym_hll_field_identifier = 311,
  alias_sym_hll_type_identifier = 312,
  anon_alias_sym_name = 313,
  anon_alias_sym_subcommand = 314,
  anon_alias_sym_subfunction = 315,
  anon_alias_sym_type = 316,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [aux_sym_block_token1] = "block_token1",
  [anon_sym_RPAREN] = ")",
  [anon_sym_LPAREN] = "(",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_subroutine_block_token1] = "identifier",
  [aux_sym_if_block_token1] = "identifier",
  [aux_sym_elif_block_token1] = "identifier",
  [aux_sym_while_block_token1] = "identifier",
  [aux_sym_while_block_token2] = "identifier",
  [aux_sym__repeat_block_pre_condition_format_token1] = "identifier",
  [anon_sym_EQ] = "=",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG] = "!",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_CARET_CARET] = "^^",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_AMP] = "&",
  [anon_sym_COLON] = ":",
  [aux_sym_macro_definition_token1] = "macro_definition_token1",
  [aux_sym_parameter_declaration_token1] = "identifier",
  [aux_sym_parameter_declaration_token2] = "identifier",
  [aux_sym_parameter_declaration_token3] = "identifier",
  [aux_sym_parameter_declaration_token4] = "identifier",
  [aux_sym_subroutine_call_expression_token1] = "identifier",
  [aux_sym_macro_definition_command_token1] = "GLOBAL",
  [aux_sym_macro_definition_command_token2] = "LOCAL",
  [aux_sym_macro_definition_command_token3] = "PRIVATE",
  [aux_sym__host_command_with_default_format_token1] = "OS",
  [anon_sym_DOT] = ".",
  [anon_sym_COMMA] = ",",
  [aux_sym__host_command_argument_list_default_format_token1] = "_host_command_argument_list_default_format_token1",
  [aux_sym__hll_non_default_format_var_command_token1] = "Var",
  [aux_sym__hll_non_default_format_var_command_token2] = "AddSticker",
  [aux_sym__hll_non_default_format_var_command_token3] = "EXPORT",
  [aux_sym__hll_non_default_format_var_command_token4] = "WRITE",
  [aux_sym__hll_non_default_format_var_command_token5] = "PATtern",
  [aux_sym__hll_var_definition_command_token1] = "_hll_var_definition_command_token1",
  [aux_sym__var_command_with_non_hll_format_token1] = "Local",
  [aux_sym__var_command_with_non_hll_format_token2] = "Ref",
  [aux_sym__var_command_with_non_hll_format_token3] = "TREE",
  [aux_sym__hll_var_definition_command_expression_token1] = "NEWLOCAL",
  [aux_sym__hll_var_definition_command_expression_token2] = "NEWGLOBAL",
  [anon_sym_QMARK] = "\?",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_hll_char_literal_token1] = "character",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_hll_string_literal_token1] = "hll_string_literal_token1",
  [anon_sym_const] = "const",
  [anon_sym_volatile] = "volatile",
  [anon_sym_struct] = "struct",
  [anon_sym_union] = "union",
  [anon_sym_enum] = "enum",
  [anon_sym_signed] = "signed",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_long] = "long",
  [anon_sym_short] = "short",
  [sym_hll_primitive_type] = "hll_primitive_type",
  [sym_hll_escape_sequence] = "hll_escape_sequence",
  [aux_sym__hll_expression_separator_token1] = "_hll_expression_separator_token1",
  [aux_sym__hll_expression_separator_token2] = "_hll_expression_separator_token2",
  [anon_sym_COLON_COLON_COLON] = ":::",
  [anon_sym_COLON_COLON] = "::",
  [sym_access_class] = "access_class",
  [aux_sym_integer_token1] = "integer_token1",
  [aux_sym_integer_token2] = "integer_token2",
  [sym_float] = "float",
  [aux_sym_bitmask_token1] = "bitmask_token1",
  [aux_sym_bitmask_token2] = "bitmask_token2",
  [aux_sym_string_token1] = "string_token1",
  [aux_sym_string_token2] = "string_token2",
  [aux_sym_character_token1] = "character_token1",
  [aux_sym_character_token2] = "character_token2",
  [sym__line_specifier] = "_line_specifier",
  [anon_sym_BSLASH_BSLASH_BSLASH] = "\\\\\\",
  [aux_sym_symbol_token1] = "symbol_token1",
  [aux_sym_symbol_token2] = "symbol_token2",
  [anon_sym_BSLASH_BSLASH] = "\\\\",
  [anon_sym_BSLASH] = "\\",
  [aux_sym_symbol_token3] = "symbol_token3",
  [aux_sym_symbol_token4] = "symbol_token4",
  [aux_sym_symbol_token5] = "symbol_token5",
  [sym__composed_name] = "identifier",
  [sym_time] = "time",
  [sym_frequency] = "frequency",
  [sym_percentage] = "percentage",
  [anon_sym_POUND] = "#",
  [aux_sym_file_handle_token1] = "file_handle_token1",
  [sym_comment] = "comment",
  [sym__blank_line] = "_blank_line",
  [sym__line_continuation] = "_line_continuation",
  [sym__blank] = "_blank",
  [sym_label_identifier] = "identifier",
  [sym__and_operator_pre_hook] = "_and_operator_pre_hook",
  [sym__decimal_number] = "_decimal_number",
  [sym__decimal_number_pre_hook] = "_decimal_number_pre_hook",
  [sym_hll_number_literal] = "hll_number_literal",
  [sym__hll_number_literal_pre_hook] = "_hll_number_literal_pre_hook",
  [sym_path] = "path",
  [sym__ampersand_char] = "_ampersand_char",
  [sym_script] = "script",
  [sym_block] = "block",
  [sym__statement] = "_statement",
  [sym__non_labeled_statement] = "_non_labeled_statement",
  [sym__parenthesized_expression] = "_parenthesized_expression",
  [sym__path_expression] = "_path_expression",
  [sym_labeled_expression] = "labeled_expression",
  [sym_subroutine_block] = "subroutine_block",
  [sym_if_block] = "if_block",
  [sym_elif_block] = "elif_block",
  [sym_else_block] = "else_block",
  [sym_while_block] = "while_block",
  [sym_repeat_block] = "repeat_block",
  [sym__repeat_block_pre_condition_format] = "_repeat_block_pre_condition_format",
  [sym__repeat_block_post_condition_format] = "_repeat_block_post_condition_format",
  [sym_macro_assignment_expression] = "assignment_expression",
  [sym_unary_expression] = "unary_expression",
  [sym__unary_expression] = "_unary_expression",
  [sym__prefix_postfix_expression] = "_prefix_postfix_expression",
  [sym_binary_expression] = "binary_expression",
  [sym__binary_expression] = "_binary_expression",
  [sym__and_expression] = "_and_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym__label] = "_label",
  [sym_macro_definition] = "macro_definition",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_subroutine_call_expression] = "subroutine_call_expression",
  [sym_macro] = "macro",
  [sym_recursive_macro_expansion] = "recursive_macro_expansion",
  [sym_macro_text_expansion] = "macro_text_expansion",
  [sym_macro_definition_command] = "identifier",
  [sym_command_expression] = "command_expression",
  [sym__host_command] = "_host_command",
  [sym__host_command_with_default_format] = "identifier",
  [sym__other_command] = "_other_command",
  [sym__command_identifier] = "identifier",
  [sym__command_arguments] = "argument_list",
  [sym__host_command_argument_list_default_format] = "argument_list",
  [sym__command_argument] = "_command_argument",
  [sym__option_value] = "_option_value",
  [sym__parenthesized_option_value] = "_parenthesized_option_value",
  [sym_option_expression] = "option_expression",
  [sym_format_expression] = "format_expression",
  [sym_call_expression] = "call_expression",
  [sym__function_identifier] = "identifier",
  [sym_argument_list] = "argument_list",
  [sym__var_command] = "_var_command",
  [sym__hll_var_command] = "_hll_var_command",
  [sym__hll_default_format_var_command] = "_hll_default_format_var_command",
  [sym__hll_non_default_format_var_command] = "_hll_non_default_format_var_command",
  [sym__non_hll_var_command] = "_non_hll_var_command",
  [sym__hll_var_definition_command] = "_hll_var_definition_command",
  [sym__hll_var_command_with_default_format] = "identifier",
  [sym__var_command_with_non_hll_format] = "identifier",
  [sym__hll_var_definition_command_expression] = "identifier",
  [sym__hll_var_if_command] = "identifier",
  [sym__hll_var_command_argument_list_default_format] = "argument_list",
  [sym__hll_var_command_argument_list_non_default_format] = "argument_list",
  [sym__hll_var_pattern_command_argument_list_format] = "argument_list",
  [sym__var_command_argument_list_non_hll_format] = "argument_list",
  [sym__var_definition_command_argument_list_format] = "argument_list",
  [sym__hll_var_call_expression_function] = "identifier",
  [sym__hll_var_call_expression] = "_hll_var_call_expression",
  [sym_hll_var_call_expression_argument_list] = "argument_list",
  [sym_hll_type_pattern] = "hll_type_pattern",
  [sym__hll_option_value] = "_hll_option_value",
  [sym__hll_parenthesized_option_value] = "_hll_parenthesized_option_value",
  [sym_hll_option_expression] = "option_expression",
  [sym__hll_expression] = "_hll_expression",
  [sym_hll_call_expression] = "hll_call_expression",
  [sym_hll_field_expression] = "hll_field_expression",
  [sym_hll_subscript_expression] = "hll_subscript_expression",
  [sym_hll_cast_expression] = "hll_cast_expression",
  [sym_hll_sizeof_expression] = "hll_sizeof_expression",
  [sym_hll_pointer_expression] = "hll_pointer_expression",
  [sym_hll_comma_expression] = "hll_comma_expression",
  [sym_hll_update_expression] = "hll_update_expression",
  [sym_hll_unary_expression] = "hll_unary_expression",
  [sym_hll_binary_expression] = "hll_binary_expression",
  [sym_hll_range_expression] = "hll_range_expression",
  [sym_hll_assignment_expression] = "hll_assignment_expression",
  [sym__hll_assignment_left_expression] = "_hll_assignment_left_expression",
  [sym_hll_conditional_expression] = "hll_conditional_expression",
  [sym_hll_char_literal] = "hll_char_literal",
  [sym_hll_string_literal] = "hll_string_literal",
  [sym_hll_parenthesized_expression] = "hll_parenthesized_expression",
  [sym_hll_type_descriptor] = "hll_type_descriptor",
  [sym_hll_type_qualifier] = "hll_type_qualifier",
  [sym__hll_declaration_modifiers] = "_hll_declaration_modifiers",
  [sym__hll_type_specifier] = "_hll_type_specifier",
  [sym_hll_struct_specifier] = "hll_struct_specifier",
  [sym_hll_union_specifier] = "hll_union_specifier",
  [sym_hll_enum_specifier] = "hll_enum_specifier",
  [sym_hll_sized_type_specifier] = "hll_sized_type_specifier",
  [sym_hll_declaration] = "hll_declaration",
  [sym__hll_declaration_specifiers] = "_hll_declaration_specifiers",
  [sym__hll_declarator] = "_hll_declarator",
  [sym_hll_pointer_declarator] = "hll_pointer_declarator",
  [sym_hll_function_declarator] = "hll_function_declarator",
  [sym_hll_array_declarator] = "hll_array_declarator",
  [sym_hll_parenthesized_declarator] = "hll_parenthesized_declarator",
  [sym__hll_pointer_declarator_specifier] = "_hll_pointer_declarator_specifier",
  [sym__hll_abstract_declarator] = "_hll_abstract_declarator",
  [sym_hll_abstract_pointer_declarator] = "hll_abstract_pointer_declarator",
  [sym_hll_abstract_function_declarator] = "hll_abstract_function_declarator",
  [sym_hll_abstract_array_declarator] = "hll_abstract_array_declarator",
  [sym_hll_abstract_parenthesized_declarator] = "hll_abstract_parenthesized_declarator",
  [sym_hll_parameter_list] = "hll_parameter_list",
  [sym_hll_parameter_declaration] = "hll_parameter_declaration",
  [sym_hll_argument_list] = "hll_argument_list",
  [sym__hll_type_identifier] = "_hll_type_identifier",
  [sym__hll_field_identifier] = "_hll_field_identifier",
  [sym__literal] = "_literal",
  [sym__address_expression] = "_address_expression",
  [sym_memory_space] = "memory_space",
  [sym_address] = "address",
  [sym__parenthesized_address_expression] = "_parenthesized_address_expression",
  [sym__address_binary_expression] = "binary_expression",
  [sym_integer] = "integer",
  [sym_bitmask] = "bitmask",
  [sym_string] = "string",
  [sym_character] = "character",
  [sym_symbol] = "symbol",
  [sym__special_command_operator] = "literal",
  [sym__file_dialog] = "_file_dialog",
  [sym_file_handle] = "file_handle",
  [sym__expression] = "_expression",
  [aux_sym_script_repeat1] = "script_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_block_repeat2] = "block_repeat2",
  [aux_sym__path_expression_repeat1] = "_path_expression_repeat1",
  [aux_sym__path_expression_repeat2] = "_path_expression_repeat2",
  [aux_sym_labeled_expression_repeat1] = "labeled_expression_repeat1",
  [aux_sym_subroutine_block_repeat1] = "subroutine_block_repeat1",
  [aux_sym_if_block_repeat1] = "if_block_repeat1",
  [aux_sym_macro_definition_repeat1] = "macro_definition_repeat1",
  [aux_sym_macro_text_expansion_repeat1] = "macro_text_expansion_repeat1",
  [aux_sym__command_identifier_repeat1] = "_command_identifier_repeat1",
  [aux_sym__command_arguments_repeat1] = "_command_arguments_repeat1",
  [aux_sym__command_arguments_repeat2] = "_command_arguments_repeat2",
  [aux_sym__command_arguments_repeat3] = "_command_arguments_repeat3",
  [aux_sym__host_command_argument_list_default_format_repeat1] = "_host_command_argument_list_default_format_repeat1",
  [aux_sym__host_command_argument_list_default_format_repeat2] = "_host_command_argument_list_default_format_repeat2",
  [aux_sym_format_expression_repeat1] = "format_expression_repeat1",
  [aux_sym__function_identifier_repeat1] = "_function_identifier_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = "_hll_var_command_argument_list_default_format_repeat1",
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = "_hll_var_command_argument_list_default_format_repeat2",
  [aux_sym__hll_var_command_argument_list_default_format_repeat3] = "_hll_var_command_argument_list_default_format_repeat3",
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = "_hll_var_pattern_command_argument_list_format_repeat1",
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = "_hll_var_pattern_command_argument_list_format_repeat2",
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = "_var_command_argument_list_non_hll_format_repeat1",
  [aux_sym_hll_type_pattern_repeat1] = "hll_type_pattern_repeat1",
  [aux_sym_hll_string_literal_repeat1] = "hll_string_literal_repeat1",
  [aux_sym_hll_type_descriptor_repeat1] = "hll_type_descriptor_repeat1",
  [aux_sym_hll_type_descriptor_repeat2] = "hll_type_descriptor_repeat2",
  [aux_sym_hll_sized_type_specifier_repeat1] = "hll_sized_type_specifier_repeat1",
  [aux_sym__hll_declaration_specifiers_repeat1] = "_hll_declaration_specifiers_repeat1",
  [aux_sym__hll_declaration_specifiers_repeat2] = "_hll_declaration_specifiers_repeat2",
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = "_hll_pointer_declarator_specifier_repeat1",
  [aux_sym_hll_parameter_list_repeat1] = "hll_parameter_list_repeat1",
  [aux_sym_hll_argument_list_repeat1] = "hll_argument_list_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_symbol_repeat1] = "symbol_repeat1",
  [aux_sym_file_handle_repeat1] = "file_handle_repeat1",
  [anon_alias_sym_IF] = "IF",
  [anon_alias_sym_command] = "command",
  [anon_alias_sym_fragment] = "fragment",
  [anon_alias_sym_function] = "function",
  [alias_sym_hll_field_identifier] = "hll_field_identifier",
  [alias_sym_hll_type_identifier] = "hll_type_identifier",
  [anon_alias_sym_name] = "name",
  [anon_alias_sym_subcommand] = "subcommand",
  [anon_alias_sym_subfunction] = "subfunction",
  [anon_alias_sym_type] = "type",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [aux_sym_block_token1] = aux_sym_block_token1,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_subroutine_block_token1] = sym_identifier,
  [aux_sym_if_block_token1] = sym_identifier,
  [aux_sym_elif_block_token1] = sym_identifier,
  [aux_sym_while_block_token1] = sym_identifier,
  [aux_sym_while_block_token2] = sym_identifier,
  [aux_sym__repeat_block_pre_condition_format_token1] = sym_identifier,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_CARET_CARET] = anon_sym_CARET_CARET,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_COLON] = anon_sym_COLON,
  [aux_sym_macro_definition_token1] = aux_sym_macro_definition_token1,
  [aux_sym_parameter_declaration_token1] = sym_identifier,
  [aux_sym_parameter_declaration_token2] = sym_identifier,
  [aux_sym_parameter_declaration_token3] = sym_identifier,
  [aux_sym_parameter_declaration_token4] = sym_identifier,
  [aux_sym_subroutine_call_expression_token1] = sym_identifier,
  [aux_sym_macro_definition_command_token1] = aux_sym_macro_definition_command_token1,
  [aux_sym_macro_definition_command_token2] = aux_sym_macro_definition_command_token2,
  [aux_sym_macro_definition_command_token3] = aux_sym_macro_definition_command_token3,
  [aux_sym__host_command_with_default_format_token1] = aux_sym__host_command_with_default_format_token1,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [aux_sym__host_command_argument_list_default_format_token1] = aux_sym__host_command_argument_list_default_format_token1,
  [aux_sym__hll_non_default_format_var_command_token1] = aux_sym__hll_non_default_format_var_command_token1,
  [aux_sym__hll_non_default_format_var_command_token2] = aux_sym__hll_non_default_format_var_command_token2,
  [aux_sym__hll_non_default_format_var_command_token3] = aux_sym__hll_non_default_format_var_command_token3,
  [aux_sym__hll_non_default_format_var_command_token4] = aux_sym__hll_non_default_format_var_command_token4,
  [aux_sym__hll_non_default_format_var_command_token5] = aux_sym__hll_non_default_format_var_command_token5,
  [aux_sym__hll_var_definition_command_token1] = aux_sym__hll_var_definition_command_token1,
  [aux_sym__var_command_with_non_hll_format_token1] = aux_sym__var_command_with_non_hll_format_token1,
  [aux_sym__var_command_with_non_hll_format_token2] = aux_sym__var_command_with_non_hll_format_token2,
  [aux_sym__var_command_with_non_hll_format_token3] = aux_sym__var_command_with_non_hll_format_token3,
  [aux_sym__hll_var_definition_command_expression_token1] = aux_sym__hll_var_definition_command_expression_token1,
  [aux_sym__hll_var_definition_command_expression_token2] = aux_sym__hll_var_definition_command_expression_token2,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_hll_char_literal_token1] = sym_character,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_hll_string_literal_token1] = aux_sym_hll_string_literal_token1,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_signed] = anon_sym_signed,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_short] = anon_sym_short,
  [sym_hll_primitive_type] = sym_hll_primitive_type,
  [sym_hll_escape_sequence] = sym_hll_escape_sequence,
  [aux_sym__hll_expression_separator_token1] = aux_sym__hll_expression_separator_token1,
  [aux_sym__hll_expression_separator_token2] = aux_sym__hll_expression_separator_token2,
  [anon_sym_COLON_COLON_COLON] = anon_sym_COLON_COLON_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [sym_access_class] = sym_access_class,
  [aux_sym_integer_token1] = aux_sym_integer_token1,
  [aux_sym_integer_token2] = aux_sym_integer_token2,
  [sym_float] = sym_float,
  [aux_sym_bitmask_token1] = aux_sym_bitmask_token1,
  [aux_sym_bitmask_token2] = aux_sym_bitmask_token2,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [aux_sym_string_token2] = aux_sym_string_token2,
  [aux_sym_character_token1] = aux_sym_character_token1,
  [aux_sym_character_token2] = aux_sym_character_token2,
  [sym__line_specifier] = sym__line_specifier,
  [anon_sym_BSLASH_BSLASH_BSLASH] = anon_sym_BSLASH_BSLASH_BSLASH,
  [aux_sym_symbol_token1] = aux_sym_symbol_token1,
  [aux_sym_symbol_token2] = aux_sym_symbol_token2,
  [anon_sym_BSLASH_BSLASH] = anon_sym_BSLASH_BSLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [aux_sym_symbol_token3] = aux_sym_symbol_token3,
  [aux_sym_symbol_token4] = aux_sym_symbol_token4,
  [aux_sym_symbol_token5] = aux_sym_symbol_token5,
  [sym__composed_name] = sym_identifier,
  [sym_time] = sym_time,
  [sym_frequency] = sym_frequency,
  [sym_percentage] = sym_percentage,
  [anon_sym_POUND] = anon_sym_POUND,
  [aux_sym_file_handle_token1] = aux_sym_file_handle_token1,
  [sym_comment] = sym_comment,
  [sym__blank_line] = sym__blank_line,
  [sym__line_continuation] = sym__line_continuation,
  [sym__blank] = sym__blank,
  [sym_label_identifier] = sym_identifier,
  [sym__and_operator_pre_hook] = sym__and_operator_pre_hook,
  [sym__decimal_number] = sym__decimal_number,
  [sym__decimal_number_pre_hook] = sym__decimal_number_pre_hook,
  [sym_hll_number_literal] = sym_hll_number_literal,
  [sym__hll_number_literal_pre_hook] = sym__hll_number_literal_pre_hook,
  [sym_path] = sym_path,
  [sym__ampersand_char] = sym__ampersand_char,
  [sym_script] = sym_script,
  [sym_block] = sym_block,
  [sym__statement] = sym__statement,
  [sym__non_labeled_statement] = sym__non_labeled_statement,
  [sym__parenthesized_expression] = sym__parenthesized_expression,
  [sym__path_expression] = sym__path_expression,
  [sym_labeled_expression] = sym_labeled_expression,
  [sym_subroutine_block] = sym_subroutine_block,
  [sym_if_block] = sym_if_block,
  [sym_elif_block] = sym_elif_block,
  [sym_else_block] = sym_else_block,
  [sym_while_block] = sym_while_block,
  [sym_repeat_block] = sym_repeat_block,
  [sym__repeat_block_pre_condition_format] = sym__repeat_block_pre_condition_format,
  [sym__repeat_block_post_condition_format] = sym__repeat_block_post_condition_format,
  [sym_macro_assignment_expression] = sym_assignment_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym__unary_expression] = sym__unary_expression,
  [sym__prefix_postfix_expression] = sym__prefix_postfix_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym__binary_expression] = sym__binary_expression,
  [sym__and_expression] = sym__and_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym__label] = sym__label,
  [sym_macro_definition] = sym_macro_definition,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_subroutine_call_expression] = sym_subroutine_call_expression,
  [sym_macro] = sym_macro,
  [sym_recursive_macro_expansion] = sym_recursive_macro_expansion,
  [sym_macro_text_expansion] = sym_macro_text_expansion,
  [sym_macro_definition_command] = sym_identifier,
  [sym_command_expression] = sym_command_expression,
  [sym__host_command] = sym__host_command,
  [sym__host_command_with_default_format] = sym_identifier,
  [sym__other_command] = sym__other_command,
  [sym__command_identifier] = sym_identifier,
  [sym__command_arguments] = sym_argument_list,
  [sym__host_command_argument_list_default_format] = sym_argument_list,
  [sym__command_argument] = sym__command_argument,
  [sym__option_value] = sym__option_value,
  [sym__parenthesized_option_value] = sym__parenthesized_option_value,
  [sym_option_expression] = sym_option_expression,
  [sym_format_expression] = sym_format_expression,
  [sym_call_expression] = sym_call_expression,
  [sym__function_identifier] = sym_identifier,
  [sym_argument_list] = sym_argument_list,
  [sym__var_command] = sym__var_command,
  [sym__hll_var_command] = sym__hll_var_command,
  [sym__hll_default_format_var_command] = sym__hll_default_format_var_command,
  [sym__hll_non_default_format_var_command] = sym__hll_non_default_format_var_command,
  [sym__non_hll_var_command] = sym__non_hll_var_command,
  [sym__hll_var_definition_command] = sym__hll_var_definition_command,
  [sym__hll_var_command_with_default_format] = sym_identifier,
  [sym__var_command_with_non_hll_format] = sym_identifier,
  [sym__hll_var_definition_command_expression] = sym_identifier,
  [sym__hll_var_if_command] = sym_identifier,
  [sym__hll_var_command_argument_list_default_format] = sym_argument_list,
  [sym__hll_var_command_argument_list_non_default_format] = sym_argument_list,
  [sym__hll_var_pattern_command_argument_list_format] = sym_argument_list,
  [sym__var_command_argument_list_non_hll_format] = sym_argument_list,
  [sym__var_definition_command_argument_list_format] = sym_argument_list,
  [sym__hll_var_call_expression_function] = sym_identifier,
  [sym__hll_var_call_expression] = sym__hll_var_call_expression,
  [sym_hll_var_call_expression_argument_list] = sym_argument_list,
  [sym_hll_type_pattern] = sym_hll_type_pattern,
  [sym__hll_option_value] = sym__hll_option_value,
  [sym__hll_parenthesized_option_value] = sym__hll_parenthesized_option_value,
  [sym_hll_option_expression] = sym_option_expression,
  [sym__hll_expression] = sym__hll_expression,
  [sym_hll_call_expression] = sym_hll_call_expression,
  [sym_hll_field_expression] = sym_hll_field_expression,
  [sym_hll_subscript_expression] = sym_hll_subscript_expression,
  [sym_hll_cast_expression] = sym_hll_cast_expression,
  [sym_hll_sizeof_expression] = sym_hll_sizeof_expression,
  [sym_hll_pointer_expression] = sym_hll_pointer_expression,
  [sym_hll_comma_expression] = sym_hll_comma_expression,
  [sym_hll_update_expression] = sym_hll_update_expression,
  [sym_hll_unary_expression] = sym_hll_unary_expression,
  [sym_hll_binary_expression] = sym_hll_binary_expression,
  [sym_hll_range_expression] = sym_hll_range_expression,
  [sym_hll_assignment_expression] = sym_hll_assignment_expression,
  [sym__hll_assignment_left_expression] = sym__hll_assignment_left_expression,
  [sym_hll_conditional_expression] = sym_hll_conditional_expression,
  [sym_hll_char_literal] = sym_hll_char_literal,
  [sym_hll_string_literal] = sym_hll_string_literal,
  [sym_hll_parenthesized_expression] = sym_hll_parenthesized_expression,
  [sym_hll_type_descriptor] = sym_hll_type_descriptor,
  [sym_hll_type_qualifier] = sym_hll_type_qualifier,
  [sym__hll_declaration_modifiers] = sym__hll_declaration_modifiers,
  [sym__hll_type_specifier] = sym__hll_type_specifier,
  [sym_hll_struct_specifier] = sym_hll_struct_specifier,
  [sym_hll_union_specifier] = sym_hll_union_specifier,
  [sym_hll_enum_specifier] = sym_hll_enum_specifier,
  [sym_hll_sized_type_specifier] = sym_hll_sized_type_specifier,
  [sym_hll_declaration] = sym_hll_declaration,
  [sym__hll_declaration_specifiers] = sym__hll_declaration_specifiers,
  [sym__hll_declarator] = sym__hll_declarator,
  [sym_hll_pointer_declarator] = sym_hll_pointer_declarator,
  [sym_hll_function_declarator] = sym_hll_function_declarator,
  [sym_hll_array_declarator] = sym_hll_array_declarator,
  [sym_hll_parenthesized_declarator] = sym_hll_parenthesized_declarator,
  [sym__hll_pointer_declarator_specifier] = sym__hll_pointer_declarator_specifier,
  [sym__hll_abstract_declarator] = sym__hll_abstract_declarator,
  [sym_hll_abstract_pointer_declarator] = sym_hll_abstract_pointer_declarator,
  [sym_hll_abstract_function_declarator] = sym_hll_abstract_function_declarator,
  [sym_hll_abstract_array_declarator] = sym_hll_abstract_array_declarator,
  [sym_hll_abstract_parenthesized_declarator] = sym_hll_abstract_parenthesized_declarator,
  [sym_hll_parameter_list] = sym_hll_parameter_list,
  [sym_hll_parameter_declaration] = sym_hll_parameter_declaration,
  [sym_hll_argument_list] = sym_hll_argument_list,
  [sym__hll_type_identifier] = sym__hll_type_identifier,
  [sym__hll_field_identifier] = sym__hll_field_identifier,
  [sym__literal] = sym__literal,
  [sym__address_expression] = sym__address_expression,
  [sym_memory_space] = sym_memory_space,
  [sym_address] = sym_address,
  [sym__parenthesized_address_expression] = sym__parenthesized_address_expression,
  [sym__address_binary_expression] = sym_binary_expression,
  [sym_integer] = sym_integer,
  [sym_bitmask] = sym_bitmask,
  [sym_string] = sym_string,
  [sym_character] = sym_character,
  [sym_symbol] = sym_symbol,
  [sym__special_command_operator] = sym__special_command_operator,
  [sym__file_dialog] = sym__file_dialog,
  [sym_file_handle] = sym_file_handle,
  [sym__expression] = sym__expression,
  [aux_sym_script_repeat1] = aux_sym_script_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_block_repeat2] = aux_sym_block_repeat2,
  [aux_sym__path_expression_repeat1] = aux_sym__path_expression_repeat1,
  [aux_sym__path_expression_repeat2] = aux_sym__path_expression_repeat2,
  [aux_sym_labeled_expression_repeat1] = aux_sym_labeled_expression_repeat1,
  [aux_sym_subroutine_block_repeat1] = aux_sym_subroutine_block_repeat1,
  [aux_sym_if_block_repeat1] = aux_sym_if_block_repeat1,
  [aux_sym_macro_definition_repeat1] = aux_sym_macro_definition_repeat1,
  [aux_sym_macro_text_expansion_repeat1] = aux_sym_macro_text_expansion_repeat1,
  [aux_sym__command_identifier_repeat1] = aux_sym__command_identifier_repeat1,
  [aux_sym__command_arguments_repeat1] = aux_sym__command_arguments_repeat1,
  [aux_sym__command_arguments_repeat2] = aux_sym__command_arguments_repeat2,
  [aux_sym__command_arguments_repeat3] = aux_sym__command_arguments_repeat3,
  [aux_sym__host_command_argument_list_default_format_repeat1] = aux_sym__host_command_argument_list_default_format_repeat1,
  [aux_sym__host_command_argument_list_default_format_repeat2] = aux_sym__host_command_argument_list_default_format_repeat2,
  [aux_sym_format_expression_repeat1] = aux_sym_format_expression_repeat1,
  [aux_sym__function_identifier_repeat1] = aux_sym__function_identifier_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = aux_sym__hll_var_command_argument_list_default_format_repeat1,
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = aux_sym__hll_var_command_argument_list_default_format_repeat2,
  [aux_sym__hll_var_command_argument_list_default_format_repeat3] = aux_sym__hll_var_command_argument_list_default_format_repeat3,
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = aux_sym__var_command_argument_list_non_hll_format_repeat1,
  [aux_sym_hll_type_pattern_repeat1] = aux_sym_hll_type_pattern_repeat1,
  [aux_sym_hll_string_literal_repeat1] = aux_sym_hll_string_literal_repeat1,
  [aux_sym_hll_type_descriptor_repeat1] = aux_sym_hll_type_descriptor_repeat1,
  [aux_sym_hll_type_descriptor_repeat2] = aux_sym_hll_type_descriptor_repeat2,
  [aux_sym_hll_sized_type_specifier_repeat1] = aux_sym_hll_sized_type_specifier_repeat1,
  [aux_sym__hll_declaration_specifiers_repeat1] = aux_sym__hll_declaration_specifiers_repeat1,
  [aux_sym__hll_declaration_specifiers_repeat2] = aux_sym__hll_declaration_specifiers_repeat2,
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = aux_sym__hll_pointer_declarator_specifier_repeat1,
  [aux_sym_hll_parameter_list_repeat1] = aux_sym_hll_parameter_list_repeat1,
  [aux_sym_hll_argument_list_repeat1] = aux_sym_hll_argument_list_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_symbol_repeat1] = aux_sym_symbol_repeat1,
  [aux_sym_file_handle_repeat1] = aux_sym_file_handle_repeat1,
  [anon_alias_sym_IF] = anon_alias_sym_IF,
  [anon_alias_sym_command] = anon_alias_sym_command,
  [anon_alias_sym_fragment] = anon_alias_sym_fragment,
  [anon_alias_sym_function] = anon_alias_sym_function,
  [alias_sym_hll_field_identifier] = alias_sym_hll_field_identifier,
  [alias_sym_hll_type_identifier] = alias_sym_hll_type_identifier,
  [anon_alias_sym_name] = anon_alias_sym_name,
  [anon_alias_sym_subcommand] = anon_alias_sym_subcommand,
  [anon_alias_sym_subfunction] = anon_alias_sym_subfunction,
  [anon_alias_sym_type] = anon_alias_sym_type,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_block_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_subroutine_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_if_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_elif_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_while_block_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_while_block_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__repeat_block_pre_condition_format_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_declaration_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token2] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token3] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_parameter_declaration_token4] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_subroutine_call_expression_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_macro_definition_command_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_command_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_macro_definition_command_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__host_command_with_default_format_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_non_default_format_var_command_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__var_command_with_non_hll_format_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__hll_var_definition_command_expression_token2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_hll_char_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_hll_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [sym_hll_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__hll_expression_separator_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_expression_separator_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_COLON_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_access_class] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_integer_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_integer_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_bitmask_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bitmask_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_character_token2] = {
    .visible = false,
    .named = false,
  },
  [sym__line_specifier] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_BSLASH_BSLASH_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_symbol_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_symbol_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_token5] = {
    .visible = false,
    .named = false,
  },
  [sym__composed_name] = {
    .visible = true,
    .named = true,
  },
  [sym_time] = {
    .visible = true,
    .named = true,
  },
  [sym_frequency] = {
    .visible = true,
    .named = true,
  },
  [sym_percentage] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUND] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_file_handle_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__blank_line] = {
    .visible = false,
    .named = true,
  },
  [sym__line_continuation] = {
    .visible = false,
    .named = true,
  },
  [sym__blank] = {
    .visible = false,
    .named = true,
  },
  [sym_label_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__and_operator_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym__decimal_number] = {
    .visible = false,
    .named = true,
  },
  [sym__decimal_number_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_number_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_number_literal_pre_hook] = {
    .visible = false,
    .named = true,
  },
  [sym_path] = {
    .visible = true,
    .named = true,
  },
  [sym__ampersand_char] = {
    .visible = false,
    .named = true,
  },
  [sym_script] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__non_labeled_statement] = {
    .visible = false,
    .named = true,
  },
  [sym__parenthesized_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__path_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_labeled_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subroutine_block] = {
    .visible = true,
    .named = true,
  },
  [sym_if_block] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_block] = {
    .visible = true,
    .named = true,
  },
  [sym_else_block] = {
    .visible = true,
    .named = true,
  },
  [sym_while_block] = {
    .visible = true,
    .named = true,
  },
  [sym_repeat_block] = {
    .visible = true,
    .named = true,
  },
  [sym__repeat_block_pre_condition_format] = {
    .visible = false,
    .named = true,
  },
  [sym__repeat_block_post_condition_format] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__unary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__prefix_postfix_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__and_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__label] = {
    .visible = false,
    .named = true,
  },
  [sym_macro_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_subroutine_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_macro] = {
    .visible = true,
    .named = true,
  },
  [sym_recursive_macro_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_text_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_definition_command] = {
    .visible = true,
    .named = true,
  },
  [sym_command_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__host_command] = {
    .visible = false,
    .named = true,
  },
  [sym__host_command_with_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__other_command] = {
    .visible = false,
    .named = true,
  },
  [sym__command_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__command_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__host_command_argument_list_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__command_argument] = {
    .visible = false,
    .named = true,
  },
  [sym__option_value] = {
    .visible = false,
    .named = true,
  },
  [sym__parenthesized_option_value] = {
    .visible = false,
    .named = true,
  },
  [sym_option_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_format_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__function_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_default_format_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_non_default_format_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__non_hll_var_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_definition_command] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_var_command_with_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command_with_non_hll_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_definition_command_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_if_command] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_command_argument_list_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_command_argument_list_non_default_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_pattern_command_argument_list_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_command_argument_list_non_hll_format] = {
    .visible = true,
    .named = true,
  },
  [sym__var_definition_command_argument_list_format] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_call_expression_function] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_var_call_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_var_call_expression_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_option_value] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_parenthesized_option_value] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_option_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_pointer_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_comma_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_assignment_left_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_declaration_modifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_type_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_struct_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_union_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_enum_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_sized_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_declaration_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_pointer_declarator_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_abstract_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_hll_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_abstract_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_hll_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__hll_type_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__hll_field_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__literal] = {
    .visible = false,
    .named = true,
  },
  [sym__address_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_memory_space] = {
    .visible = true,
    .named = true,
  },
  [sym_address] = {
    .visible = true,
    .named = true,
  },
  [sym__parenthesized_address_expression] = {
    .visible = false,
    .named = true,
  },
  [sym__address_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_bitmask] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_character] = {
    .visible = true,
    .named = true,
  },
  [sym_symbol] = {
    .visible = true,
    .named = true,
  },
  [sym__special_command_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__file_dialog] = {
    .visible = false,
    .named = true,
  },
  [sym_file_handle] = {
    .visible = true,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_script_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__path_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__path_expression_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_labeled_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subroutine_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_macro_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_macro_text_expansion_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__command_arguments_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__host_command_argument_list_default_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_format_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_identifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_command_argument_list_default_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_command_argument_list_default_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_command_argument_list_default_format_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_var_pattern_command_argument_list_format_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__var_command_argument_list_non_hll_format_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_descriptor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_type_descriptor_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_sized_type_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_declaration_specifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_declaration_specifiers_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__hll_pointer_declarator_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_hll_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_symbol_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_file_handle_repeat1] = {
    .visible = false,
    .named = false,
  },
  [anon_alias_sym_IF] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_command] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_fragment] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_function] = {
    .visible = true,
    .named = false,
  },
  [alias_sym_hll_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_hll_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_alias_sym_name] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_subcommand] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_subfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_alias_sym_type] = {
    .visible = true,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_access = 1,
  field_alternative = 2,
  field_argument = 3,
  field_arguments = 4,
  field_command = 5,
  field_condition = 6,
  field_consequence = 7,
  field_declarator = 8,
  field_field = 9,
  field_function = 10,
  field_index = 11,
  field_label = 12,
  field_left = 13,
  field_location = 14,
  field_machine = 15,
  field_macro = 16,
  field_name = 17,
  field_operator = 18,
  field_option = 19,
  field_parameters = 20,
  field_right = 21,
  field_segment = 22,
  field_size = 23,
  field_space = 24,
  field_subroutine = 25,
  field_type = 26,
  field_value = 27,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_access] = "access",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_command] = "command",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_declarator] = "declarator",
  [field_field] = "field",
  [field_function] = "function",
  [field_index] = "index",
  [field_label] = "label",
  [field_left] = "left",
  [field_location] = "location",
  [field_machine] = "machine",
  [field_macro] = "macro",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_option] = "option",
  [field_parameters] = "parameters",
  [field_right] = "right",
  [field_segment] = "segment",
  [field_size] = "size",
  [field_space] = "space",
  [field_subroutine] = "subroutine",
  [field_type] = "type",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 2},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 3},
  [6] = {.index = 8, .length = 1},
  [8] = {.index = 9, .length = 1},
  [10] = {.index = 10, .length = 2},
  [11] = {.index = 12, .length = 3},
  [12] = {.index = 15, .length = 2},
  [13] = {.index = 17, .length = 2},
  [14] = {.index = 19, .length = 3},
  [15] = {.index = 22, .length = 1},
  [16] = {.index = 23, .length = 2},
  [17] = {.index = 25, .length = 2},
  [21] = {.index = 27, .length = 2},
  [23] = {.index = 29, .length = 1},
  [24] = {.index = 30, .length = 2},
  [25] = {.index = 32, .length = 2},
  [27] = {.index = 34, .length = 2},
  [28] = {.index = 36, .length = 1},
  [29] = {.index = 37, .length = 1},
  [30] = {.index = 38, .length = 1},
  [31] = {.index = 39, .length = 1},
  [32] = {.index = 40, .length = 2},
  [33] = {.index = 42, .length = 1},
  [34] = {.index = 43, .length = 2},
  [36] = {.index = 45, .length = 2},
  [37] = {.index = 47, .length = 2},
  [38] = {.index = 49, .length = 3},
  [39] = {.index = 52, .length = 1},
  [40] = {.index = 53, .length = 2},
  [41] = {.index = 55, .length = 1},
  [43] = {.index = 56, .length = 2},
  [45] = {.index = 58, .length = 2},
  [47] = {.index = 60, .length = 3},
  [48] = {.index = 63, .length = 2},
  [49] = {.index = 65, .length = 2},
  [50] = {.index = 67, .length = 4},
  [52] = {.index = 71, .length = 3},
  [53] = {.index = 74, .length = 3},
  [54] = {.index = 77, .length = 2},
  [55] = {.index = 79, .length = 1},
  [56] = {.index = 80, .length = 3},
  [57] = {.index = 83, .length = 2},
  [58] = {.index = 85, .length = 1},
  [59] = {.index = 86, .length = 2},
  [60] = {.index = 88, .length = 2},
  [61] = {.index = 90, .length = 2},
  [62] = {.index = 92, .length = 2},
  [63] = {.index = 94, .length = 2},
  [64] = {.index = 96, .length = 2},
  [65] = {.index = 98, .length = 2},
  [66] = {.index = 100, .length = 2},
  [67] = {.index = 102, .length = 1},
  [68] = {.index = 103, .length = 2},
  [69] = {.index = 105, .length = 2},
  [70] = {.index = 107, .length = 2},
  [71] = {.index = 109, .length = 3},
  [72] = {.index = 112, .length = 3},
  [73] = {.index = 115, .length = 2},
  [74] = {.index = 117, .length = 2},
  [75] = {.index = 119, .length = 1},
  [76] = {.index = 120, .length = 1},
  [77] = {.index = 121, .length = 2},
  [78] = {.index = 123, .length = 2},
  [79] = {.index = 125, .length = 1},
  [80] = {.index = 126, .length = 1},
  [81] = {.index = 127, .length = 2},
  [82] = {.index = 129, .length = 2},
  [83] = {.index = 131, .length = 2},
  [84] = {.index = 133, .length = 2},
  [85] = {.index = 135, .length = 1},
  [86] = {.index = 136, .length = 3},
  [87] = {.index = 139, .length = 3},
  [88] = {.index = 142, .length = 3},
  [89] = {.index = 145, .length = 2},
  [90] = {.index = 147, .length = 1},
  [91] = {.index = 148, .length = 3},
  [92] = {.index = 151, .length = 2},
  [93] = {.index = 153, .length = 1},
  [94] = {.index = 154, .length = 2},
  [95] = {.index = 156, .length = 2},
  [96] = {.index = 158, .length = 2},
  [97] = {.index = 160, .length = 2},
  [98] = {.index = 162, .length = 2},
  [99] = {.index = 164, .length = 3},
  [100] = {.index = 167, .length = 2},
  [101] = {.index = 169, .length = 3},
  [102] = {.index = 172, .length = 1},
  [103] = {.index = 173, .length = 2},
  [104] = {.index = 175, .length = 2},
  [105] = {.index = 177, .length = 3},
  [106] = {.index = 180, .length = 2},
  [107] = {.index = 182, .length = 3},
  [108] = {.index = 185, .length = 2},
  [109] = {.index = 187, .length = 3},
  [110] = {.index = 190, .length = 2},
  [111] = {.index = 192, .length = 3},
  [112] = {.index = 195, .length = 2},
  [113] = {.index = 197, .length = 3},
  [114] = {.index = 200, .length = 1},
  [115] = {.index = 201, .length = 3},
  [116] = {.index = 204, .length = 4},
  [117] = {.index = 208, .length = 3},
  [118] = {.index = 211, .length = 3},
  [119] = {.index = 214, .length = 2},
  [120] = {.index = 216, .length = 3},
  [121] = {.index = 219, .length = 4},
  [122] = {.index = 223, .length = 3},
  [123] = {.index = 226, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_command, 0, .inherited = true},
    {field_condition, 0, .inherited = true},
  [2] =
    {field_command, 0},
  [3] =
    {field_arguments, 0, .inherited = true},
    {field_command, 0, .inherited = true},
  [5] =
    {field_arguments, 0, .inherited = true},
    {field_command, 0, .inherited = true},
    {field_value, 0, .inherited = true},
  [8] =
    {field_label, 0},
  [9] =
    {field_label, 0, .inherited = true},
  [10] =
    {field_argument, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
  [12] =
    {field_left, 0, .inherited = true},
    {field_operator, 0, .inherited = true},
    {field_right, 0, .inherited = true},
  [15] =
    {field_arguments, 0, .inherited = true},
    {field_function, 0, .inherited = true},
  [17] =
    {field_arguments, 1, .inherited = true},
    {field_command, 1, .inherited = true},
  [19] =
    {field_arguments, 1, .inherited = true},
    {field_command, 1, .inherited = true},
    {field_value, 1, .inherited = true},
  [22] =
    {field_macro, 1},
  [23] =
    {field_command, 0},
    {field_macro, 1, .inherited = true},
  [25] =
    {field_macro, 0, .inherited = true},
    {field_macro, 1, .inherited = true},
  [27] =
    {field_arguments, 2},
    {field_command, 0},
  [29] =
    {field_type, 0},
  [30] =
    {field_argument, 1},
    {field_operator, 0},
  [32] =
    {field_access, 0},
    {field_location, 1},
  [34] =
    {field_arguments, 1},
    {field_function, 0},
  [36] =
    {field_segment, 0},
  [37] =
    {field_machine, 0},
  [38] =
    {field_space, 0},
  [39] =
    {field_location, 1},
  [40] =
    {field_argument, 0},
    {field_operator, 1},
  [42] =
    {field_value, 1},
  [43] =
    {field_command, 0},
    {field_condition, 2},
  [45] =
    {field_command, 1},
    {field_macro, 2, .inherited = true},
  [47] =
    {field_command, 0},
    {field_subroutine, 2},
  [49] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [52] =
    {field_option, 1},
  [53] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [55] =
    {field_type, 1},
  [56] =
    {field_access, 0},
    {field_location, 2},
  [58] =
    {field_declarator, 1},
    {field_type, 0},
  [60] =
    {field_argument, 0},
    {field_field, 2},
    {field_operator, 1},
  [63] =
    {field_command, 1},
    {field_subroutine, 3},
  [65] =
    {field_command, 0},
    {field_macro, 3, .inherited = true},
  [67] =
    {field_arguments, 4},
    {field_command, 0},
    {field_command, 1},
    {field_command, 2},
  [71] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 3},
  [74] =
    {field_left, 0},
    {field_operator, 2},
    {field_right, 3},
  [77] =
    {field_value, 1},
    {field_value, 2, .inherited = true},
  [79] =
    {field_name, 2},
  [80] =
    {field_arguments, 2},
    {field_command, 0},
    {field_value, 4},
  [83] =
    {field_declarator, 0},
    {field_parameters, 1},
  [85] =
    {field_declarator, 1},
  [86] =
    {field_declarator, 2},
    {field_type, 0, .inherited = true},
  [88] =
    {field_machine, 0},
    {field_segment, 2},
  [90] =
    {field_machine, 0},
    {field_space, 2},
  [92] =
    {field_segment, 2},
    {field_space, 0},
  [94] =
    {field_left, 0},
    {field_right, 2},
  [96] =
    {field_type, 1},
    {field_value, 3},
  [98] =
    {field_declarator, 2},
    {field_type, 0},
  [100] =
    {field_declarator, 2},
    {field_type, 1},
  [102] =
    {field_type, 2},
  [103] =
    {field_alternative, 3},
    {field_condition, 0},
  [105] =
    {field_argument, 0},
    {field_index, 2},
  [107] =
    {field_command, 1},
    {field_macro, 4, .inherited = true},
  [109] =
    {field_arguments, 4},
    {field_command, 0},
    {field_subroutine, 2},
  [112] =
    {field_left, 0},
    {field_operator, 2},
    {field_right, 4},
  [115] =
    {field_option, 1},
    {field_value, 3},
  [117] =
    {field_value, 0, .inherited = true},
    {field_value, 1, .inherited = true},
  [119] =
    {field_declarator, 2},
  [120] =
    {field_type, 0, .inherited = true},
  [121] =
    {field_declarator, 0},
    {field_parameters, 2},
  [123] =
    {field_type, 1},
    {field_value, 4},
  [125] =
    {field_size, 1},
  [126] =
    {field_declarator, 0},
  [127] =
    {field_declarator, 3},
    {field_type, 0},
  [129] =
    {field_type, 2},
    {field_value, 4},
  [131] =
    {field_declarator, 3},
    {field_type, 1},
  [133] =
    {field_declarator, 3},
    {field_type, 2},
  [135] =
    {field_type, 3},
  [136] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [139] =
    {field_command, 0},
    {field_command, 3},
    {field_condition, 5},
  [142] =
    {field_arguments, 5},
    {field_command, 1},
    {field_subroutine, 3},
  [145] =
    {field_declarator, 3},
    {field_size, 1},
  [147] =
    {field_declarator, 3},
  [148] =
    {field_machine, 0},
    {field_segment, 4},
    {field_space, 2},
  [151] =
    {field_size, 1},
    {field_size, 2},
  [153] =
    {field_size, 2},
  [154] =
    {field_declarator, 0},
    {field_size, 2},
  [156] =
    {field_declarator, 0},
    {field_declarator, 1},
  [158] =
    {field_type, 2},
    {field_value, 5},
  [160] =
    {field_declarator, 4},
    {field_type, 1},
  [162] =
    {field_declarator, 4},
    {field_type, 2},
  [164] =
    {field_command, 0},
    {field_command, 4},
    {field_condition, 6},
  [167] =
    {field_declarator, 4},
    {field_size, 1},
  [169] =
    {field_declarator, 4},
    {field_size, 1},
    {field_size, 2},
  [172] =
    {field_declarator, 4},
  [173] =
    {field_declarator, 4},
    {field_size, 2},
  [175] =
    {field_size, 2},
    {field_size, 3},
  [177] =
    {field_declarator, 0},
    {field_size, 2},
    {field_size, 3},
  [180] =
    {field_declarator, 0},
    {field_size, 3},
  [182] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 3},
  [185] =
    {field_declarator, 5},
    {field_type, 2},
  [187] =
    {field_command, 0},
    {field_command, 5},
    {field_condition, 7},
  [190] =
    {field_declarator, 5},
    {field_size, 1},
  [192] =
    {field_declarator, 5},
    {field_size, 1},
    {field_size, 2},
  [195] =
    {field_declarator, 5},
    {field_size, 2},
  [197] =
    {field_declarator, 5},
    {field_size, 2},
    {field_size, 3},
  [200] =
    {field_declarator, 5},
  [201] =
    {field_declarator, 0},
    {field_size, 3},
    {field_size, 4},
  [204] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 3},
    {field_size, 4},
  [208] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 4},
  [211] =
    {field_declarator, 6},
    {field_size, 1},
    {field_size, 2},
  [214] =
    {field_declarator, 6},
    {field_size, 2},
  [216] =
    {field_declarator, 6},
    {field_size, 2},
    {field_size, 3},
  [219] =
    {field_declarator, 0},
    {field_declarator, 1},
    {field_size, 4},
    {field_size, 5},
  [223] =
    {field_declarator, 7},
    {field_size, 2},
    {field_size, 3},
  [226] =
    {field_command, 0},
    {field_command, 2},
    {field_condition, 4},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = anon_alias_sym_command,
  },
  [7] = {
    [1] = anon_alias_sym_name,
  },
  [9] = {
    [0] = anon_alias_sym_function,
  },
  [18] = {
    [2] = anon_alias_sym_subcommand,
  },
  [19] = {
    [2] = anon_alias_sym_IF,
  },
  [20] = {
    [1] = anon_alias_sym_subcommand,
  },
  [22] = {
    [0] = alias_sym_hll_type_identifier,
  },
  [26] = {
    [0] = anon_alias_sym_fragment,
  },
  [35] = {
    [2] = anon_alias_sym_name,
  },
  [42] = {
    [2] = anon_alias_sym_subfunction,
  },
  [44] = {
    [1] = anon_alias_sym_subfunction,
  },
  [46] = {
    [0] = alias_sym_hll_field_identifier,
  },
  [50] = {
    [1] = sym_identifier,
  },
  [51] = {
    [0] = anon_alias_sym_type,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 3,
  [5] = 2,
  [6] = 3,
  [7] = 2,
  [8] = 3,
  [9] = 9,
  [10] = 9,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 9,
  [16] = 9,
  [17] = 14,
  [18] = 12,
  [19] = 13,
  [20] = 11,
  [21] = 21,
  [22] = 12,
  [23] = 14,
  [24] = 11,
  [25] = 13,
  [26] = 11,
  [27] = 14,
  [28] = 12,
  [29] = 13,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 34,
  [36] = 36,
  [37] = 36,
  [38] = 36,
  [39] = 39,
  [40] = 39,
  [41] = 41,
  [42] = 42,
  [43] = 12,
  [44] = 13,
  [45] = 14,
  [46] = 11,
  [47] = 12,
  [48] = 13,
  [49] = 14,
  [50] = 11,
  [51] = 51,
  [52] = 51,
  [53] = 39,
  [54] = 51,
  [55] = 39,
  [56] = 42,
  [57] = 41,
  [58] = 51,
  [59] = 39,
  [60] = 51,
  [61] = 39,
  [62] = 51,
  [63] = 51,
  [64] = 51,
  [65] = 39,
  [66] = 42,
  [67] = 41,
  [68] = 51,
  [69] = 39,
  [70] = 51,
  [71] = 39,
  [72] = 51,
  [73] = 39,
  [74] = 42,
  [75] = 41,
  [76] = 42,
  [77] = 41,
  [78] = 42,
  [79] = 41,
  [80] = 42,
  [81] = 41,
  [82] = 42,
  [83] = 41,
  [84] = 42,
  [85] = 41,
  [86] = 42,
  [87] = 41,
  [88] = 42,
  [89] = 41,
  [90] = 41,
  [91] = 41,
  [92] = 39,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 97,
  [100] = 100,
  [101] = 101,
  [102] = 101,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 100,
  [107] = 103,
  [108] = 108,
  [109] = 98,
  [110] = 110,
  [111] = 100,
  [112] = 101,
  [113] = 103,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 94,
  [118] = 98,
  [119] = 119,
  [120] = 98,
  [121] = 100,
  [122] = 101,
  [123] = 103,
  [124] = 124,
  [125] = 94,
  [126] = 96,
  [127] = 124,
  [128] = 124,
  [129] = 124,
  [130] = 97,
  [131] = 97,
  [132] = 94,
  [133] = 133,
  [134] = 13,
  [135] = 14,
  [136] = 11,
  [137] = 12,
  [138] = 13,
  [139] = 14,
  [140] = 11,
  [141] = 141,
  [142] = 141,
  [143] = 12,
  [144] = 13,
  [145] = 14,
  [146] = 11,
  [147] = 141,
  [148] = 148,
  [149] = 148,
  [150] = 12,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 158,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 162,
  [165] = 165,
  [166] = 166,
  [167] = 152,
  [168] = 158,
  [169] = 162,
  [170] = 170,
  [171] = 151,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 170,
  [176] = 151,
  [177] = 172,
  [178] = 173,
  [179] = 174,
  [180] = 180,
  [181] = 161,
  [182] = 173,
  [183] = 183,
  [184] = 13,
  [185] = 14,
  [186] = 153,
  [187] = 154,
  [188] = 155,
  [189] = 156,
  [190] = 157,
  [191] = 160,
  [192] = 160,
  [193] = 153,
  [194] = 154,
  [195] = 155,
  [196] = 156,
  [197] = 157,
  [198] = 161,
  [199] = 174,
  [200] = 200,
  [201] = 180,
  [202] = 183,
  [203] = 203,
  [204] = 11,
  [205] = 163,
  [206] = 206,
  [207] = 165,
  [208] = 170,
  [209] = 152,
  [210] = 152,
  [211] = 158,
  [212] = 162,
  [213] = 170,
  [214] = 151,
  [215] = 180,
  [216] = 183,
  [217] = 172,
  [218] = 173,
  [219] = 174,
  [220] = 160,
  [221] = 161,
  [222] = 200,
  [223] = 203,
  [224] = 180,
  [225] = 183,
  [226] = 153,
  [227] = 154,
  [228] = 180,
  [229] = 183,
  [230] = 155,
  [231] = 156,
  [232] = 180,
  [233] = 183,
  [234] = 203,
  [235] = 157,
  [236] = 153,
  [237] = 154,
  [238] = 155,
  [239] = 156,
  [240] = 157,
  [241] = 241,
  [242] = 242,
  [243] = 12,
  [244] = 13,
  [245] = 14,
  [246] = 11,
  [247] = 12,
  [248] = 163,
  [249] = 165,
  [250] = 166,
  [251] = 163,
  [252] = 172,
  [253] = 200,
  [254] = 165,
  [255] = 166,
  [256] = 166,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 264,
  [267] = 267,
  [268] = 268,
  [269] = 269,
  [270] = 270,
  [271] = 265,
  [272] = 272,
  [273] = 269,
  [274] = 267,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 265,
  [280] = 269,
  [281] = 268,
  [282] = 275,
  [283] = 269,
  [284] = 264,
  [285] = 277,
  [286] = 270,
  [287] = 287,
  [288] = 278,
  [289] = 287,
  [290] = 264,
  [291] = 268,
  [292] = 270,
  [293] = 272,
  [294] = 267,
  [295] = 275,
  [296] = 278,
  [297] = 278,
  [298] = 287,
  [299] = 287,
  [300] = 268,
  [301] = 270,
  [302] = 272,
  [303] = 267,
  [304] = 275,
  [305] = 265,
  [306] = 272,
  [307] = 276,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 313,
  [315] = 313,
  [316] = 313,
  [317] = 309,
  [318] = 318,
  [319] = 319,
  [320] = 311,
  [321] = 312,
  [322] = 308,
  [323] = 323,
  [324] = 310,
  [325] = 325,
  [326] = 310,
  [327] = 308,
  [328] = 309,
  [329] = 325,
  [330] = 312,
  [331] = 311,
  [332] = 332,
  [333] = 333,
  [334] = 332,
  [335] = 335,
  [336] = 332,
  [337] = 325,
  [338] = 338,
  [339] = 339,
  [340] = 325,
  [341] = 332,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 344,
  [346] = 346,
  [347] = 344,
  [348] = 348,
  [349] = 344,
  [350] = 309,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 310,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 310,
  [363] = 312,
  [364] = 309,
  [365] = 312,
  [366] = 358,
  [367] = 357,
  [368] = 368,
  [369] = 311,
  [370] = 308,
  [371] = 311,
  [372] = 308,
  [373] = 373,
  [374] = 354,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 343,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
  [414] = 414,
  [415] = 342,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 423,
  [433] = 430,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 339,
  [449] = 348,
  [450] = 333,
  [451] = 335,
  [452] = 338,
  [453] = 342,
  [454] = 378,
  [455] = 346,
  [456] = 368,
  [457] = 343,
  [458] = 373,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 392,
  [464] = 411,
  [465] = 465,
  [466] = 466,
  [467] = 444,
  [468] = 445,
  [469] = 416,
  [470] = 418,
  [471] = 420,
  [472] = 472,
  [473] = 421,
  [474] = 422,
  [475] = 424,
  [476] = 425,
  [477] = 477,
  [478] = 447,
  [479] = 427,
  [480] = 480,
  [481] = 481,
  [482] = 431,
  [483] = 434,
  [484] = 435,
  [485] = 436,
  [486] = 437,
  [487] = 438,
  [488] = 441,
  [489] = 442,
  [490] = 414,
  [491] = 380,
  [492] = 381,
  [493] = 493,
  [494] = 382,
  [495] = 383,
  [496] = 384,
  [497] = 385,
  [498] = 387,
  [499] = 388,
  [500] = 389,
  [501] = 390,
  [502] = 391,
  [503] = 503,
  [504] = 504,
  [505] = 394,
  [506] = 395,
  [507] = 396,
  [508] = 397,
  [509] = 398,
  [510] = 399,
  [511] = 400,
  [512] = 401,
  [513] = 402,
  [514] = 403,
  [515] = 404,
  [516] = 405,
  [517] = 406,
  [518] = 407,
  [519] = 408,
  [520] = 409,
  [521] = 410,
  [522] = 522,
  [523] = 523,
  [524] = 524,
  [525] = 525,
  [526] = 526,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 533,
  [534] = 339,
  [535] = 333,
  [536] = 536,
  [537] = 335,
  [538] = 538,
  [539] = 393,
  [540] = 339,
  [541] = 541,
  [542] = 333,
  [543] = 543,
  [544] = 544,
  [545] = 335,
  [546] = 338,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 525,
  [558] = 378,
  [559] = 368,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 373,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 525,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 579,
  [580] = 580,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 584,
  [585] = 585,
  [586] = 523,
  [587] = 526,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 593,
  [594] = 594,
  [595] = 595,
  [596] = 596,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 600,
  [601] = 443,
  [602] = 417,
  [603] = 603,
  [604] = 604,
  [605] = 338,
  [606] = 606,
  [607] = 607,
  [608] = 443,
  [609] = 417,
  [610] = 393,
  [611] = 411,
  [612] = 612,
  [613] = 613,
  [614] = 416,
  [615] = 418,
  [616] = 420,
  [617] = 421,
  [618] = 422,
  [619] = 424,
  [620] = 425,
  [621] = 427,
  [622] = 431,
  [623] = 434,
  [624] = 435,
  [625] = 436,
  [626] = 437,
  [627] = 438,
  [628] = 441,
  [629] = 442,
  [630] = 630,
  [631] = 631,
  [632] = 414,
  [633] = 380,
  [634] = 381,
  [635] = 635,
  [636] = 382,
  [637] = 383,
  [638] = 333,
  [639] = 384,
  [640] = 385,
  [641] = 641,
  [642] = 387,
  [643] = 388,
  [644] = 343,
  [645] = 389,
  [646] = 390,
  [647] = 391,
  [648] = 342,
  [649] = 392,
  [650] = 650,
  [651] = 651,
  [652] = 394,
  [653] = 395,
  [654] = 335,
  [655] = 338,
  [656] = 396,
  [657] = 397,
  [658] = 444,
  [659] = 445,
  [660] = 447,
  [661] = 333,
  [662] = 339,
  [663] = 398,
  [664] = 399,
  [665] = 400,
  [666] = 401,
  [667] = 346,
  [668] = 335,
  [669] = 348,
  [670] = 338,
  [671] = 402,
  [672] = 339,
  [673] = 403,
  [674] = 355,
  [675] = 404,
  [676] = 405,
  [677] = 406,
  [678] = 407,
  [679] = 408,
  [680] = 680,
  [681] = 409,
  [682] = 682,
  [683] = 410,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 685,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 459,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 343,
  [699] = 699,
  [700] = 700,
  [701] = 687,
  [702] = 702,
  [703] = 703,
  [704] = 687,
  [705] = 705,
  [706] = 706,
  [707] = 685,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 687,
  [716] = 606,
  [717] = 685,
  [718] = 686,
  [719] = 462,
  [720] = 720,
  [721] = 342,
  [722] = 703,
  [723] = 700,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 591,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 445,
  [738] = 447,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 736,
  [747] = 747,
  [748] = 748,
  [749] = 745,
  [750] = 743,
  [751] = 736,
  [752] = 741,
  [753] = 346,
  [754] = 461,
  [755] = 335,
  [756] = 373,
  [757] = 348,
  [758] = 338,
  [759] = 741,
  [760] = 743,
  [761] = 339,
  [762] = 736,
  [763] = 462,
  [764] = 378,
  [765] = 355,
  [766] = 745,
  [767] = 743,
  [768] = 736,
  [769] = 741,
  [770] = 355,
  [771] = 335,
  [772] = 346,
  [773] = 368,
  [774] = 348,
  [775] = 333,
  [776] = 338,
  [777] = 741,
  [778] = 778,
  [779] = 743,
  [780] = 444,
  [781] = 745,
  [782] = 743,
  [783] = 689,
  [784] = 444,
  [785] = 745,
  [786] = 743,
  [787] = 736,
  [788] = 741,
  [789] = 745,
  [790] = 743,
  [791] = 736,
  [792] = 741,
  [793] = 745,
  [794] = 743,
  [795] = 736,
  [796] = 741,
  [797] = 736,
  [798] = 445,
  [799] = 373,
  [800] = 447,
  [801] = 378,
  [802] = 368,
  [803] = 803,
  [804] = 743,
  [805] = 333,
  [806] = 745,
  [807] = 778,
  [808] = 736,
  [809] = 339,
  [810] = 741,
  [811] = 460,
  [812] = 743,
  [813] = 745,
  [814] = 736,
  [815] = 735,
  [816] = 816,
  [817] = 778,
  [818] = 742,
  [819] = 742,
  [820] = 742,
  [821] = 745,
  [822] = 822,
  [823] = 745,
  [824] = 741,
  [825] = 825,
  [826] = 826,
  [827] = 778,
  [828] = 459,
  [829] = 741,
  [830] = 410,
  [831] = 522,
  [832] = 597,
  [833] = 541,
  [834] = 538,
  [835] = 416,
  [836] = 418,
  [837] = 562,
  [838] = 420,
  [839] = 567,
  [840] = 443,
  [841] = 417,
  [842] = 393,
  [843] = 411,
  [844] = 421,
  [845] = 845,
  [846] = 422,
  [847] = 847,
  [848] = 848,
  [849] = 424,
  [850] = 425,
  [851] = 851,
  [852] = 852,
  [853] = 427,
  [854] = 854,
  [855] = 855,
  [856] = 579,
  [857] = 431,
  [858] = 858,
  [859] = 859,
  [860] = 434,
  [861] = 435,
  [862] = 436,
  [863] = 437,
  [864] = 438,
  [865] = 441,
  [866] = 442,
  [867] = 596,
  [868] = 594,
  [869] = 588,
  [870] = 414,
  [871] = 380,
  [872] = 381,
  [873] = 590,
  [874] = 382,
  [875] = 383,
  [876] = 384,
  [877] = 385,
  [878] = 592,
  [879] = 387,
  [880] = 388,
  [881] = 881,
  [882] = 882,
  [883] = 389,
  [884] = 390,
  [885] = 391,
  [886] = 392,
  [887] = 887,
  [888] = 888,
  [889] = 416,
  [890] = 418,
  [891] = 394,
  [892] = 604,
  [893] = 580,
  [894] = 395,
  [895] = 895,
  [896] = 396,
  [897] = 397,
  [898] = 398,
  [899] = 399,
  [900] = 847,
  [901] = 400,
  [902] = 401,
  [903] = 402,
  [904] = 904,
  [905] = 403,
  [906] = 404,
  [907] = 405,
  [908] = 406,
  [909] = 407,
  [910] = 408,
  [911] = 409,
  [912] = 410,
  [913] = 333,
  [914] = 595,
  [915] = 477,
  [916] = 598,
  [917] = 847,
  [918] = 465,
  [919] = 584,
  [920] = 472,
  [921] = 571,
  [922] = 922,
  [923] = 591,
  [924] = 503,
  [925] = 847,
  [926] = 504,
  [927] = 593,
  [928] = 355,
  [929] = 335,
  [930] = 847,
  [931] = 528,
  [932] = 600,
  [933] = 338,
  [934] = 466,
  [935] = 847,
  [936] = 543,
  [937] = 544,
  [938] = 569,
  [939] = 339,
  [940] = 847,
  [941] = 847,
  [942] = 847,
  [943] = 847,
  [944] = 551,
  [945] = 565,
  [946] = 461,
  [947] = 947,
  [948] = 421,
  [949] = 422,
  [950] = 950,
  [951] = 951,
  [952] = 424,
  [953] = 554,
  [954] = 576,
  [955] = 548,
  [956] = 425,
  [957] = 957,
  [958] = 958,
  [959] = 335,
  [960] = 960,
  [961] = 961,
  [962] = 427,
  [963] = 963,
  [964] = 578,
  [965] = 577,
  [966] = 355,
  [967] = 444,
  [968] = 445,
  [969] = 847,
  [970] = 950,
  [971] = 581,
  [972] = 972,
  [973] = 950,
  [974] = 431,
  [975] = 434,
  [976] = 435,
  [977] = 436,
  [978] = 437,
  [979] = 438,
  [980] = 441,
  [981] = 442,
  [982] = 346,
  [983] = 950,
  [984] = 348,
  [985] = 447,
  [986] = 333,
  [987] = 414,
  [988] = 380,
  [989] = 381,
  [990] = 335,
  [991] = 382,
  [992] = 383,
  [993] = 384,
  [994] = 385,
  [995] = 338,
  [996] = 387,
  [997] = 388,
  [998] = 389,
  [999] = 390,
  [1000] = 391,
  [1001] = 392,
  [1002] = 1002,
  [1003] = 394,
  [1004] = 395,
  [1005] = 396,
  [1006] = 1006,
  [1007] = 603,
  [1008] = 397,
  [1009] = 398,
  [1010] = 460,
  [1011] = 399,
  [1012] = 333,
  [1013] = 400,
  [1014] = 339,
  [1015] = 401,
  [1016] = 589,
  [1017] = 402,
  [1018] = 403,
  [1019] = 404,
  [1020] = 405,
  [1021] = 1021,
  [1022] = 406,
  [1023] = 407,
  [1024] = 408,
  [1025] = 409,
  [1026] = 564,
  [1027] = 481,
  [1028] = 480,
  [1029] = 527,
  [1030] = 338,
  [1031] = 443,
  [1032] = 339,
  [1033] = 547,
  [1034] = 1034,
  [1035] = 417,
  [1036] = 1036,
  [1037] = 552,
  [1038] = 553,
  [1039] = 393,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 411,
  [1043] = 346,
  [1044] = 348,
  [1045] = 420,
  [1046] = 699,
  [1047] = 604,
  [1048] = 580,
  [1049] = 565,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1057,
  [1058] = 1058,
  [1059] = 1059,
  [1060] = 578,
  [1061] = 481,
  [1062] = 527,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1063,
  [1066] = 547,
  [1067] = 462,
  [1068] = 552,
  [1069] = 553,
  [1070] = 564,
  [1071] = 1071,
  [1072] = 569,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 576,
  [1077] = 579,
  [1078] = 584,
  [1079] = 1064,
  [1080] = 589,
  [1081] = 594,
  [1082] = 1082,
  [1083] = 600,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 603,
  [1089] = 597,
  [1090] = 538,
  [1091] = 592,
  [1092] = 477,
  [1093] = 571,
  [1094] = 593,
  [1095] = 466,
  [1096] = 548,
  [1097] = 577,
  [1098] = 581,
  [1099] = 1050,
  [1100] = 480,
  [1101] = 522,
  [1102] = 541,
  [1103] = 1051,
  [1104] = 562,
  [1105] = 567,
  [1106] = 1052,
  [1107] = 1053,
  [1108] = 1054,
  [1109] = 588,
  [1110] = 590,
  [1111] = 1055,
  [1112] = 1056,
  [1113] = 595,
  [1114] = 1057,
  [1115] = 598,
  [1116] = 465,
  [1117] = 1058,
  [1118] = 472,
  [1119] = 1059,
  [1120] = 503,
  [1121] = 504,
  [1122] = 528,
  [1123] = 543,
  [1124] = 544,
  [1125] = 551,
  [1126] = 554,
  [1127] = 333,
  [1128] = 1050,
  [1129] = 1051,
  [1130] = 1052,
  [1131] = 1053,
  [1132] = 1054,
  [1133] = 1055,
  [1134] = 1056,
  [1135] = 1057,
  [1136] = 1058,
  [1137] = 1059,
  [1138] = 1063,
  [1139] = 1064,
  [1140] = 1073,
  [1141] = 1074,
  [1142] = 1075,
  [1143] = 1085,
  [1144] = 607,
  [1145] = 1063,
  [1146] = 732,
  [1147] = 1064,
  [1148] = 1073,
  [1149] = 1074,
  [1150] = 1073,
  [1151] = 1074,
  [1152] = 1075,
  [1153] = 1075,
  [1154] = 1085,
  [1155] = 684,
  [1156] = 335,
  [1157] = 697,
  [1158] = 591,
  [1159] = 338,
  [1160] = 339,
  [1161] = 459,
  [1162] = 462,
  [1163] = 355,
  [1164] = 1050,
  [1165] = 1051,
  [1166] = 1052,
  [1167] = 735,
  [1168] = 1053,
  [1169] = 1054,
  [1170] = 1055,
  [1171] = 1085,
  [1172] = 689,
  [1173] = 1056,
  [1174] = 1057,
  [1175] = 1058,
  [1176] = 591,
  [1177] = 1059,
  [1178] = 355,
  [1179] = 444,
  [1180] = 445,
  [1181] = 447,
  [1182] = 346,
  [1183] = 348,
  [1184] = 333,
  [1185] = 335,
  [1186] = 338,
  [1187] = 1050,
  [1188] = 339,
  [1189] = 1051,
  [1190] = 1052,
  [1191] = 1053,
  [1192] = 1054,
  [1193] = 1055,
  [1194] = 346,
  [1195] = 348,
  [1196] = 1056,
  [1197] = 1057,
  [1198] = 1058,
  [1199] = 1059,
  [1200] = 1082,
  [1201] = 1084,
  [1202] = 1086,
  [1203] = 1087,
  [1204] = 444,
  [1205] = 445,
  [1206] = 596,
  [1207] = 1051,
  [1208] = 1052,
  [1209] = 1053,
  [1210] = 1054,
  [1211] = 1055,
  [1212] = 1056,
  [1213] = 1057,
  [1214] = 1058,
  [1215] = 1059,
  [1216] = 1063,
  [1217] = 1064,
  [1218] = 1063,
  [1219] = 1073,
  [1220] = 1074,
  [1221] = 1075,
  [1222] = 1085,
  [1223] = 1082,
  [1224] = 1084,
  [1225] = 1086,
  [1226] = 1087,
  [1227] = 1064,
  [1228] = 1050,
  [1229] = 1051,
  [1230] = 1052,
  [1231] = 1053,
  [1232] = 1054,
  [1233] = 1055,
  [1234] = 1056,
  [1235] = 1057,
  [1236] = 1058,
  [1237] = 1059,
  [1238] = 1063,
  [1239] = 1064,
  [1240] = 1073,
  [1241] = 1074,
  [1242] = 1075,
  [1243] = 1085,
  [1244] = 1082,
  [1245] = 1084,
  [1246] = 1086,
  [1247] = 1087,
  [1248] = 447,
  [1249] = 1050,
  [1250] = 1051,
  [1251] = 1052,
  [1252] = 1053,
  [1253] = 1054,
  [1254] = 1055,
  [1255] = 1056,
  [1256] = 1057,
  [1257] = 1058,
  [1258] = 1059,
  [1259] = 1063,
  [1260] = 1064,
  [1261] = 1073,
  [1262] = 1074,
  [1263] = 1075,
  [1264] = 1073,
  [1265] = 1085,
  [1266] = 1082,
  [1267] = 1084,
  [1268] = 1087,
  [1269] = 1074,
  [1270] = 1050,
  [1271] = 1051,
  [1272] = 1052,
  [1273] = 1053,
  [1274] = 1054,
  [1275] = 1055,
  [1276] = 1056,
  [1277] = 1057,
  [1278] = 1058,
  [1279] = 1059,
  [1280] = 1063,
  [1281] = 1064,
  [1282] = 1073,
  [1283] = 1074,
  [1284] = 1075,
  [1285] = 1075,
  [1286] = 1085,
  [1287] = 1082,
  [1288] = 1084,
  [1289] = 1087,
  [1290] = 1050,
  [1291] = 1051,
  [1292] = 1052,
  [1293] = 1053,
  [1294] = 1054,
  [1295] = 1055,
  [1296] = 1056,
  [1297] = 1057,
  [1298] = 1058,
  [1299] = 1059,
  [1300] = 1063,
  [1301] = 1064,
  [1302] = 1073,
  [1303] = 1074,
  [1304] = 1075,
  [1305] = 1085,
  [1306] = 1082,
  [1307] = 1084,
  [1308] = 1087,
  [1309] = 1050,
  [1310] = 1051,
  [1311] = 1052,
  [1312] = 1053,
  [1313] = 1054,
  [1314] = 1055,
  [1315] = 1056,
  [1316] = 1057,
  [1317] = 1058,
  [1318] = 1059,
  [1319] = 1063,
  [1320] = 1064,
  [1321] = 1073,
  [1322] = 1074,
  [1323] = 1075,
  [1324] = 1085,
  [1325] = 1082,
  [1326] = 1084,
  [1327] = 1087,
  [1328] = 1082,
  [1329] = 1084,
  [1330] = 1087,
  [1331] = 1082,
  [1332] = 1084,
  [1333] = 1087,
  [1334] = 1082,
  [1335] = 1084,
  [1336] = 1087,
  [1337] = 1071,
  [1338] = 1085,
  [1339] = 1071,
  [1340] = 459,
  [1341] = 1050,
  [1342] = 699,
  [1343] = 355,
  [1344] = 346,
  [1345] = 348,
  [1346] = 735,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1349,
  [1350] = 689,
  [1351] = 444,
  [1352] = 445,
  [1353] = 447,
  [1354] = 447,
  [1355] = 355,
  [1356] = 346,
  [1357] = 348,
  [1358] = 333,
  [1359] = 461,
  [1360] = 1360,
  [1361] = 335,
  [1362] = 338,
  [1363] = 444,
  [1364] = 339,
  [1365] = 346,
  [1366] = 348,
  [1367] = 1367,
  [1368] = 445,
  [1369] = 460,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 684,
  [1375] = 607,
  [1376] = 333,
  [1377] = 697,
  [1378] = 732,
  [1379] = 355,
  [1380] = 1380,
  [1381] = 735,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1384,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 1388,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 689,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1396,
  [1397] = 1397,
  [1398] = 335,
  [1399] = 591,
  [1400] = 338,
  [1401] = 339,
  [1402] = 461,
  [1403] = 460,
  [1404] = 1404,
  [1405] = 1395,
  [1406] = 569,
  [1407] = 355,
  [1408] = 1408,
  [1409] = 590,
  [1410] = 576,
  [1411] = 579,
  [1412] = 584,
  [1413] = 595,
  [1414] = 598,
  [1415] = 346,
  [1416] = 1416,
  [1417] = 348,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 591,
  [1421] = 589,
  [1422] = 465,
  [1423] = 594,
  [1424] = 600,
  [1425] = 472,
  [1426] = 604,
  [1427] = 603,
  [1428] = 1360,
  [1429] = 355,
  [1430] = 503,
  [1431] = 504,
  [1432] = 1404,
  [1433] = 597,
  [1434] = 538,
  [1435] = 528,
  [1436] = 592,
  [1437] = 580,
  [1438] = 477,
  [1439] = 578,
  [1440] = 543,
  [1441] = 1441,
  [1442] = 1442,
  [1443] = 1382,
  [1444] = 571,
  [1445] = 593,
  [1446] = 346,
  [1447] = 348,
  [1448] = 1383,
  [1449] = 1384,
  [1450] = 1385,
  [1451] = 1386,
  [1452] = 1387,
  [1453] = 1388,
  [1454] = 544,
  [1455] = 1389,
  [1456] = 1456,
  [1457] = 1390,
  [1458] = 466,
  [1459] = 591,
  [1460] = 1391,
  [1461] = 551,
  [1462] = 548,
  [1463] = 1393,
  [1464] = 565,
  [1465] = 1394,
  [1466] = 481,
  [1467] = 1467,
  [1468] = 577,
  [1469] = 581,
  [1470] = 527,
  [1471] = 1396,
  [1472] = 1472,
  [1473] = 1397,
  [1474] = 554,
  [1475] = 1380,
  [1476] = 480,
  [1477] = 1041,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 522,
  [1481] = 947,
  [1482] = 541,
  [1483] = 1348,
  [1484] = 851,
  [1485] = 562,
  [1486] = 1380,
  [1487] = 852,
  [1488] = 888,
  [1489] = 547,
  [1490] = 552,
  [1491] = 553,
  [1492] = 564,
  [1493] = 569,
  [1494] = 1002,
  [1495] = 1371,
  [1496] = 1372,
  [1497] = 564,
  [1498] = 845,
  [1499] = 576,
  [1500] = 579,
  [1501] = 1034,
  [1502] = 1502,
  [1503] = 584,
  [1504] = 589,
  [1505] = 594,
  [1506] = 957,
  [1507] = 600,
  [1508] = 854,
  [1509] = 567,
  [1510] = 904,
  [1511] = 603,
  [1512] = 1021,
  [1513] = 597,
  [1514] = 538,
  [1515] = 1036,
  [1516] = 1040,
  [1517] = 588,
  [1518] = 1518,
  [1519] = 1519,
  [1520] = 590,
  [1521] = 1521,
  [1522] = 592,
  [1523] = 1347,
  [1524] = 595,
  [1525] = 598,
  [1526] = 1526,
  [1527] = 465,
  [1528] = 472,
  [1529] = 1373,
  [1530] = 503,
  [1531] = 504,
  [1532] = 528,
  [1533] = 543,
  [1534] = 544,
  [1535] = 477,
  [1536] = 551,
  [1537] = 554,
  [1538] = 571,
  [1539] = 588,
  [1540] = 735,
  [1541] = 593,
  [1542] = 466,
  [1543] = 689,
  [1544] = 548,
  [1545] = 596,
  [1546] = 577,
  [1547] = 581,
  [1548] = 604,
  [1549] = 580,
  [1550] = 565,
  [1551] = 480,
  [1552] = 578,
  [1553] = 522,
  [1554] = 481,
  [1555] = 527,
  [1556] = 541,
  [1557] = 547,
  [1558] = 1558,
  [1559] = 562,
  [1560] = 1560,
  [1561] = 567,
  [1562] = 1562,
  [1563] = 1563,
  [1564] = 596,
  [1565] = 552,
  [1566] = 1380,
  [1567] = 1349,
  [1568] = 553,
  [1569] = 1367,
  [1570] = 348,
  [1571] = 1036,
  [1572] = 689,
  [1573] = 1041,
  [1574] = 355,
  [1575] = 735,
  [1576] = 1416,
  [1577] = 1467,
  [1578] = 684,
  [1579] = 591,
  [1580] = 1034,
  [1581] = 1518,
  [1582] = 1562,
  [1583] = 697,
  [1584] = 1558,
  [1585] = 1472,
  [1586] = 845,
  [1587] = 1040,
  [1588] = 1380,
  [1589] = 957,
  [1590] = 1560,
  [1591] = 1478,
  [1592] = 1479,
  [1593] = 607,
  [1594] = 1518,
  [1595] = 1441,
  [1596] = 735,
  [1597] = 947,
  [1598] = 888,
  [1599] = 346,
  [1600] = 1563,
  [1601] = 699,
  [1602] = 607,
  [1603] = 699,
  [1604] = 1021,
  [1605] = 348,
  [1606] = 1442,
  [1607] = 684,
  [1608] = 1002,
  [1609] = 852,
  [1610] = 1456,
  [1611] = 732,
  [1612] = 732,
  [1613] = 697,
  [1614] = 689,
  [1615] = 355,
  [1616] = 1408,
  [1617] = 904,
  [1618] = 1502,
  [1619] = 591,
  [1620] = 1419,
  [1621] = 1519,
  [1622] = 851,
  [1623] = 1518,
  [1624] = 854,
  [1625] = 1526,
  [1626] = 346,
  [1627] = 1380,
  [1628] = 1382,
  [1629] = 1383,
  [1630] = 1384,
  [1631] = 1385,
  [1632] = 1396,
  [1633] = 1397,
  [1634] = 1386,
  [1635] = 1387,
  [1636] = 1367,
  [1637] = 1388,
  [1638] = 1638,
  [1639] = 1404,
  [1640] = 310,
  [1641] = 1371,
  [1642] = 1372,
  [1643] = 1373,
  [1644] = 1380,
  [1645] = 1360,
  [1646] = 1380,
  [1647] = 1389,
  [1648] = 1390,
  [1649] = 309,
  [1650] = 1391,
  [1651] = 312,
  [1652] = 1382,
  [1653] = 1383,
  [1654] = 1384,
  [1655] = 1385,
  [1656] = 1386,
  [1657] = 1387,
  [1658] = 1388,
  [1659] = 1389,
  [1660] = 1390,
  [1661] = 1391,
  [1662] = 1393,
  [1663] = 1347,
  [1664] = 1395,
  [1665] = 1396,
  [1666] = 1397,
  [1667] = 309,
  [1668] = 312,
  [1669] = 735,
  [1670] = 311,
  [1671] = 1380,
  [1672] = 1380,
  [1673] = 308,
  [1674] = 735,
  [1675] = 689,
  [1676] = 1347,
  [1677] = 1348,
  [1678] = 1349,
  [1679] = 1518,
  [1680] = 1349,
  [1681] = 689,
  [1682] = 311,
  [1683] = 1348,
  [1684] = 1360,
  [1685] = 1367,
  [1686] = 1393,
  [1687] = 1394,
  [1688] = 1395,
  [1689] = 1404,
  [1690] = 1380,
  [1691] = 1638,
  [1692] = 308,
  [1693] = 310,
  [1694] = 1371,
  [1695] = 1372,
  [1696] = 1373,
  [1697] = 1394,
  [1698] = 1518,
  [1699] = 854,
  [1700] = 1518,
  [1701] = 1002,
  [1702] = 1563,
  [1703] = 1703,
  [1704] = 904,
  [1705] = 1021,
  [1706] = 845,
  [1707] = 1036,
  [1708] = 1040,
  [1709] = 1467,
  [1710] = 1034,
  [1711] = 957,
  [1712] = 854,
  [1713] = 1041,
  [1714] = 904,
  [1715] = 1021,
  [1716] = 1036,
  [1717] = 947,
  [1718] = 1040,
  [1719] = 1478,
  [1720] = 1419,
  [1721] = 1560,
  [1722] = 1518,
  [1723] = 1558,
  [1724] = 1479,
  [1725] = 1560,
  [1726] = 1456,
  [1727] = 1562,
  [1728] = 1728,
  [1729] = 1408,
  [1730] = 947,
  [1731] = 851,
  [1732] = 1034,
  [1733] = 1416,
  [1734] = 1419,
  [1735] = 1472,
  [1736] = 851,
  [1737] = 1502,
  [1738] = 1518,
  [1739] = 1739,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1441,
  [1743] = 1442,
  [1744] = 1519,
  [1745] = 1416,
  [1746] = 1562,
  [1747] = 1526,
  [1748] = 845,
  [1749] = 1441,
  [1750] = 852,
  [1751] = 1472,
  [1752] = 1728,
  [1753] = 1502,
  [1754] = 1442,
  [1755] = 852,
  [1756] = 1519,
  [1757] = 1518,
  [1758] = 1478,
  [1759] = 1479,
  [1760] = 1728,
  [1761] = 888,
  [1762] = 1526,
  [1763] = 1467,
  [1764] = 957,
  [1765] = 1765,
  [1766] = 1002,
  [1767] = 1558,
  [1768] = 1563,
  [1769] = 1769,
  [1770] = 1370,
  [1771] = 888,
  [1772] = 1041,
  [1773] = 1456,
  [1774] = 1408,
  [1775] = 1518,
  [1776] = 1776,
  [1777] = 1638,
  [1778] = 1778,
  [1779] = 1779,
  [1780] = 1780,
  [1781] = 333,
  [1782] = 339,
  [1783] = 335,
  [1784] = 338,
  [1785] = 1728,
  [1786] = 335,
  [1787] = 1370,
  [1788] = 338,
  [1789] = 333,
  [1790] = 339,
  [1791] = 343,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1794,
  [1795] = 342,
  [1796] = 1796,
  [1797] = 1797,
  [1798] = 343,
  [1799] = 342,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 346,
  [1803] = 354,
  [1804] = 355,
  [1805] = 348,
  [1806] = 368,
  [1807] = 373,
  [1808] = 355,
  [1809] = 373,
  [1810] = 346,
  [1811] = 354,
  [1812] = 354,
  [1813] = 368,
  [1814] = 378,
  [1815] = 348,
  [1816] = 378,
  [1817] = 354,
  [1818] = 354,
  [1819] = 422,
  [1820] = 381,
  [1821] = 406,
  [1822] = 407,
  [1823] = 408,
  [1824] = 409,
  [1825] = 436,
  [1826] = 437,
  [1827] = 410,
  [1828] = 438,
  [1829] = 421,
  [1830] = 441,
  [1831] = 435,
  [1832] = 442,
  [1833] = 422,
  [1834] = 424,
  [1835] = 425,
  [1836] = 424,
  [1837] = 425,
  [1838] = 436,
  [1839] = 437,
  [1840] = 382,
  [1841] = 383,
  [1842] = 384,
  [1843] = 385,
  [1844] = 414,
  [1845] = 380,
  [1846] = 381,
  [1847] = 434,
  [1848] = 420,
  [1849] = 427,
  [1850] = 382,
  [1851] = 383,
  [1852] = 418,
  [1853] = 384,
  [1854] = 385,
  [1855] = 421,
  [1856] = 443,
  [1857] = 438,
  [1858] = 427,
  [1859] = 417,
  [1860] = 441,
  [1861] = 393,
  [1862] = 411,
  [1863] = 387,
  [1864] = 420,
  [1865] = 387,
  [1866] = 388,
  [1867] = 388,
  [1868] = 431,
  [1869] = 389,
  [1870] = 389,
  [1871] = 1871,
  [1872] = 380,
  [1873] = 442,
  [1874] = 391,
  [1875] = 392,
  [1876] = 394,
  [1877] = 395,
  [1878] = 1878,
  [1879] = 396,
  [1880] = 397,
  [1881] = 390,
  [1882] = 398,
  [1883] = 399,
  [1884] = 443,
  [1885] = 391,
  [1886] = 400,
  [1887] = 392,
  [1888] = 417,
  [1889] = 393,
  [1890] = 354,
  [1891] = 416,
  [1892] = 411,
  [1893] = 431,
  [1894] = 394,
  [1895] = 401,
  [1896] = 395,
  [1897] = 396,
  [1898] = 397,
  [1899] = 398,
  [1900] = 402,
  [1901] = 399,
  [1902] = 400,
  [1903] = 401,
  [1904] = 402,
  [1905] = 403,
  [1906] = 404,
  [1907] = 405,
  [1908] = 406,
  [1909] = 416,
  [1910] = 407,
  [1911] = 408,
  [1912] = 409,
  [1913] = 410,
  [1914] = 418,
  [1915] = 403,
  [1916] = 434,
  [1917] = 404,
  [1918] = 405,
  [1919] = 435,
  [1920] = 414,
  [1921] = 390,
  [1922] = 1408,
  [1923] = 335,
  [1924] = 348,
  [1925] = 335,
  [1926] = 338,
  [1927] = 1419,
  [1928] = 1928,
  [1929] = 338,
  [1930] = 333,
  [1931] = 1931,
  [1932] = 339,
  [1933] = 462,
  [1934] = 445,
  [1935] = 447,
  [1936] = 339,
  [1937] = 1416,
  [1938] = 444,
  [1939] = 445,
  [1940] = 348,
  [1941] = 459,
  [1942] = 1441,
  [1943] = 1943,
  [1944] = 447,
  [1945] = 346,
  [1946] = 1370,
  [1947] = 1878,
  [1948] = 444,
  [1949] = 1949,
  [1950] = 462,
  [1951] = 1442,
  [1952] = 459,
  [1953] = 333,
  [1954] = 346,
  [1955] = 339,
  [1956] = 1956,
  [1957] = 1957,
  [1958] = 338,
  [1959] = 338,
  [1960] = 444,
  [1961] = 445,
  [1962] = 444,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 447,
  [1967] = 447,
  [1968] = 446,
  [1969] = 1969,
  [1970] = 1970,
  [1971] = 335,
  [1972] = 1972,
  [1973] = 1973,
  [1974] = 1974,
  [1975] = 1975,
  [1976] = 1976,
  [1977] = 333,
  [1978] = 1978,
  [1979] = 335,
  [1980] = 446,
  [1981] = 333,
  [1982] = 1982,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 339,
  [1986] = 445,
  [1987] = 1878,
  [1988] = 1988,
  [1989] = 1371,
  [1990] = 1372,
  [1991] = 1373,
  [1992] = 550,
  [1993] = 1348,
  [1994] = 1349,
  [1995] = 1382,
  [1996] = 1382,
  [1997] = 1383,
  [1998] = 1384,
  [1999] = 1385,
  [2000] = 1386,
  [2001] = 1387,
  [2002] = 1388,
  [2003] = 1389,
  [2004] = 1390,
  [2005] = 1391,
  [2006] = 460,
  [2007] = 1988,
  [2008] = 2008,
  [2009] = 461,
  [2010] = 1383,
  [2011] = 1384,
  [2012] = 1385,
  [2013] = 1386,
  [2014] = 1387,
  [2015] = 1388,
  [2016] = 1367,
  [2017] = 1389,
  [2018] = 1390,
  [2019] = 1391,
  [2020] = 1988,
  [2021] = 2008,
  [2022] = 1988,
  [2023] = 1404,
  [2024] = 2008,
  [2025] = 1393,
  [2026] = 1393,
  [2027] = 1394,
  [2028] = 1395,
  [2029] = 2008,
  [2030] = 355,
  [2031] = 346,
  [2032] = 1394,
  [2033] = 1395,
  [2034] = 348,
  [2035] = 2035,
  [2036] = 346,
  [2037] = 1371,
  [2038] = 461,
  [2039] = 1372,
  [2040] = 1396,
  [2041] = 1397,
  [2042] = 355,
  [2043] = 1396,
  [2044] = 1397,
  [2045] = 460,
  [2046] = 348,
  [2047] = 1373,
  [2048] = 1347,
  [2049] = 1348,
  [2050] = 1349,
  [2051] = 1404,
  [2052] = 570,
  [2053] = 1347,
  [2054] = 1367,
  [2055] = 550,
  [2056] = 2056,
  [2057] = 570,
  [2058] = 2058,
  [2059] = 2059,
  [2060] = 547,
  [2061] = 593,
  [2062] = 598,
  [2063] = 466,
  [2064] = 2064,
  [2065] = 582,
  [2066] = 583,
  [2067] = 2059,
  [2068] = 580,
  [2069] = 2069,
  [2070] = 1419,
  [2071] = 547,
  [2072] = 465,
  [2073] = 589,
  [2074] = 2074,
  [2075] = 2075,
  [2076] = 472,
  [2077] = 603,
  [2078] = 592,
  [2079] = 576,
  [2080] = 569,
  [2081] = 477,
  [2082] = 526,
  [2083] = 576,
  [2084] = 579,
  [2085] = 529,
  [2086] = 503,
  [2087] = 504,
  [2088] = 571,
  [2089] = 523,
  [2090] = 575,
  [2091] = 2074,
  [2092] = 2075,
  [2093] = 524,
  [2094] = 528,
  [2095] = 556,
  [2096] = 2096,
  [2097] = 582,
  [2098] = 530,
  [2099] = 603,
  [2100] = 555,
  [2101] = 2059,
  [2102] = 532,
  [2103] = 543,
  [2104] = 544,
  [2105] = 583,
  [2106] = 564,
  [2107] = 533,
  [2108] = 562,
  [2109] = 493,
  [2110] = 597,
  [2111] = 2035,
  [2112] = 584,
  [2113] = 2064,
  [2114] = 585,
  [2115] = 556,
  [2116] = 536,
  [2117] = 596,
  [2118] = 2118,
  [2119] = 346,
  [2120] = 561,
  [2121] = 548,
  [2122] = 561,
  [2123] = 355,
  [2124] = 696,
  [2125] = 526,
  [2126] = 2126,
  [2127] = 696,
  [2128] = 2069,
  [2129] = 2059,
  [2130] = 346,
  [2131] = 538,
  [2132] = 2132,
  [2133] = 493,
  [2134] = 1408,
  [2135] = 593,
  [2136] = 2136,
  [2137] = 348,
  [2138] = 551,
  [2139] = 575,
  [2140] = 2069,
  [2141] = 554,
  [2142] = 589,
  [2143] = 577,
  [2144] = 466,
  [2145] = 604,
  [2146] = 588,
  [2147] = 580,
  [2148] = 581,
  [2149] = 552,
  [2150] = 348,
  [2151] = 481,
  [2152] = 2126,
  [2153] = 2064,
  [2154] = 552,
  [2155] = 527,
  [2156] = 531,
  [2157] = 579,
  [2158] = 565,
  [2159] = 355,
  [2160] = 523,
  [2161] = 568,
  [2162] = 526,
  [2163] = 2163,
  [2164] = 555,
  [2165] = 578,
  [2166] = 526,
  [2167] = 578,
  [2168] = 585,
  [2169] = 2074,
  [2170] = 2075,
  [2171] = 594,
  [2172] = 529,
  [2173] = 549,
  [2174] = 2174,
  [2175] = 530,
  [2176] = 2132,
  [2177] = 532,
  [2178] = 2126,
  [2179] = 2074,
  [2180] = 2075,
  [2181] = 2132,
  [2182] = 533,
  [2183] = 573,
  [2184] = 1441,
  [2185] = 536,
  [2186] = 1442,
  [2187] = 596,
  [2188] = 548,
  [2189] = 564,
  [2190] = 480,
  [2191] = 522,
  [2192] = 600,
  [2193] = 541,
  [2194] = 577,
  [2195] = 562,
  [2196] = 567,
  [2197] = 600,
  [2198] = 581,
  [2199] = 584,
  [2200] = 597,
  [2201] = 538,
  [2202] = 1416,
  [2203] = 568,
  [2204] = 594,
  [2205] = 588,
  [2206] = 590,
  [2207] = 2132,
  [2208] = 592,
  [2209] = 595,
  [2210] = 2210,
  [2211] = 598,
  [2212] = 523,
  [2213] = 591,
  [2214] = 465,
  [2215] = 477,
  [2216] = 472,
  [2217] = 2064,
  [2218] = 531,
  [2219] = 503,
  [2220] = 553,
  [2221] = 504,
  [2222] = 569,
  [2223] = 528,
  [2224] = 2126,
  [2225] = 590,
  [2226] = 480,
  [2227] = 543,
  [2228] = 544,
  [2229] = 522,
  [2230] = 551,
  [2231] = 554,
  [2232] = 571,
  [2233] = 2096,
  [2234] = 481,
  [2235] = 2235,
  [2236] = 527,
  [2237] = 567,
  [2238] = 526,
  [2239] = 565,
  [2240] = 541,
  [2241] = 573,
  [2242] = 604,
  [2243] = 599,
  [2244] = 523,
  [2245] = 591,
  [2246] = 2069,
  [2247] = 549,
  [2248] = 595,
  [2249] = 524,
  [2250] = 523,
  [2251] = 599,
  [2252] = 553,
  [2253] = 708,
  [2254] = 1348,
  [2255] = 1383,
  [2256] = 2256,
  [2257] = 1384,
  [2258] = 2258,
  [2259] = 1367,
  [2260] = 2260,
  [2261] = 1385,
  [2262] = 1386,
  [2263] = 1404,
  [2264] = 1387,
  [2265] = 1371,
  [2266] = 1372,
  [2267] = 1373,
  [2268] = 446,
  [2269] = 1390,
  [2270] = 1391,
  [2271] = 1388,
  [2272] = 1389,
  [2273] = 346,
  [2274] = 1390,
  [2275] = 1391,
  [2276] = 1347,
  [2277] = 348,
  [2278] = 1393,
  [2279] = 650,
  [2280] = 1394,
  [2281] = 1395,
  [2282] = 1396,
  [2283] = 2283,
  [2284] = 1397,
  [2285] = 346,
  [2286] = 712,
  [2287] = 2287,
  [2288] = 2288,
  [2289] = 725,
  [2290] = 697,
  [2291] = 726,
  [2292] = 2292,
  [2293] = 1404,
  [2294] = 727,
  [2295] = 2295,
  [2296] = 2296,
  [2297] = 2297,
  [2298] = 682,
  [2299] = 1393,
  [2300] = 1394,
  [2301] = 2301,
  [2302] = 446,
  [2303] = 729,
  [2304] = 2304,
  [2305] = 1373,
  [2306] = 2306,
  [2307] = 702,
  [2308] = 725,
  [2309] = 2309,
  [2310] = 726,
  [2311] = 2311,
  [2312] = 2312,
  [2313] = 727,
  [2314] = 705,
  [2315] = 2306,
  [2316] = 728,
  [2317] = 706,
  [2318] = 708,
  [2319] = 1395,
  [2320] = 1349,
  [2321] = 1382,
  [2322] = 1383,
  [2323] = 1384,
  [2324] = 1385,
  [2325] = 1386,
  [2326] = 1387,
  [2327] = 1388,
  [2328] = 1389,
  [2329] = 1390,
  [2330] = 1391,
  [2331] = 1393,
  [2332] = 1394,
  [2333] = 1395,
  [2334] = 1396,
  [2335] = 1397,
  [2336] = 709,
  [2337] = 710,
  [2338] = 711,
  [2339] = 711,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 735,
  [2344] = 728,
  [2345] = 1347,
  [2346] = 713,
  [2347] = 2347,
  [2348] = 1348,
  [2349] = 2349,
  [2350] = 1349,
  [2351] = 729,
  [2352] = 650,
  [2353] = 735,
  [2354] = 682,
  [2355] = 712,
  [2356] = 713,
  [2357] = 1371,
  [2358] = 1372,
  [2359] = 2359,
  [2360] = 2360,
  [2361] = 714,
  [2362] = 2362,
  [2363] = 1396,
  [2364] = 1397,
  [2365] = 689,
  [2366] = 2309,
  [2367] = 2367,
  [2368] = 1367,
  [2369] = 684,
  [2370] = 591,
  [2371] = 744,
  [2372] = 732,
  [2373] = 680,
  [2374] = 2374,
  [2375] = 1382,
  [2376] = 714,
  [2377] = 1383,
  [2378] = 689,
  [2379] = 697,
  [2380] = 2380,
  [2381] = 2288,
  [2382] = 1373,
  [2383] = 684,
  [2384] = 526,
  [2385] = 1404,
  [2386] = 523,
  [2387] = 1384,
  [2388] = 1385,
  [2389] = 1386,
  [2390] = 1387,
  [2391] = 1371,
  [2392] = 1372,
  [2393] = 1388,
  [2394] = 1367,
  [2395] = 1389,
  [2396] = 732,
  [2397] = 710,
  [2398] = 591,
  [2399] = 607,
  [2400] = 2311,
  [2401] = 744,
  [2402] = 1347,
  [2403] = 2258,
  [2404] = 1348,
  [2405] = 607,
  [2406] = 702,
  [2407] = 699,
  [2408] = 705,
  [2409] = 680,
  [2410] = 706,
  [2411] = 1349,
  [2412] = 709,
  [2413] = 699,
  [2414] = 2301,
  [2415] = 695,
  [2416] = 2035,
  [2417] = 695,
  [2418] = 1382,
  [2419] = 2419,
  [2420] = 2258,
  [2421] = 2380,
  [2422] = 348,
  [2423] = 1384,
  [2424] = 848,
  [2425] = 1347,
  [2426] = 1371,
  [2427] = 1348,
  [2428] = 1349,
  [2429] = 747,
  [2430] = 1372,
  [2431] = 1396,
  [2432] = 1397,
  [2433] = 2433,
  [2434] = 2434,
  [2435] = 1408,
  [2436] = 1419,
  [2437] = 1382,
  [2438] = 1383,
  [2439] = 1385,
  [2440] = 1386,
  [2441] = 1387,
  [2442] = 1388,
  [2443] = 1389,
  [2444] = 1390,
  [2445] = 1391,
  [2446] = 1393,
  [2447] = 1394,
  [2448] = 1395,
  [2449] = 1396,
  [2450] = 1397,
  [2451] = 2451,
  [2452] = 2452,
  [2453] = 1416,
  [2454] = 1441,
  [2455] = 1442,
  [2456] = 2456,
  [2457] = 2457,
  [2458] = 2458,
  [2459] = 1373,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2462,
  [2463] = 735,
  [2464] = 689,
  [2465] = 2465,
  [2466] = 346,
  [2467] = 348,
  [2468] = 2468,
  [2469] = 1382,
  [2470] = 1383,
  [2471] = 1384,
  [2472] = 1385,
  [2473] = 1386,
  [2474] = 1387,
  [2475] = 1388,
  [2476] = 1367,
  [2477] = 1389,
  [2478] = 1390,
  [2479] = 1391,
  [2480] = 2480,
  [2481] = 346,
  [2482] = 735,
  [2483] = 2483,
  [2484] = 348,
  [2485] = 2485,
  [2486] = 748,
  [2487] = 689,
  [2488] = 1404,
  [2489] = 2260,
  [2490] = 2490,
  [2491] = 2434,
  [2492] = 1393,
  [2493] = 1394,
  [2494] = 1395,
  [2495] = 2451,
  [2496] = 2458,
  [2497] = 2497,
  [2498] = 2461,
  [2499] = 2485,
  [2500] = 848,
  [2501] = 1408,
  [2502] = 1349,
  [2503] = 1416,
  [2504] = 1419,
  [2505] = 2465,
  [2506] = 1441,
  [2507] = 1442,
  [2508] = 2451,
  [2509] = 2485,
  [2510] = 2451,
  [2511] = 2485,
  [2512] = 2490,
  [2513] = 2458,
  [2514] = 2461,
  [2515] = 2515,
  [2516] = 748,
  [2517] = 747,
  [2518] = 2458,
  [2519] = 2461,
  [2520] = 2520,
  [2521] = 2521,
  [2522] = 2522,
  [2523] = 1041,
  [2524] = 702,
  [2525] = 705,
  [2526] = 708,
  [2527] = 709,
  [2528] = 710,
  [2529] = 711,
  [2530] = 712,
  [2531] = 713,
  [2532] = 714,
  [2533] = 725,
  [2534] = 726,
  [2535] = 727,
  [2536] = 728,
  [2537] = 947,
  [2538] = 1034,
  [2539] = 729,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 963,
  [2543] = 2543,
  [2544] = 851,
  [2545] = 2545,
  [2546] = 2546,
  [2547] = 852,
  [2548] = 852,
  [2549] = 881,
  [2550] = 2546,
  [2551] = 888,
  [2552] = 881,
  [2553] = 2540,
  [2554] = 2541,
  [2555] = 882,
  [2556] = 1002,
  [2557] = 2546,
  [2558] = 1041,
  [2559] = 957,
  [2560] = 851,
  [2561] = 845,
  [2562] = 2546,
  [2563] = 2563,
  [2564] = 1034,
  [2565] = 957,
  [2566] = 2546,
  [2567] = 854,
  [2568] = 904,
  [2569] = 1021,
  [2570] = 1036,
  [2571] = 1040,
  [2572] = 2546,
  [2573] = 2573,
  [2574] = 2546,
  [2575] = 854,
  [2576] = 2546,
  [2577] = 947,
  [2578] = 2546,
  [2579] = 904,
  [2580] = 1021,
  [2581] = 1036,
  [2582] = 882,
  [2583] = 2545,
  [2584] = 1040,
  [2585] = 2585,
  [2586] = 2586,
  [2587] = 2347,
  [2588] = 2588,
  [2589] = 2260,
  [2590] = 2540,
  [2591] = 2541,
  [2592] = 680,
  [2593] = 682,
  [2594] = 706,
  [2595] = 960,
  [2596] = 2596,
  [2597] = 958,
  [2598] = 961,
  [2599] = 2599,
  [2600] = 2600,
  [2601] = 855,
  [2602] = 922,
  [2603] = 888,
  [2604] = 958,
  [2605] = 960,
  [2606] = 961,
  [2607] = 963,
  [2608] = 845,
  [2609] = 2609,
  [2610] = 1002,
  [2611] = 855,
  [2612] = 2545,
  [2613] = 2546,
  [2614] = 1370,
  [2615] = 2615,
  [2616] = 922,
  [2617] = 2546,
  [2618] = 2618,
  [2619] = 2619,
  [2620] = 2620,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2563,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2626,
  [2627] = 2627,
  [2628] = 2628,
  [2629] = 2629,
  [2630] = 2630,
  [2631] = 2631,
  [2632] = 2632,
  [2633] = 2633,
  [2634] = 2634,
  [2635] = 2635,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2638,
  [2639] = 2639,
  [2640] = 2640,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2490,
  [2648] = 2648,
  [2649] = 2649,
  [2650] = 2650,
  [2651] = 2434,
  [2652] = 2629,
  [2653] = 2653,
  [2654] = 2654,
  [2655] = 2655,
  [2656] = 2629,
  [2657] = 2657,
  [2658] = 2658,
  [2659] = 2659,
  [2660] = 2615,
  [2661] = 2629,
  [2662] = 2662,
  [2663] = 2663,
  [2664] = 2664,
  [2665] = 2641,
  [2666] = 2666,
  [2667] = 2667,
  [2668] = 2668,
  [2669] = 2669,
  [2670] = 2670,
  [2671] = 2671,
  [2672] = 2672,
  [2673] = 2673,
  [2674] = 2674,
  [2675] = 2675,
  [2676] = 2676,
  [2677] = 2677,
  [2678] = 2678,
  [2679] = 2679,
  [2680] = 2680,
  [2681] = 2681,
  [2682] = 2682,
  [2683] = 2683,
  [2684] = 2684,
  [2685] = 2685,
  [2686] = 2686,
  [2687] = 2687,
  [2688] = 2641,
  [2689] = 2689,
  [2690] = 2690,
  [2691] = 2691,
  [2692] = 2692,
  [2693] = 2693,
  [2694] = 2694,
  [2695] = 2695,
  [2696] = 2696,
  [2697] = 2697,
  [2698] = 2698,
  [2699] = 2699,
  [2700] = 2700,
  [2701] = 2701,
  [2702] = 2678,
  [2703] = 2703,
  [2704] = 2704,
  [2705] = 2703,
  [2706] = 1370,
  [2707] = 2707,
  [2708] = 2678,
  [2709] = 2709,
  [2710] = 2710,
  [2711] = 2711,
  [2712] = 2712,
  [2713] = 2713,
  [2714] = 2714,
  [2715] = 2715,
  [2716] = 2715,
  [2717] = 2717,
  [2718] = 2718,
  [2719] = 2719,
  [2720] = 2720,
  [2721] = 2721,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2724,
  [2725] = 2725,
  [2726] = 2726,
  [2727] = 2727,
  [2728] = 2728,
  [2729] = 2729,
  [2730] = 2730,
  [2731] = 2731,
  [2732] = 2732,
  [2733] = 2733,
  [2734] = 2734,
  [2735] = 2735,
  [2736] = 310,
  [2737] = 2732,
  [2738] = 2734,
  [2739] = 2739,
  [2740] = 2740,
  [2741] = 2741,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 2744,
  [2745] = 2745,
  [2746] = 2746,
  [2747] = 2733,
  [2748] = 2748,
  [2749] = 2749,
  [2750] = 2750,
  [2751] = 312,
  [2752] = 2752,
  [2753] = 2753,
  [2754] = 2754,
  [2755] = 2755,
  [2756] = 2750,
  [2757] = 2757,
  [2758] = 2758,
  [2759] = 2759,
  [2760] = 2740,
  [2761] = 2761,
  [2762] = 2731,
  [2763] = 2763,
  [2764] = 2759,
  [2765] = 2729,
  [2766] = 2741,
  [2767] = 2728,
  [2768] = 2743,
  [2769] = 2745,
  [2770] = 2755,
  [2771] = 308,
  [2772] = 2746,
  [2773] = 309,
  [2774] = 2749,
  [2775] = 2752,
  [2776] = 2739,
  [2777] = 2742,
  [2778] = 2753,
  [2779] = 2744,
  [2780] = 2754,
  [2781] = 2757,
  [2782] = 2758,
  [2783] = 2783,
  [2784] = 2761,
  [2785] = 2763,
  [2786] = 311,
  [2787] = 2783,
  [2788] = 2788,
  [2789] = 310,
  [2790] = 308,
  [2791] = 2791,
  [2792] = 312,
  [2793] = 309,
  [2794] = 311,
  [2795] = 2795,
  [2796] = 2796,
  [2797] = 2797,
  [2798] = 2798,
  [2799] = 2799,
  [2800] = 2800,
  [2801] = 2801,
  [2802] = 2802,
  [2803] = 2056,
  [2804] = 2804,
  [2805] = 530,
  [2806] = 575,
  [2807] = 529,
  [2808] = 532,
  [2809] = 533,
  [2810] = 536,
  [2811] = 2811,
  [2812] = 2812,
  [2813] = 2813,
  [2814] = 599,
  [2815] = 2815,
  [2816] = 342,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2819,
  [2820] = 343,
  [2821] = 2821,
  [2822] = 2822,
  [2823] = 2823,
  [2824] = 2824,
  [2825] = 2825,
  [2826] = 2826,
  [2827] = 2827,
  [2828] = 2819,
  [2829] = 2829,
  [2830] = 2821,
  [2831] = 2831,
  [2832] = 2821,
  [2833] = 2833,
  [2834] = 2834,
  [2835] = 2835,
  [2836] = 2819,
  [2837] = 2821,
  [2838] = 2838,
  [2839] = 2056,
  [2840] = 2819,
  [2841] = 2841,
  [2842] = 373,
  [2843] = 2843,
  [2844] = 342,
  [2845] = 2843,
  [2846] = 2841,
  [2847] = 343,
  [2848] = 2843,
  [2849] = 368,
  [2850] = 2841,
  [2851] = 2841,
  [2852] = 533,
  [2853] = 2841,
  [2854] = 2843,
  [2855] = 2841,
  [2856] = 2841,
  [2857] = 2857,
  [2858] = 2858,
  [2859] = 2859,
  [2860] = 2843,
  [2861] = 2843,
  [2862] = 2843,
  [2863] = 378,
  [2864] = 2841,
  [2865] = 2865,
  [2866] = 536,
  [2867] = 1370,
  [2868] = 2868,
  [2869] = 2869,
  [2870] = 2841,
  [2871] = 2843,
  [2872] = 2841,
  [2873] = 2843,
  [2874] = 2843,
  [2875] = 2841,
  [2876] = 529,
  [2877] = 2843,
  [2878] = 532,
  [2879] = 2879,
  [2880] = 420,
  [2881] = 333,
  [2882] = 335,
  [2883] = 338,
  [2884] = 339,
  [2885] = 373,
  [2886] = 335,
  [2887] = 338,
  [2888] = 416,
  [2889] = 339,
  [2890] = 418,
  [2891] = 443,
  [2892] = 417,
  [2893] = 2893,
  [2894] = 421,
  [2895] = 422,
  [2896] = 424,
  [2897] = 425,
  [2898] = 393,
  [2899] = 411,
  [2900] = 427,
  [2901] = 2901,
  [2902] = 2902,
  [2903] = 431,
  [2904] = 2904,
  [2905] = 2905,
  [2906] = 2906,
  [2907] = 434,
  [2908] = 2818,
  [2909] = 435,
  [2910] = 436,
  [2911] = 2834,
  [2912] = 437,
  [2913] = 438,
  [2914] = 441,
  [2915] = 442,
  [2916] = 414,
  [2917] = 2917,
  [2918] = 380,
  [2919] = 381,
  [2920] = 333,
  [2921] = 383,
  [2922] = 384,
  [2923] = 385,
  [2924] = 387,
  [2925] = 388,
  [2926] = 389,
  [2927] = 2927,
  [2928] = 390,
  [2929] = 391,
  [2930] = 392,
  [2931] = 394,
  [2932] = 395,
  [2933] = 396,
  [2934] = 397,
  [2935] = 398,
  [2936] = 399,
  [2937] = 400,
  [2938] = 401,
  [2939] = 2815,
  [2940] = 402,
  [2941] = 403,
  [2942] = 404,
  [2943] = 405,
  [2944] = 406,
  [2945] = 407,
  [2946] = 2946,
  [2947] = 408,
  [2948] = 2826,
  [2949] = 409,
  [2950] = 410,
  [2951] = 378,
  [2952] = 368,
  [2953] = 382,
  [2954] = 400,
  [2955] = 381,
  [2956] = 462,
  [2957] = 382,
  [2958] = 383,
  [2959] = 384,
  [2960] = 385,
  [2961] = 387,
  [2962] = 388,
  [2963] = 389,
  [2964] = 390,
  [2965] = 391,
  [2966] = 392,
  [2967] = 394,
  [2968] = 395,
  [2969] = 396,
  [2970] = 397,
  [2971] = 398,
  [2972] = 399,
  [2973] = 333,
  [2974] = 401,
  [2975] = 402,
  [2976] = 403,
  [2977] = 404,
  [2978] = 405,
  [2979] = 406,
  [2980] = 407,
  [2981] = 408,
  [2982] = 380,
  [2983] = 410,
  [2984] = 1370,
  [2985] = 339,
  [2986] = 416,
  [2987] = 418,
  [2988] = 393,
  [2989] = 411,
  [2990] = 420,
  [2991] = 2991,
  [2992] = 421,
  [2993] = 2993,
  [2994] = 2994,
  [2995] = 422,
  [2996] = 424,
  [2997] = 425,
  [2998] = 427,
  [2999] = 459,
  [3000] = 431,
  [3001] = 434,
  [3002] = 435,
  [3003] = 436,
  [3004] = 437,
  [3005] = 438,
  [3006] = 441,
  [3007] = 442,
  [3008] = 335,
  [3009] = 338,
  [3010] = 444,
  [3011] = 445,
  [3012] = 447,
  [3013] = 414,
  [3014] = 443,
  [3015] = 417,
  [3016] = 409,
  [3017] = 339,
  [3018] = 445,
  [3019] = 346,
  [3020] = 348,
  [3021] = 1871,
  [3022] = 346,
  [3023] = 348,
  [3024] = 3024,
  [3025] = 335,
  [3026] = 335,
  [3027] = 333,
  [3028] = 338,
  [3029] = 445,
  [3030] = 339,
  [3031] = 1370,
  [3032] = 447,
  [3033] = 2791,
  [3034] = 444,
  [3035] = 355,
  [3036] = 459,
  [3037] = 338,
  [3038] = 447,
  [3039] = 333,
  [3040] = 355,
  [3041] = 462,
  [3042] = 444,
  [3043] = 3043,
  [3044] = 460,
  [3045] = 338,
  [3046] = 3046,
  [3047] = 447,
  [3048] = 3048,
  [3049] = 333,
  [3050] = 339,
  [3051] = 346,
  [3052] = 3052,
  [3053] = 355,
  [3054] = 339,
  [3055] = 348,
  [3056] = 335,
  [3057] = 444,
  [3058] = 335,
  [3059] = 445,
  [3060] = 333,
  [3061] = 461,
  [3062] = 338,
  [3063] = 3063,
  [3064] = 3064,
  [3065] = 3043,
  [3066] = 2811,
  [3067] = 579,
  [3068] = 584,
  [3069] = 481,
  [3070] = 3064,
  [3071] = 548,
  [3072] = 460,
  [3073] = 2865,
  [3074] = 577,
  [3075] = 581,
  [3076] = 569,
  [3077] = 527,
  [3078] = 589,
  [3079] = 552,
  [3080] = 480,
  [3081] = 3064,
  [3082] = 522,
  [3083] = 553,
  [3084] = 541,
  [3085] = 594,
  [3086] = 3064,
  [3087] = 2812,
  [3088] = 562,
  [3089] = 567,
  [3090] = 355,
  [3091] = 600,
  [3092] = 355,
  [3093] = 588,
  [3094] = 590,
  [3095] = 3064,
  [3096] = 604,
  [3097] = 346,
  [3098] = 595,
  [3099] = 603,
  [3100] = 2813,
  [3101] = 598,
  [3102] = 465,
  [3103] = 564,
  [3104] = 472,
  [3105] = 3105,
  [3106] = 3106,
  [3107] = 466,
  [3108] = 503,
  [3109] = 3109,
  [3110] = 3105,
  [3111] = 504,
  [3112] = 565,
  [3113] = 528,
  [3114] = 348,
  [3115] = 580,
  [3116] = 597,
  [3117] = 538,
  [3118] = 3064,
  [3119] = 543,
  [3120] = 544,
  [3121] = 576,
  [3122] = 346,
  [3123] = 551,
  [3124] = 554,
  [3125] = 3109,
  [3126] = 3064,
  [3127] = 3105,
  [3128] = 592,
  [3129] = 596,
  [3130] = 461,
  [3131] = 3106,
  [3132] = 348,
  [3133] = 477,
  [3134] = 547,
  [3135] = 591,
  [3136] = 3136,
  [3137] = 3106,
  [3138] = 3109,
  [3139] = 3105,
  [3140] = 571,
  [3141] = 2859,
  [3142] = 593,
  [3143] = 3064,
  [3144] = 3144,
  [3145] = 578,
  [3146] = 3106,
  [3147] = 3109,
  [3148] = 3064,
  [3149] = 3149,
  [3150] = 3150,
  [3151] = 527,
  [3152] = 603,
  [3153] = 346,
  [3154] = 3154,
  [3155] = 597,
  [3156] = 3149,
  [3157] = 538,
  [3158] = 2902,
  [3159] = 591,
  [3160] = 346,
  [3161] = 3161,
  [3162] = 697,
  [3163] = 2904,
  [3164] = 2905,
  [3165] = 592,
  [3166] = 348,
  [3167] = 3167,
  [3168] = 477,
  [3169] = 3169,
  [3170] = 3170,
  [3171] = 578,
  [3172] = 3150,
  [3173] = 3169,
  [3174] = 3174,
  [3175] = 3175,
  [3176] = 3176,
  [3177] = 3177,
  [3178] = 3178,
  [3179] = 3179,
  [3180] = 3169,
  [3181] = 571,
  [3182] = 607,
  [3183] = 593,
  [3184] = 466,
  [3185] = 355,
  [3186] = 3161,
  [3187] = 552,
  [3188] = 548,
  [3189] = 553,
  [3190] = 577,
  [3191] = 581,
  [3192] = 348,
  [3193] = 3161,
  [3194] = 3149,
  [3195] = 699,
  [3196] = 3150,
  [3197] = 3169,
  [3198] = 3174,
  [3199] = 3175,
  [3200] = 3176,
  [3201] = 3177,
  [3202] = 3178,
  [3203] = 3179,
  [3204] = 3150,
  [3205] = 3169,
  [3206] = 3048,
  [3207] = 3149,
  [3208] = 3174,
  [3209] = 3175,
  [3210] = 3176,
  [3211] = 3161,
  [3212] = 3177,
  [3213] = 3178,
  [3214] = 3150,
  [3215] = 3169,
  [3216] = 3174,
  [3217] = 3175,
  [3218] = 3176,
  [3219] = 3177,
  [3220] = 3178,
  [3221] = 3179,
  [3222] = 3179,
  [3223] = 732,
  [3224] = 3224,
  [3225] = 3225,
  [3226] = 3174,
  [3227] = 2058,
  [3228] = 3149,
  [3229] = 480,
  [3230] = 522,
  [3231] = 2707,
  [3232] = 3232,
  [3233] = 3161,
  [3234] = 3179,
  [3235] = 3235,
  [3236] = 3150,
  [3237] = 3169,
  [3238] = 3174,
  [3239] = 3175,
  [3240] = 3176,
  [3241] = 3177,
  [3242] = 3178,
  [3243] = 3179,
  [3244] = 3244,
  [3245] = 3245,
  [3246] = 3246,
  [3247] = 541,
  [3248] = 564,
  [3249] = 3249,
  [3250] = 3149,
  [3251] = 2946,
  [3252] = 562,
  [3253] = 567,
  [3254] = 3176,
  [3255] = 3161,
  [3256] = 3256,
  [3257] = 3150,
  [3258] = 3169,
  [3259] = 3174,
  [3260] = 3175,
  [3261] = 3176,
  [3262] = 3177,
  [3263] = 3178,
  [3264] = 3179,
  [3265] = 3149,
  [3266] = 588,
  [3267] = 590,
  [3268] = 3161,
  [3269] = 3149,
  [3270] = 595,
  [3271] = 3271,
  [3272] = 3161,
  [3273] = 3175,
  [3274] = 598,
  [3275] = 465,
  [3276] = 3161,
  [3277] = 3277,
  [3278] = 3278,
  [3279] = 472,
  [3280] = 3280,
  [3281] = 3281,
  [3282] = 3282,
  [3283] = 503,
  [3284] = 3284,
  [3285] = 3285,
  [3286] = 3150,
  [3287] = 3149,
  [3288] = 3288,
  [3289] = 3289,
  [3290] = 3176,
  [3291] = 504,
  [3292] = 3292,
  [3293] = 528,
  [3294] = 2901,
  [3295] = 576,
  [3296] = 3296,
  [3297] = 3161,
  [3298] = 3177,
  [3299] = 543,
  [3300] = 544,
  [3301] = 551,
  [3302] = 3302,
  [3303] = 554,
  [3304] = 3177,
  [3305] = 579,
  [3306] = 584,
  [3307] = 3307,
  [3308] = 3154,
  [3309] = 547,
  [3310] = 589,
  [3311] = 3178,
  [3312] = 596,
  [3313] = 565,
  [3314] = 3314,
  [3315] = 3179,
  [3316] = 3316,
  [3317] = 3317,
  [3318] = 3318,
  [3319] = 594,
  [3320] = 3175,
  [3321] = 684,
  [3322] = 604,
  [3323] = 3323,
  [3324] = 735,
  [3325] = 600,
  [3326] = 3326,
  [3327] = 3150,
  [3328] = 689,
  [3329] = 580,
  [3330] = 3169,
  [3331] = 3174,
  [3332] = 3167,
  [3333] = 3175,
  [3334] = 3176,
  [3335] = 3177,
  [3336] = 3174,
  [3337] = 3178,
  [3338] = 3179,
  [3339] = 3149,
  [3340] = 481,
  [3341] = 355,
  [3342] = 3342,
  [3343] = 3343,
  [3344] = 3344,
  [3345] = 591,
  [3346] = 3178,
  [3347] = 569,
  [3348] = 3314,
  [3349] = 3349,
  [3350] = 3350,
  [3351] = 3350,
  [3352] = 3352,
  [3353] = 3353,
  [3354] = 1370,
  [3355] = 3355,
  [3356] = 3356,
  [3357] = 3357,
  [3358] = 3232,
  [3359] = 3359,
  [3360] = 3349,
  [3361] = 3361,
  [3362] = 3235,
  [3363] = 3245,
  [3364] = 3246,
  [3365] = 3318,
  [3366] = 699,
  [3367] = 3367,
  [3368] = 3368,
  [3369] = 3359,
  [3370] = 3370,
  [3371] = 3371,
  [3372] = 3349,
  [3373] = 3323,
  [3374] = 3374,
  [3375] = 3375,
  [3376] = 3376,
  [3377] = 3377,
  [3378] = 3378,
  [3379] = 3379,
  [3380] = 3350,
  [3381] = 3350,
  [3382] = 3382,
  [3383] = 3359,
  [3384] = 735,
  [3385] = 3277,
  [3386] = 3278,
  [3387] = 3280,
  [3388] = 3282,
  [3389] = 3284,
  [3390] = 3390,
  [3391] = 732,
  [3392] = 3359,
  [3393] = 3393,
  [3394] = 3349,
  [3395] = 3395,
  [3396] = 3396,
  [3397] = 3359,
  [3398] = 3349,
  [3399] = 3399,
  [3400] = 3400,
  [3401] = 3317,
  [3402] = 3402,
  [3403] = 3349,
  [3404] = 3350,
  [3405] = 3359,
  [3406] = 3349,
  [3407] = 3256,
  [3408] = 689,
  [3409] = 591,
  [3410] = 3281,
  [3411] = 3292,
  [3412] = 3350,
  [3413] = 3342,
  [3414] = 3414,
  [3415] = 3415,
  [3416] = 684,
  [3417] = 3350,
  [3418] = 3418,
  [3419] = 3419,
  [3420] = 3359,
  [3421] = 3350,
  [3422] = 3349,
  [3423] = 607,
  [3424] = 3395,
  [3425] = 3425,
  [3426] = 3350,
  [3427] = 689,
  [3428] = 3428,
  [3429] = 3429,
  [3430] = 3430,
  [3431] = 3431,
  [3432] = 3350,
  [3433] = 3350,
  [3434] = 3434,
  [3435] = 3350,
  [3436] = 3350,
  [3437] = 3350,
  [3438] = 3350,
  [3439] = 735,
  [3440] = 3350,
  [3441] = 3350,
  [3442] = 3350,
  [3443] = 3359,
  [3444] = 3349,
  [3445] = 697,
  [3446] = 3144,
  [3447] = 3359,
  [3448] = 3316,
  [3449] = 3449,
  [3450] = 3450,
  [3451] = 3451,
  [3452] = 3452,
  [3453] = 3453,
  [3454] = 1036,
  [3455] = 1040,
  [3456] = 3456,
  [3457] = 3457,
  [3458] = 3458,
  [3459] = 3459,
  [3460] = 3460,
  [3461] = 3461,
  [3462] = 3462,
  [3463] = 3463,
  [3464] = 346,
  [3465] = 3465,
  [3466] = 3466,
  [3467] = 3467,
  [3468] = 3225,
  [3469] = 3469,
  [3470] = 3470,
  [3471] = 3471,
  [3472] = 3472,
  [3473] = 3473,
  [3474] = 3474,
  [3475] = 3475,
  [3476] = 3461,
  [3477] = 3477,
  [3478] = 3462,
  [3479] = 3479,
  [3480] = 3480,
  [3481] = 3481,
  [3482] = 3482,
  [3483] = 3460,
  [3484] = 888,
  [3485] = 3485,
  [3486] = 3486,
  [3487] = 3487,
  [3488] = 3488,
  [3489] = 947,
  [3490] = 3490,
  [3491] = 1034,
  [3492] = 3492,
  [3493] = 3493,
  [3494] = 3296,
  [3495] = 3302,
  [3496] = 3496,
  [3497] = 3497,
  [3498] = 3498,
  [3499] = 3499,
  [3500] = 3500,
  [3501] = 3501,
  [3502] = 3502,
  [3503] = 3503,
  [3504] = 550,
  [3505] = 3505,
  [3506] = 3506,
  [3507] = 3507,
  [3508] = 957,
  [3509] = 3462,
  [3510] = 3510,
  [3511] = 3507,
  [3512] = 3461,
  [3513] = 3513,
  [3514] = 3514,
  [3515] = 3515,
  [3516] = 3516,
  [3517] = 1370,
  [3518] = 3518,
  [3519] = 3519,
  [3520] = 3520,
  [3521] = 3449,
  [3522] = 3522,
  [3523] = 3523,
  [3524] = 3460,
  [3525] = 3498,
  [3526] = 3461,
  [3527] = 3527,
  [3528] = 3528,
  [3529] = 3529,
  [3530] = 3530,
  [3531] = 3531,
  [3532] = 3532,
  [3533] = 3462,
  [3534] = 3497,
  [3535] = 3485,
  [3536] = 570,
  [3537] = 854,
  [3538] = 3465,
  [3539] = 3486,
  [3540] = 3523,
  [3541] = 3541,
  [3542] = 3542,
  [3543] = 3510,
  [3544] = 3528,
  [3545] = 3469,
  [3546] = 3546,
  [3547] = 3547,
  [3548] = 1002,
  [3549] = 3549,
  [3550] = 3550,
  [3551] = 3551,
  [3552] = 852,
  [3553] = 3553,
  [3554] = 904,
  [3555] = 3555,
  [3556] = 3556,
  [3557] = 3557,
  [3558] = 3558,
  [3559] = 3559,
  [3560] = 3560,
  [3561] = 3561,
  [3562] = 3562,
  [3563] = 3563,
  [3564] = 3564,
  [3565] = 3565,
  [3566] = 3566,
  [3567] = 3567,
  [3568] = 3529,
  [3569] = 3530,
  [3570] = 3570,
  [3571] = 735,
  [3572] = 348,
  [3573] = 3573,
  [3574] = 3499,
  [3575] = 1041,
  [3576] = 3576,
  [3577] = 1021,
  [3578] = 689,
  [3579] = 851,
  [3580] = 3580,
  [3581] = 3485,
  [3582] = 3486,
  [3583] = 3523,
  [3584] = 3510,
  [3585] = 3585,
  [3586] = 3528,
  [3587] = 3469,
  [3588] = 3588,
  [3589] = 3589,
  [3590] = 3485,
  [3591] = 3486,
  [3592] = 3523,
  [3593] = 3593,
  [3594] = 3510,
  [3595] = 3528,
  [3596] = 3469,
  [3597] = 845,
  [3598] = 3598,
  [3599] = 3599,
  [3600] = 3600,
  [3601] = 3601,
  [3602] = 3602,
  [3603] = 3603,
  [3604] = 3604,
  [3605] = 1041,
  [3606] = 3606,
  [3607] = 3607,
  [3608] = 3608,
  [3609] = 888,
  [3610] = 3610,
  [3611] = 3611,
  [3612] = 1021,
  [3613] = 3357,
  [3614] = 3614,
  [3615] = 3603,
  [3616] = 3616,
  [3617] = 3617,
  [3618] = 3607,
  [3619] = 3619,
  [3620] = 3620,
  [3621] = 3621,
  [3622] = 3622,
  [3623] = 3608,
  [3624] = 1036,
  [3625] = 3453,
  [3626] = 3626,
  [3627] = 3627,
  [3628] = 957,
  [3629] = 1040,
  [3630] = 3617,
  [3631] = 3603,
  [3632] = 947,
  [3633] = 3633,
  [3634] = 3430,
  [3635] = 3431,
  [3636] = 3399,
  [3637] = 845,
  [3638] = 3393,
  [3639] = 3639,
  [3640] = 3640,
  [3641] = 3641,
  [3642] = 3633,
  [3643] = 3603,
  [3644] = 3607,
  [3645] = 3645,
  [3646] = 3603,
  [3647] = 3647,
  [3648] = 3603,
  [3649] = 3649,
  [3650] = 3650,
  [3651] = 3567,
  [3652] = 3378,
  [3653] = 3653,
  [3654] = 3654,
  [3655] = 3655,
  [3656] = 3656,
  [3657] = 3656,
  [3658] = 3598,
  [3659] = 3659,
  [3660] = 3660,
  [3661] = 3661,
  [3662] = 3662,
  [3663] = 3663,
  [3664] = 3607,
  [3665] = 3665,
  [3666] = 3666,
  [3667] = 3667,
  [3668] = 3668,
  [3669] = 3654,
  [3670] = 3467,
  [3671] = 3671,
  [3672] = 3672,
  [3673] = 1002,
  [3674] = 3653,
  [3675] = 3675,
  [3676] = 3607,
  [3677] = 3677,
  [3678] = 3603,
  [3679] = 3599,
  [3680] = 1034,
  [3681] = 3650,
  [3682] = 3607,
  [3683] = 3683,
  [3684] = 3684,
  [3685] = 852,
  [3686] = 851,
  [3687] = 3687,
  [3688] = 3607,
  [3689] = 3617,
  [3690] = 3690,
  [3691] = 3608,
  [3692] = 3607,
  [3693] = 3633,
  [3694] = 3694,
  [3695] = 854,
  [3696] = 3696,
  [3697] = 3696,
  [3698] = 3604,
  [3699] = 3626,
  [3700] = 3700,
  [3701] = 3701,
  [3702] = 3702,
  [3703] = 3617,
  [3704] = 3603,
  [3705] = 3608,
  [3706] = 3706,
  [3707] = 904,
  [3708] = 3655,
  [3709] = 3603,
  [3710] = 3607,
  [3711] = 3496,
  [3712] = 3633,
  [3713] = 3667,
  [3714] = 3576,
  [3715] = 3715,
  [3716] = 3716,
  [3717] = 3717,
  [3718] = 3718,
  [3719] = 3719,
  [3720] = 3720,
  [3721] = 3721,
  [3722] = 3715,
  [3723] = 3716,
  [3724] = 3717,
  [3725] = 3725,
  [3726] = 3726,
  [3727] = 3727,
  [3728] = 3728,
  [3729] = 3729,
  [3730] = 3730,
  [3731] = 3731,
  [3732] = 3716,
  [3733] = 3717,
  [3734] = 348,
  [3735] = 3735,
  [3736] = 3719,
  [3737] = 3720,
  [3738] = 3721,
  [3739] = 3739,
  [3740] = 3715,
  [3741] = 3741,
  [3742] = 3742,
  [3743] = 3731,
  [3744] = 3716,
  [3745] = 3717,
  [3746] = 3746,
  [3747] = 3719,
  [3748] = 3720,
  [3749] = 3721,
  [3750] = 3750,
  [3751] = 3729,
  [3752] = 3719,
  [3753] = 3753,
  [3754] = 3720,
  [3755] = 3721,
  [3756] = 346,
  [3757] = 3753,
  [3758] = 3739,
  [3759] = 348,
  [3760] = 3731,
  [3761] = 3716,
  [3762] = 3717,
  [3763] = 3763,
  [3764] = 3719,
  [3765] = 3720,
  [3766] = 3721,
  [3767] = 3715,
  [3768] = 3729,
  [3769] = 3715,
  [3770] = 3770,
  [3771] = 3771,
  [3772] = 3772,
  [3773] = 3739,
  [3774] = 3774,
  [3775] = 3750,
  [3776] = 3731,
  [3777] = 3716,
  [3778] = 3717,
  [3779] = 3719,
  [3780] = 3720,
  [3781] = 3721,
  [3782] = 3715,
  [3783] = 3729,
  [3784] = 3729,
  [3785] = 3785,
  [3786] = 3729,
  [3787] = 3729,
  [3788] = 3729,
  [3789] = 3739,
  [3790] = 3729,
  [3791] = 3715,
  [3792] = 3729,
  [3793] = 3793,
  [3794] = 3729,
  [3795] = 3729,
  [3796] = 3729,
  [3797] = 3729,
  [3798] = 3729,
  [3799] = 3729,
  [3800] = 3729,
  [3801] = 3729,
  [3802] = 3729,
  [3803] = 3729,
  [3804] = 3729,
  [3805] = 3729,
  [3806] = 3729,
  [3807] = 3729,
  [3808] = 3729,
  [3809] = 3729,
  [3810] = 3729,
  [3811] = 3729,
  [3812] = 3729,
  [3813] = 3729,
  [3814] = 3729,
  [3815] = 3729,
  [3816] = 3729,
  [3817] = 3817,
  [3818] = 3818,
  [3819] = 3819,
  [3820] = 3820,
  [3821] = 3718,
  [3822] = 3716,
  [3823] = 3823,
  [3824] = 3824,
  [3825] = 3825,
  [3826] = 3826,
  [3827] = 3827,
  [3828] = 3828,
  [3829] = 3829,
  [3830] = 3556,
  [3831] = 3831,
  [3832] = 3832,
  [3833] = 3729,
  [3834] = 3772,
  [3835] = 3835,
  [3836] = 3731,
  [3837] = 3826,
  [3838] = 3838,
  [3839] = 3718,
  [3840] = 3739,
  [3841] = 3716,
  [3842] = 3717,
  [3843] = 3843,
  [3844] = 3832,
  [3845] = 3845,
  [3846] = 3846,
  [3847] = 3731,
  [3848] = 3716,
  [3849] = 3726,
  [3850] = 3717,
  [3851] = 3851,
  [3852] = 3852,
  [3853] = 3719,
  [3854] = 3854,
  [3855] = 3720,
  [3856] = 3721,
  [3857] = 3715,
  [3858] = 3858,
  [3859] = 3731,
  [3860] = 3860,
  [3861] = 3845,
  [3862] = 3862,
  [3863] = 3717,
  [3864] = 3864,
  [3865] = 3865,
  [3866] = 3746,
  [3867] = 3867,
  [3868] = 3719,
  [3869] = 3720,
  [3870] = 3721,
  [3871] = 3718,
  [3872] = 3753,
  [3873] = 3716,
  [3874] = 3715,
  [3875] = 3875,
  [3876] = 3793,
  [3877] = 3717,
  [3878] = 3828,
  [3879] = 3729,
  [3880] = 3880,
  [3881] = 3881,
  [3882] = 3882,
  [3883] = 3883,
  [3884] = 3884,
  [3885] = 3885,
  [3886] = 3886,
  [3887] = 3750,
  [3888] = 3739,
  [3889] = 3739,
  [3890] = 3890,
  [3891] = 3793,
  [3892] = 3892,
  [3893] = 3893,
  [3894] = 3739,
  [3895] = 3895,
  [3896] = 3828,
  [3897] = 3746,
  [3898] = 3731,
  [3899] = 3716,
  [3900] = 3717,
  [3901] = 3746,
  [3902] = 3719,
  [3903] = 3720,
  [3904] = 3904,
  [3905] = 3835,
  [3906] = 3721,
  [3907] = 3715,
  [3908] = 3771,
  [3909] = 3729,
  [3910] = 3719,
  [3911] = 3750,
  [3912] = 3739,
  [3913] = 3785,
  [3914] = 3914,
  [3915] = 3720,
  [3916] = 697,
  [3917] = 3719,
  [3918] = 3721,
  [3919] = 3919,
  [3920] = 3920,
  [3921] = 3921,
  [3922] = 3772,
  [3923] = 3923,
  [3924] = 3753,
  [3925] = 3729,
  [3926] = 3926,
  [3927] = 3927,
  [3928] = 3720,
  [3929] = 3721,
  [3930] = 3930,
  [3931] = 3731,
  [3932] = 3729,
  [3933] = 3933,
  [3934] = 3729,
  [3935] = 3935,
  [3936] = 3936,
  [3937] = 3937,
  [3938] = 3938,
  [3939] = 3939,
  [3940] = 3771,
  [3941] = 3715,
  [3942] = 3729,
  [3943] = 684,
  [3944] = 3944,
  [3945] = 3793,
  [3946] = 3946,
  [3947] = 346,
  [3948] = 3771,
  [3949] = 3949,
  [3950] = 3950,
  [3951] = 3772,
  [3952] = 3731,
  [3953] = 3739,
  [3954] = 3926,
  [3955] = 3828,
  [3956] = 3739,
  [3957] = 3731,
  [3958] = 3958,
  [3959] = 3959,
  [3960] = 3960,
  [3961] = 531,
  [3962] = 3960,
  [3963] = 3963,
  [3964] = 3960,
  [3965] = 3960,
  [3966] = 3966,
  [3967] = 3960,
  [3968] = 3968,
  [3969] = 3960,
  [3970] = 3970,
  [3971] = 3960,
  [3972] = 3968,
  [3973] = 3960,
  [3974] = 3963,
  [3975] = 3960,
  [3976] = 3976,
  [3977] = 3960,
  [3978] = 3978,
  [3979] = 3979,
  [3980] = 3980,
  [3981] = 3981,
  [3982] = 3982,
  [3983] = 3960,
  [3984] = 3984,
  [3985] = 3985,
  [3986] = 3986,
  [3987] = 3987,
  [3988] = 3988,
  [3989] = 3976,
  [3990] = 3990,
  [3991] = 3991,
  [3992] = 3992,
  [3993] = 3960,
  [3994] = 3994,
  [3995] = 3995,
  [3996] = 3988,
  [3997] = 3997,
  [3998] = 3960,
  [3999] = 348,
  [4000] = 3968,
  [4001] = 4001,
  [4002] = 4002,
  [4003] = 3987,
  [4004] = 4004,
  [4005] = 3959,
  [4006] = 4006,
  [4007] = 1441,
  [4008] = 4008,
  [4009] = 4009,
  [4010] = 4010,
  [4011] = 4011,
  [4012] = 4012,
  [4013] = 4013,
  [4014] = 3958,
  [4015] = 4015,
  [4016] = 4016,
  [4017] = 4017,
  [4018] = 3976,
  [4019] = 3665,
  [4020] = 3960,
  [4021] = 3968,
  [4022] = 4022,
  [4023] = 4023,
  [4024] = 3982,
  [4025] = 3985,
  [4026] = 3667,
  [4027] = 3987,
  [4028] = 4028,
  [4029] = 4029,
  [4030] = 4030,
  [4031] = 1416,
  [4032] = 493,
  [4033] = 4033,
  [4034] = 1442,
  [4035] = 3987,
  [4036] = 3960,
  [4037] = 4037,
  [4038] = 3987,
  [4039] = 4039,
  [4040] = 3960,
  [4041] = 3987,
  [4042] = 4001,
  [4043] = 3987,
  [4044] = 4044,
  [4045] = 3987,
  [4046] = 3960,
  [4047] = 3987,
  [4048] = 4028,
  [4049] = 4049,
  [4050] = 3960,
  [4051] = 4051,
  [4052] = 4052,
  [4053] = 3960,
  [4054] = 3960,
  [4055] = 3958,
  [4056] = 3997,
  [4057] = 3959,
  [4058] = 4058,
  [4059] = 4059,
  [4060] = 4060,
  [4061] = 4061,
  [4062] = 4062,
  [4063] = 4063,
  [4064] = 4001,
  [4065] = 4065,
  [4066] = 4066,
  [4067] = 4067,
  [4068] = 3958,
  [4069] = 4059,
  [4070] = 4023,
  [4071] = 4059,
  [4072] = 4072,
  [4073] = 4073,
  [4074] = 3960,
  [4075] = 4075,
  [4076] = 4001,
  [4077] = 346,
  [4078] = 3980,
  [4079] = 3960,
  [4080] = 4080,
  [4081] = 3960,
  [4082] = 4082,
  [4083] = 4059,
  [4084] = 3985,
  [4085] = 3960,
  [4086] = 4086,
  [4087] = 4087,
  [4088] = 4088,
  [4089] = 3960,
  [4090] = 3994,
  [4091] = 3960,
  [4092] = 3960,
  [4093] = 3960,
  [4094] = 4094,
  [4095] = 3994,
  [4096] = 3997,
  [4097] = 3959,
  [4098] = 3988,
  [4099] = 4067,
  [4100] = 3997,
  [4101] = 4101,
  [4102] = 4102,
  [4103] = 4103,
  [4104] = 4104,
  [4105] = 4104,
  [4106] = 4104,
  [4107] = 4104,
  [4108] = 4108,
  [4109] = 4109,
  [4110] = 4110,
  [4111] = 4111,
  [4112] = 4103,
  [4113] = 4113,
  [4114] = 4104,
  [4115] = 4104,
  [4116] = 4102,
  [4117] = 4117,
  [4118] = 4118,
  [4119] = 4103,
  [4120] = 4104,
  [4121] = 3867,
  [4122] = 4122,
  [4123] = 4103,
  [4124] = 4104,
  [4125] = 4125,
  [4126] = 4126,
  [4127] = 4111,
  [4128] = 4103,
  [4129] = 4104,
  [4130] = 4130,
  [4131] = 4131,
  [4132] = 4132,
  [4133] = 4133,
  [4134] = 4102,
  [4135] = 4117,
  [4136] = 4104,
  [4137] = 4137,
  [4138] = 4103,
  [4139] = 4104,
  [4140] = 4104,
  [4141] = 4103,
  [4142] = 4103,
  [4143] = 4104,
  [4144] = 4102,
  [4145] = 4117,
  [4146] = 4104,
  [4147] = 4103,
  [4148] = 4102,
  [4149] = 4117,
  [4150] = 4130,
  [4151] = 4102,
  [4152] = 4117,
  [4153] = 4110,
  [4154] = 4154,
  [4155] = 4103,
  [4156] = 4104,
  [4157] = 4130,
  [4158] = 4102,
  [4159] = 4117,
  [4160] = 4137,
  [4161] = 4111,
  [4162] = 4162,
  [4163] = 4102,
  [4164] = 4117,
  [4165] = 4113,
  [4166] = 4103,
  [4167] = 4118,
  [4168] = 4102,
  [4169] = 4117,
  [4170] = 4111,
  [4171] = 4103,
  [4172] = 4118,
  [4173] = 4102,
  [4174] = 4117,
  [4175] = 4104,
  [4176] = 4104,
  [4177] = 4102,
  [4178] = 4117,
  [4179] = 4179,
  [4180] = 4108,
  [4181] = 4102,
  [4182] = 4117,
  [4183] = 4183,
  [4184] = 4102,
  [4185] = 4117,
  [4186] = 4118,
  [4187] = 4102,
  [4188] = 4117,
  [4189] = 4102,
  [4190] = 4117,
  [4191] = 4102,
  [4192] = 4117,
  [4193] = 4102,
  [4194] = 4117,
  [4195] = 4102,
  [4196] = 4117,
  [4197] = 4102,
  [4198] = 4117,
  [4199] = 4102,
  [4200] = 4117,
  [4201] = 4102,
  [4202] = 4117,
  [4203] = 4102,
  [4204] = 4117,
  [4205] = 4102,
  [4206] = 4117,
  [4207] = 4102,
  [4208] = 4117,
  [4209] = 4102,
  [4210] = 4117,
  [4211] = 4102,
  [4212] = 4117,
  [4213] = 4102,
  [4214] = 4117,
  [4215] = 4102,
  [4216] = 4117,
  [4217] = 4102,
  [4218] = 4117,
  [4219] = 4102,
  [4220] = 4117,
  [4221] = 4102,
  [4222] = 4117,
  [4223] = 4102,
  [4224] = 4117,
  [4225] = 346,
  [4226] = 4103,
  [4227] = 4102,
  [4228] = 4117,
  [4229] = 4102,
  [4230] = 4117,
  [4231] = 4102,
  [4232] = 4117,
  [4233] = 4102,
  [4234] = 4117,
  [4235] = 4102,
  [4236] = 4117,
  [4237] = 4102,
  [4238] = 4117,
  [4239] = 4102,
  [4240] = 4117,
  [4241] = 4103,
  [4242] = 4104,
  [4243] = 4103,
  [4244] = 4102,
  [4245] = 4104,
  [4246] = 4246,
  [4247] = 4247,
  [4248] = 4103,
  [4249] = 4109,
  [4250] = 4104,
  [4251] = 4103,
  [4252] = 4104,
  [4253] = 3949,
  [4254] = 3895,
  [4255] = 3893,
  [4256] = 4111,
  [4257] = 4104,
  [4258] = 4111,
  [4259] = 4103,
  [4260] = 4103,
  [4261] = 4261,
  [4262] = 4111,
  [4263] = 4263,
  [4264] = 4103,
  [4265] = 4104,
  [4266] = 4108,
  [4267] = 4117,
  [4268] = 4103,
  [4269] = 4104,
  [4270] = 4154,
  [4271] = 4118,
  [4272] = 4104,
  [4273] = 4118,
  [4274] = 4274,
  [4275] = 4118,
  [4276] = 4104,
  [4277] = 4103,
  [4278] = 4104,
  [4279] = 4103,
  [4280] = 4111,
  [4281] = 4104,
  [4282] = 348,
  [4283] = 4103,
  [4284] = 4103,
  [4285] = 4104,
  [4286] = 4104,
  [4287] = 4287,
  [4288] = 4126,
  [4289] = 4261,
  [4290] = 4103,
  [4291] = 4104,
  [4292] = 4261,
  [4293] = 4293,
  [4294] = 4110,
  [4295] = 4103,
  [4296] = 4103,
  [4297] = 4104,
  [4298] = 4298,
  [4299] = 4113,
  [4300] = 4300,
  [4301] = 4104,
  [4302] = 4133,
  [4303] = 4108,
  [4304] = 4103,
  [4305] = 4103,
  [4306] = 4103,
  [4307] = 4104,
  [4308] = 4104,
  [4309] = 4261,
  [4310] = 4103,
  [4311] = 4103,
  [4312] = 4104,
  [4313] = 4300,
  [4314] = 4104,
  [4315] = 4103,
  [4316] = 4103,
  [4317] = 4104,
  [4318] = 4104,
  [4319] = 4103,
  [4320] = 4126,
  [4321] = 4103,
  [4322] = 4104,
  [4323] = 4103,
  [4324] = 4118,
  [4325] = 4111,
  [4326] = 4103,
  [4327] = 4103,
  [4328] = 4117,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(147);
      ADVANCE_MAP(
        '\n', 344,
        '\r', 244,
        '!', 166,
        '"', 251,
        '#', 313,
        '%', 178,
        '&', 202,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 158,
        ',', 214,
        '-', 161,
        '.', 212,
        '/', 174,
        ':', 205,
        '<', 193,
        '=', 156,
        '>', 188,
        '?', 224,
        '[', 226,
        '\\', 300,
        ']', 227,
        '^', 183,
        '{', 153,
        '|', 180,
        '}', 154,
        '~', 165,
        '\t', 245,
        ' ', 245,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(219);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(220);
      if (lookahead != 0) ADVANCE(215);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(344);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '#', 313,
        '%', 178,
        '&', 202,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 175,
        '0', 78,
        ':', 206,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 301,
        '^', 185,
        '_', 329,
        '`', 145,
        '{', 153,
        '|', 182,
        '}', 154,
        '~', 165,
        '\t', 349,
        ' ', 349,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(328);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '#', 313,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 164,
        '.', 213,
        '/', 175,
        '0', 78,
        ':', 91,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '?', 224,
        'B', 326,
        '[', 226,
        '\\', 301,
        ']', 227,
        '^', 185,
        '_', 329,
        '`', 145,
        '{', 153,
        '|', 182,
        '~', 165,
        '\t', 349,
        ' ', 349,
        'V', 323,
        'v', 323,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(328);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 257,
        '-', 164,
        '.', 212,
        '/', 175,
        ':', 205,
        ';', 258,
        '<', 194,
        '=', 99,
        '>', 189,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        ']', 227,
        '^', 183,
        '`', 145,
        'u', 318,
        '|', 182,
        '~', 165,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 152,
        '*', 172,
        '+', 159,
        '-', 164,
        '.', 212,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 99,
        '>', 189,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        '^', 183,
        '`', 145,
        'u', 318,
        '|', 182,
        '~', 165,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '%', 179,
        '&', 204,
        '\'', 242,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        '^', 184,
        '`', 145,
        'u', 318,
        '|', 181,
        '~', 165,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 167,
        '"', 251,
        '%', 179,
        '&', 204,
        '\'', 242,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        '^', 184,
        '`', 145,
        'u', 318,
        '|', 181,
        '~', 165,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '"', 251,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '"', 251,
        '%', 178,
        '&', 203,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ':', 91,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        'B', 292,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '\t', 349,
        ' ', 349,
        'V', 287,
        'v', 287,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '"', 251,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '"', 251,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 175,
        ':', 206,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '?', 224,
        '\\', 302,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 300,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 42,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(315);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 203,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 175,
        ':', 207,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        'B', 327,
        '\\', 302,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
        'V', 324,
        'v', 324,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(314);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 203,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 175,
        ':', 91,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        'B', 327,
        '\\', 300,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
        'V', 324,
        'v', 324,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 203,
        '(', 152,
        '*', 172,
        '+', 159,
        '-', 162,
        '.', 88,
        '/', 175,
        ':', 91,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        'B', 327,
        '\\', 303,
        '^', 185,
        '|', 182,
        '\t', 349,
        ' ', 349,
        'V', 324,
        'v', 324,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 178,
        '&', 203,
        '(', 152,
        '*', 172,
        '+', 159,
        '-', 162,
        '.', 88,
        '/', 175,
        ':', 91,
        ';', 44,
        '<', 194,
        '=', 157,
        '>', 189,
        'B', 291,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '\t', 349,
        ' ', 349,
        'V', 289,
        'v', 289,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 300,
        '^', 184,
        '|', 181,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 302,
        '^', 184,
        '|', 181,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 258,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '|', 181,
        '\t', 347,
        ' ', 347,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 300,
        '^', 184,
        '|', 181,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 302,
        '^', 184,
        '|', 181,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        '-', 163,
        '.', 212,
        '/', 176,
        ';', 44,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '|', 181,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '"', 251,
        '&', 202,
        '(', 152,
        '/', 89,
        ';', 44,
        '=', 221,
        '\\', 303,
        '`', 145,
        '\t', 348,
        ' ', 348,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '"', 251,
        '\'', 242,
        '(', 152,
        '/', 89,
        '0', 116,
        ';', 44,
        '=', 221,
        'L', 73,
        'U', 74,
        '\\', 302,
        'u', 75,
        '\t', 348,
        ' ', 348,
      );
      END_STATE();
    case 31:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '&', 202,
        '(', 152,
        '/', 89,
        ';', 44,
        '=', 221,
        '\\', 300,
        '\t', 348,
        ' ', 348,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '&', 202,
        '(', 152,
        '/', 89,
        ';', 44,
        '=', 221,
        '\\', 302,
        '\t', 348,
        ' ', 348,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '&', 202,
        '(', 152,
        '/', 89,
        ';', 44,
        '=', 221,
        '\\', 303,
        '`', 145,
        '\t', 348,
        ' ', 348,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '&', 202,
        '(', 152,
        '/', 89,
        ';', 44,
        '=', 221,
        '\\', 303,
        '\t', 348,
        ' ', 348,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '(', 149,
        '/', 89,
        ';', 44,
        '\\', 42,
        '\t', 349,
        ' ', 349,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 36:
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ',') ADVANCE(257);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(258);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(36);
      END_STATE();
    case 37:
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '=') ADVANCE(221);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(37);
      END_STATE();
    case 38:
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(38);
      END_STATE();
    case 39:
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(218);
      if (lookahead == ';') ADVANCE(217);
      if (lookahead == '\\') ADVANCE(216);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(349);
      if (lookahead != 0) ADVANCE(215);
      END_STATE();
    case 40:
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(40);
      END_STATE();
    case 41:
      if (lookahead == '\n') ADVANCE(345);
      END_STATE();
    case 42:
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      END_STATE();
    case 43:
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(282);
      END_STATE();
    case 44:
      if (lookahead == '\n') ADVANCE(342);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 45:
      if (lookahead == '\n') ADVANCE(343);
      if (lookahead == '\r') ADVANCE(46);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 46:
      if (lookahead == '\n') ADVANCE(343);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 47:
      if (lookahead == '\n') ADVANCE(254);
      if (lookahead == '\r') ADVANCE(254);
      if (lookahead == 'U') ADVANCE(141);
      if (lookahead == 'u') ADVANCE(137);
      if (lookahead == 'x') ADVANCE(135);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      if (lookahead != 0) ADVANCE(254);
      END_STATE();
    case 48:
      ADVANCE_MAP(
        '!', 166,
        '"', 251,
        '%', 178,
        '&', 202,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        '-', 162,
        '/', 174,
        ':', 205,
        'L', 316,
        'U', 317,
        '\\', 301,
        ']', 227,
        '`', 145,
        'u', 318,
        '~', 165,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 49:
      ADVANCE_MAP(
        '!', 167,
        '"', 251,
        '#', 313,
        '%', 178,
        '&', 202,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 174,
        '0', 78,
        ':', 206,
        '<', 194,
        '=', 157,
        '>', 189,
        '[', 226,
        '\\', 301,
        ']', 227,
        '^', 185,
        '_', 329,
        '`', 145,
        '{', 153,
        '|', 182,
        '}', 154,
        '~', 165,
        '\t', 346,
        ' ', 346,
      );
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(328);
      END_STATE();
    case 50:
      ADVANCE_MAP(
        '!', 167,
        '"', 251,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 164,
        '.', 213,
        '/', 174,
        '<', 194,
        '=', 99,
        '>', 189,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        ']', 227,
        '^', 183,
        '`', 145,
        'u', 318,
        '|', 182,
        '~', 165,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        '!', 167,
        '"', 251,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 152,
        '*', 172,
        '+', 159,
        ',', 257,
        '-', 164,
        '.', 212,
        '/', 174,
        ';', 259,
        '<', 194,
        '=', 99,
        '>', 189,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        '^', 183,
        '`', 145,
        'u', 318,
        '|', 182,
        '~', 165,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '!', 167,
        '"', 251,
        '%', 179,
        '&', 204,
        '\'', 242,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        ']', 227,
        '^', 184,
        '`', 145,
        'u', 318,
        '|', 181,
        '~', 165,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 53:
      ADVANCE_MAP(
        '!', 167,
        '"', 251,
        '%', 179,
        '&', 204,
        '\'', 242,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        'L', 316,
        'U', 317,
        '[', 226,
        '\\', 301,
        '^', 184,
        '`', 145,
        'u', 318,
        '|', 181,
        '~', 165,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 54:
      ADVANCE_MAP(
        '!', 98,
        '"', 251,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 174,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 55:
      ADVANCE_MAP(
        '!', 98,
        '"', 251,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 174,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '`', 145,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 56:
      ADVANCE_MAP(
        '!', 98,
        '"', 251,
        '%', 179,
        '&', 204,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        ']', 227,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 57:
      ADVANCE_MAP(
        '!', 98,
        '"', 251,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 58:
      ADVANCE_MAP(
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 213,
        '/', 174,
        ':', 206,
        '<', 194,
        '=', 157,
        '>', 189,
        '?', 224,
        '[', 226,
        '\\', 302,
        '^', 185,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 59:
      ADVANCE_MAP(
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 174,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 300,
        '^', 185,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 60:
      ADVANCE_MAP(
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 174,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 303,
        '^', 185,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        '!', 98,
        '%', 178,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        '+', 159,
        ',', 214,
        '-', 162,
        '.', 88,
        '/', 174,
        '<', 194,
        '=', 157,
        '>', 189,
        '\\', 42,
        '^', 185,
        '|', 182,
        '}', 154,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(315);
      END_STATE();
    case 62:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 300,
        ']', 227,
        '^', 184,
        '|', 181,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 63:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 302,
        ']', 227,
        '^', 184,
        '{', 153,
        '|', 181,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 64:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        ']', 227,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 65:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        ')', 151,
        '*', 173,
        '+', 160,
        ',', 214,
        '-', 163,
        '.', 213,
        '/', 177,
        ':', 205,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        ']', 227,
        '^', 184,
        '|', 181,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 66:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 300,
        '^', 184,
        '|', 181,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 67:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 302,
        '^', 184,
        '|', 181,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 68:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '`', 145,
        '|', 181,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 69:
      ADVANCE_MAP(
        '!', 98,
        '%', 179,
        '&', 204,
        '(', 152,
        '*', 173,
        '+', 160,
        ',', 257,
        '-', 163,
        '.', 212,
        '/', 177,
        ';', 259,
        '<', 195,
        '=', 157,
        '>', 190,
        '?', 224,
        '[', 226,
        '\\', 303,
        '^', 184,
        '|', 181,
        '\t', 350,
        ' ', 350,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 70:
      ADVANCE_MAP(
        '"', 251,
        '#', 313,
        '%', 125,
        '&', 202,
        '(', 152,
        ')', 151,
        '*', 172,
        ',', 214,
        '[', 226,
        '\\', 301,
        '`', 145,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 71:
      if (lookahead == '"') ADVANCE(251);
      if (lookahead == '&') ADVANCE(202);
      if (lookahead == '\\') ADVANCE(216);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(346);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(215);
      END_STATE();
    case 72:
      if (lookahead == '"') ADVANCE(251);
      if (lookahead == '\\') ADVANCE(47);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(253);
      END_STATE();
    case 73:
      if (lookahead == '"') ADVANCE(247);
      if (lookahead == '\'') ADVANCE(238);
      END_STATE();
    case 74:
      if (lookahead == '"') ADVANCE(249);
      if (lookahead == '\'') ADVANCE(240);
      END_STATE();
    case 75:
      if (lookahead == '"') ADVANCE(248);
      if (lookahead == '\'') ADVANCE(239);
      if (lookahead == '8') ADVANCE(76);
      END_STATE();
    case 76:
      if (lookahead == '"') ADVANCE(250);
      if (lookahead == '\'') ADVANCE(241);
      END_STATE();
    case 77:
      if (lookahead == '"') ADVANCE(252);
      if (lookahead == '&') ADVANCE(202);
      if (lookahead == '\\') ADVANCE(274);
      if (lookahead != 0) ADVANCE(276);
      END_STATE();
    case 78:
      ADVANCE_MAP(
        '%', 312,
        '.', 80,
        'X', 340,
        'm', 330,
        's', 309,
        'x', 337,
        'y', 338,
        'H', 339,
        'h', 339,
        'n', 331,
        'u', 331,
        'G', 334,
        'K', 334,
        'M', 334,
        'g', 334,
        'k', 334,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 79:
      ADVANCE_MAP(
        '%', 312,
        '.', 80,
        'm', 330,
        's', 309,
        'H', 339,
        'h', 339,
        'n', 331,
        'u', 331,
        'G', 334,
        'K', 334,
        'M', 334,
        'g', 334,
        'k', 334,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(79);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 80:
      ADVANCE_MAP(
        '%', 312,
        'm', 114,
        's', 308,
        'H', 128,
        'h', 128,
        'n', 115,
        'u', 115,
        'G', 121,
        'K', 121,
        'M', 121,
        'g', 121,
        'k', 121,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 81:
      ADVANCE_MAP(
        '%', 179,
        '&', 100,
        '(', 149,
        ')', 151,
        '*', 101,
        '+', 102,
        ',', 214,
        '-', 103,
        '.', 88,
        '/', 177,
        '<', 97,
        '=', 156,
        '>', 108,
        '\\', 42,
        ']', 227,
        '^', 104,
        '|', 105,
        '\t', 346,
        ' ', 346,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 82:
      if (lookahead == '%') ADVANCE(125);
      if (lookahead == '&') ADVANCE(202);
      if (lookahead == '/') ADVANCE(174);
      if (lookahead == '\\') ADVANCE(42);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(346);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 83:
      if (lookahead == '&') ADVANCE(202);
      if (lookahead == '\\') ADVANCE(42);
      if (lookahead == '`') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(304);
      END_STATE();
    case 84:
      if (lookahead == '&') ADVANCE(202);
      if (lookahead == '\\') ADVANCE(42);
      if (lookahead == '`') ADVANCE(145);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(305);
      END_STATE();
    case 85:
      ADVANCE_MAP(
        '&', 203,
        '(', 149,
        ')', 151,
        ':', 91,
        '=', 156,
        'B', 327,
        '\\', 42,
        '\t', 346,
        ' ', 346,
        'V', 324,
        'v', 324,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 86:
      ADVANCE_MAP(
        '(', 149,
        '/', 89,
        ';', 44,
        '\\', 42,
        '\t', 351,
        ' ', 351,
        'L', 222,
        'l', 222,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 87:
      if (lookahead == ',') ADVANCE(257);
      if (lookahead == ';') ADVANCE(259);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(87);
      END_STATE();
    case 88:
      if (lookahead == '.') ADVANCE(200);
      END_STATE();
    case 89:
      if (lookahead == '/') ADVANCE(44);
      END_STATE();
    case 90:
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(90);
      END_STATE();
    case 91:
      if (lookahead == ':') ADVANCE(109);
      END_STATE();
    case 92:
      if (lookahead == ':') ADVANCE(208);
      END_STATE();
    case 93:
      if (lookahead == ':') ADVANCE(142);
      END_STATE();
    case 94:
      if (lookahead == ':') ADVANCE(92);
      END_STATE();
    case 95:
      if (lookahead == ':') ADVANCE(210);
      END_STATE();
    case 96:
      if (lookahead == ':') ADVANCE(143);
      END_STATE();
    case 97:
      if (lookahead == '<') ADVANCE(106);
      END_STATE();
    case 98:
      if (lookahead == '=') ADVANCE(187);
      END_STATE();
    case 99:
      if (lookahead == '=') ADVANCE(186);
      END_STATE();
    case 100:
      if (lookahead == '=') ADVANCE(235);
      END_STATE();
    case 101:
      if (lookahead == '=') ADVANCE(228);
      END_STATE();
    case 102:
      if (lookahead == '=') ADVANCE(231);
      END_STATE();
    case 103:
      if (lookahead == '=') ADVANCE(232);
      END_STATE();
    case 104:
      if (lookahead == '=') ADVANCE(236);
      END_STATE();
    case 105:
      if (lookahead == '=') ADVANCE(237);
      END_STATE();
    case 106:
      if (lookahead == '=') ADVANCE(233);
      END_STATE();
    case 107:
      if (lookahead == '=') ADVANCE(234);
      END_STATE();
    case 108:
      if (lookahead == '>') ADVANCE(107);
      END_STATE();
    case 109:
      if (lookahead == 'B') ADVANCE(94);
      END_STATE();
    case 110:
      if (lookahead == '\\') ADVANCE(130);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(283);
      END_STATE();
    case 111:
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(280);
      END_STATE();
    case 112:
      if (lookahead == '\\') ADVANCE(246);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(243);
      END_STATE();
    case 113:
      if (lookahead == '`') ADVANCE(286);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(113);
      END_STATE();
    case 114:
      ADVANCE_MAP(
        'm', 114,
        's', 308,
        'H', 128,
        'h', 128,
        'n', 115,
        'u', 115,
        'G', 121,
        'K', 121,
        'M', 121,
        'g', 121,
        'k', 121,
      );
      END_STATE();
    case 115:
      if (lookahead == 's') ADVANCE(308);
      if (lookahead == 'm' ||
          lookahead == 'n' ||
          lookahead == 'u') ADVANCE(115);
      END_STATE();
    case 116:
      if (lookahead == 'y') ADVANCE(132);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(133);
      END_STATE();
    case 117:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(131);
      END_STATE();
    case 118:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 119:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(211);
      END_STATE();
    case 120:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(122);
      END_STATE();
    case 121:
      ADVANCE_MAP(
        'H', 128,
        'h', 128,
        'G', 121,
        'K', 121,
        'M', 121,
        'g', 121,
        'k', 121,
        'm', 121,
      );
      END_STATE();
    case 122:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(124);
      END_STATE();
    case 123:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(126);
      END_STATE();
    case 124:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(118);
      END_STATE();
    case 125:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(123);
      END_STATE();
    case 126:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(119);
      END_STATE();
    case 127:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(120);
      END_STATE();
    case 128:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(310);
      END_STATE();
    case 129:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 130:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      END_STATE();
    case 131:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 132:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(266);
      END_STATE();
    case 133:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(269);
      END_STATE();
    case 134:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(254);
      END_STATE();
    case 135:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(134);
      END_STATE();
    case 136:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(135);
      END_STATE();
    case 137:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(136);
      END_STATE();
    case 138:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(137);
      END_STATE();
    case 139:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(138);
      END_STATE();
    case 140:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(139);
      END_STATE();
    case 141:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(140);
      END_STATE();
    case 142:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(306);
      END_STATE();
    case 143:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(304);
      END_STATE();
    case 144:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(307);
      END_STATE();
    case 145:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(113);
      END_STATE();
    case 146:
      if (eof) ADVANCE(147);
      ADVANCE_MAP(
        '\n', 344,
        '\r', 1,
        '%', 178,
        '&', 203,
        '\'', 242,
        '(', 149,
        ')', 151,
        ',', 214,
        '.', 212,
        '/', 175,
        ':', 91,
        ';', 44,
        '=', 156,
        'B', 327,
        '\\', 43,
        ']', 227,
        '}', 154,
        '\t', 349,
        ' ', 349,
        'V', 324,
        'v', 324,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(aux_sym_block_token1);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(aux_sym_block_token1);
      if (lookahead == '&') ADVANCE(150);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(aux_sym_block_token1);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(148);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(aux_sym_while_block_token2);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(186);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(168);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(168);
      if (lookahead == '=') ADVANCE(231);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(169);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(169);
      if (lookahead == '=') ADVANCE(232);
      if (lookahead == '>') ADVANCE(225);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(169);
      if (lookahead == '>') ADVANCE(225);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(187);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_CARET_CARET);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(228);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(44);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(44);
      if (lookahead == '=') ADVANCE(229);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '=') ADVANCE(229);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(230);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(237);
      if (lookahead == '|') ADVANCE(171);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(171);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(236);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '^') ADVANCE(170);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(191);
      if (lookahead == '>') ADVANCE(198);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(191);
      if (lookahead == '>') ADVANCE(199);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(196);
      if (lookahead == '=') ADVANCE(192);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(197);
      if (lookahead == '=') ADVANCE(192);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(233);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(234);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(201);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(201);
      if (lookahead == '=') ADVANCE(235);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(261);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(262);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(aux_sym_macro_definition_token1);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(aux_sym_macro_definition_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(306);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(aux_sym_macro_definition_token1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(304);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token4);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(200);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '\n') ADVANCE(342);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (lookahead == '/') ADVANCE(44);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(129);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym__host_command_argument_list_default_format_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(221);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token1);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(333);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(344);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(40);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym_hll_char_literal_token1);
      if (lookahead == '\n') ADVANCE(254);
      if (lookahead == '\r') ADVANCE(254);
      if (lookahead == 'U') ADVANCE(141);
      if (lookahead == 'u') ADVANCE(137);
      if (lookahead == 'x') ADVANCE(135);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(256);
      if (lookahead != 0) ADVANCE(254);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(277);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(aux_sym_hll_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(253);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(254);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(sym_hll_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(255);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token1);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(257);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token2);
      if (lookahead == '\n') ADVANCE(342);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(258);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(aux_sym__hll_expression_separator_token2);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(259);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(anon_sym_COLON_COLON_COLON);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == ':') ADVANCE(260);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      if (lookahead == ':') ADVANCE(260);
      if (lookahead == 'B') ADVANCE(94);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_access_class);
      if (lookahead == ':') ADVANCE(209);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_access_class);
      if (lookahead == ':') ADVANCE(142);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(aux_sym_integer_token1);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(272);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(265);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(aux_sym_integer_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(266);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(267);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(268);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(aux_sym_integer_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(269);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_float);
      ADVANCE_MAP(
        '%', 312,
        'e', 117,
        'm', 114,
        's', 308,
        'H', 128,
        'h', 128,
        'n', 115,
        'u', 115,
        'G', 121,
        'K', 121,
        'M', 121,
        'g', 121,
        'k', 121,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(270);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(sym_float);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(271);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_bitmask_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == 'X' ||
          lookahead == 'x') ADVANCE(272);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(aux_sym_bitmask_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          lookahead == 'X' ||
          ('a' <= lookahead && lookahead <= 'f') ||
          lookahead == 'x') ADVANCE(273);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '\n') ADVANCE(276);
      if (lookahead == '\r') ADVANCE(275);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(276);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead == '\n') ADVANCE(276);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(276);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_string_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '&') ADVANCE(276);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_string_token2);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(aux_sym_character_token1);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(aux_sym_character_token1);
      if (lookahead == '\n') ADVANCE(345);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(aux_sym_character_token2);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(aux_sym_character_token2);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(279);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(278);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(sym__line_specifier);
      if (lookahead == '\\') ADVANCE(110);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(282);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(sym__line_specifier);
      if (lookahead == '\\') ADVANCE(130);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(283);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(sym__line_specifier);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(284);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(anon_sym_BSLASH_BSLASH_BSLASH);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(aux_sym_symbol_token1);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == ':') ADVANCE(96);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(293);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == ':') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(295);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == '.') ADVANCE(127);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == ':') ADVANCE(95);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == ':') ADVANCE(96);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == ':') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(294);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(296);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(aux_sym_symbol_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(297);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(anon_sym_BSLASH_BSLASH);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(anon_sym_BSLASH_BSLASH);
      if (lookahead == '\\') ADVANCE(285);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      if (lookahead == '\\') ADVANCE(299);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      if (lookahead == '\\') ADVANCE(298);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(282);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      if (lookahead == '\n') ADVANCE(345);
      if (lookahead == '\r') ADVANCE(41);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(282);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(aux_sym_symbol_token3);
      if (lookahead == ':') ADVANCE(96);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(304);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(aux_sym_symbol_token4);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(305);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(aux_sym_symbol_token5);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(306);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(sym__composed_name);
      if (lookahead == '-') ADVANCE(144);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(307);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(sym_time);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(sym_time);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(sym_frequency);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(sym_frequency);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(sym_percentage);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(anon_sym_POUND);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(aux_sym_file_handle_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(314);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(aux_sym_file_handle_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(315);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(247);
      if (lookahead == '\'') ADVANCE(238);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(249);
      if (lookahead == '\'') ADVANCE(240);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(248);
      if (lookahead == '\'') ADVANCE(239);
      if (lookahead == '8') ADVANCE(319);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(250);
      if (lookahead == '\'') ADVANCE(241);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(144);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == ':') ADVANCE(264);
      if (lookahead == '_') ADVANCE(329);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(144);
      if (lookahead == ':') ADVANCE(264);
      if (lookahead == '_') ADVANCE(329);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(320);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '-') ADVANCE(144);
      if (lookahead == ':') ADVANCE(264);
      if (lookahead == '_') ADVANCE(329);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == ':') ADVANCE(264);
      if (lookahead == '_') ADVANCE(329);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(321);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(127);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(336);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(127);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(263);
      if (lookahead == '_') ADVANCE(329);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(264);
      if (lookahead == '_') ADVANCE(329);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(322);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == ':') ADVANCE(93);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(329);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'm', 330,
        's', 309,
        'H', 339,
        'h', 339,
        'n', 331,
        'u', 331,
        'G', 334,
        'K', 334,
        'M', 334,
        'g', 334,
        'k', 334,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(309);
      if (lookahead == 'm' ||
          lookahead == 'n' ||
          lookahead == 'u') ADVANCE(331);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(335);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(sym_identifier);
      ADVANCE_MAP(
        'H', 339,
        'h', 339,
        'G', 334,
        'K', 334,
        'M', 334,
        'g', 334,
        'k', 334,
        'm', 334,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(223);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(325);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(273);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(267);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(272);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(265);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(311);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Y') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'y')) ADVANCE(341);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(268);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(341);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(342);
      if (lookahead == '\\') ADVANCE(45);
      if (lookahead != 0) ADVANCE(44);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(sym__blank_line);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(sym__line_continuation);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(sym__blank);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == ',') ADVANCE(257);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(258);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(36);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '=') ADVANCE(221);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(37);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '\n') ADVANCE(344);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(38);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == ',') ADVANCE(257);
      if (lookahead == ';') ADVANCE(259);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(87);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(sym__blank);
      if (lookahead == '/') ADVANCE(89);
      if (lookahead == ';') ADVANCE(44);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(90);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'E', 1,
        'I', 2,
        'L', 3,
        'S', 4,
        'V', 5,
        'b', 6,
        'c', 7,
        'd', 8,
        'e', 9,
        'f', 10,
        'i', 11,
        'l', 12,
        's', 13,
        'u', 14,
        'v', 15,
        'A', 16,
        'a', 16,
        'G', 17,
        'g', 17,
        'N', 18,
        'n', 18,
        'O', 19,
        'o', 19,
        'P', 20,
        'p', 20,
        'R', 21,
        'r', 21,
        'T', 22,
        't', 22,
        'W', 23,
        'w', 23,
      );
      END_STATE();
    case 1:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(24);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(25);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(26);
      END_STATE();
    case 2:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 3:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(28);
      END_STATE();
    case 4:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(29);
      END_STATE();
    case 5:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 6:
      if (lookahead == 'o') ADVANCE(31);
      END_STATE();
    case 7:
      if (lookahead == 'h') ADVANCE(32);
      if (lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 8:
      if (lookahead == 'o') ADVANCE(34);
      END_STATE();
    case 9:
      if (lookahead == 'N') ADVANCE(25);
      if (lookahead == 'n') ADVANCE(35);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(24);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(26);
      END_STATE();
    case 10:
      if (lookahead == 'l') ADVANCE(36);
      END_STATE();
    case 11:
      if (lookahead == 'n') ADVANCE(37);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(27);
      END_STATE();
    case 12:
      if (lookahead == 'O') ADVANCE(28);
      if (lookahead == 'o') ADVANCE(38);
      END_STATE();
    case 13:
      if (lookahead == 'h') ADVANCE(39);
      if (lookahead == 'i') ADVANCE(40);
      if (lookahead == 's') ADVANCE(41);
      if (lookahead == 't') ADVANCE(42);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(29);
      END_STATE();
    case 14:
      if (lookahead == 'i') ADVANCE(43);
      if (lookahead == 'n') ADVANCE(44);
      END_STATE();
    case 15:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      if (lookahead == 'o') ADVANCE(45);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(30);
      END_STATE();
    case 16:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(46);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(47);
      END_STATE();
    case 17:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(48);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(49);
      END_STATE();
    case 18:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 19:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(51);
      END_STATE();
    case 20:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(52);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(53);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token2);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(54);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(55);
      END_STATE();
    case 22:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(56);
      END_STATE();
    case 23:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(57);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 24:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(59);
      END_STATE();
    case 25:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(60);
      END_STATE();
    case 26:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(61);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(aux_sym_if_block_token1);
      END_STATE();
    case 28:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(62);
      END_STATE();
    case 29:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(63);
      END_STATE();
    case 30:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(64);
      END_STATE();
    case 31:
      if (lookahead == 'o') ADVANCE(65);
      END_STATE();
    case 32:
      if (lookahead == 'a') ADVANCE(66);
      END_STATE();
    case 33:
      if (lookahead == 'n') ADVANCE(67);
      END_STATE();
    case 34:
      if (lookahead == 'u') ADVANCE(68);
      END_STATE();
    case 35:
      if (lookahead == 'u') ADVANCE(69);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(60);
      END_STATE();
    case 36:
      if (lookahead == 'o') ADVANCE(70);
      END_STATE();
    case 37:
      if (lookahead == 't') ADVANCE(71);
      END_STATE();
    case 38:
      if (lookahead == 'n') ADVANCE(72);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(62);
      END_STATE();
    case 39:
      if (lookahead == 'o') ADVANCE(73);
      END_STATE();
    case 40:
      if (lookahead == 'g') ADVANCE(74);
      if (lookahead == 'z') ADVANCE(75);
      END_STATE();
    case 41:
      if (lookahead == 'i') ADVANCE(76);
      END_STATE();
    case 42:
      if (lookahead == 'r') ADVANCE(77);
      END_STATE();
    case 43:
      if (lookahead == 'n') ADVANCE(78);
      END_STATE();
    case 44:
      if (lookahead == 'i') ADVANCE(79);
      if (lookahead == 's') ADVANCE(80);
      END_STATE();
    case 45:
      if (lookahead == 'i') ADVANCE(81);
      if (lookahead == 'l') ADVANCE(82);
      END_STATE();
    case 46:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(83);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token2);
      END_STATE();
    case 48:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(84);
      END_STATE();
    case 49:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(85);
      END_STATE();
    case 50:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(86);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(aux_sym__host_command_with_default_format_token1);
      END_STATE();
    case 52:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(87);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(88);
      END_STATE();
    case 53:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(89);
      END_STATE();
    case 54:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(90);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(91);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(92);
      END_STATE();
    case 55:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(93);
      END_STATE();
    case 56:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(94);
      END_STATE();
    case 57:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(95);
      END_STATE();
    case 58:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(96);
      END_STATE();
    case 59:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(97);
      END_STATE();
    case 60:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(98);
      END_STATE();
    case 61:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(99);
      END_STATE();
    case 62:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(100);
      END_STATE();
    case 63:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(101);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token1);
      END_STATE();
    case 65:
      if (lookahead == 'l') ADVANCE(102);
      END_STATE();
    case 66:
      if (lookahead == 'r') ADVANCE(103);
      END_STATE();
    case 67:
      if (lookahead == 's') ADVANCE(104);
      END_STATE();
    case 68:
      if (lookahead == 'b') ADVANCE(105);
      END_STATE();
    case 69:
      if (lookahead == 'm') ADVANCE(106);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(107);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      if (lookahead == '1') ADVANCE(108);
      if (lookahead == '3') ADVANCE(109);
      if (lookahead == '6') ADVANCE(110);
      if (lookahead == '8') ADVANCE(111);
      if (lookahead == 'p') ADVANCE(112);
      END_STATE();
    case 72:
      if (lookahead == 'g') ADVANCE(113);
      END_STATE();
    case 73:
      if (lookahead == 'r') ADVANCE(114);
      END_STATE();
    case 74:
      if (lookahead == 'n') ADVANCE(115);
      END_STATE();
    case 75:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 76:
      if (lookahead == 'z') ADVANCE(117);
      END_STATE();
    case 77:
      if (lookahead == 'u') ADVANCE(118);
      END_STATE();
    case 78:
      if (lookahead == 't') ADVANCE(119);
      END_STATE();
    case 79:
      if (lookahead == 'o') ADVANCE(120);
      END_STATE();
    case 80:
      if (lookahead == 'i') ADVANCE(121);
      END_STATE();
    case 81:
      if (lookahead == 'd') ADVANCE(102);
      END_STATE();
    case 82:
      if (lookahead == 'a') ADVANCE(122);
      END_STATE();
    case 83:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 84:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(124);
      END_STATE();
    case 85:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(125);
      END_STATE();
    case 86:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(126);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 87:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(128);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token5);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(129);
      END_STATE();
    case 89:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(130);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token2);
      END_STATE();
    case 91:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 92:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(132);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(aux_sym__repeat_block_pre_condition_format_token1);
      END_STATE();
    case 94:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(133);
      END_STATE();
    case 95:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(134);
      END_STATE();
    case 96:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(135);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(aux_sym_elif_block_token1);
      END_STATE();
    case 98:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(136);
      END_STATE();
    case 99:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(137);
      END_STATE();
    case 100:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(138);
      END_STATE();
    case 101:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(139);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(sym_hll_primitive_type);
      if (lookahead == '1') ADVANCE(140);
      if (lookahead == '3') ADVANCE(141);
      if (lookahead == '6') ADVANCE(142);
      if (lookahead == '8') ADVANCE(143);
      if (lookahead == 'p') ADVANCE(144);
      END_STATE();
    case 104:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 105:
      if (lookahead == 'l') ADVANCE(146);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 107:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 108:
      if (lookahead == '6') ADVANCE(147);
      END_STATE();
    case 109:
      if (lookahead == '2') ADVANCE(148);
      END_STATE();
    case 110:
      if (lookahead == '4') ADVANCE(149);
      END_STATE();
    case 111:
      if (lookahead == '_') ADVANCE(150);
      END_STATE();
    case 112:
      if (lookahead == 't') ADVANCE(151);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 114:
      if (lookahead == 't') ADVANCE(152);
      END_STATE();
    case 115:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 116:
      if (lookahead == '_') ADVANCE(154);
      if (lookahead == 'o') ADVANCE(155);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 118:
      if (lookahead == 'c') ADVANCE(157);
      END_STATE();
    case 119:
      if (lookahead == '1') ADVANCE(158);
      if (lookahead == '3') ADVANCE(159);
      if (lookahead == '6') ADVANCE(160);
      if (lookahead == '8') ADVANCE(161);
      if (lookahead == 'p') ADVANCE(162);
      END_STATE();
    case 120:
      if (lookahead == 'n') ADVANCE(163);
      END_STATE();
    case 121:
      if (lookahead == 'g') ADVANCE(164);
      END_STATE();
    case 122:
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 123:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(166);
      END_STATE();
    case 124:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(167);
      END_STATE();
    case 125:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(168);
      END_STATE();
    case 126:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(169);
      END_STATE();
    case 127:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(170);
      END_STATE();
    case 128:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(171);
      END_STATE();
    case 129:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(172);
      END_STATE();
    case 130:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(173);
      END_STATE();
    case 131:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(174);
      END_STATE();
    case 132:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(175);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(aux_sym__var_command_with_non_hll_format_token3);
      END_STATE();
    case 134:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(176);
      END_STATE();
    case 135:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(177);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token3);
      END_STATE();
    case 137:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(178);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token2);
      END_STATE();
    case 139:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(179);
      END_STATE();
    case 140:
      if (lookahead == '6') ADVANCE(180);
      END_STATE();
    case 141:
      if (lookahead == '2') ADVANCE(181);
      END_STATE();
    case 142:
      if (lookahead == '4') ADVANCE(182);
      END_STATE();
    case 143:
      if (lookahead == '_') ADVANCE(183);
      END_STATE();
    case 144:
      if (lookahead == 't') ADVANCE(184);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 147:
      if (lookahead == '_') ADVANCE(185);
      END_STATE();
    case 148:
      if (lookahead == '_') ADVANCE(186);
      END_STATE();
    case 149:
      if (lookahead == '_') ADVANCE(187);
      END_STATE();
    case 150:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 151:
      if (lookahead == 'r') ADVANCE(188);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 153:
      if (lookahead == 'd') ADVANCE(189);
      END_STATE();
    case 154:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 155:
      if (lookahead == 'f') ADVANCE(190);
      END_STATE();
    case 156:
      if (lookahead == '_') ADVANCE(191);
      END_STATE();
    case 157:
      if (lookahead == 't') ADVANCE(192);
      END_STATE();
    case 158:
      if (lookahead == '6') ADVANCE(193);
      END_STATE();
    case 159:
      if (lookahead == '2') ADVANCE(194);
      END_STATE();
    case 160:
      if (lookahead == '4') ADVANCE(195);
      END_STATE();
    case 161:
      if (lookahead == '_') ADVANCE(196);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 164:
      if (lookahead == 'n') ADVANCE(198);
      END_STATE();
    case 165:
      if (lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 166:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(200);
      END_STATE();
    case 167:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(201);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(aux_sym_subroutine_call_expression_token1);
      END_STATE();
    case 169:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(202);
      END_STATE();
    case 170:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(203);
      END_STATE();
    case 171:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(204);
      END_STATE();
    case 172:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(205);
      END_STATE();
    case 173:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(206);
      END_STATE();
    case 174:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(93);
      END_STATE();
    case 175:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(207);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(aux_sym_while_block_token1);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token4);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token3);
      END_STATE();
    case 179:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(208);
      END_STATE();
    case 180:
      if (lookahead == '_') ADVANCE(209);
      END_STATE();
    case 181:
      if (lookahead == '_') ADVANCE(210);
      END_STATE();
    case 182:
      if (lookahead == '_') ADVANCE(211);
      END_STATE();
    case 183:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 185:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 186:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 187:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 188:
      if (lookahead == '_') ADVANCE(213);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_signed);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 191:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 193:
      if (lookahead == '_') ADVANCE(214);
      END_STATE();
    case 194:
      if (lookahead == '_') ADVANCE(215);
      END_STATE();
    case 195:
      if (lookahead == '_') ADVANCE(216);
      END_STATE();
    case 196:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 197:
      if (lookahead == 'r') ADVANCE(217);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(218);
      END_STATE();
    case 199:
      if (lookahead == 'l') ADVANCE(219);
      END_STATE();
    case 200:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(220);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token1);
      END_STATE();
    case 202:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(221);
      END_STATE();
    case 203:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(222);
      END_STATE();
    case 204:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(223);
      END_STATE();
    case 205:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(224);
      END_STATE();
    case 206:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(225);
      END_STATE();
    case 207:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(226);
      END_STATE();
    case 208:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(227);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 210:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 212:
      if (lookahead == '_') ADVANCE(228);
      END_STATE();
    case 213:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 215:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 216:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 217:
      if (lookahead == '_') ADVANCE(229);
      END_STATE();
    case 218:
      if (lookahead == 'd') ADVANCE(230);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 220:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(232);
      END_STATE();
    case 221:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(233);
      END_STATE();
    case 222:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(234);
      END_STATE();
    case 223:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(aux_sym__hll_non_default_format_var_command_token5);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(aux_sym_macro_definition_command_token3);
      END_STATE();
    case 226:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(236);
      END_STATE();
    case 227:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(237);
      END_STATE();
    case 228:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 229:
      if (lookahead == 't') ADVANCE(102);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 232:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 233:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(239);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_expression_token1);
      END_STATE();
    case 235:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(240);
      END_STATE();
    case 236:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(241);
      END_STATE();
    case 237:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 238:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(47);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym__hll_var_definition_command_expression_token2);
      END_STATE();
    case 240:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(243);
      END_STATE();
    case 241:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(244);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym_subroutine_block_token1);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token1);
      END_STATE();
    case 244:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 245:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(246);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym_parameter_declaration_token2);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 146, .external_lex_state = 2},
  [2] = {.lex_state = 3, .external_lex_state = 3},
  [3] = {.lex_state = 3, .external_lex_state = 3},
  [4] = {.lex_state = 2, .external_lex_state = 4},
  [5] = {.lex_state = 49, .external_lex_state = 4},
  [6] = {.lex_state = 49, .external_lex_state = 4},
  [7] = {.lex_state = 2, .external_lex_state = 4},
  [8] = {.lex_state = 49, .external_lex_state = 4},
  [9] = {.lex_state = 17, .external_lex_state = 5},
  [10] = {.lex_state = 17, .external_lex_state = 5},
  [11] = {.lex_state = 52, .external_lex_state = 6},
  [12] = {.lex_state = 52, .external_lex_state = 6},
  [13] = {.lex_state = 52, .external_lex_state = 6},
  [14] = {.lex_state = 52, .external_lex_state = 6},
  [15] = {.lex_state = 17, .external_lex_state = 5},
  [16] = {.lex_state = 17, .external_lex_state = 5},
  [17] = {.lex_state = 6, .external_lex_state = 6},
  [18] = {.lex_state = 6, .external_lex_state = 6},
  [19] = {.lex_state = 6, .external_lex_state = 6},
  [20] = {.lex_state = 6, .external_lex_state = 6},
  [21] = {.lex_state = 2, .external_lex_state = 7},
  [22] = {.lex_state = 7, .external_lex_state = 6},
  [23] = {.lex_state = 7, .external_lex_state = 6},
  [24] = {.lex_state = 7, .external_lex_state = 6},
  [25] = {.lex_state = 7, .external_lex_state = 6},
  [26] = {.lex_state = 53, .external_lex_state = 6},
  [27] = {.lex_state = 53, .external_lex_state = 6},
  [28] = {.lex_state = 53, .external_lex_state = 6},
  [29] = {.lex_state = 53, .external_lex_state = 6},
  [30] = {.lex_state = 49, .external_lex_state = 7},
  [31] = {.lex_state = 49, .external_lex_state = 7},
  [32] = {.lex_state = 2, .external_lex_state = 7},
  [33] = {.lex_state = 2, .external_lex_state = 7},
  [34] = {.lex_state = 49, .external_lex_state = 7},
  [35] = {.lex_state = 49, .external_lex_state = 7},
  [36] = {.lex_state = 48, .external_lex_state = 8},
  [37] = {.lex_state = 48, .external_lex_state = 8},
  [38] = {.lex_state = 48, .external_lex_state = 8},
  [39] = {.lex_state = 48, .external_lex_state = 8},
  [40] = {.lex_state = 48, .external_lex_state = 8},
  [41] = {.lex_state = 48, .external_lex_state = 8},
  [42] = {.lex_state = 48, .external_lex_state = 8},
  [43] = {.lex_state = 4, .external_lex_state = 6},
  [44] = {.lex_state = 4, .external_lex_state = 6},
  [45] = {.lex_state = 4, .external_lex_state = 6},
  [46] = {.lex_state = 4, .external_lex_state = 6},
  [47] = {.lex_state = 50, .external_lex_state = 6},
  [48] = {.lex_state = 50, .external_lex_state = 6},
  [49] = {.lex_state = 50, .external_lex_state = 6},
  [50] = {.lex_state = 50, .external_lex_state = 6},
  [51] = {.lex_state = 48, .external_lex_state = 8},
  [52] = {.lex_state = 48, .external_lex_state = 8},
  [53] = {.lex_state = 48, .external_lex_state = 8},
  [54] = {.lex_state = 48, .external_lex_state = 8},
  [55] = {.lex_state = 48, .external_lex_state = 8},
  [56] = {.lex_state = 48, .external_lex_state = 8},
  [57] = {.lex_state = 48, .external_lex_state = 8},
  [58] = {.lex_state = 48, .external_lex_state = 8},
  [59] = {.lex_state = 48, .external_lex_state = 8},
  [60] = {.lex_state = 48, .external_lex_state = 8},
  [61] = {.lex_state = 48, .external_lex_state = 8},
  [62] = {.lex_state = 48, .external_lex_state = 8},
  [63] = {.lex_state = 48, .external_lex_state = 8},
  [64] = {.lex_state = 48, .external_lex_state = 8},
  [65] = {.lex_state = 48, .external_lex_state = 8},
  [66] = {.lex_state = 48, .external_lex_state = 8},
  [67] = {.lex_state = 48, .external_lex_state = 8},
  [68] = {.lex_state = 48, .external_lex_state = 8},
  [69] = {.lex_state = 48, .external_lex_state = 8},
  [70] = {.lex_state = 48, .external_lex_state = 8},
  [71] = {.lex_state = 48, .external_lex_state = 8},
  [72] = {.lex_state = 48, .external_lex_state = 8},
  [73] = {.lex_state = 48, .external_lex_state = 8},
  [74] = {.lex_state = 48, .external_lex_state = 8},
  [75] = {.lex_state = 48, .external_lex_state = 8},
  [76] = {.lex_state = 48, .external_lex_state = 8},
  [77] = {.lex_state = 48, .external_lex_state = 8},
  [78] = {.lex_state = 48, .external_lex_state = 8},
  [79] = {.lex_state = 48, .external_lex_state = 8},
  [80] = {.lex_state = 48, .external_lex_state = 8},
  [81] = {.lex_state = 48, .external_lex_state = 8},
  [82] = {.lex_state = 48, .external_lex_state = 8},
  [83] = {.lex_state = 48, .external_lex_state = 8},
  [84] = {.lex_state = 48, .external_lex_state = 8},
  [85] = {.lex_state = 48, .external_lex_state = 8},
  [86] = {.lex_state = 48, .external_lex_state = 8},
  [87] = {.lex_state = 48, .external_lex_state = 8},
  [88] = {.lex_state = 48, .external_lex_state = 8},
  [89] = {.lex_state = 48, .external_lex_state = 8},
  [90] = {.lex_state = 48, .external_lex_state = 8},
  [91] = {.lex_state = 48, .external_lex_state = 8},
  [92] = {.lex_state = 48, .external_lex_state = 8},
  [93] = {.lex_state = 49, .external_lex_state = 7},
  [94] = {.lex_state = 49, .external_lex_state = 7},
  [95] = {.lex_state = 49, .external_lex_state = 7},
  [96] = {.lex_state = 49, .external_lex_state = 7},
  [97] = {.lex_state = 49, .external_lex_state = 7},
  [98] = {.lex_state = 49, .external_lex_state = 7},
  [99] = {.lex_state = 49, .external_lex_state = 7},
  [100] = {.lex_state = 49, .external_lex_state = 7},
  [101] = {.lex_state = 49, .external_lex_state = 7},
  [102] = {.lex_state = 49, .external_lex_state = 7},
  [103] = {.lex_state = 49, .external_lex_state = 7},
  [104] = {.lex_state = 49, .external_lex_state = 7},
  [105] = {.lex_state = 49, .external_lex_state = 7},
  [106] = {.lex_state = 49, .external_lex_state = 7},
  [107] = {.lex_state = 49, .external_lex_state = 7},
  [108] = {.lex_state = 49, .external_lex_state = 7},
  [109] = {.lex_state = 49, .external_lex_state = 7},
  [110] = {.lex_state = 49, .external_lex_state = 7},
  [111] = {.lex_state = 49, .external_lex_state = 7},
  [112] = {.lex_state = 49, .external_lex_state = 7},
  [113] = {.lex_state = 49, .external_lex_state = 7},
  [114] = {.lex_state = 49, .external_lex_state = 7},
  [115] = {.lex_state = 49, .external_lex_state = 7},
  [116] = {.lex_state = 49, .external_lex_state = 7},
  [117] = {.lex_state = 49, .external_lex_state = 7},
  [118] = {.lex_state = 49, .external_lex_state = 7},
  [119] = {.lex_state = 49, .external_lex_state = 7},
  [120] = {.lex_state = 49, .external_lex_state = 7},
  [121] = {.lex_state = 49, .external_lex_state = 7},
  [122] = {.lex_state = 49, .external_lex_state = 7},
  [123] = {.lex_state = 49, .external_lex_state = 7},
  [124] = {.lex_state = 49, .external_lex_state = 7},
  [125] = {.lex_state = 49, .external_lex_state = 7},
  [126] = {.lex_state = 49, .external_lex_state = 7},
  [127] = {.lex_state = 49, .external_lex_state = 7},
  [128] = {.lex_state = 49, .external_lex_state = 7},
  [129] = {.lex_state = 49, .external_lex_state = 7},
  [130] = {.lex_state = 49, .external_lex_state = 7},
  [131] = {.lex_state = 49, .external_lex_state = 7},
  [132] = {.lex_state = 49, .external_lex_state = 7},
  [133] = {.lex_state = 49, .external_lex_state = 7},
  [134] = {.lex_state = 51, .external_lex_state = 6},
  [135] = {.lex_state = 51, .external_lex_state = 6},
  [136] = {.lex_state = 51, .external_lex_state = 6},
  [137] = {.lex_state = 4, .external_lex_state = 6},
  [138] = {.lex_state = 4, .external_lex_state = 6},
  [139] = {.lex_state = 4, .external_lex_state = 6},
  [140] = {.lex_state = 4, .external_lex_state = 6},
  [141] = {.lex_state = 2, .external_lex_state = 7},
  [142] = {.lex_state = 2, .external_lex_state = 7},
  [143] = {.lex_state = 5, .external_lex_state = 6},
  [144] = {.lex_state = 5, .external_lex_state = 6},
  [145] = {.lex_state = 5, .external_lex_state = 6},
  [146] = {.lex_state = 5, .external_lex_state = 6},
  [147] = {.lex_state = 2, .external_lex_state = 7},
  [148] = {.lex_state = 2, .external_lex_state = 7},
  [149] = {.lex_state = 2, .external_lex_state = 7},
  [150] = {.lex_state = 51, .external_lex_state = 6},
  [151] = {.lex_state = 2, .external_lex_state = 7},
  [152] = {.lex_state = 2, .external_lex_state = 7},
  [153] = {.lex_state = 2, .external_lex_state = 7},
  [154] = {.lex_state = 2, .external_lex_state = 7},
  [155] = {.lex_state = 2, .external_lex_state = 7},
  [156] = {.lex_state = 2, .external_lex_state = 7},
  [157] = {.lex_state = 2, .external_lex_state = 7},
  [158] = {.lex_state = 2, .external_lex_state = 7},
  [159] = {.lex_state = 2, .external_lex_state = 7},
  [160] = {.lex_state = 2, .external_lex_state = 7},
  [161] = {.lex_state = 2, .external_lex_state = 7},
  [162] = {.lex_state = 2, .external_lex_state = 7},
  [163] = {.lex_state = 2, .external_lex_state = 7},
  [164] = {.lex_state = 2, .external_lex_state = 7},
  [165] = {.lex_state = 2, .external_lex_state = 7},
  [166] = {.lex_state = 2, .external_lex_state = 7},
  [167] = {.lex_state = 2, .external_lex_state = 7},
  [168] = {.lex_state = 2, .external_lex_state = 7},
  [169] = {.lex_state = 2, .external_lex_state = 7},
  [170] = {.lex_state = 2, .external_lex_state = 7},
  [171] = {.lex_state = 2, .external_lex_state = 7},
  [172] = {.lex_state = 2, .external_lex_state = 7},
  [173] = {.lex_state = 2, .external_lex_state = 7},
  [174] = {.lex_state = 2, .external_lex_state = 7},
  [175] = {.lex_state = 2, .external_lex_state = 7},
  [176] = {.lex_state = 2, .external_lex_state = 7},
  [177] = {.lex_state = 2, .external_lex_state = 7},
  [178] = {.lex_state = 2, .external_lex_state = 7},
  [179] = {.lex_state = 2, .external_lex_state = 7},
  [180] = {.lex_state = 2, .external_lex_state = 7},
  [181] = {.lex_state = 2, .external_lex_state = 7},
  [182] = {.lex_state = 2, .external_lex_state = 7},
  [183] = {.lex_state = 2, .external_lex_state = 7},
  [184] = {.lex_state = 4, .external_lex_state = 6},
  [185] = {.lex_state = 4, .external_lex_state = 6},
  [186] = {.lex_state = 2, .external_lex_state = 7},
  [187] = {.lex_state = 2, .external_lex_state = 7},
  [188] = {.lex_state = 2, .external_lex_state = 7},
  [189] = {.lex_state = 2, .external_lex_state = 7},
  [190] = {.lex_state = 2, .external_lex_state = 7},
  [191] = {.lex_state = 2, .external_lex_state = 7},
  [192] = {.lex_state = 2, .external_lex_state = 7},
  [193] = {.lex_state = 2, .external_lex_state = 7},
  [194] = {.lex_state = 2, .external_lex_state = 7},
  [195] = {.lex_state = 2, .external_lex_state = 7},
  [196] = {.lex_state = 2, .external_lex_state = 7},
  [197] = {.lex_state = 2, .external_lex_state = 7},
  [198] = {.lex_state = 2, .external_lex_state = 7},
  [199] = {.lex_state = 2, .external_lex_state = 7},
  [200] = {.lex_state = 2, .external_lex_state = 7},
  [201] = {.lex_state = 2, .external_lex_state = 7},
  [202] = {.lex_state = 2, .external_lex_state = 7},
  [203] = {.lex_state = 2, .external_lex_state = 7},
  [204] = {.lex_state = 4, .external_lex_state = 6},
  [205] = {.lex_state = 2, .external_lex_state = 7},
  [206] = {.lex_state = 2, .external_lex_state = 7},
  [207] = {.lex_state = 2, .external_lex_state = 7},
  [208] = {.lex_state = 2, .external_lex_state = 7},
  [209] = {.lex_state = 2, .external_lex_state = 7},
  [210] = {.lex_state = 2, .external_lex_state = 7},
  [211] = {.lex_state = 2, .external_lex_state = 7},
  [212] = {.lex_state = 2, .external_lex_state = 7},
  [213] = {.lex_state = 2, .external_lex_state = 7},
  [214] = {.lex_state = 2, .external_lex_state = 7},
  [215] = {.lex_state = 2, .external_lex_state = 7},
  [216] = {.lex_state = 2, .external_lex_state = 7},
  [217] = {.lex_state = 2, .external_lex_state = 7},
  [218] = {.lex_state = 2, .external_lex_state = 7},
  [219] = {.lex_state = 2, .external_lex_state = 7},
  [220] = {.lex_state = 2, .external_lex_state = 7},
  [221] = {.lex_state = 2, .external_lex_state = 7},
  [222] = {.lex_state = 2, .external_lex_state = 7},
  [223] = {.lex_state = 2, .external_lex_state = 7},
  [224] = {.lex_state = 2, .external_lex_state = 7},
  [225] = {.lex_state = 2, .external_lex_state = 7},
  [226] = {.lex_state = 2, .external_lex_state = 7},
  [227] = {.lex_state = 2, .external_lex_state = 7},
  [228] = {.lex_state = 2, .external_lex_state = 7},
  [229] = {.lex_state = 2, .external_lex_state = 7},
  [230] = {.lex_state = 2, .external_lex_state = 7},
  [231] = {.lex_state = 2, .external_lex_state = 7},
  [232] = {.lex_state = 2, .external_lex_state = 7},
  [233] = {.lex_state = 2, .external_lex_state = 7},
  [234] = {.lex_state = 2, .external_lex_state = 7},
  [235] = {.lex_state = 2, .external_lex_state = 7},
  [236] = {.lex_state = 2, .external_lex_state = 7},
  [237] = {.lex_state = 2, .external_lex_state = 7},
  [238] = {.lex_state = 2, .external_lex_state = 7},
  [239] = {.lex_state = 2, .external_lex_state = 7},
  [240] = {.lex_state = 2, .external_lex_state = 7},
  [241] = {.lex_state = 2, .external_lex_state = 7},
  [242] = {.lex_state = 2, .external_lex_state = 7},
  [243] = {.lex_state = 51, .external_lex_state = 6},
  [244] = {.lex_state = 51, .external_lex_state = 6},
  [245] = {.lex_state = 51, .external_lex_state = 6},
  [246] = {.lex_state = 51, .external_lex_state = 6},
  [247] = {.lex_state = 4, .external_lex_state = 6},
  [248] = {.lex_state = 2, .external_lex_state = 7},
  [249] = {.lex_state = 2, .external_lex_state = 7},
  [250] = {.lex_state = 2, .external_lex_state = 7},
  [251] = {.lex_state = 2, .external_lex_state = 7},
  [252] = {.lex_state = 2, .external_lex_state = 7},
  [253] = {.lex_state = 2, .external_lex_state = 7},
  [254] = {.lex_state = 2, .external_lex_state = 7},
  [255] = {.lex_state = 2, .external_lex_state = 7},
  [256] = {.lex_state = 2, .external_lex_state = 7},
  [257] = {.lex_state = 146, .external_lex_state = 2},
  [258] = {.lex_state = 146, .external_lex_state = 2},
  [259] = {.lex_state = 146, .external_lex_state = 2},
  [260] = {.lex_state = 146, .external_lex_state = 2},
  [261] = {.lex_state = 146, .external_lex_state = 2},
  [262] = {.lex_state = 146, .external_lex_state = 2},
  [263] = {.lex_state = 146, .external_lex_state = 2},
  [264] = {.lex_state = 146, .external_lex_state = 2},
  [265] = {.lex_state = 146, .external_lex_state = 2},
  [266] = {.lex_state = 146, .external_lex_state = 2},
  [267] = {.lex_state = 146, .external_lex_state = 2},
  [268] = {.lex_state = 146, .external_lex_state = 2},
  [269] = {.lex_state = 146, .external_lex_state = 2},
  [270] = {.lex_state = 146, .external_lex_state = 2},
  [271] = {.lex_state = 146, .external_lex_state = 2},
  [272] = {.lex_state = 146, .external_lex_state = 2},
  [273] = {.lex_state = 146, .external_lex_state = 2},
  [274] = {.lex_state = 146, .external_lex_state = 2},
  [275] = {.lex_state = 146, .external_lex_state = 2},
  [276] = {.lex_state = 146, .external_lex_state = 2},
  [277] = {.lex_state = 146, .external_lex_state = 2},
  [278] = {.lex_state = 146, .external_lex_state = 2},
  [279] = {.lex_state = 146, .external_lex_state = 2},
  [280] = {.lex_state = 146, .external_lex_state = 2},
  [281] = {.lex_state = 146, .external_lex_state = 2},
  [282] = {.lex_state = 146, .external_lex_state = 2},
  [283] = {.lex_state = 146, .external_lex_state = 2},
  [284] = {.lex_state = 146, .external_lex_state = 2},
  [285] = {.lex_state = 146, .external_lex_state = 2},
  [286] = {.lex_state = 146, .external_lex_state = 2},
  [287] = {.lex_state = 146, .external_lex_state = 2},
  [288] = {.lex_state = 146, .external_lex_state = 2},
  [289] = {.lex_state = 146, .external_lex_state = 2},
  [290] = {.lex_state = 146, .external_lex_state = 2},
  [291] = {.lex_state = 146, .external_lex_state = 2},
  [292] = {.lex_state = 146, .external_lex_state = 2},
  [293] = {.lex_state = 146, .external_lex_state = 2},
  [294] = {.lex_state = 146, .external_lex_state = 2},
  [295] = {.lex_state = 146, .external_lex_state = 2},
  [296] = {.lex_state = 146, .external_lex_state = 2},
  [297] = {.lex_state = 146, .external_lex_state = 2},
  [298] = {.lex_state = 146, .external_lex_state = 2},
  [299] = {.lex_state = 146, .external_lex_state = 2},
  [300] = {.lex_state = 146, .external_lex_state = 2},
  [301] = {.lex_state = 146, .external_lex_state = 2},
  [302] = {.lex_state = 146, .external_lex_state = 2},
  [303] = {.lex_state = 146, .external_lex_state = 2},
  [304] = {.lex_state = 146, .external_lex_state = 2},
  [305] = {.lex_state = 146, .external_lex_state = 2},
  [306] = {.lex_state = 146, .external_lex_state = 2},
  [307] = {.lex_state = 146, .external_lex_state = 2},
  [308] = {.lex_state = 9, .external_lex_state = 5},
  [309] = {.lex_state = 9, .external_lex_state = 5},
  [310] = {.lex_state = 9, .external_lex_state = 5},
  [311] = {.lex_state = 9, .external_lex_state = 5},
  [312] = {.lex_state = 9, .external_lex_state = 5},
  [313] = {.lex_state = 146, .external_lex_state = 2},
  [314] = {.lex_state = 146, .external_lex_state = 2},
  [315] = {.lex_state = 146, .external_lex_state = 2},
  [316] = {.lex_state = 146, .external_lex_state = 2},
  [317] = {.lex_state = 56, .external_lex_state = 9},
  [318] = {.lex_state = 85, .external_lex_state = 2},
  [319] = {.lex_state = 85, .external_lex_state = 2},
  [320] = {.lex_state = 56, .external_lex_state = 9},
  [321] = {.lex_state = 56, .external_lex_state = 9},
  [322] = {.lex_state = 56, .external_lex_state = 9},
  [323] = {.lex_state = 85, .external_lex_state = 2},
  [324] = {.lex_state = 56, .external_lex_state = 9},
  [325] = {.lex_state = 85, .external_lex_state = 2},
  [326] = {.lex_state = 10, .external_lex_state = 9},
  [327] = {.lex_state = 10, .external_lex_state = 9},
  [328] = {.lex_state = 10, .external_lex_state = 9},
  [329] = {.lex_state = 85, .external_lex_state = 2},
  [330] = {.lex_state = 10, .external_lex_state = 9},
  [331] = {.lex_state = 10, .external_lex_state = 9},
  [332] = {.lex_state = 85, .external_lex_state = 2},
  [333] = {.lex_state = 17, .external_lex_state = 5},
  [334] = {.lex_state = 85, .external_lex_state = 2},
  [335] = {.lex_state = 17, .external_lex_state = 5},
  [336] = {.lex_state = 85, .external_lex_state = 2},
  [337] = {.lex_state = 85, .external_lex_state = 2},
  [338] = {.lex_state = 17, .external_lex_state = 5},
  [339] = {.lex_state = 17, .external_lex_state = 5},
  [340] = {.lex_state = 85, .external_lex_state = 2},
  [341] = {.lex_state = 85, .external_lex_state = 2},
  [342] = {.lex_state = 20, .external_lex_state = 5},
  [343] = {.lex_state = 20, .external_lex_state = 5},
  [344] = {.lex_state = 85, .external_lex_state = 2},
  [345] = {.lex_state = 85, .external_lex_state = 2},
  [346] = {.lex_state = 17, .external_lex_state = 5},
  [347] = {.lex_state = 85, .external_lex_state = 2},
  [348] = {.lex_state = 17, .external_lex_state = 5},
  [349] = {.lex_state = 85, .external_lex_state = 2},
  [350] = {.lex_state = 11, .external_lex_state = 9},
  [351] = {.lex_state = 48, .external_lex_state = 8},
  [352] = {.lex_state = 48, .external_lex_state = 8},
  [353] = {.lex_state = 48, .external_lex_state = 8},
  [354] = {.lex_state = 17, .external_lex_state = 10},
  [355] = {.lex_state = 17, .external_lex_state = 5},
  [356] = {.lex_state = 57, .external_lex_state = 9},
  [357] = {.lex_state = 48, .external_lex_state = 8},
  [358] = {.lex_state = 48, .external_lex_state = 8},
  [359] = {.lex_state = 48, .external_lex_state = 8},
  [360] = {.lex_state = 48, .external_lex_state = 8},
  [361] = {.lex_state = 48, .external_lex_state = 8},
  [362] = {.lex_state = 11, .external_lex_state = 9},
  [363] = {.lex_state = 57, .external_lex_state = 9},
  [364] = {.lex_state = 57, .external_lex_state = 9},
  [365] = {.lex_state = 11, .external_lex_state = 9},
  [366] = {.lex_state = 48, .external_lex_state = 8},
  [367] = {.lex_state = 48, .external_lex_state = 8},
  [368] = {.lex_state = 17, .external_lex_state = 5},
  [369] = {.lex_state = 11, .external_lex_state = 9},
  [370] = {.lex_state = 11, .external_lex_state = 9},
  [371] = {.lex_state = 57, .external_lex_state = 9},
  [372] = {.lex_state = 57, .external_lex_state = 9},
  [373] = {.lex_state = 17, .external_lex_state = 5},
  [374] = {.lex_state = 17, .external_lex_state = 10},
  [375] = {.lex_state = 48, .external_lex_state = 8},
  [376] = {.lex_state = 48, .external_lex_state = 8},
  [377] = {.lex_state = 48, .external_lex_state = 8},
  [378] = {.lex_state = 17, .external_lex_state = 5},
  [379] = {.lex_state = 64, .external_lex_state = 9},
  [380] = {.lex_state = 19, .external_lex_state = 5},
  [381] = {.lex_state = 19, .external_lex_state = 5},
  [382] = {.lex_state = 19, .external_lex_state = 5},
  [383] = {.lex_state = 19, .external_lex_state = 5},
  [384] = {.lex_state = 19, .external_lex_state = 5},
  [385] = {.lex_state = 19, .external_lex_state = 5},
  [386] = {.lex_state = 48, .external_lex_state = 8},
  [387] = {.lex_state = 19, .external_lex_state = 5},
  [388] = {.lex_state = 19, .external_lex_state = 5},
  [389] = {.lex_state = 19, .external_lex_state = 5},
  [390] = {.lex_state = 19, .external_lex_state = 5},
  [391] = {.lex_state = 19, .external_lex_state = 5},
  [392] = {.lex_state = 19, .external_lex_state = 5},
  [393] = {.lex_state = 19, .external_lex_state = 5},
  [394] = {.lex_state = 19, .external_lex_state = 5},
  [395] = {.lex_state = 19, .external_lex_state = 5},
  [396] = {.lex_state = 19, .external_lex_state = 5},
  [397] = {.lex_state = 19, .external_lex_state = 5},
  [398] = {.lex_state = 19, .external_lex_state = 5},
  [399] = {.lex_state = 19, .external_lex_state = 5},
  [400] = {.lex_state = 19, .external_lex_state = 5},
  [401] = {.lex_state = 19, .external_lex_state = 5},
  [402] = {.lex_state = 19, .external_lex_state = 5},
  [403] = {.lex_state = 19, .external_lex_state = 5},
  [404] = {.lex_state = 19, .external_lex_state = 5},
  [405] = {.lex_state = 19, .external_lex_state = 5},
  [406] = {.lex_state = 19, .external_lex_state = 5},
  [407] = {.lex_state = 19, .external_lex_state = 5},
  [408] = {.lex_state = 19, .external_lex_state = 5},
  [409] = {.lex_state = 19, .external_lex_state = 5},
  [410] = {.lex_state = 19, .external_lex_state = 5},
  [411] = {.lex_state = 19, .external_lex_state = 5},
  [412] = {.lex_state = 48, .external_lex_state = 8},
  [413] = {.lex_state = 48, .external_lex_state = 8},
  [414] = {.lex_state = 19, .external_lex_state = 5},
  [415] = {.lex_state = 64, .external_lex_state = 9},
  [416] = {.lex_state = 19, .external_lex_state = 5},
  [417] = {.lex_state = 19, .external_lex_state = 5},
  [418] = {.lex_state = 19, .external_lex_state = 5},
  [419] = {.lex_state = 48, .external_lex_state = 8},
  [420] = {.lex_state = 19, .external_lex_state = 5},
  [421] = {.lex_state = 19, .external_lex_state = 5},
  [422] = {.lex_state = 19, .external_lex_state = 5},
  [423] = {.lex_state = 48, .external_lex_state = 8},
  [424] = {.lex_state = 19, .external_lex_state = 5},
  [425] = {.lex_state = 19, .external_lex_state = 5},
  [426] = {.lex_state = 48, .external_lex_state = 8},
  [427] = {.lex_state = 19, .external_lex_state = 5},
  [428] = {.lex_state = 48, .external_lex_state = 8},
  [429] = {.lex_state = 48, .external_lex_state = 8},
  [430] = {.lex_state = 48, .external_lex_state = 8},
  [431] = {.lex_state = 19, .external_lex_state = 5},
  [432] = {.lex_state = 48, .external_lex_state = 8},
  [433] = {.lex_state = 48, .external_lex_state = 8},
  [434] = {.lex_state = 19, .external_lex_state = 5},
  [435] = {.lex_state = 19, .external_lex_state = 5},
  [436] = {.lex_state = 19, .external_lex_state = 5},
  [437] = {.lex_state = 19, .external_lex_state = 5},
  [438] = {.lex_state = 19, .external_lex_state = 5},
  [439] = {.lex_state = 48, .external_lex_state = 8},
  [440] = {.lex_state = 48, .external_lex_state = 8},
  [441] = {.lex_state = 19, .external_lex_state = 5},
  [442] = {.lex_state = 19, .external_lex_state = 5},
  [443] = {.lex_state = 19, .external_lex_state = 5},
  [444] = {.lex_state = 19, .external_lex_state = 5},
  [445] = {.lex_state = 19, .external_lex_state = 5},
  [446] = {.lex_state = 17, .external_lex_state = 5},
  [447] = {.lex_state = 19, .external_lex_state = 5},
  [448] = {.lex_state = 19, .external_lex_state = 5},
  [449] = {.lex_state = 17, .external_lex_state = 10},
  [450] = {.lex_state = 19, .external_lex_state = 5},
  [451] = {.lex_state = 19, .external_lex_state = 5},
  [452] = {.lex_state = 19, .external_lex_state = 5},
  [453] = {.lex_state = 23, .external_lex_state = 9},
  [454] = {.lex_state = 63, .external_lex_state = 9},
  [455] = {.lex_state = 17, .external_lex_state = 10},
  [456] = {.lex_state = 63, .external_lex_state = 9},
  [457] = {.lex_state = 23, .external_lex_state = 9},
  [458] = {.lex_state = 63, .external_lex_state = 9},
  [459] = {.lex_state = 18, .external_lex_state = 5},
  [460] = {.lex_state = 17, .external_lex_state = 5},
  [461] = {.lex_state = 17, .external_lex_state = 5},
  [462] = {.lex_state = 18, .external_lex_state = 5},
  [463] = {.lex_state = 65, .external_lex_state = 9},
  [464] = {.lex_state = 65, .external_lex_state = 9},
  [465] = {.lex_state = 19, .external_lex_state = 5},
  [466] = {.lex_state = 19, .external_lex_state = 5},
  [467] = {.lex_state = 18, .external_lex_state = 5},
  [468] = {.lex_state = 18, .external_lex_state = 5},
  [469] = {.lex_state = 65, .external_lex_state = 9},
  [470] = {.lex_state = 65, .external_lex_state = 9},
  [471] = {.lex_state = 65, .external_lex_state = 9},
  [472] = {.lex_state = 19, .external_lex_state = 5},
  [473] = {.lex_state = 65, .external_lex_state = 9},
  [474] = {.lex_state = 65, .external_lex_state = 9},
  [475] = {.lex_state = 65, .external_lex_state = 9},
  [476] = {.lex_state = 65, .external_lex_state = 9},
  [477] = {.lex_state = 19, .external_lex_state = 5},
  [478] = {.lex_state = 18, .external_lex_state = 5},
  [479] = {.lex_state = 65, .external_lex_state = 9},
  [480] = {.lex_state = 19, .external_lex_state = 5},
  [481] = {.lex_state = 19, .external_lex_state = 5},
  [482] = {.lex_state = 65, .external_lex_state = 9},
  [483] = {.lex_state = 65, .external_lex_state = 9},
  [484] = {.lex_state = 65, .external_lex_state = 9},
  [485] = {.lex_state = 65, .external_lex_state = 9},
  [486] = {.lex_state = 65, .external_lex_state = 9},
  [487] = {.lex_state = 65, .external_lex_state = 9},
  [488] = {.lex_state = 65, .external_lex_state = 9},
  [489] = {.lex_state = 65, .external_lex_state = 9},
  [490] = {.lex_state = 65, .external_lex_state = 9},
  [491] = {.lex_state = 65, .external_lex_state = 9},
  [492] = {.lex_state = 65, .external_lex_state = 9},
  [493] = {.lex_state = 17, .external_lex_state = 5},
  [494] = {.lex_state = 65, .external_lex_state = 9},
  [495] = {.lex_state = 65, .external_lex_state = 9},
  [496] = {.lex_state = 65, .external_lex_state = 9},
  [497] = {.lex_state = 65, .external_lex_state = 9},
  [498] = {.lex_state = 65, .external_lex_state = 9},
  [499] = {.lex_state = 65, .external_lex_state = 9},
  [500] = {.lex_state = 65, .external_lex_state = 9},
  [501] = {.lex_state = 65, .external_lex_state = 9},
  [502] = {.lex_state = 65, .external_lex_state = 9},
  [503] = {.lex_state = 19, .external_lex_state = 5},
  [504] = {.lex_state = 19, .external_lex_state = 5},
  [505] = {.lex_state = 65, .external_lex_state = 9},
  [506] = {.lex_state = 65, .external_lex_state = 9},
  [507] = {.lex_state = 65, .external_lex_state = 9},
  [508] = {.lex_state = 65, .external_lex_state = 9},
  [509] = {.lex_state = 65, .external_lex_state = 9},
  [510] = {.lex_state = 65, .external_lex_state = 9},
  [511] = {.lex_state = 65, .external_lex_state = 9},
  [512] = {.lex_state = 65, .external_lex_state = 9},
  [513] = {.lex_state = 65, .external_lex_state = 9},
  [514] = {.lex_state = 65, .external_lex_state = 9},
  [515] = {.lex_state = 65, .external_lex_state = 9},
  [516] = {.lex_state = 65, .external_lex_state = 9},
  [517] = {.lex_state = 65, .external_lex_state = 9},
  [518] = {.lex_state = 65, .external_lex_state = 9},
  [519] = {.lex_state = 65, .external_lex_state = 9},
  [520] = {.lex_state = 65, .external_lex_state = 9},
  [521] = {.lex_state = 65, .external_lex_state = 9},
  [522] = {.lex_state = 19, .external_lex_state = 5},
  [523] = {.lex_state = 17, .external_lex_state = 5},
  [524] = {.lex_state = 17, .external_lex_state = 5},
  [525] = {.lex_state = 48, .external_lex_state = 8},
  [526] = {.lex_state = 17, .external_lex_state = 5},
  [527] = {.lex_state = 19, .external_lex_state = 5},
  [528] = {.lex_state = 19, .external_lex_state = 5},
  [529] = {.lex_state = 17, .external_lex_state = 5},
  [530] = {.lex_state = 17, .external_lex_state = 5},
  [531] = {.lex_state = 17, .external_lex_state = 5},
  [532] = {.lex_state = 17, .external_lex_state = 5},
  [533] = {.lex_state = 17, .external_lex_state = 5},
  [534] = {.lex_state = 18, .external_lex_state = 5},
  [535] = {.lex_state = 63, .external_lex_state = 9},
  [536] = {.lex_state = 17, .external_lex_state = 5},
  [537] = {.lex_state = 63, .external_lex_state = 9},
  [538] = {.lex_state = 19, .external_lex_state = 5},
  [539] = {.lex_state = 65, .external_lex_state = 9},
  [540] = {.lex_state = 63, .external_lex_state = 9},
  [541] = {.lex_state = 19, .external_lex_state = 5},
  [542] = {.lex_state = 18, .external_lex_state = 5},
  [543] = {.lex_state = 19, .external_lex_state = 5},
  [544] = {.lex_state = 19, .external_lex_state = 5},
  [545] = {.lex_state = 18, .external_lex_state = 5},
  [546] = {.lex_state = 18, .external_lex_state = 5},
  [547] = {.lex_state = 19, .external_lex_state = 5},
  [548] = {.lex_state = 19, .external_lex_state = 5},
  [549] = {.lex_state = 17, .external_lex_state = 5},
  [550] = {.lex_state = 17, .external_lex_state = 5},
  [551] = {.lex_state = 19, .external_lex_state = 5},
  [552] = {.lex_state = 19, .external_lex_state = 5},
  [553] = {.lex_state = 19, .external_lex_state = 5},
  [554] = {.lex_state = 19, .external_lex_state = 5},
  [555] = {.lex_state = 17, .external_lex_state = 5},
  [556] = {.lex_state = 17, .external_lex_state = 5},
  [557] = {.lex_state = 48, .external_lex_state = 8},
  [558] = {.lex_state = 22, .external_lex_state = 9},
  [559] = {.lex_state = 22, .external_lex_state = 9},
  [560] = {.lex_state = 48, .external_lex_state = 8},
  [561] = {.lex_state = 17, .external_lex_state = 5},
  [562] = {.lex_state = 19, .external_lex_state = 5},
  [563] = {.lex_state = 48, .external_lex_state = 8},
  [564] = {.lex_state = 19, .external_lex_state = 5},
  [565] = {.lex_state = 19, .external_lex_state = 5},
  [566] = {.lex_state = 22, .external_lex_state = 9},
  [567] = {.lex_state = 19, .external_lex_state = 5},
  [568] = {.lex_state = 17, .external_lex_state = 5},
  [569] = {.lex_state = 19, .external_lex_state = 5},
  [570] = {.lex_state = 17, .external_lex_state = 5},
  [571] = {.lex_state = 19, .external_lex_state = 5},
  [572] = {.lex_state = 48, .external_lex_state = 8},
  [573] = {.lex_state = 17, .external_lex_state = 5},
  [574] = {.lex_state = 48, .external_lex_state = 8},
  [575] = {.lex_state = 17, .external_lex_state = 5},
  [576] = {.lex_state = 19, .external_lex_state = 5},
  [577] = {.lex_state = 19, .external_lex_state = 5},
  [578] = {.lex_state = 19, .external_lex_state = 5},
  [579] = {.lex_state = 19, .external_lex_state = 5},
  [580] = {.lex_state = 19, .external_lex_state = 5},
  [581] = {.lex_state = 19, .external_lex_state = 5},
  [582] = {.lex_state = 17, .external_lex_state = 5},
  [583] = {.lex_state = 17, .external_lex_state = 5},
  [584] = {.lex_state = 19, .external_lex_state = 5},
  [585] = {.lex_state = 17, .external_lex_state = 5},
  [586] = {.lex_state = 17, .external_lex_state = 5},
  [587] = {.lex_state = 17, .external_lex_state = 5},
  [588] = {.lex_state = 19, .external_lex_state = 5},
  [589] = {.lex_state = 19, .external_lex_state = 5},
  [590] = {.lex_state = 19, .external_lex_state = 5},
  [591] = {.lex_state = 19, .external_lex_state = 5},
  [592] = {.lex_state = 19, .external_lex_state = 5},
  [593] = {.lex_state = 19, .external_lex_state = 5},
  [594] = {.lex_state = 19, .external_lex_state = 5},
  [595] = {.lex_state = 19, .external_lex_state = 5},
  [596] = {.lex_state = 19, .external_lex_state = 5},
  [597] = {.lex_state = 19, .external_lex_state = 5},
  [598] = {.lex_state = 19, .external_lex_state = 5},
  [599] = {.lex_state = 17, .external_lex_state = 5},
  [600] = {.lex_state = 19, .external_lex_state = 5},
  [601] = {.lex_state = 65, .external_lex_state = 9},
  [602] = {.lex_state = 65, .external_lex_state = 9},
  [603] = {.lex_state = 19, .external_lex_state = 5},
  [604] = {.lex_state = 19, .external_lex_state = 5},
  [605] = {.lex_state = 63, .external_lex_state = 9},
  [606] = {.lex_state = 48, .external_lex_state = 8},
  [607] = {.lex_state = 18, .external_lex_state = 5},
  [608] = {.lex_state = 24, .external_lex_state = 9},
  [609] = {.lex_state = 24, .external_lex_state = 9},
  [610] = {.lex_state = 24, .external_lex_state = 9},
  [611] = {.lex_state = 24, .external_lex_state = 9},
  [612] = {.lex_state = 48, .external_lex_state = 8},
  [613] = {.lex_state = 48, .external_lex_state = 8},
  [614] = {.lex_state = 24, .external_lex_state = 9},
  [615] = {.lex_state = 24, .external_lex_state = 9},
  [616] = {.lex_state = 24, .external_lex_state = 9},
  [617] = {.lex_state = 24, .external_lex_state = 9},
  [618] = {.lex_state = 24, .external_lex_state = 9},
  [619] = {.lex_state = 24, .external_lex_state = 9},
  [620] = {.lex_state = 24, .external_lex_state = 9},
  [621] = {.lex_state = 24, .external_lex_state = 9},
  [622] = {.lex_state = 24, .external_lex_state = 9},
  [623] = {.lex_state = 24, .external_lex_state = 9},
  [624] = {.lex_state = 24, .external_lex_state = 9},
  [625] = {.lex_state = 24, .external_lex_state = 9},
  [626] = {.lex_state = 24, .external_lex_state = 9},
  [627] = {.lex_state = 24, .external_lex_state = 9},
  [628] = {.lex_state = 24, .external_lex_state = 9},
  [629] = {.lex_state = 24, .external_lex_state = 9},
  [630] = {.lex_state = 48, .external_lex_state = 8},
  [631] = {.lex_state = 48, .external_lex_state = 8},
  [632] = {.lex_state = 24, .external_lex_state = 9},
  [633] = {.lex_state = 24, .external_lex_state = 9},
  [634] = {.lex_state = 24, .external_lex_state = 9},
  [635] = {.lex_state = 48, .external_lex_state = 8},
  [636] = {.lex_state = 24, .external_lex_state = 9},
  [637] = {.lex_state = 24, .external_lex_state = 9},
  [638] = {.lex_state = 22, .external_lex_state = 9},
  [639] = {.lex_state = 24, .external_lex_state = 9},
  [640] = {.lex_state = 24, .external_lex_state = 9},
  [641] = {.lex_state = 48, .external_lex_state = 8},
  [642] = {.lex_state = 24, .external_lex_state = 9},
  [643] = {.lex_state = 24, .external_lex_state = 9},
  [644] = {.lex_state = 68, .external_lex_state = 9},
  [645] = {.lex_state = 24, .external_lex_state = 9},
  [646] = {.lex_state = 24, .external_lex_state = 9},
  [647] = {.lex_state = 24, .external_lex_state = 9},
  [648] = {.lex_state = 68, .external_lex_state = 9},
  [649] = {.lex_state = 24, .external_lex_state = 9},
  [650] = {.lex_state = 17, .external_lex_state = 10},
  [651] = {.lex_state = 48, .external_lex_state = 8},
  [652] = {.lex_state = 24, .external_lex_state = 9},
  [653] = {.lex_state = 24, .external_lex_state = 9},
  [654] = {.lex_state = 22, .external_lex_state = 9},
  [655] = {.lex_state = 22, .external_lex_state = 9},
  [656] = {.lex_state = 24, .external_lex_state = 9},
  [657] = {.lex_state = 24, .external_lex_state = 9},
  [658] = {.lex_state = 65, .external_lex_state = 9},
  [659] = {.lex_state = 65, .external_lex_state = 9},
  [660] = {.lex_state = 65, .external_lex_state = 9},
  [661] = {.lex_state = 65, .external_lex_state = 9},
  [662] = {.lex_state = 22, .external_lex_state = 9},
  [663] = {.lex_state = 24, .external_lex_state = 9},
  [664] = {.lex_state = 24, .external_lex_state = 9},
  [665] = {.lex_state = 24, .external_lex_state = 9},
  [666] = {.lex_state = 24, .external_lex_state = 9},
  [667] = {.lex_state = 19, .external_lex_state = 5},
  [668] = {.lex_state = 65, .external_lex_state = 9},
  [669] = {.lex_state = 19, .external_lex_state = 5},
  [670] = {.lex_state = 65, .external_lex_state = 9},
  [671] = {.lex_state = 24, .external_lex_state = 9},
  [672] = {.lex_state = 65, .external_lex_state = 9},
  [673] = {.lex_state = 24, .external_lex_state = 9},
  [674] = {.lex_state = 19, .external_lex_state = 5},
  [675] = {.lex_state = 24, .external_lex_state = 9},
  [676] = {.lex_state = 24, .external_lex_state = 9},
  [677] = {.lex_state = 24, .external_lex_state = 9},
  [678] = {.lex_state = 24, .external_lex_state = 9},
  [679] = {.lex_state = 24, .external_lex_state = 9},
  [680] = {.lex_state = 17, .external_lex_state = 5},
  [681] = {.lex_state = 24, .external_lex_state = 9},
  [682] = {.lex_state = 17, .external_lex_state = 5},
  [683] = {.lex_state = 24, .external_lex_state = 9},
  [684] = {.lex_state = 19, .external_lex_state = 5},
  [685] = {.lex_state = 48, .external_lex_state = 8},
  [686] = {.lex_state = 48, .external_lex_state = 8},
  [687] = {.lex_state = 48, .external_lex_state = 8},
  [688] = {.lex_state = 48, .external_lex_state = 8},
  [689] = {.lex_state = 19, .external_lex_state = 5},
  [690] = {.lex_state = 48, .external_lex_state = 8},
  [691] = {.lex_state = 48, .external_lex_state = 8},
  [692] = {.lex_state = 48, .external_lex_state = 8},
  [693] = {.lex_state = 48, .external_lex_state = 8},
  [694] = {.lex_state = 62, .external_lex_state = 9},
  [695] = {.lex_state = 17, .external_lex_state = 10},
  [696] = {.lex_state = 17, .external_lex_state = 5},
  [697] = {.lex_state = 19, .external_lex_state = 5},
  [698] = {.lex_state = 27, .external_lex_state = 9},
  [699] = {.lex_state = 18, .external_lex_state = 5},
  [700] = {.lex_state = 48, .external_lex_state = 8},
  [701] = {.lex_state = 48, .external_lex_state = 8},
  [702] = {.lex_state = 17, .external_lex_state = 5},
  [703] = {.lex_state = 48, .external_lex_state = 8},
  [704] = {.lex_state = 48, .external_lex_state = 8},
  [705] = {.lex_state = 17, .external_lex_state = 5},
  [706] = {.lex_state = 17, .external_lex_state = 5},
  [707] = {.lex_state = 48, .external_lex_state = 8},
  [708] = {.lex_state = 17, .external_lex_state = 5},
  [709] = {.lex_state = 17, .external_lex_state = 5},
  [710] = {.lex_state = 17, .external_lex_state = 5},
  [711] = {.lex_state = 17, .external_lex_state = 5},
  [712] = {.lex_state = 17, .external_lex_state = 5},
  [713] = {.lex_state = 17, .external_lex_state = 5},
  [714] = {.lex_state = 17, .external_lex_state = 5},
  [715] = {.lex_state = 48, .external_lex_state = 8},
  [716] = {.lex_state = 48, .external_lex_state = 8},
  [717] = {.lex_state = 48, .external_lex_state = 8},
  [718] = {.lex_state = 48, .external_lex_state = 8},
  [719] = {.lex_state = 62, .external_lex_state = 9},
  [720] = {.lex_state = 48, .external_lex_state = 8},
  [721] = {.lex_state = 27, .external_lex_state = 9},
  [722] = {.lex_state = 48, .external_lex_state = 8},
  [723] = {.lex_state = 48, .external_lex_state = 8},
  [724] = {.lex_state = 48, .external_lex_state = 8},
  [725] = {.lex_state = 17, .external_lex_state = 5},
  [726] = {.lex_state = 17, .external_lex_state = 5},
  [727] = {.lex_state = 17, .external_lex_state = 5},
  [728] = {.lex_state = 17, .external_lex_state = 5},
  [729] = {.lex_state = 17, .external_lex_state = 5},
  [730] = {.lex_state = 48, .external_lex_state = 8},
  [731] = {.lex_state = 48, .external_lex_state = 8},
  [732] = {.lex_state = 18, .external_lex_state = 5},
  [733] = {.lex_state = 18, .external_lex_state = 5},
  [734] = {.lex_state = 48, .external_lex_state = 8},
  [735] = {.lex_state = 19, .external_lex_state = 5},
  [736] = {.lex_state = 48, .external_lex_state = 8},
  [737] = {.lex_state = 24, .external_lex_state = 9},
  [738] = {.lex_state = 24, .external_lex_state = 9},
  [739] = {.lex_state = 48, .external_lex_state = 8},
  [740] = {.lex_state = 48, .external_lex_state = 8},
  [741] = {.lex_state = 48, .external_lex_state = 8},
  [742] = {.lex_state = 48, .external_lex_state = 8},
  [743] = {.lex_state = 48, .external_lex_state = 8},
  [744] = {.lex_state = 17, .external_lex_state = 5},
  [745] = {.lex_state = 48, .external_lex_state = 8},
  [746] = {.lex_state = 48, .external_lex_state = 8},
  [747] = {.lex_state = 17, .external_lex_state = 10},
  [748] = {.lex_state = 17, .external_lex_state = 10},
  [749] = {.lex_state = 48, .external_lex_state = 8},
  [750] = {.lex_state = 48, .external_lex_state = 8},
  [751] = {.lex_state = 48, .external_lex_state = 8},
  [752] = {.lex_state = 48, .external_lex_state = 8},
  [753] = {.lex_state = 18, .external_lex_state = 5},
  [754] = {.lex_state = 63, .external_lex_state = 9},
  [755] = {.lex_state = 62, .external_lex_state = 9},
  [756] = {.lex_state = 26, .external_lex_state = 9},
  [757] = {.lex_state = 18, .external_lex_state = 5},
  [758] = {.lex_state = 62, .external_lex_state = 9},
  [759] = {.lex_state = 48, .external_lex_state = 8},
  [760] = {.lex_state = 48, .external_lex_state = 8},
  [761] = {.lex_state = 62, .external_lex_state = 9},
  [762] = {.lex_state = 48, .external_lex_state = 8},
  [763] = {.lex_state = 21, .external_lex_state = 9},
  [764] = {.lex_state = 67, .external_lex_state = 9},
  [765] = {.lex_state = 18, .external_lex_state = 5},
  [766] = {.lex_state = 48, .external_lex_state = 8},
  [767] = {.lex_state = 48, .external_lex_state = 8},
  [768] = {.lex_state = 48, .external_lex_state = 8},
  [769] = {.lex_state = 48, .external_lex_state = 8},
  [770] = {.lex_state = 63, .external_lex_state = 9},
  [771] = {.lex_state = 24, .external_lex_state = 9},
  [772] = {.lex_state = 63, .external_lex_state = 9},
  [773] = {.lex_state = 67, .external_lex_state = 9},
  [774] = {.lex_state = 63, .external_lex_state = 9},
  [775] = {.lex_state = 24, .external_lex_state = 9},
  [776] = {.lex_state = 24, .external_lex_state = 9},
  [777] = {.lex_state = 48, .external_lex_state = 8},
  [778] = {.lex_state = 48, .external_lex_state = 8},
  [779] = {.lex_state = 48, .external_lex_state = 8},
  [780] = {.lex_state = 62, .external_lex_state = 9},
  [781] = {.lex_state = 48, .external_lex_state = 8},
  [782] = {.lex_state = 48, .external_lex_state = 8},
  [783] = {.lex_state = 18, .external_lex_state = 5},
  [784] = {.lex_state = 24, .external_lex_state = 9},
  [785] = {.lex_state = 48, .external_lex_state = 8},
  [786] = {.lex_state = 48, .external_lex_state = 8},
  [787] = {.lex_state = 48, .external_lex_state = 8},
  [788] = {.lex_state = 48, .external_lex_state = 8},
  [789] = {.lex_state = 48, .external_lex_state = 8},
  [790] = {.lex_state = 48, .external_lex_state = 8},
  [791] = {.lex_state = 48, .external_lex_state = 8},
  [792] = {.lex_state = 48, .external_lex_state = 8},
  [793] = {.lex_state = 48, .external_lex_state = 8},
  [794] = {.lex_state = 48, .external_lex_state = 8},
  [795] = {.lex_state = 48, .external_lex_state = 8},
  [796] = {.lex_state = 48, .external_lex_state = 8},
  [797] = {.lex_state = 48, .external_lex_state = 8},
  [798] = {.lex_state = 62, .external_lex_state = 9},
  [799] = {.lex_state = 67, .external_lex_state = 9},
  [800] = {.lex_state = 62, .external_lex_state = 9},
  [801] = {.lex_state = 26, .external_lex_state = 9},
  [802] = {.lex_state = 26, .external_lex_state = 9},
  [803] = {.lex_state = 48, .external_lex_state = 8},
  [804] = {.lex_state = 48, .external_lex_state = 8},
  [805] = {.lex_state = 62, .external_lex_state = 9},
  [806] = {.lex_state = 48, .external_lex_state = 8},
  [807] = {.lex_state = 48, .external_lex_state = 8},
  [808] = {.lex_state = 48, .external_lex_state = 8},
  [809] = {.lex_state = 24, .external_lex_state = 9},
  [810] = {.lex_state = 48, .external_lex_state = 8},
  [811] = {.lex_state = 63, .external_lex_state = 9},
  [812] = {.lex_state = 48, .external_lex_state = 8},
  [813] = {.lex_state = 48, .external_lex_state = 8},
  [814] = {.lex_state = 48, .external_lex_state = 8},
  [815] = {.lex_state = 18, .external_lex_state = 5},
  [816] = {.lex_state = 48, .external_lex_state = 8},
  [817] = {.lex_state = 48, .external_lex_state = 8},
  [818] = {.lex_state = 48, .external_lex_state = 8},
  [819] = {.lex_state = 48, .external_lex_state = 8},
  [820] = {.lex_state = 48, .external_lex_state = 8},
  [821] = {.lex_state = 48, .external_lex_state = 8},
  [822] = {.lex_state = 48, .external_lex_state = 8},
  [823] = {.lex_state = 48, .external_lex_state = 8},
  [824] = {.lex_state = 48, .external_lex_state = 8},
  [825] = {.lex_state = 48, .external_lex_state = 8},
  [826] = {.lex_state = 48, .external_lex_state = 8},
  [827] = {.lex_state = 48, .external_lex_state = 8},
  [828] = {.lex_state = 21, .external_lex_state = 9},
  [829] = {.lex_state = 48, .external_lex_state = 8},
  [830] = {.lex_state = 28, .external_lex_state = 9},
  [831] = {.lex_state = 56, .external_lex_state = 9},
  [832] = {.lex_state = 56, .external_lex_state = 9},
  [833] = {.lex_state = 56, .external_lex_state = 9},
  [834] = {.lex_state = 56, .external_lex_state = 9},
  [835] = {.lex_state = 69, .external_lex_state = 9},
  [836] = {.lex_state = 69, .external_lex_state = 9},
  [837] = {.lex_state = 56, .external_lex_state = 9},
  [838] = {.lex_state = 69, .external_lex_state = 9},
  [839] = {.lex_state = 56, .external_lex_state = 9},
  [840] = {.lex_state = 28, .external_lex_state = 9},
  [841] = {.lex_state = 28, .external_lex_state = 9},
  [842] = {.lex_state = 28, .external_lex_state = 9},
  [843] = {.lex_state = 28, .external_lex_state = 9},
  [844] = {.lex_state = 69, .external_lex_state = 9},
  [845] = {.lex_state = 17, .external_lex_state = 5},
  [846] = {.lex_state = 69, .external_lex_state = 9},
  [847] = {.lex_state = 48, .external_lex_state = 8},
  [848] = {.lex_state = 17, .external_lex_state = 5},
  [849] = {.lex_state = 69, .external_lex_state = 9},
  [850] = {.lex_state = 69, .external_lex_state = 9},
  [851] = {.lex_state = 17, .external_lex_state = 5},
  [852] = {.lex_state = 17, .external_lex_state = 5},
  [853] = {.lex_state = 69, .external_lex_state = 9},
  [854] = {.lex_state = 17, .external_lex_state = 5},
  [855] = {.lex_state = 17, .external_lex_state = 5},
  [856] = {.lex_state = 56, .external_lex_state = 9},
  [857] = {.lex_state = 69, .external_lex_state = 9},
  [858] = {.lex_state = 48, .external_lex_state = 8},
  [859] = {.lex_state = 48, .external_lex_state = 8},
  [860] = {.lex_state = 69, .external_lex_state = 9},
  [861] = {.lex_state = 69, .external_lex_state = 9},
  [862] = {.lex_state = 69, .external_lex_state = 9},
  [863] = {.lex_state = 69, .external_lex_state = 9},
  [864] = {.lex_state = 69, .external_lex_state = 9},
  [865] = {.lex_state = 69, .external_lex_state = 9},
  [866] = {.lex_state = 69, .external_lex_state = 9},
  [867] = {.lex_state = 56, .external_lex_state = 9},
  [868] = {.lex_state = 56, .external_lex_state = 9},
  [869] = {.lex_state = 56, .external_lex_state = 9},
  [870] = {.lex_state = 69, .external_lex_state = 9},
  [871] = {.lex_state = 69, .external_lex_state = 9},
  [872] = {.lex_state = 69, .external_lex_state = 9},
  [873] = {.lex_state = 56, .external_lex_state = 9},
  [874] = {.lex_state = 69, .external_lex_state = 9},
  [875] = {.lex_state = 69, .external_lex_state = 9},
  [876] = {.lex_state = 69, .external_lex_state = 9},
  [877] = {.lex_state = 69, .external_lex_state = 9},
  [878] = {.lex_state = 56, .external_lex_state = 9},
  [879] = {.lex_state = 69, .external_lex_state = 9},
  [880] = {.lex_state = 69, .external_lex_state = 9},
  [881] = {.lex_state = 17, .external_lex_state = 5},
  [882] = {.lex_state = 17, .external_lex_state = 5},
  [883] = {.lex_state = 69, .external_lex_state = 9},
  [884] = {.lex_state = 69, .external_lex_state = 9},
  [885] = {.lex_state = 69, .external_lex_state = 9},
  [886] = {.lex_state = 69, .external_lex_state = 9},
  [887] = {.lex_state = 48, .external_lex_state = 8},
  [888] = {.lex_state = 17, .external_lex_state = 5},
  [889] = {.lex_state = 28, .external_lex_state = 9},
  [890] = {.lex_state = 28, .external_lex_state = 9},
  [891] = {.lex_state = 69, .external_lex_state = 9},
  [892] = {.lex_state = 56, .external_lex_state = 9},
  [893] = {.lex_state = 56, .external_lex_state = 9},
  [894] = {.lex_state = 69, .external_lex_state = 9},
  [895] = {.lex_state = 48, .external_lex_state = 8},
  [896] = {.lex_state = 69, .external_lex_state = 9},
  [897] = {.lex_state = 69, .external_lex_state = 9},
  [898] = {.lex_state = 69, .external_lex_state = 9},
  [899] = {.lex_state = 69, .external_lex_state = 9},
  [900] = {.lex_state = 48, .external_lex_state = 8},
  [901] = {.lex_state = 69, .external_lex_state = 9},
  [902] = {.lex_state = 69, .external_lex_state = 9},
  [903] = {.lex_state = 69, .external_lex_state = 9},
  [904] = {.lex_state = 17, .external_lex_state = 5},
  [905] = {.lex_state = 69, .external_lex_state = 9},
  [906] = {.lex_state = 69, .external_lex_state = 9},
  [907] = {.lex_state = 69, .external_lex_state = 9},
  [908] = {.lex_state = 69, .external_lex_state = 9},
  [909] = {.lex_state = 69, .external_lex_state = 9},
  [910] = {.lex_state = 69, .external_lex_state = 9},
  [911] = {.lex_state = 69, .external_lex_state = 9},
  [912] = {.lex_state = 69, .external_lex_state = 9},
  [913] = {.lex_state = 21, .external_lex_state = 9},
  [914] = {.lex_state = 56, .external_lex_state = 9},
  [915] = {.lex_state = 56, .external_lex_state = 9},
  [916] = {.lex_state = 56, .external_lex_state = 9},
  [917] = {.lex_state = 48, .external_lex_state = 8},
  [918] = {.lex_state = 56, .external_lex_state = 9},
  [919] = {.lex_state = 56, .external_lex_state = 9},
  [920] = {.lex_state = 56, .external_lex_state = 9},
  [921] = {.lex_state = 56, .external_lex_state = 9},
  [922] = {.lex_state = 17, .external_lex_state = 5},
  [923] = {.lex_state = 56, .external_lex_state = 9},
  [924] = {.lex_state = 56, .external_lex_state = 9},
  [925] = {.lex_state = 48, .external_lex_state = 8},
  [926] = {.lex_state = 56, .external_lex_state = 9},
  [927] = {.lex_state = 56, .external_lex_state = 9},
  [928] = {.lex_state = 65, .external_lex_state = 9},
  [929] = {.lex_state = 21, .external_lex_state = 9},
  [930] = {.lex_state = 48, .external_lex_state = 8},
  [931] = {.lex_state = 56, .external_lex_state = 9},
  [932] = {.lex_state = 56, .external_lex_state = 9},
  [933] = {.lex_state = 21, .external_lex_state = 9},
  [934] = {.lex_state = 56, .external_lex_state = 9},
  [935] = {.lex_state = 48, .external_lex_state = 8},
  [936] = {.lex_state = 56, .external_lex_state = 9},
  [937] = {.lex_state = 56, .external_lex_state = 9},
  [938] = {.lex_state = 56, .external_lex_state = 9},
  [939] = {.lex_state = 21, .external_lex_state = 9},
  [940] = {.lex_state = 48, .external_lex_state = 8},
  [941] = {.lex_state = 48, .external_lex_state = 8},
  [942] = {.lex_state = 48, .external_lex_state = 8},
  [943] = {.lex_state = 48, .external_lex_state = 8},
  [944] = {.lex_state = 56, .external_lex_state = 9},
  [945] = {.lex_state = 56, .external_lex_state = 9},
  [946] = {.lex_state = 22, .external_lex_state = 9},
  [947] = {.lex_state = 17, .external_lex_state = 5},
  [948] = {.lex_state = 28, .external_lex_state = 9},
  [949] = {.lex_state = 28, .external_lex_state = 9},
  [950] = {.lex_state = 48, .external_lex_state = 8},
  [951] = {.lex_state = 48, .external_lex_state = 8},
  [952] = {.lex_state = 28, .external_lex_state = 9},
  [953] = {.lex_state = 56, .external_lex_state = 9},
  [954] = {.lex_state = 56, .external_lex_state = 9},
  [955] = {.lex_state = 56, .external_lex_state = 9},
  [956] = {.lex_state = 28, .external_lex_state = 9},
  [957] = {.lex_state = 17, .external_lex_state = 5},
  [958] = {.lex_state = 17, .external_lex_state = 5},
  [959] = {.lex_state = 26, .external_lex_state = 9},
  [960] = {.lex_state = 17, .external_lex_state = 5},
  [961] = {.lex_state = 17, .external_lex_state = 5},
  [962] = {.lex_state = 28, .external_lex_state = 9},
  [963] = {.lex_state = 17, .external_lex_state = 5},
  [964] = {.lex_state = 56, .external_lex_state = 9},
  [965] = {.lex_state = 56, .external_lex_state = 9},
  [966] = {.lex_state = 22, .external_lex_state = 9},
  [967] = {.lex_state = 21, .external_lex_state = 9},
  [968] = {.lex_state = 21, .external_lex_state = 9},
  [969] = {.lex_state = 48, .external_lex_state = 8},
  [970] = {.lex_state = 48, .external_lex_state = 8},
  [971] = {.lex_state = 56, .external_lex_state = 9},
  [972] = {.lex_state = 48, .external_lex_state = 8},
  [973] = {.lex_state = 48, .external_lex_state = 8},
  [974] = {.lex_state = 28, .external_lex_state = 9},
  [975] = {.lex_state = 28, .external_lex_state = 9},
  [976] = {.lex_state = 28, .external_lex_state = 9},
  [977] = {.lex_state = 28, .external_lex_state = 9},
  [978] = {.lex_state = 28, .external_lex_state = 9},
  [979] = {.lex_state = 28, .external_lex_state = 9},
  [980] = {.lex_state = 28, .external_lex_state = 9},
  [981] = {.lex_state = 28, .external_lex_state = 9},
  [982] = {.lex_state = 22, .external_lex_state = 9},
  [983] = {.lex_state = 48, .external_lex_state = 8},
  [984] = {.lex_state = 22, .external_lex_state = 9},
  [985] = {.lex_state = 21, .external_lex_state = 9},
  [986] = {.lex_state = 67, .external_lex_state = 9},
  [987] = {.lex_state = 28, .external_lex_state = 9},
  [988] = {.lex_state = 28, .external_lex_state = 9},
  [989] = {.lex_state = 28, .external_lex_state = 9},
  [990] = {.lex_state = 67, .external_lex_state = 9},
  [991] = {.lex_state = 28, .external_lex_state = 9},
  [992] = {.lex_state = 28, .external_lex_state = 9},
  [993] = {.lex_state = 28, .external_lex_state = 9},
  [994] = {.lex_state = 28, .external_lex_state = 9},
  [995] = {.lex_state = 67, .external_lex_state = 9},
  [996] = {.lex_state = 28, .external_lex_state = 9},
  [997] = {.lex_state = 28, .external_lex_state = 9},
  [998] = {.lex_state = 28, .external_lex_state = 9},
  [999] = {.lex_state = 28, .external_lex_state = 9},
  [1000] = {.lex_state = 28, .external_lex_state = 9},
  [1001] = {.lex_state = 28, .external_lex_state = 9},
  [1002] = {.lex_state = 17, .external_lex_state = 5},
  [1003] = {.lex_state = 28, .external_lex_state = 9},
  [1004] = {.lex_state = 28, .external_lex_state = 9},
  [1005] = {.lex_state = 28, .external_lex_state = 9},
  [1006] = {.lex_state = 48, .external_lex_state = 8},
  [1007] = {.lex_state = 56, .external_lex_state = 9},
  [1008] = {.lex_state = 28, .external_lex_state = 9},
  [1009] = {.lex_state = 28, .external_lex_state = 9},
  [1010] = {.lex_state = 22, .external_lex_state = 9},
  [1011] = {.lex_state = 28, .external_lex_state = 9},
  [1012] = {.lex_state = 26, .external_lex_state = 9},
  [1013] = {.lex_state = 28, .external_lex_state = 9},
  [1014] = {.lex_state = 67, .external_lex_state = 9},
  [1015] = {.lex_state = 28, .external_lex_state = 9},
  [1016] = {.lex_state = 56, .external_lex_state = 9},
  [1017] = {.lex_state = 28, .external_lex_state = 9},
  [1018] = {.lex_state = 28, .external_lex_state = 9},
  [1019] = {.lex_state = 28, .external_lex_state = 9},
  [1020] = {.lex_state = 28, .external_lex_state = 9},
  [1021] = {.lex_state = 17, .external_lex_state = 5},
  [1022] = {.lex_state = 28, .external_lex_state = 9},
  [1023] = {.lex_state = 28, .external_lex_state = 9},
  [1024] = {.lex_state = 28, .external_lex_state = 9},
  [1025] = {.lex_state = 28, .external_lex_state = 9},
  [1026] = {.lex_state = 56, .external_lex_state = 9},
  [1027] = {.lex_state = 56, .external_lex_state = 9},
  [1028] = {.lex_state = 56, .external_lex_state = 9},
  [1029] = {.lex_state = 56, .external_lex_state = 9},
  [1030] = {.lex_state = 26, .external_lex_state = 9},
  [1031] = {.lex_state = 69, .external_lex_state = 9},
  [1032] = {.lex_state = 26, .external_lex_state = 9},
  [1033] = {.lex_state = 56, .external_lex_state = 9},
  [1034] = {.lex_state = 17, .external_lex_state = 5},
  [1035] = {.lex_state = 69, .external_lex_state = 9},
  [1036] = {.lex_state = 17, .external_lex_state = 5},
  [1037] = {.lex_state = 56, .external_lex_state = 9},
  [1038] = {.lex_state = 56, .external_lex_state = 9},
  [1039] = {.lex_state = 69, .external_lex_state = 9},
  [1040] = {.lex_state = 17, .external_lex_state = 5},
  [1041] = {.lex_state = 17, .external_lex_state = 5},
  [1042] = {.lex_state = 69, .external_lex_state = 9},
  [1043] = {.lex_state = 65, .external_lex_state = 9},
  [1044] = {.lex_state = 65, .external_lex_state = 9},
  [1045] = {.lex_state = 28, .external_lex_state = 9},
  [1046] = {.lex_state = 62, .external_lex_state = 9},
  [1047] = {.lex_state = 10, .external_lex_state = 9},
  [1048] = {.lex_state = 10, .external_lex_state = 9},
  [1049] = {.lex_state = 10, .external_lex_state = 9},
  [1050] = {.lex_state = 48, .external_lex_state = 8},
  [1051] = {.lex_state = 48, .external_lex_state = 8},
  [1052] = {.lex_state = 48, .external_lex_state = 8},
  [1053] = {.lex_state = 48, .external_lex_state = 8},
  [1054] = {.lex_state = 48, .external_lex_state = 8},
  [1055] = {.lex_state = 48, .external_lex_state = 8},
  [1056] = {.lex_state = 48, .external_lex_state = 8},
  [1057] = {.lex_state = 48, .external_lex_state = 8},
  [1058] = {.lex_state = 48, .external_lex_state = 8},
  [1059] = {.lex_state = 48, .external_lex_state = 8},
  [1060] = {.lex_state = 10, .external_lex_state = 9},
  [1061] = {.lex_state = 10, .external_lex_state = 9},
  [1062] = {.lex_state = 10, .external_lex_state = 9},
  [1063] = {.lex_state = 48, .external_lex_state = 8},
  [1064] = {.lex_state = 48, .external_lex_state = 8},
  [1065] = {.lex_state = 48, .external_lex_state = 8},
  [1066] = {.lex_state = 10, .external_lex_state = 9},
  [1067] = {.lex_state = 25, .external_lex_state = 9},
  [1068] = {.lex_state = 10, .external_lex_state = 9},
  [1069] = {.lex_state = 10, .external_lex_state = 9},
  [1070] = {.lex_state = 10, .external_lex_state = 9},
  [1071] = {.lex_state = 48, .external_lex_state = 8},
  [1072] = {.lex_state = 10, .external_lex_state = 9},
  [1073] = {.lex_state = 48, .external_lex_state = 8},
  [1074] = {.lex_state = 48, .external_lex_state = 8},
  [1075] = {.lex_state = 48, .external_lex_state = 8},
  [1076] = {.lex_state = 10, .external_lex_state = 9},
  [1077] = {.lex_state = 10, .external_lex_state = 9},
  [1078] = {.lex_state = 10, .external_lex_state = 9},
  [1079] = {.lex_state = 48, .external_lex_state = 8},
  [1080] = {.lex_state = 10, .external_lex_state = 9},
  [1081] = {.lex_state = 10, .external_lex_state = 9},
  [1082] = {.lex_state = 48, .external_lex_state = 8},
  [1083] = {.lex_state = 10, .external_lex_state = 9},
  [1084] = {.lex_state = 48, .external_lex_state = 8},
  [1085] = {.lex_state = 48, .external_lex_state = 8},
  [1086] = {.lex_state = 48, .external_lex_state = 8},
  [1087] = {.lex_state = 48, .external_lex_state = 8},
  [1088] = {.lex_state = 10, .external_lex_state = 9},
  [1089] = {.lex_state = 10, .external_lex_state = 9},
  [1090] = {.lex_state = 10, .external_lex_state = 9},
  [1091] = {.lex_state = 10, .external_lex_state = 9},
  [1092] = {.lex_state = 10, .external_lex_state = 9},
  [1093] = {.lex_state = 10, .external_lex_state = 9},
  [1094] = {.lex_state = 10, .external_lex_state = 9},
  [1095] = {.lex_state = 10, .external_lex_state = 9},
  [1096] = {.lex_state = 10, .external_lex_state = 9},
  [1097] = {.lex_state = 10, .external_lex_state = 9},
  [1098] = {.lex_state = 10, .external_lex_state = 9},
  [1099] = {.lex_state = 48, .external_lex_state = 8},
  [1100] = {.lex_state = 10, .external_lex_state = 9},
  [1101] = {.lex_state = 10, .external_lex_state = 9},
  [1102] = {.lex_state = 10, .external_lex_state = 9},
  [1103] = {.lex_state = 48, .external_lex_state = 8},
  [1104] = {.lex_state = 10, .external_lex_state = 9},
  [1105] = {.lex_state = 10, .external_lex_state = 9},
  [1106] = {.lex_state = 48, .external_lex_state = 8},
  [1107] = {.lex_state = 48, .external_lex_state = 8},
  [1108] = {.lex_state = 48, .external_lex_state = 8},
  [1109] = {.lex_state = 10, .external_lex_state = 9},
  [1110] = {.lex_state = 10, .external_lex_state = 9},
  [1111] = {.lex_state = 48, .external_lex_state = 8},
  [1112] = {.lex_state = 48, .external_lex_state = 8},
  [1113] = {.lex_state = 10, .external_lex_state = 9},
  [1114] = {.lex_state = 48, .external_lex_state = 8},
  [1115] = {.lex_state = 10, .external_lex_state = 9},
  [1116] = {.lex_state = 10, .external_lex_state = 9},
  [1117] = {.lex_state = 48, .external_lex_state = 8},
  [1118] = {.lex_state = 10, .external_lex_state = 9},
  [1119] = {.lex_state = 48, .external_lex_state = 8},
  [1120] = {.lex_state = 10, .external_lex_state = 9},
  [1121] = {.lex_state = 10, .external_lex_state = 9},
  [1122] = {.lex_state = 10, .external_lex_state = 9},
  [1123] = {.lex_state = 10, .external_lex_state = 9},
  [1124] = {.lex_state = 10, .external_lex_state = 9},
  [1125] = {.lex_state = 10, .external_lex_state = 9},
  [1126] = {.lex_state = 10, .external_lex_state = 9},
  [1127] = {.lex_state = 28, .external_lex_state = 9},
  [1128] = {.lex_state = 48, .external_lex_state = 8},
  [1129] = {.lex_state = 48, .external_lex_state = 8},
  [1130] = {.lex_state = 48, .external_lex_state = 8},
  [1131] = {.lex_state = 48, .external_lex_state = 8},
  [1132] = {.lex_state = 48, .external_lex_state = 8},
  [1133] = {.lex_state = 48, .external_lex_state = 8},
  [1134] = {.lex_state = 48, .external_lex_state = 8},
  [1135] = {.lex_state = 48, .external_lex_state = 8},
  [1136] = {.lex_state = 48, .external_lex_state = 8},
  [1137] = {.lex_state = 48, .external_lex_state = 8},
  [1138] = {.lex_state = 48, .external_lex_state = 8},
  [1139] = {.lex_state = 48, .external_lex_state = 8},
  [1140] = {.lex_state = 48, .external_lex_state = 8},
  [1141] = {.lex_state = 48, .external_lex_state = 8},
  [1142] = {.lex_state = 48, .external_lex_state = 8},
  [1143] = {.lex_state = 48, .external_lex_state = 8},
  [1144] = {.lex_state = 62, .external_lex_state = 9},
  [1145] = {.lex_state = 48, .external_lex_state = 8},
  [1146] = {.lex_state = 62, .external_lex_state = 9},
  [1147] = {.lex_state = 48, .external_lex_state = 8},
  [1148] = {.lex_state = 48, .external_lex_state = 8},
  [1149] = {.lex_state = 48, .external_lex_state = 8},
  [1150] = {.lex_state = 48, .external_lex_state = 8},
  [1151] = {.lex_state = 48, .external_lex_state = 8},
  [1152] = {.lex_state = 48, .external_lex_state = 8},
  [1153] = {.lex_state = 48, .external_lex_state = 8},
  [1154] = {.lex_state = 48, .external_lex_state = 8},
  [1155] = {.lex_state = 56, .external_lex_state = 9},
  [1156] = {.lex_state = 28, .external_lex_state = 9},
  [1157] = {.lex_state = 56, .external_lex_state = 9},
  [1158] = {.lex_state = 10, .external_lex_state = 9},
  [1159] = {.lex_state = 28, .external_lex_state = 9},
  [1160] = {.lex_state = 28, .external_lex_state = 9},
  [1161] = {.lex_state = 66, .external_lex_state = 9},
  [1162] = {.lex_state = 66, .external_lex_state = 9},
  [1163] = {.lex_state = 24, .external_lex_state = 9},
  [1164] = {.lex_state = 48, .external_lex_state = 8},
  [1165] = {.lex_state = 48, .external_lex_state = 8},
  [1166] = {.lex_state = 48, .external_lex_state = 8},
  [1167] = {.lex_state = 56, .external_lex_state = 9},
  [1168] = {.lex_state = 48, .external_lex_state = 8},
  [1169] = {.lex_state = 48, .external_lex_state = 8},
  [1170] = {.lex_state = 48, .external_lex_state = 8},
  [1171] = {.lex_state = 48, .external_lex_state = 8},
  [1172] = {.lex_state = 56, .external_lex_state = 9},
  [1173] = {.lex_state = 48, .external_lex_state = 8},
  [1174] = {.lex_state = 48, .external_lex_state = 8},
  [1175] = {.lex_state = 48, .external_lex_state = 8},
  [1176] = {.lex_state = 62, .external_lex_state = 9},
  [1177] = {.lex_state = 48, .external_lex_state = 8},
  [1178] = {.lex_state = 62, .external_lex_state = 9},
  [1179] = {.lex_state = 69, .external_lex_state = 9},
  [1180] = {.lex_state = 69, .external_lex_state = 9},
  [1181] = {.lex_state = 69, .external_lex_state = 9},
  [1182] = {.lex_state = 24, .external_lex_state = 9},
  [1183] = {.lex_state = 24, .external_lex_state = 9},
  [1184] = {.lex_state = 69, .external_lex_state = 9},
  [1185] = {.lex_state = 69, .external_lex_state = 9},
  [1186] = {.lex_state = 69, .external_lex_state = 9},
  [1187] = {.lex_state = 48, .external_lex_state = 8},
  [1188] = {.lex_state = 69, .external_lex_state = 9},
  [1189] = {.lex_state = 48, .external_lex_state = 8},
  [1190] = {.lex_state = 48, .external_lex_state = 8},
  [1191] = {.lex_state = 48, .external_lex_state = 8},
  [1192] = {.lex_state = 48, .external_lex_state = 8},
  [1193] = {.lex_state = 48, .external_lex_state = 8},
  [1194] = {.lex_state = 62, .external_lex_state = 9},
  [1195] = {.lex_state = 62, .external_lex_state = 9},
  [1196] = {.lex_state = 48, .external_lex_state = 8},
  [1197] = {.lex_state = 48, .external_lex_state = 8},
  [1198] = {.lex_state = 48, .external_lex_state = 8},
  [1199] = {.lex_state = 48, .external_lex_state = 8},
  [1200] = {.lex_state = 48, .external_lex_state = 8},
  [1201] = {.lex_state = 48, .external_lex_state = 8},
  [1202] = {.lex_state = 48, .external_lex_state = 8},
  [1203] = {.lex_state = 48, .external_lex_state = 8},
  [1204] = {.lex_state = 28, .external_lex_state = 9},
  [1205] = {.lex_state = 28, .external_lex_state = 9},
  [1206] = {.lex_state = 10, .external_lex_state = 9},
  [1207] = {.lex_state = 48, .external_lex_state = 8},
  [1208] = {.lex_state = 48, .external_lex_state = 8},
  [1209] = {.lex_state = 48, .external_lex_state = 8},
  [1210] = {.lex_state = 48, .external_lex_state = 8},
  [1211] = {.lex_state = 48, .external_lex_state = 8},
  [1212] = {.lex_state = 48, .external_lex_state = 8},
  [1213] = {.lex_state = 48, .external_lex_state = 8},
  [1214] = {.lex_state = 48, .external_lex_state = 8},
  [1215] = {.lex_state = 48, .external_lex_state = 8},
  [1216] = {.lex_state = 48, .external_lex_state = 8},
  [1217] = {.lex_state = 48, .external_lex_state = 8},
  [1218] = {.lex_state = 48, .external_lex_state = 8},
  [1219] = {.lex_state = 48, .external_lex_state = 8},
  [1220] = {.lex_state = 48, .external_lex_state = 8},
  [1221] = {.lex_state = 48, .external_lex_state = 8},
  [1222] = {.lex_state = 48, .external_lex_state = 8},
  [1223] = {.lex_state = 48, .external_lex_state = 8},
  [1224] = {.lex_state = 48, .external_lex_state = 8},
  [1225] = {.lex_state = 48, .external_lex_state = 8},
  [1226] = {.lex_state = 48, .external_lex_state = 8},
  [1227] = {.lex_state = 48, .external_lex_state = 8},
  [1228] = {.lex_state = 48, .external_lex_state = 8},
  [1229] = {.lex_state = 48, .external_lex_state = 8},
  [1230] = {.lex_state = 48, .external_lex_state = 8},
  [1231] = {.lex_state = 48, .external_lex_state = 8},
  [1232] = {.lex_state = 48, .external_lex_state = 8},
  [1233] = {.lex_state = 48, .external_lex_state = 8},
  [1234] = {.lex_state = 48, .external_lex_state = 8},
  [1235] = {.lex_state = 48, .external_lex_state = 8},
  [1236] = {.lex_state = 48, .external_lex_state = 8},
  [1237] = {.lex_state = 48, .external_lex_state = 8},
  [1238] = {.lex_state = 48, .external_lex_state = 8},
  [1239] = {.lex_state = 48, .external_lex_state = 8},
  [1240] = {.lex_state = 48, .external_lex_state = 8},
  [1241] = {.lex_state = 48, .external_lex_state = 8},
  [1242] = {.lex_state = 48, .external_lex_state = 8},
  [1243] = {.lex_state = 48, .external_lex_state = 8},
  [1244] = {.lex_state = 48, .external_lex_state = 8},
  [1245] = {.lex_state = 48, .external_lex_state = 8},
  [1246] = {.lex_state = 48, .external_lex_state = 8},
  [1247] = {.lex_state = 48, .external_lex_state = 8},
  [1248] = {.lex_state = 28, .external_lex_state = 9},
  [1249] = {.lex_state = 48, .external_lex_state = 8},
  [1250] = {.lex_state = 48, .external_lex_state = 8},
  [1251] = {.lex_state = 48, .external_lex_state = 8},
  [1252] = {.lex_state = 48, .external_lex_state = 8},
  [1253] = {.lex_state = 48, .external_lex_state = 8},
  [1254] = {.lex_state = 48, .external_lex_state = 8},
  [1255] = {.lex_state = 48, .external_lex_state = 8},
  [1256] = {.lex_state = 48, .external_lex_state = 8},
  [1257] = {.lex_state = 48, .external_lex_state = 8},
  [1258] = {.lex_state = 48, .external_lex_state = 8},
  [1259] = {.lex_state = 48, .external_lex_state = 8},
  [1260] = {.lex_state = 48, .external_lex_state = 8},
  [1261] = {.lex_state = 48, .external_lex_state = 8},
  [1262] = {.lex_state = 48, .external_lex_state = 8},
  [1263] = {.lex_state = 48, .external_lex_state = 8},
  [1264] = {.lex_state = 48, .external_lex_state = 8},
  [1265] = {.lex_state = 48, .external_lex_state = 8},
  [1266] = {.lex_state = 48, .external_lex_state = 8},
  [1267] = {.lex_state = 48, .external_lex_state = 8},
  [1268] = {.lex_state = 48, .external_lex_state = 8},
  [1269] = {.lex_state = 48, .external_lex_state = 8},
  [1270] = {.lex_state = 48, .external_lex_state = 8},
  [1271] = {.lex_state = 48, .external_lex_state = 8},
  [1272] = {.lex_state = 48, .external_lex_state = 8},
  [1273] = {.lex_state = 48, .external_lex_state = 8},
  [1274] = {.lex_state = 48, .external_lex_state = 8},
  [1275] = {.lex_state = 48, .external_lex_state = 8},
  [1276] = {.lex_state = 48, .external_lex_state = 8},
  [1277] = {.lex_state = 48, .external_lex_state = 8},
  [1278] = {.lex_state = 48, .external_lex_state = 8},
  [1279] = {.lex_state = 48, .external_lex_state = 8},
  [1280] = {.lex_state = 48, .external_lex_state = 8},
  [1281] = {.lex_state = 48, .external_lex_state = 8},
  [1282] = {.lex_state = 48, .external_lex_state = 8},
  [1283] = {.lex_state = 48, .external_lex_state = 8},
  [1284] = {.lex_state = 48, .external_lex_state = 8},
  [1285] = {.lex_state = 48, .external_lex_state = 8},
  [1286] = {.lex_state = 48, .external_lex_state = 8},
  [1287] = {.lex_state = 48, .external_lex_state = 8},
  [1288] = {.lex_state = 48, .external_lex_state = 8},
  [1289] = {.lex_state = 48, .external_lex_state = 8},
  [1290] = {.lex_state = 48, .external_lex_state = 8},
  [1291] = {.lex_state = 48, .external_lex_state = 8},
  [1292] = {.lex_state = 48, .external_lex_state = 8},
  [1293] = {.lex_state = 48, .external_lex_state = 8},
  [1294] = {.lex_state = 48, .external_lex_state = 8},
  [1295] = {.lex_state = 48, .external_lex_state = 8},
  [1296] = {.lex_state = 48, .external_lex_state = 8},
  [1297] = {.lex_state = 48, .external_lex_state = 8},
  [1298] = {.lex_state = 48, .external_lex_state = 8},
  [1299] = {.lex_state = 48, .external_lex_state = 8},
  [1300] = {.lex_state = 48, .external_lex_state = 8},
  [1301] = {.lex_state = 48, .external_lex_state = 8},
  [1302] = {.lex_state = 48, .external_lex_state = 8},
  [1303] = {.lex_state = 48, .external_lex_state = 8},
  [1304] = {.lex_state = 48, .external_lex_state = 8},
  [1305] = {.lex_state = 48, .external_lex_state = 8},
  [1306] = {.lex_state = 48, .external_lex_state = 8},
  [1307] = {.lex_state = 48, .external_lex_state = 8},
  [1308] = {.lex_state = 48, .external_lex_state = 8},
  [1309] = {.lex_state = 48, .external_lex_state = 8},
  [1310] = {.lex_state = 48, .external_lex_state = 8},
  [1311] = {.lex_state = 48, .external_lex_state = 8},
  [1312] = {.lex_state = 48, .external_lex_state = 8},
  [1313] = {.lex_state = 48, .external_lex_state = 8},
  [1314] = {.lex_state = 48, .external_lex_state = 8},
  [1315] = {.lex_state = 48, .external_lex_state = 8},
  [1316] = {.lex_state = 48, .external_lex_state = 8},
  [1317] = {.lex_state = 48, .external_lex_state = 8},
  [1318] = {.lex_state = 48, .external_lex_state = 8},
  [1319] = {.lex_state = 48, .external_lex_state = 8},
  [1320] = {.lex_state = 48, .external_lex_state = 8},
  [1321] = {.lex_state = 48, .external_lex_state = 8},
  [1322] = {.lex_state = 48, .external_lex_state = 8},
  [1323] = {.lex_state = 48, .external_lex_state = 8},
  [1324] = {.lex_state = 48, .external_lex_state = 8},
  [1325] = {.lex_state = 48, .external_lex_state = 8},
  [1326] = {.lex_state = 48, .external_lex_state = 8},
  [1327] = {.lex_state = 48, .external_lex_state = 8},
  [1328] = {.lex_state = 48, .external_lex_state = 8},
  [1329] = {.lex_state = 48, .external_lex_state = 8},
  [1330] = {.lex_state = 48, .external_lex_state = 8},
  [1331] = {.lex_state = 48, .external_lex_state = 8},
  [1332] = {.lex_state = 48, .external_lex_state = 8},
  [1333] = {.lex_state = 48, .external_lex_state = 8},
  [1334] = {.lex_state = 48, .external_lex_state = 8},
  [1335] = {.lex_state = 48, .external_lex_state = 8},
  [1336] = {.lex_state = 48, .external_lex_state = 8},
  [1337] = {.lex_state = 48, .external_lex_state = 8},
  [1338] = {.lex_state = 48, .external_lex_state = 8},
  [1339] = {.lex_state = 48, .external_lex_state = 8},
  [1340] = {.lex_state = 25, .external_lex_state = 9},
  [1341] = {.lex_state = 48, .external_lex_state = 8},
  [1342] = {.lex_state = 21, .external_lex_state = 9},
  [1343] = {.lex_state = 21, .external_lex_state = 9},
  [1344] = {.lex_state = 26, .external_lex_state = 9},
  [1345] = {.lex_state = 26, .external_lex_state = 9},
  [1346] = {.lex_state = 62, .external_lex_state = 9},
  [1347] = {.lex_state = 52, .external_lex_state = 9},
  [1348] = {.lex_state = 52, .external_lex_state = 9},
  [1349] = {.lex_state = 52, .external_lex_state = 9},
  [1350] = {.lex_state = 62, .external_lex_state = 9},
  [1351] = {.lex_state = 66, .external_lex_state = 9},
  [1352] = {.lex_state = 66, .external_lex_state = 9},
  [1353] = {.lex_state = 66, .external_lex_state = 9},
  [1354] = {.lex_state = 25, .external_lex_state = 9},
  [1355] = {.lex_state = 67, .external_lex_state = 9},
  [1356] = {.lex_state = 21, .external_lex_state = 9},
  [1357] = {.lex_state = 21, .external_lex_state = 9},
  [1358] = {.lex_state = 66, .external_lex_state = 9},
  [1359] = {.lex_state = 26, .external_lex_state = 9},
  [1360] = {.lex_state = 52, .external_lex_state = 9},
  [1361] = {.lex_state = 66, .external_lex_state = 9},
  [1362] = {.lex_state = 66, .external_lex_state = 9},
  [1363] = {.lex_state = 25, .external_lex_state = 9},
  [1364] = {.lex_state = 66, .external_lex_state = 9},
  [1365] = {.lex_state = 67, .external_lex_state = 9},
  [1366] = {.lex_state = 67, .external_lex_state = 9},
  [1367] = {.lex_state = 52, .external_lex_state = 9},
  [1368] = {.lex_state = 25, .external_lex_state = 9},
  [1369] = {.lex_state = 26, .external_lex_state = 9},
  [1370] = {.lex_state = 48, .external_lex_state = 8},
  [1371] = {.lex_state = 52, .external_lex_state = 9},
  [1372] = {.lex_state = 52, .external_lex_state = 9},
  [1373] = {.lex_state = 52, .external_lex_state = 9},
  [1374] = {.lex_state = 10, .external_lex_state = 9},
  [1375] = {.lex_state = 21, .external_lex_state = 9},
  [1376] = {.lex_state = 25, .external_lex_state = 9},
  [1377] = {.lex_state = 10, .external_lex_state = 9},
  [1378] = {.lex_state = 21, .external_lex_state = 9},
  [1379] = {.lex_state = 26, .external_lex_state = 9},
  [1380] = {.lex_state = 56, .external_lex_state = 9},
  [1381] = {.lex_state = 10, .external_lex_state = 9},
  [1382] = {.lex_state = 52, .external_lex_state = 9},
  [1383] = {.lex_state = 52, .external_lex_state = 9},
  [1384] = {.lex_state = 52, .external_lex_state = 9},
  [1385] = {.lex_state = 52, .external_lex_state = 9},
  [1386] = {.lex_state = 52, .external_lex_state = 9},
  [1387] = {.lex_state = 52, .external_lex_state = 9},
  [1388] = {.lex_state = 52, .external_lex_state = 9},
  [1389] = {.lex_state = 52, .external_lex_state = 9},
  [1390] = {.lex_state = 52, .external_lex_state = 9},
  [1391] = {.lex_state = 52, .external_lex_state = 9},
  [1392] = {.lex_state = 10, .external_lex_state = 9},
  [1393] = {.lex_state = 52, .external_lex_state = 9},
  [1394] = {.lex_state = 52, .external_lex_state = 9},
  [1395] = {.lex_state = 52, .external_lex_state = 9},
  [1396] = {.lex_state = 52, .external_lex_state = 9},
  [1397] = {.lex_state = 52, .external_lex_state = 9},
  [1398] = {.lex_state = 25, .external_lex_state = 9},
  [1399] = {.lex_state = 21, .external_lex_state = 9},
  [1400] = {.lex_state = 25, .external_lex_state = 9},
  [1401] = {.lex_state = 25, .external_lex_state = 9},
  [1402] = {.lex_state = 67, .external_lex_state = 9},
  [1403] = {.lex_state = 67, .external_lex_state = 9},
  [1404] = {.lex_state = 52, .external_lex_state = 9},
  [1405] = {.lex_state = 6, .external_lex_state = 9},
  [1406] = {.lex_state = 57, .external_lex_state = 9},
  [1407] = {.lex_state = 28, .external_lex_state = 9},
  [1408] = {.lex_state = 52, .external_lex_state = 9},
  [1409] = {.lex_state = 11, .external_lex_state = 9},
  [1410] = {.lex_state = 57, .external_lex_state = 9},
  [1411] = {.lex_state = 57, .external_lex_state = 9},
  [1412] = {.lex_state = 57, .external_lex_state = 9},
  [1413] = {.lex_state = 11, .external_lex_state = 9},
  [1414] = {.lex_state = 11, .external_lex_state = 9},
  [1415] = {.lex_state = 28, .external_lex_state = 9},
  [1416] = {.lex_state = 52, .external_lex_state = 9},
  [1417] = {.lex_state = 28, .external_lex_state = 9},
  [1418] = {.lex_state = 63, .external_lex_state = 9},
  [1419] = {.lex_state = 52, .external_lex_state = 9},
  [1420] = {.lex_state = 57, .external_lex_state = 9},
  [1421] = {.lex_state = 57, .external_lex_state = 9},
  [1422] = {.lex_state = 11, .external_lex_state = 9},
  [1423] = {.lex_state = 57, .external_lex_state = 9},
  [1424] = {.lex_state = 57, .external_lex_state = 9},
  [1425] = {.lex_state = 11, .external_lex_state = 9},
  [1426] = {.lex_state = 11, .external_lex_state = 9},
  [1427] = {.lex_state = 57, .external_lex_state = 9},
  [1428] = {.lex_state = 6, .external_lex_state = 9},
  [1429] = {.lex_state = 69, .external_lex_state = 9},
  [1430] = {.lex_state = 11, .external_lex_state = 9},
  [1431] = {.lex_state = 11, .external_lex_state = 9},
  [1432] = {.lex_state = 6, .external_lex_state = 9},
  [1433] = {.lex_state = 57, .external_lex_state = 9},
  [1434] = {.lex_state = 57, .external_lex_state = 9},
  [1435] = {.lex_state = 11, .external_lex_state = 9},
  [1436] = {.lex_state = 57, .external_lex_state = 9},
  [1437] = {.lex_state = 11, .external_lex_state = 9},
  [1438] = {.lex_state = 57, .external_lex_state = 9},
  [1439] = {.lex_state = 11, .external_lex_state = 9},
  [1440] = {.lex_state = 11, .external_lex_state = 9},
  [1441] = {.lex_state = 52, .external_lex_state = 9},
  [1442] = {.lex_state = 52, .external_lex_state = 9},
  [1443] = {.lex_state = 6, .external_lex_state = 9},
  [1444] = {.lex_state = 57, .external_lex_state = 9},
  [1445] = {.lex_state = 57, .external_lex_state = 9},
  [1446] = {.lex_state = 69, .external_lex_state = 9},
  [1447] = {.lex_state = 69, .external_lex_state = 9},
  [1448] = {.lex_state = 6, .external_lex_state = 9},
  [1449] = {.lex_state = 6, .external_lex_state = 9},
  [1450] = {.lex_state = 6, .external_lex_state = 9},
  [1451] = {.lex_state = 6, .external_lex_state = 9},
  [1452] = {.lex_state = 6, .external_lex_state = 9},
  [1453] = {.lex_state = 6, .external_lex_state = 9},
  [1454] = {.lex_state = 11, .external_lex_state = 9},
  [1455] = {.lex_state = 6, .external_lex_state = 9},
  [1456] = {.lex_state = 52, .external_lex_state = 9},
  [1457] = {.lex_state = 6, .external_lex_state = 9},
  [1458] = {.lex_state = 57, .external_lex_state = 9},
  [1459] = {.lex_state = 11, .external_lex_state = 9},
  [1460] = {.lex_state = 6, .external_lex_state = 9},
  [1461] = {.lex_state = 11, .external_lex_state = 9},
  [1462] = {.lex_state = 57, .external_lex_state = 9},
  [1463] = {.lex_state = 6, .external_lex_state = 9},
  [1464] = {.lex_state = 11, .external_lex_state = 9},
  [1465] = {.lex_state = 6, .external_lex_state = 9},
  [1466] = {.lex_state = 11, .external_lex_state = 9},
  [1467] = {.lex_state = 52, .external_lex_state = 9},
  [1468] = {.lex_state = 57, .external_lex_state = 9},
  [1469] = {.lex_state = 57, .external_lex_state = 9},
  [1470] = {.lex_state = 11, .external_lex_state = 9},
  [1471] = {.lex_state = 6, .external_lex_state = 9},
  [1472] = {.lex_state = 52, .external_lex_state = 9},
  [1473] = {.lex_state = 6, .external_lex_state = 9},
  [1474] = {.lex_state = 11, .external_lex_state = 9},
  [1475] = {.lex_state = 56, .external_lex_state = 9},
  [1476] = {.lex_state = 57, .external_lex_state = 9},
  [1477] = {.lex_state = 52, .external_lex_state = 9},
  [1478] = {.lex_state = 52, .external_lex_state = 9},
  [1479] = {.lex_state = 52, .external_lex_state = 9},
  [1480] = {.lex_state = 57, .external_lex_state = 9},
  [1481] = {.lex_state = 52, .external_lex_state = 9},
  [1482] = {.lex_state = 57, .external_lex_state = 9},
  [1483] = {.lex_state = 6, .external_lex_state = 9},
  [1484] = {.lex_state = 52, .external_lex_state = 9},
  [1485] = {.lex_state = 57, .external_lex_state = 9},
  [1486] = {.lex_state = 10, .external_lex_state = 9},
  [1487] = {.lex_state = 52, .external_lex_state = 9},
  [1488] = {.lex_state = 52, .external_lex_state = 9},
  [1489] = {.lex_state = 11, .external_lex_state = 9},
  [1490] = {.lex_state = 11, .external_lex_state = 9},
  [1491] = {.lex_state = 11, .external_lex_state = 9},
  [1492] = {.lex_state = 11, .external_lex_state = 9},
  [1493] = {.lex_state = 11, .external_lex_state = 9},
  [1494] = {.lex_state = 52, .external_lex_state = 9},
  [1495] = {.lex_state = 6, .external_lex_state = 9},
  [1496] = {.lex_state = 6, .external_lex_state = 9},
  [1497] = {.lex_state = 57, .external_lex_state = 9},
  [1498] = {.lex_state = 52, .external_lex_state = 9},
  [1499] = {.lex_state = 11, .external_lex_state = 9},
  [1500] = {.lex_state = 11, .external_lex_state = 9},
  [1501] = {.lex_state = 52, .external_lex_state = 9},
  [1502] = {.lex_state = 52, .external_lex_state = 9},
  [1503] = {.lex_state = 11, .external_lex_state = 9},
  [1504] = {.lex_state = 11, .external_lex_state = 9},
  [1505] = {.lex_state = 11, .external_lex_state = 9},
  [1506] = {.lex_state = 52, .external_lex_state = 9},
  [1507] = {.lex_state = 11, .external_lex_state = 9},
  [1508] = {.lex_state = 52, .external_lex_state = 9},
  [1509] = {.lex_state = 57, .external_lex_state = 9},
  [1510] = {.lex_state = 52, .external_lex_state = 9},
  [1511] = {.lex_state = 11, .external_lex_state = 9},
  [1512] = {.lex_state = 52, .external_lex_state = 9},
  [1513] = {.lex_state = 11, .external_lex_state = 9},
  [1514] = {.lex_state = 11, .external_lex_state = 9},
  [1515] = {.lex_state = 52, .external_lex_state = 9},
  [1516] = {.lex_state = 52, .external_lex_state = 9},
  [1517] = {.lex_state = 57, .external_lex_state = 9},
  [1518] = {.lex_state = 52, .external_lex_state = 9},
  [1519] = {.lex_state = 52, .external_lex_state = 9},
  [1520] = {.lex_state = 57, .external_lex_state = 9},
  [1521] = {.lex_state = 63, .external_lex_state = 9},
  [1522] = {.lex_state = 11, .external_lex_state = 9},
  [1523] = {.lex_state = 6, .external_lex_state = 9},
  [1524] = {.lex_state = 57, .external_lex_state = 9},
  [1525] = {.lex_state = 57, .external_lex_state = 9},
  [1526] = {.lex_state = 52, .external_lex_state = 9},
  [1527] = {.lex_state = 57, .external_lex_state = 9},
  [1528] = {.lex_state = 57, .external_lex_state = 9},
  [1529] = {.lex_state = 6, .external_lex_state = 9},
  [1530] = {.lex_state = 57, .external_lex_state = 9},
  [1531] = {.lex_state = 57, .external_lex_state = 9},
  [1532] = {.lex_state = 57, .external_lex_state = 9},
  [1533] = {.lex_state = 57, .external_lex_state = 9},
  [1534] = {.lex_state = 57, .external_lex_state = 9},
  [1535] = {.lex_state = 11, .external_lex_state = 9},
  [1536] = {.lex_state = 57, .external_lex_state = 9},
  [1537] = {.lex_state = 57, .external_lex_state = 9},
  [1538] = {.lex_state = 11, .external_lex_state = 9},
  [1539] = {.lex_state = 11, .external_lex_state = 9},
  [1540] = {.lex_state = 21, .external_lex_state = 9},
  [1541] = {.lex_state = 11, .external_lex_state = 9},
  [1542] = {.lex_state = 11, .external_lex_state = 9},
  [1543] = {.lex_state = 21, .external_lex_state = 9},
  [1544] = {.lex_state = 11, .external_lex_state = 9},
  [1545] = {.lex_state = 57, .external_lex_state = 9},
  [1546] = {.lex_state = 11, .external_lex_state = 9},
  [1547] = {.lex_state = 11, .external_lex_state = 9},
  [1548] = {.lex_state = 57, .external_lex_state = 9},
  [1549] = {.lex_state = 57, .external_lex_state = 9},
  [1550] = {.lex_state = 57, .external_lex_state = 9},
  [1551] = {.lex_state = 11, .external_lex_state = 9},
  [1552] = {.lex_state = 57, .external_lex_state = 9},
  [1553] = {.lex_state = 11, .external_lex_state = 9},
  [1554] = {.lex_state = 57, .external_lex_state = 9},
  [1555] = {.lex_state = 57, .external_lex_state = 9},
  [1556] = {.lex_state = 11, .external_lex_state = 9},
  [1557] = {.lex_state = 57, .external_lex_state = 9},
  [1558] = {.lex_state = 52, .external_lex_state = 9},
  [1559] = {.lex_state = 11, .external_lex_state = 9},
  [1560] = {.lex_state = 52, .external_lex_state = 9},
  [1561] = {.lex_state = 11, .external_lex_state = 9},
  [1562] = {.lex_state = 52, .external_lex_state = 9},
  [1563] = {.lex_state = 52, .external_lex_state = 9},
  [1564] = {.lex_state = 11, .external_lex_state = 9},
  [1565] = {.lex_state = 57, .external_lex_state = 9},
  [1566] = {.lex_state = 10, .external_lex_state = 9},
  [1567] = {.lex_state = 6, .external_lex_state = 9},
  [1568] = {.lex_state = 57, .external_lex_state = 9},
  [1569] = {.lex_state = 6, .external_lex_state = 9},
  [1570] = {.lex_state = 25, .external_lex_state = 9},
  [1571] = {.lex_state = 6, .external_lex_state = 9},
  [1572] = {.lex_state = 57, .external_lex_state = 9},
  [1573] = {.lex_state = 6, .external_lex_state = 9},
  [1574] = {.lex_state = 25, .external_lex_state = 9},
  [1575] = {.lex_state = 57, .external_lex_state = 9},
  [1576] = {.lex_state = 6, .external_lex_state = 9},
  [1577] = {.lex_state = 6, .external_lex_state = 9},
  [1578] = {.lex_state = 57, .external_lex_state = 9},
  [1579] = {.lex_state = 66, .external_lex_state = 9},
  [1580] = {.lex_state = 6, .external_lex_state = 9},
  [1581] = {.lex_state = 52, .external_lex_state = 9},
  [1582] = {.lex_state = 6, .external_lex_state = 9},
  [1583] = {.lex_state = 57, .external_lex_state = 9},
  [1584] = {.lex_state = 6, .external_lex_state = 9},
  [1585] = {.lex_state = 6, .external_lex_state = 9},
  [1586] = {.lex_state = 6, .external_lex_state = 9},
  [1587] = {.lex_state = 6, .external_lex_state = 9},
  [1588] = {.lex_state = 56, .external_lex_state = 9},
  [1589] = {.lex_state = 6, .external_lex_state = 9},
  [1590] = {.lex_state = 6, .external_lex_state = 9},
  [1591] = {.lex_state = 6, .external_lex_state = 9},
  [1592] = {.lex_state = 6, .external_lex_state = 9},
  [1593] = {.lex_state = 25, .external_lex_state = 9},
  [1594] = {.lex_state = 6, .external_lex_state = 9},
  [1595] = {.lex_state = 6, .external_lex_state = 9},
  [1596] = {.lex_state = 11, .external_lex_state = 9},
  [1597] = {.lex_state = 6, .external_lex_state = 9},
  [1598] = {.lex_state = 6, .external_lex_state = 9},
  [1599] = {.lex_state = 66, .external_lex_state = 9},
  [1600] = {.lex_state = 6, .external_lex_state = 9},
  [1601] = {.lex_state = 25, .external_lex_state = 9},
  [1602] = {.lex_state = 66, .external_lex_state = 9},
  [1603] = {.lex_state = 66, .external_lex_state = 9},
  [1604] = {.lex_state = 6, .external_lex_state = 9},
  [1605] = {.lex_state = 66, .external_lex_state = 9},
  [1606] = {.lex_state = 6, .external_lex_state = 9},
  [1607] = {.lex_state = 11, .external_lex_state = 9},
  [1608] = {.lex_state = 6, .external_lex_state = 9},
  [1609] = {.lex_state = 6, .external_lex_state = 9},
  [1610] = {.lex_state = 6, .external_lex_state = 9},
  [1611] = {.lex_state = 66, .external_lex_state = 9},
  [1612] = {.lex_state = 25, .external_lex_state = 9},
  [1613] = {.lex_state = 11, .external_lex_state = 9},
  [1614] = {.lex_state = 11, .external_lex_state = 9},
  [1615] = {.lex_state = 66, .external_lex_state = 9},
  [1616] = {.lex_state = 6, .external_lex_state = 9},
  [1617] = {.lex_state = 6, .external_lex_state = 9},
  [1618] = {.lex_state = 6, .external_lex_state = 9},
  [1619] = {.lex_state = 25, .external_lex_state = 9},
  [1620] = {.lex_state = 6, .external_lex_state = 9},
  [1621] = {.lex_state = 6, .external_lex_state = 9},
  [1622] = {.lex_state = 6, .external_lex_state = 9},
  [1623] = {.lex_state = 6, .external_lex_state = 9},
  [1624] = {.lex_state = 6, .external_lex_state = 9},
  [1625] = {.lex_state = 6, .external_lex_state = 9},
  [1626] = {.lex_state = 25, .external_lex_state = 9},
  [1627] = {.lex_state = 11, .external_lex_state = 9},
  [1628] = {.lex_state = 7, .external_lex_state = 9},
  [1629] = {.lex_state = 7, .external_lex_state = 9},
  [1630] = {.lex_state = 7, .external_lex_state = 9},
  [1631] = {.lex_state = 7, .external_lex_state = 9},
  [1632] = {.lex_state = 7, .external_lex_state = 9},
  [1633] = {.lex_state = 7, .external_lex_state = 9},
  [1634] = {.lex_state = 7, .external_lex_state = 9},
  [1635] = {.lex_state = 7, .external_lex_state = 9},
  [1636] = {.lex_state = 53, .external_lex_state = 9},
  [1637] = {.lex_state = 7, .external_lex_state = 9},
  [1638] = {.lex_state = 11, .external_lex_state = 9},
  [1639] = {.lex_state = 53, .external_lex_state = 9},
  [1640] = {.lex_state = 54, .external_lex_state = 11},
  [1641] = {.lex_state = 53, .external_lex_state = 9},
  [1642] = {.lex_state = 53, .external_lex_state = 9},
  [1643] = {.lex_state = 53, .external_lex_state = 9},
  [1644] = {.lex_state = 57, .external_lex_state = 9},
  [1645] = {.lex_state = 7, .external_lex_state = 9},
  [1646] = {.lex_state = 57, .external_lex_state = 9},
  [1647] = {.lex_state = 7, .external_lex_state = 9},
  [1648] = {.lex_state = 7, .external_lex_state = 9},
  [1649] = {.lex_state = 8, .external_lex_state = 11},
  [1650] = {.lex_state = 7, .external_lex_state = 9},
  [1651] = {.lex_state = 54, .external_lex_state = 11},
  [1652] = {.lex_state = 53, .external_lex_state = 9},
  [1653] = {.lex_state = 53, .external_lex_state = 9},
  [1654] = {.lex_state = 53, .external_lex_state = 9},
  [1655] = {.lex_state = 53, .external_lex_state = 9},
  [1656] = {.lex_state = 53, .external_lex_state = 9},
  [1657] = {.lex_state = 53, .external_lex_state = 9},
  [1658] = {.lex_state = 53, .external_lex_state = 9},
  [1659] = {.lex_state = 53, .external_lex_state = 9},
  [1660] = {.lex_state = 53, .external_lex_state = 9},
  [1661] = {.lex_state = 53, .external_lex_state = 9},
  [1662] = {.lex_state = 53, .external_lex_state = 9},
  [1663] = {.lex_state = 53, .external_lex_state = 9},
  [1664] = {.lex_state = 53, .external_lex_state = 9},
  [1665] = {.lex_state = 53, .external_lex_state = 9},
  [1666] = {.lex_state = 53, .external_lex_state = 9},
  [1667] = {.lex_state = 54, .external_lex_state = 11},
  [1668] = {.lex_state = 8, .external_lex_state = 11},
  [1669] = {.lex_state = 25, .external_lex_state = 9},
  [1670] = {.lex_state = 54, .external_lex_state = 11},
  [1671] = {.lex_state = 57, .external_lex_state = 9},
  [1672] = {.lex_state = 11, .external_lex_state = 9},
  [1673] = {.lex_state = 54, .external_lex_state = 11},
  [1674] = {.lex_state = 66, .external_lex_state = 9},
  [1675] = {.lex_state = 66, .external_lex_state = 9},
  [1676] = {.lex_state = 7, .external_lex_state = 9},
  [1677] = {.lex_state = 7, .external_lex_state = 9},
  [1678] = {.lex_state = 7, .external_lex_state = 9},
  [1679] = {.lex_state = 52, .external_lex_state = 9},
  [1680] = {.lex_state = 53, .external_lex_state = 9},
  [1681] = {.lex_state = 25, .external_lex_state = 9},
  [1682] = {.lex_state = 8, .external_lex_state = 11},
  [1683] = {.lex_state = 53, .external_lex_state = 9},
  [1684] = {.lex_state = 53, .external_lex_state = 9},
  [1685] = {.lex_state = 7, .external_lex_state = 9},
  [1686] = {.lex_state = 7, .external_lex_state = 9},
  [1687] = {.lex_state = 7, .external_lex_state = 9},
  [1688] = {.lex_state = 7, .external_lex_state = 9},
  [1689] = {.lex_state = 7, .external_lex_state = 9},
  [1690] = {.lex_state = 11, .external_lex_state = 9},
  [1691] = {.lex_state = 11, .external_lex_state = 9},
  [1692] = {.lex_state = 8, .external_lex_state = 11},
  [1693] = {.lex_state = 8, .external_lex_state = 11},
  [1694] = {.lex_state = 7, .external_lex_state = 9},
  [1695] = {.lex_state = 7, .external_lex_state = 9},
  [1696] = {.lex_state = 7, .external_lex_state = 9},
  [1697] = {.lex_state = 53, .external_lex_state = 9},
  [1698] = {.lex_state = 53, .external_lex_state = 9},
  [1699] = {.lex_state = 7, .external_lex_state = 9},
  [1700] = {.lex_state = 7, .external_lex_state = 9},
  [1701] = {.lex_state = 53, .external_lex_state = 9},
  [1702] = {.lex_state = 53, .external_lex_state = 9},
  [1703] = {.lex_state = 49, .external_lex_state = 7},
  [1704] = {.lex_state = 7, .external_lex_state = 9},
  [1705] = {.lex_state = 7, .external_lex_state = 9},
  [1706] = {.lex_state = 53, .external_lex_state = 9},
  [1707] = {.lex_state = 7, .external_lex_state = 9},
  [1708] = {.lex_state = 7, .external_lex_state = 9},
  [1709] = {.lex_state = 7, .external_lex_state = 9},
  [1710] = {.lex_state = 53, .external_lex_state = 9},
  [1711] = {.lex_state = 53, .external_lex_state = 9},
  [1712] = {.lex_state = 53, .external_lex_state = 9},
  [1713] = {.lex_state = 53, .external_lex_state = 9},
  [1714] = {.lex_state = 53, .external_lex_state = 9},
  [1715] = {.lex_state = 53, .external_lex_state = 9},
  [1716] = {.lex_state = 53, .external_lex_state = 9},
  [1717] = {.lex_state = 7, .external_lex_state = 9},
  [1718] = {.lex_state = 53, .external_lex_state = 9},
  [1719] = {.lex_state = 53, .external_lex_state = 9},
  [1720] = {.lex_state = 53, .external_lex_state = 9},
  [1721] = {.lex_state = 53, .external_lex_state = 9},
  [1722] = {.lex_state = 7, .external_lex_state = 9},
  [1723] = {.lex_state = 7, .external_lex_state = 9},
  [1724] = {.lex_state = 53, .external_lex_state = 9},
  [1725] = {.lex_state = 7, .external_lex_state = 9},
  [1726] = {.lex_state = 7, .external_lex_state = 9},
  [1727] = {.lex_state = 53, .external_lex_state = 9},
  [1728] = {.lex_state = 7, .external_lex_state = 9},
  [1729] = {.lex_state = 7, .external_lex_state = 9},
  [1730] = {.lex_state = 53, .external_lex_state = 9},
  [1731] = {.lex_state = 53, .external_lex_state = 9},
  [1732] = {.lex_state = 7, .external_lex_state = 9},
  [1733] = {.lex_state = 7, .external_lex_state = 9},
  [1734] = {.lex_state = 7, .external_lex_state = 9},
  [1735] = {.lex_state = 53, .external_lex_state = 9},
  [1736] = {.lex_state = 7, .external_lex_state = 9},
  [1737] = {.lex_state = 53, .external_lex_state = 9},
  [1738] = {.lex_state = 53, .external_lex_state = 9},
  [1739] = {.lex_state = 49, .external_lex_state = 7},
  [1740] = {.lex_state = 49, .external_lex_state = 7},
  [1741] = {.lex_state = 49, .external_lex_state = 7},
  [1742] = {.lex_state = 7, .external_lex_state = 9},
  [1743] = {.lex_state = 7, .external_lex_state = 9},
  [1744] = {.lex_state = 53, .external_lex_state = 9},
  [1745] = {.lex_state = 53, .external_lex_state = 9},
  [1746] = {.lex_state = 7, .external_lex_state = 9},
  [1747] = {.lex_state = 53, .external_lex_state = 9},
  [1748] = {.lex_state = 7, .external_lex_state = 9},
  [1749] = {.lex_state = 53, .external_lex_state = 9},
  [1750] = {.lex_state = 7, .external_lex_state = 9},
  [1751] = {.lex_state = 7, .external_lex_state = 9},
  [1752] = {.lex_state = 7, .external_lex_state = 9},
  [1753] = {.lex_state = 7, .external_lex_state = 9},
  [1754] = {.lex_state = 53, .external_lex_state = 9},
  [1755] = {.lex_state = 53, .external_lex_state = 9},
  [1756] = {.lex_state = 7, .external_lex_state = 9},
  [1757] = {.lex_state = 7, .external_lex_state = 9},
  [1758] = {.lex_state = 7, .external_lex_state = 9},
  [1759] = {.lex_state = 7, .external_lex_state = 9},
  [1760] = {.lex_state = 52, .external_lex_state = 9},
  [1761] = {.lex_state = 7, .external_lex_state = 9},
  [1762] = {.lex_state = 7, .external_lex_state = 9},
  [1763] = {.lex_state = 53, .external_lex_state = 9},
  [1764] = {.lex_state = 7, .external_lex_state = 9},
  [1765] = {.lex_state = 49, .external_lex_state = 7},
  [1766] = {.lex_state = 7, .external_lex_state = 9},
  [1767] = {.lex_state = 53, .external_lex_state = 9},
  [1768] = {.lex_state = 7, .external_lex_state = 9},
  [1769] = {.lex_state = 49, .external_lex_state = 7},
  [1770] = {.lex_state = 2, .external_lex_state = 7},
  [1771] = {.lex_state = 53, .external_lex_state = 9},
  [1772] = {.lex_state = 7, .external_lex_state = 9},
  [1773] = {.lex_state = 53, .external_lex_state = 9},
  [1774] = {.lex_state = 53, .external_lex_state = 9},
  [1775] = {.lex_state = 53, .external_lex_state = 9},
  [1776] = {.lex_state = 2, .external_lex_state = 7},
  [1777] = {.lex_state = 56, .external_lex_state = 9},
  [1778] = {.lex_state = 2, .external_lex_state = 7},
  [1779] = {.lex_state = 2, .external_lex_state = 7},
  [1780] = {.lex_state = 2, .external_lex_state = 7},
  [1781] = {.lex_state = 58, .external_lex_state = 11},
  [1782] = {.lex_state = 58, .external_lex_state = 11},
  [1783] = {.lex_state = 12, .external_lex_state = 11},
  [1784] = {.lex_state = 58, .external_lex_state = 11},
  [1785] = {.lex_state = 52, .external_lex_state = 9},
  [1786] = {.lex_state = 58, .external_lex_state = 11},
  [1787] = {.lex_state = 49, .external_lex_state = 7},
  [1788] = {.lex_state = 12, .external_lex_state = 11},
  [1789] = {.lex_state = 12, .external_lex_state = 11},
  [1790] = {.lex_state = 12, .external_lex_state = 11},
  [1791] = {.lex_state = 55, .external_lex_state = 11},
  [1792] = {.lex_state = 49, .external_lex_state = 7},
  [1793] = {.lex_state = 49, .external_lex_state = 7},
  [1794] = {.lex_state = 49, .external_lex_state = 7},
  [1795] = {.lex_state = 14, .external_lex_state = 11},
  [1796] = {.lex_state = 49, .external_lex_state = 7},
  [1797] = {.lex_state = 49, .external_lex_state = 7},
  [1798] = {.lex_state = 14, .external_lex_state = 11},
  [1799] = {.lex_state = 55, .external_lex_state = 11},
  [1800] = {.lex_state = 49, .external_lex_state = 7},
  [1801] = {.lex_state = 49, .external_lex_state = 7},
  [1802] = {.lex_state = 12, .external_lex_state = 11},
  [1803] = {.lex_state = 12, .external_lex_state = 12},
  [1804] = {.lex_state = 12, .external_lex_state = 11},
  [1805] = {.lex_state = 58, .external_lex_state = 11},
  [1806] = {.lex_state = 58, .external_lex_state = 11},
  [1807] = {.lex_state = 58, .external_lex_state = 11},
  [1808] = {.lex_state = 58, .external_lex_state = 11},
  [1809] = {.lex_state = 12, .external_lex_state = 11},
  [1810] = {.lex_state = 58, .external_lex_state = 11},
  [1811] = {.lex_state = 58, .external_lex_state = 12},
  [1812] = {.lex_state = 58, .external_lex_state = 12},
  [1813] = {.lex_state = 12, .external_lex_state = 11},
  [1814] = {.lex_state = 12, .external_lex_state = 11},
  [1815] = {.lex_state = 12, .external_lex_state = 11},
  [1816] = {.lex_state = 58, .external_lex_state = 11},
  [1817] = {.lex_state = 58, .external_lex_state = 12},
  [1818] = {.lex_state = 12, .external_lex_state = 12},
  [1819] = {.lex_state = 15, .external_lex_state = 11},
  [1820] = {.lex_state = 15, .external_lex_state = 11},
  [1821] = {.lex_state = 60, .external_lex_state = 11},
  [1822] = {.lex_state = 60, .external_lex_state = 11},
  [1823] = {.lex_state = 60, .external_lex_state = 11},
  [1824] = {.lex_state = 60, .external_lex_state = 11},
  [1825] = {.lex_state = 60, .external_lex_state = 11},
  [1826] = {.lex_state = 60, .external_lex_state = 11},
  [1827] = {.lex_state = 60, .external_lex_state = 11},
  [1828] = {.lex_state = 60, .external_lex_state = 11},
  [1829] = {.lex_state = 15, .external_lex_state = 11},
  [1830] = {.lex_state = 60, .external_lex_state = 11},
  [1831] = {.lex_state = 15, .external_lex_state = 11},
  [1832] = {.lex_state = 60, .external_lex_state = 11},
  [1833] = {.lex_state = 60, .external_lex_state = 11},
  [1834] = {.lex_state = 60, .external_lex_state = 11},
  [1835] = {.lex_state = 60, .external_lex_state = 11},
  [1836] = {.lex_state = 15, .external_lex_state = 11},
  [1837] = {.lex_state = 15, .external_lex_state = 11},
  [1838] = {.lex_state = 15, .external_lex_state = 11},
  [1839] = {.lex_state = 15, .external_lex_state = 11},
  [1840] = {.lex_state = 15, .external_lex_state = 11},
  [1841] = {.lex_state = 15, .external_lex_state = 11},
  [1842] = {.lex_state = 15, .external_lex_state = 11},
  [1843] = {.lex_state = 15, .external_lex_state = 11},
  [1844] = {.lex_state = 60, .external_lex_state = 11},
  [1845] = {.lex_state = 60, .external_lex_state = 11},
  [1846] = {.lex_state = 60, .external_lex_state = 11},
  [1847] = {.lex_state = 15, .external_lex_state = 11},
  [1848] = {.lex_state = 60, .external_lex_state = 11},
  [1849] = {.lex_state = 15, .external_lex_state = 11},
  [1850] = {.lex_state = 60, .external_lex_state = 11},
  [1851] = {.lex_state = 60, .external_lex_state = 11},
  [1852] = {.lex_state = 60, .external_lex_state = 11},
  [1853] = {.lex_state = 60, .external_lex_state = 11},
  [1854] = {.lex_state = 60, .external_lex_state = 11},
  [1855] = {.lex_state = 60, .external_lex_state = 11},
  [1856] = {.lex_state = 15, .external_lex_state = 11},
  [1857] = {.lex_state = 15, .external_lex_state = 11},
  [1858] = {.lex_state = 60, .external_lex_state = 11},
  [1859] = {.lex_state = 15, .external_lex_state = 11},
  [1860] = {.lex_state = 15, .external_lex_state = 11},
  [1861] = {.lex_state = 15, .external_lex_state = 11},
  [1862] = {.lex_state = 15, .external_lex_state = 11},
  [1863] = {.lex_state = 15, .external_lex_state = 11},
  [1864] = {.lex_state = 15, .external_lex_state = 11},
  [1865] = {.lex_state = 60, .external_lex_state = 11},
  [1866] = {.lex_state = 60, .external_lex_state = 11},
  [1867] = {.lex_state = 15, .external_lex_state = 11},
  [1868] = {.lex_state = 15, .external_lex_state = 11},
  [1869] = {.lex_state = 60, .external_lex_state = 11},
  [1870] = {.lex_state = 15, .external_lex_state = 11},
  [1871] = {.lex_state = 48, .external_lex_state = 8},
  [1872] = {.lex_state = 15, .external_lex_state = 11},
  [1873] = {.lex_state = 15, .external_lex_state = 11},
  [1874] = {.lex_state = 60, .external_lex_state = 11},
  [1875] = {.lex_state = 60, .external_lex_state = 11},
  [1876] = {.lex_state = 60, .external_lex_state = 11},
  [1877] = {.lex_state = 60, .external_lex_state = 11},
  [1878] = {.lex_state = 12, .external_lex_state = 12},
  [1879] = {.lex_state = 60, .external_lex_state = 11},
  [1880] = {.lex_state = 60, .external_lex_state = 11},
  [1881] = {.lex_state = 15, .external_lex_state = 11},
  [1882] = {.lex_state = 60, .external_lex_state = 11},
  [1883] = {.lex_state = 60, .external_lex_state = 11},
  [1884] = {.lex_state = 60, .external_lex_state = 11},
  [1885] = {.lex_state = 15, .external_lex_state = 11},
  [1886] = {.lex_state = 60, .external_lex_state = 11},
  [1887] = {.lex_state = 15, .external_lex_state = 11},
  [1888] = {.lex_state = 60, .external_lex_state = 11},
  [1889] = {.lex_state = 60, .external_lex_state = 11},
  [1890] = {.lex_state = 58, .external_lex_state = 12},
  [1891] = {.lex_state = 60, .external_lex_state = 11},
  [1892] = {.lex_state = 60, .external_lex_state = 11},
  [1893] = {.lex_state = 60, .external_lex_state = 11},
  [1894] = {.lex_state = 15, .external_lex_state = 11},
  [1895] = {.lex_state = 60, .external_lex_state = 11},
  [1896] = {.lex_state = 15, .external_lex_state = 11},
  [1897] = {.lex_state = 15, .external_lex_state = 11},
  [1898] = {.lex_state = 15, .external_lex_state = 11},
  [1899] = {.lex_state = 15, .external_lex_state = 11},
  [1900] = {.lex_state = 60, .external_lex_state = 11},
  [1901] = {.lex_state = 15, .external_lex_state = 11},
  [1902] = {.lex_state = 15, .external_lex_state = 11},
  [1903] = {.lex_state = 15, .external_lex_state = 11},
  [1904] = {.lex_state = 15, .external_lex_state = 11},
  [1905] = {.lex_state = 15, .external_lex_state = 11},
  [1906] = {.lex_state = 15, .external_lex_state = 11},
  [1907] = {.lex_state = 15, .external_lex_state = 11},
  [1908] = {.lex_state = 15, .external_lex_state = 11},
  [1909] = {.lex_state = 15, .external_lex_state = 11},
  [1910] = {.lex_state = 15, .external_lex_state = 11},
  [1911] = {.lex_state = 15, .external_lex_state = 11},
  [1912] = {.lex_state = 15, .external_lex_state = 11},
  [1913] = {.lex_state = 15, .external_lex_state = 11},
  [1914] = {.lex_state = 15, .external_lex_state = 11},
  [1915] = {.lex_state = 60, .external_lex_state = 11},
  [1916] = {.lex_state = 60, .external_lex_state = 11},
  [1917] = {.lex_state = 60, .external_lex_state = 11},
  [1918] = {.lex_state = 60, .external_lex_state = 11},
  [1919] = {.lex_state = 60, .external_lex_state = 11},
  [1920] = {.lex_state = 15, .external_lex_state = 11},
  [1921] = {.lex_state = 60, .external_lex_state = 11},
  [1922] = {.lex_state = 4, .external_lex_state = 9},
  [1923] = {.lex_state = 15, .external_lex_state = 11},
  [1924] = {.lex_state = 58, .external_lex_state = 12},
  [1925] = {.lex_state = 60, .external_lex_state = 11},
  [1926] = {.lex_state = 60, .external_lex_state = 11},
  [1927] = {.lex_state = 4, .external_lex_state = 9},
  [1928] = {.lex_state = 48, .external_lex_state = 8},
  [1929] = {.lex_state = 15, .external_lex_state = 11},
  [1930] = {.lex_state = 60, .external_lex_state = 11},
  [1931] = {.lex_state = 48, .external_lex_state = 8},
  [1932] = {.lex_state = 60, .external_lex_state = 11},
  [1933] = {.lex_state = 59, .external_lex_state = 11},
  [1934] = {.lex_state = 60, .external_lex_state = 11},
  [1935] = {.lex_state = 15, .external_lex_state = 11},
  [1936] = {.lex_state = 15, .external_lex_state = 11},
  [1937] = {.lex_state = 4, .external_lex_state = 9},
  [1938] = {.lex_state = 15, .external_lex_state = 11},
  [1939] = {.lex_state = 15, .external_lex_state = 11},
  [1940] = {.lex_state = 12, .external_lex_state = 12},
  [1941] = {.lex_state = 13, .external_lex_state = 11},
  [1942] = {.lex_state = 4, .external_lex_state = 9},
  [1943] = {.lex_state = 48, .external_lex_state = 8},
  [1944] = {.lex_state = 60, .external_lex_state = 11},
  [1945] = {.lex_state = 12, .external_lex_state = 12},
  [1946] = {.lex_state = 81},
  [1947] = {.lex_state = 58, .external_lex_state = 12},
  [1948] = {.lex_state = 60, .external_lex_state = 11},
  [1949] = {.lex_state = 48, .external_lex_state = 8},
  [1950] = {.lex_state = 13, .external_lex_state = 11},
  [1951] = {.lex_state = 4, .external_lex_state = 9},
  [1952] = {.lex_state = 59, .external_lex_state = 11},
  [1953] = {.lex_state = 15, .external_lex_state = 11},
  [1954] = {.lex_state = 58, .external_lex_state = 12},
  [1955] = {.lex_state = 13, .external_lex_state = 11},
  [1956] = {.lex_state = 4, .external_lex_state = 9},
  [1957] = {.lex_state = 4, .external_lex_state = 9},
  [1958] = {.lex_state = 59, .external_lex_state = 11},
  [1959] = {.lex_state = 13, .external_lex_state = 11},
  [1960] = {.lex_state = 59, .external_lex_state = 11},
  [1961] = {.lex_state = 59, .external_lex_state = 11},
  [1962] = {.lex_state = 13, .external_lex_state = 11},
  [1963] = {.lex_state = 2, .external_lex_state = 7},
  [1964] = {.lex_state = 48, .external_lex_state = 8},
  [1965] = {.lex_state = 4, .external_lex_state = 9},
  [1966] = {.lex_state = 59, .external_lex_state = 11},
  [1967] = {.lex_state = 13, .external_lex_state = 11},
  [1968] = {.lex_state = 8, .external_lex_state = 11},
  [1969] = {.lex_state = 4, .external_lex_state = 9},
  [1970] = {.lex_state = 4, .external_lex_state = 9},
  [1971] = {.lex_state = 13, .external_lex_state = 11},
  [1972] = {.lex_state = 2, .external_lex_state = 7},
  [1973] = {.lex_state = 2, .external_lex_state = 7},
  [1974] = {.lex_state = 2, .external_lex_state = 7},
  [1975] = {.lex_state = 4, .external_lex_state = 9},
  [1976] = {.lex_state = 48, .external_lex_state = 8},
  [1977] = {.lex_state = 59, .external_lex_state = 11},
  [1978] = {.lex_state = 48, .external_lex_state = 8},
  [1979] = {.lex_state = 59, .external_lex_state = 11},
  [1980] = {.lex_state = 54, .external_lex_state = 11},
  [1981] = {.lex_state = 13, .external_lex_state = 11},
  [1982] = {.lex_state = 48, .external_lex_state = 8},
  [1983] = {.lex_state = 4, .external_lex_state = 9},
  [1984] = {.lex_state = 4, .external_lex_state = 9},
  [1985] = {.lex_state = 59, .external_lex_state = 11},
  [1986] = {.lex_state = 13, .external_lex_state = 11},
  [1987] = {.lex_state = 58, .external_lex_state = 12},
  [1988] = {.lex_state = 50, .external_lex_state = 9},
  [1989] = {.lex_state = 4, .external_lex_state = 9},
  [1990] = {.lex_state = 4, .external_lex_state = 9},
  [1991] = {.lex_state = 4, .external_lex_state = 9},
  [1992] = {.lex_state = 61, .external_lex_state = 11},
  [1993] = {.lex_state = 50, .external_lex_state = 9},
  [1994] = {.lex_state = 50, .external_lex_state = 9},
  [1995] = {.lex_state = 4, .external_lex_state = 9},
  [1996] = {.lex_state = 50, .external_lex_state = 9},
  [1997] = {.lex_state = 50, .external_lex_state = 9},
  [1998] = {.lex_state = 50, .external_lex_state = 9},
  [1999] = {.lex_state = 50, .external_lex_state = 9},
  [2000] = {.lex_state = 50, .external_lex_state = 9},
  [2001] = {.lex_state = 50, .external_lex_state = 9},
  [2002] = {.lex_state = 50, .external_lex_state = 9},
  [2003] = {.lex_state = 50, .external_lex_state = 9},
  [2004] = {.lex_state = 50, .external_lex_state = 9},
  [2005] = {.lex_state = 50, .external_lex_state = 9},
  [2006] = {.lex_state = 58, .external_lex_state = 13},
  [2007] = {.lex_state = 50, .external_lex_state = 9},
  [2008] = {.lex_state = 50, .external_lex_state = 9},
  [2009] = {.lex_state = 17, .external_lex_state = 13},
  [2010] = {.lex_state = 4, .external_lex_state = 9},
  [2011] = {.lex_state = 4, .external_lex_state = 9},
  [2012] = {.lex_state = 4, .external_lex_state = 9},
  [2013] = {.lex_state = 4, .external_lex_state = 9},
  [2014] = {.lex_state = 4, .external_lex_state = 9},
  [2015] = {.lex_state = 4, .external_lex_state = 9},
  [2016] = {.lex_state = 50, .external_lex_state = 9},
  [2017] = {.lex_state = 4, .external_lex_state = 9},
  [2018] = {.lex_state = 4, .external_lex_state = 9},
  [2019] = {.lex_state = 4, .external_lex_state = 9},
  [2020] = {.lex_state = 50, .external_lex_state = 9},
  [2021] = {.lex_state = 50, .external_lex_state = 9},
  [2022] = {.lex_state = 50, .external_lex_state = 9},
  [2023] = {.lex_state = 50, .external_lex_state = 9},
  [2024] = {.lex_state = 50, .external_lex_state = 9},
  [2025] = {.lex_state = 50, .external_lex_state = 9},
  [2026] = {.lex_state = 4, .external_lex_state = 9},
  [2027] = {.lex_state = 4, .external_lex_state = 9},
  [2028] = {.lex_state = 4, .external_lex_state = 9},
  [2029] = {.lex_state = 50, .external_lex_state = 9},
  [2030] = {.lex_state = 15, .external_lex_state = 11},
  [2031] = {.lex_state = 60, .external_lex_state = 11},
  [2032] = {.lex_state = 50, .external_lex_state = 9},
  [2033] = {.lex_state = 50, .external_lex_state = 9},
  [2034] = {.lex_state = 60, .external_lex_state = 11},
  [2035] = {.lex_state = 8, .external_lex_state = 11},
  [2036] = {.lex_state = 15, .external_lex_state = 11},
  [2037] = {.lex_state = 50, .external_lex_state = 9},
  [2038] = {.lex_state = 58, .external_lex_state = 13},
  [2039] = {.lex_state = 50, .external_lex_state = 9},
  [2040] = {.lex_state = 4, .external_lex_state = 9},
  [2041] = {.lex_state = 4, .external_lex_state = 9},
  [2042] = {.lex_state = 60, .external_lex_state = 11},
  [2043] = {.lex_state = 50, .external_lex_state = 9},
  [2044] = {.lex_state = 50, .external_lex_state = 9},
  [2045] = {.lex_state = 17, .external_lex_state = 13},
  [2046] = {.lex_state = 15, .external_lex_state = 11},
  [2047] = {.lex_state = 50, .external_lex_state = 9},
  [2048] = {.lex_state = 4, .external_lex_state = 9},
  [2049] = {.lex_state = 4, .external_lex_state = 9},
  [2050] = {.lex_state = 4, .external_lex_state = 9},
  [2051] = {.lex_state = 4, .external_lex_state = 9},
  [2052] = {.lex_state = 16, .external_lex_state = 11},
  [2053] = {.lex_state = 50, .external_lex_state = 9},
  [2054] = {.lex_state = 4, .external_lex_state = 9},
  [2055] = {.lex_state = 16, .external_lex_state = 11},
  [2056] = {.lex_state = 48, .external_lex_state = 8},
  [2057] = {.lex_state = 61, .external_lex_state = 11},
  [2058] = {.lex_state = 48, .external_lex_state = 8},
  [2059] = {.lex_state = 50, .external_lex_state = 9},
  [2060] = {.lex_state = 9, .external_lex_state = 13},
  [2061] = {.lex_state = 9, .external_lex_state = 13},
  [2062] = {.lex_state = 54, .external_lex_state = 13},
  [2063] = {.lex_state = 9, .external_lex_state = 13},
  [2064] = {.lex_state = 50, .external_lex_state = 9},
  [2065] = {.lex_state = 49, .external_lex_state = 13},
  [2066] = {.lex_state = 49, .external_lex_state = 13},
  [2067] = {.lex_state = 50, .external_lex_state = 9},
  [2068] = {.lex_state = 9, .external_lex_state = 13},
  [2069] = {.lex_state = 50, .external_lex_state = 9},
  [2070] = {.lex_state = 50, .external_lex_state = 9},
  [2071] = {.lex_state = 54, .external_lex_state = 13},
  [2072] = {.lex_state = 54, .external_lex_state = 13},
  [2073] = {.lex_state = 9, .external_lex_state = 13},
  [2074] = {.lex_state = 146, .external_lex_state = 2},
  [2075] = {.lex_state = 146, .external_lex_state = 2},
  [2076] = {.lex_state = 54, .external_lex_state = 13},
  [2077] = {.lex_state = 9, .external_lex_state = 13},
  [2078] = {.lex_state = 54, .external_lex_state = 13},
  [2079] = {.lex_state = 54, .external_lex_state = 13},
  [2080] = {.lex_state = 9, .external_lex_state = 13},
  [2081] = {.lex_state = 54, .external_lex_state = 13},
  [2082] = {.lex_state = 49, .external_lex_state = 13},
  [2083] = {.lex_state = 9, .external_lex_state = 13},
  [2084] = {.lex_state = 54, .external_lex_state = 13},
  [2085] = {.lex_state = 49, .external_lex_state = 13},
  [2086] = {.lex_state = 54, .external_lex_state = 13},
  [2087] = {.lex_state = 54, .external_lex_state = 13},
  [2088] = {.lex_state = 54, .external_lex_state = 13},
  [2089] = {.lex_state = 2, .external_lex_state = 13},
  [2090] = {.lex_state = 2, .external_lex_state = 13},
  [2091] = {.lex_state = 146, .external_lex_state = 2},
  [2092] = {.lex_state = 146, .external_lex_state = 2},
  [2093] = {.lex_state = 2, .external_lex_state = 13},
  [2094] = {.lex_state = 54, .external_lex_state = 13},
  [2095] = {.lex_state = 2, .external_lex_state = 13},
  [2096] = {.lex_state = 49, .external_lex_state = 11},
  [2097] = {.lex_state = 2, .external_lex_state = 13},
  [2098] = {.lex_state = 49, .external_lex_state = 13},
  [2099] = {.lex_state = 54, .external_lex_state = 13},
  [2100] = {.lex_state = 49, .external_lex_state = 13},
  [2101] = {.lex_state = 50, .external_lex_state = 9},
  [2102] = {.lex_state = 49, .external_lex_state = 13},
  [2103] = {.lex_state = 54, .external_lex_state = 13},
  [2104] = {.lex_state = 54, .external_lex_state = 13},
  [2105] = {.lex_state = 2, .external_lex_state = 13},
  [2106] = {.lex_state = 54, .external_lex_state = 13},
  [2107] = {.lex_state = 49, .external_lex_state = 13},
  [2108] = {.lex_state = 54, .external_lex_state = 13},
  [2109] = {.lex_state = 49, .external_lex_state = 13},
  [2110] = {.lex_state = 54, .external_lex_state = 13},
  [2111] = {.lex_state = 54, .external_lex_state = 11},
  [2112] = {.lex_state = 54, .external_lex_state = 13},
  [2113] = {.lex_state = 50, .external_lex_state = 9},
  [2114] = {.lex_state = 2, .external_lex_state = 13},
  [2115] = {.lex_state = 49, .external_lex_state = 13},
  [2116] = {.lex_state = 49, .external_lex_state = 13},
  [2117] = {.lex_state = 54, .external_lex_state = 13},
  [2118] = {.lex_state = 50, .external_lex_state = 9},
  [2119] = {.lex_state = 13, .external_lex_state = 11},
  [2120] = {.lex_state = 49, .external_lex_state = 13},
  [2121] = {.lex_state = 9, .external_lex_state = 13},
  [2122] = {.lex_state = 2, .external_lex_state = 13},
  [2123] = {.lex_state = 13, .external_lex_state = 11},
  [2124] = {.lex_state = 2, .external_lex_state = 11},
  [2125] = {.lex_state = 2, .external_lex_state = 13},
  [2126] = {.lex_state = 146, .external_lex_state = 2},
  [2127] = {.lex_state = 49, .external_lex_state = 11},
  [2128] = {.lex_state = 50, .external_lex_state = 9},
  [2129] = {.lex_state = 50, .external_lex_state = 9},
  [2130] = {.lex_state = 59, .external_lex_state = 11},
  [2131] = {.lex_state = 54, .external_lex_state = 13},
  [2132] = {.lex_state = 146, .external_lex_state = 2},
  [2133] = {.lex_state = 2, .external_lex_state = 13},
  [2134] = {.lex_state = 50, .external_lex_state = 9},
  [2135] = {.lex_state = 54, .external_lex_state = 13},
  [2136] = {.lex_state = 48, .external_lex_state = 8},
  [2137] = {.lex_state = 59, .external_lex_state = 11},
  [2138] = {.lex_state = 54, .external_lex_state = 13},
  [2139] = {.lex_state = 49, .external_lex_state = 13},
  [2140] = {.lex_state = 50, .external_lex_state = 9},
  [2141] = {.lex_state = 54, .external_lex_state = 13},
  [2142] = {.lex_state = 54, .external_lex_state = 13},
  [2143] = {.lex_state = 9, .external_lex_state = 13},
  [2144] = {.lex_state = 54, .external_lex_state = 13},
  [2145] = {.lex_state = 54, .external_lex_state = 13},
  [2146] = {.lex_state = 54, .external_lex_state = 13},
  [2147] = {.lex_state = 54, .external_lex_state = 13},
  [2148] = {.lex_state = 9, .external_lex_state = 13},
  [2149] = {.lex_state = 54, .external_lex_state = 13},
  [2150] = {.lex_state = 13, .external_lex_state = 11},
  [2151] = {.lex_state = 54, .external_lex_state = 13},
  [2152] = {.lex_state = 146, .external_lex_state = 2},
  [2153] = {.lex_state = 50, .external_lex_state = 9},
  [2154] = {.lex_state = 9, .external_lex_state = 13},
  [2155] = {.lex_state = 54, .external_lex_state = 13},
  [2156] = {.lex_state = 49, .external_lex_state = 13},
  [2157] = {.lex_state = 9, .external_lex_state = 13},
  [2158] = {.lex_state = 54, .external_lex_state = 13},
  [2159] = {.lex_state = 59, .external_lex_state = 11},
  [2160] = {.lex_state = 49, .external_lex_state = 13},
  [2161] = {.lex_state = 2, .external_lex_state = 13},
  [2162] = {.lex_state = 49, .external_lex_state = 13},
  [2163] = {.lex_state = 48, .external_lex_state = 8},
  [2164] = {.lex_state = 2, .external_lex_state = 13},
  [2165] = {.lex_state = 9, .external_lex_state = 13},
  [2166] = {.lex_state = 2, .external_lex_state = 13},
  [2167] = {.lex_state = 54, .external_lex_state = 13},
  [2168] = {.lex_state = 49, .external_lex_state = 13},
  [2169] = {.lex_state = 146, .external_lex_state = 2},
  [2170] = {.lex_state = 146, .external_lex_state = 2},
  [2171] = {.lex_state = 54, .external_lex_state = 13},
  [2172] = {.lex_state = 2, .external_lex_state = 13},
  [2173] = {.lex_state = 49, .external_lex_state = 13},
  [2174] = {.lex_state = 51, .external_lex_state = 9},
  [2175] = {.lex_state = 2, .external_lex_state = 13},
  [2176] = {.lex_state = 146, .external_lex_state = 2},
  [2177] = {.lex_state = 2, .external_lex_state = 13},
  [2178] = {.lex_state = 146, .external_lex_state = 2},
  [2179] = {.lex_state = 146, .external_lex_state = 2},
  [2180] = {.lex_state = 146, .external_lex_state = 2},
  [2181] = {.lex_state = 146, .external_lex_state = 2},
  [2182] = {.lex_state = 2, .external_lex_state = 13},
  [2183] = {.lex_state = 49, .external_lex_state = 13},
  [2184] = {.lex_state = 50, .external_lex_state = 9},
  [2185] = {.lex_state = 2, .external_lex_state = 13},
  [2186] = {.lex_state = 50, .external_lex_state = 9},
  [2187] = {.lex_state = 9, .external_lex_state = 13},
  [2188] = {.lex_state = 54, .external_lex_state = 13},
  [2189] = {.lex_state = 9, .external_lex_state = 13},
  [2190] = {.lex_state = 9, .external_lex_state = 13},
  [2191] = {.lex_state = 9, .external_lex_state = 13},
  [2192] = {.lex_state = 54, .external_lex_state = 13},
  [2193] = {.lex_state = 9, .external_lex_state = 13},
  [2194] = {.lex_state = 54, .external_lex_state = 13},
  [2195] = {.lex_state = 9, .external_lex_state = 13},
  [2196] = {.lex_state = 9, .external_lex_state = 13},
  [2197] = {.lex_state = 9, .external_lex_state = 13},
  [2198] = {.lex_state = 54, .external_lex_state = 13},
  [2199] = {.lex_state = 9, .external_lex_state = 13},
  [2200] = {.lex_state = 9, .external_lex_state = 13},
  [2201] = {.lex_state = 9, .external_lex_state = 13},
  [2202] = {.lex_state = 50, .external_lex_state = 9},
  [2203] = {.lex_state = 49, .external_lex_state = 13},
  [2204] = {.lex_state = 9, .external_lex_state = 13},
  [2205] = {.lex_state = 9, .external_lex_state = 13},
  [2206] = {.lex_state = 9, .external_lex_state = 13},
  [2207] = {.lex_state = 146, .external_lex_state = 2},
  [2208] = {.lex_state = 9, .external_lex_state = 13},
  [2209] = {.lex_state = 9, .external_lex_state = 13},
  [2210] = {.lex_state = 50, .external_lex_state = 9},
  [2211] = {.lex_state = 9, .external_lex_state = 13},
  [2212] = {.lex_state = 49, .external_lex_state = 13},
  [2213] = {.lex_state = 9, .external_lex_state = 13},
  [2214] = {.lex_state = 9, .external_lex_state = 13},
  [2215] = {.lex_state = 9, .external_lex_state = 13},
  [2216] = {.lex_state = 9, .external_lex_state = 13},
  [2217] = {.lex_state = 50, .external_lex_state = 9},
  [2218] = {.lex_state = 2, .external_lex_state = 13},
  [2219] = {.lex_state = 9, .external_lex_state = 13},
  [2220] = {.lex_state = 54, .external_lex_state = 13},
  [2221] = {.lex_state = 9, .external_lex_state = 13},
  [2222] = {.lex_state = 54, .external_lex_state = 13},
  [2223] = {.lex_state = 9, .external_lex_state = 13},
  [2224] = {.lex_state = 146, .external_lex_state = 2},
  [2225] = {.lex_state = 54, .external_lex_state = 13},
  [2226] = {.lex_state = 54, .external_lex_state = 13},
  [2227] = {.lex_state = 9, .external_lex_state = 13},
  [2228] = {.lex_state = 9, .external_lex_state = 13},
  [2229] = {.lex_state = 54, .external_lex_state = 13},
  [2230] = {.lex_state = 9, .external_lex_state = 13},
  [2231] = {.lex_state = 9, .external_lex_state = 13},
  [2232] = {.lex_state = 9, .external_lex_state = 13},
  [2233] = {.lex_state = 2, .external_lex_state = 11},
  [2234] = {.lex_state = 9, .external_lex_state = 13},
  [2235] = {.lex_state = 51, .external_lex_state = 9},
  [2236] = {.lex_state = 9, .external_lex_state = 13},
  [2237] = {.lex_state = 54, .external_lex_state = 13},
  [2238] = {.lex_state = 49, .external_lex_state = 13},
  [2239] = {.lex_state = 9, .external_lex_state = 13},
  [2240] = {.lex_state = 54, .external_lex_state = 13},
  [2241] = {.lex_state = 2, .external_lex_state = 13},
  [2242] = {.lex_state = 9, .external_lex_state = 13},
  [2243] = {.lex_state = 2, .external_lex_state = 13},
  [2244] = {.lex_state = 49, .external_lex_state = 13},
  [2245] = {.lex_state = 54, .external_lex_state = 13},
  [2246] = {.lex_state = 50, .external_lex_state = 9},
  [2247] = {.lex_state = 2, .external_lex_state = 13},
  [2248] = {.lex_state = 54, .external_lex_state = 13},
  [2249] = {.lex_state = 49, .external_lex_state = 13},
  [2250] = {.lex_state = 2, .external_lex_state = 13},
  [2251] = {.lex_state = 49, .external_lex_state = 13},
  [2252] = {.lex_state = 9, .external_lex_state = 13},
  [2253] = {.lex_state = 3, .external_lex_state = 13},
  [2254] = {.lex_state = 51, .external_lex_state = 9},
  [2255] = {.lex_state = 3, .external_lex_state = 9},
  [2256] = {.lex_state = 146, .external_lex_state = 2},
  [2257] = {.lex_state = 3, .external_lex_state = 9},
  [2258] = {.lex_state = 49, .external_lex_state = 13},
  [2259] = {.lex_state = 4, .external_lex_state = 9},
  [2260] = {.lex_state = 2, .external_lex_state = 13},
  [2261] = {.lex_state = 3, .external_lex_state = 9},
  [2262] = {.lex_state = 3, .external_lex_state = 9},
  [2263] = {.lex_state = 4, .external_lex_state = 9},
  [2264] = {.lex_state = 3, .external_lex_state = 9},
  [2265] = {.lex_state = 4, .external_lex_state = 9},
  [2266] = {.lex_state = 4, .external_lex_state = 9},
  [2267] = {.lex_state = 4, .external_lex_state = 9},
  [2268] = {.lex_state = 54, .external_lex_state = 11},
  [2269] = {.lex_state = 4, .external_lex_state = 9},
  [2270] = {.lex_state = 4, .external_lex_state = 9},
  [2271] = {.lex_state = 3, .external_lex_state = 9},
  [2272] = {.lex_state = 3, .external_lex_state = 9},
  [2273] = {.lex_state = 61, .external_lex_state = 11},
  [2274] = {.lex_state = 3, .external_lex_state = 9},
  [2275] = {.lex_state = 3, .external_lex_state = 9},
  [2276] = {.lex_state = 3, .external_lex_state = 9},
  [2277] = {.lex_state = 61, .external_lex_state = 11},
  [2278] = {.lex_state = 3, .external_lex_state = 9},
  [2279] = {.lex_state = 3, .external_lex_state = 14},
  [2280] = {.lex_state = 3, .external_lex_state = 9},
  [2281] = {.lex_state = 3, .external_lex_state = 9},
  [2282] = {.lex_state = 3, .external_lex_state = 9},
  [2283] = {.lex_state = 50, .external_lex_state = 9},
  [2284] = {.lex_state = 3, .external_lex_state = 9},
  [2285] = {.lex_state = 16, .external_lex_state = 11},
  [2286] = {.lex_state = 3, .external_lex_state = 13},
  [2287] = {.lex_state = 50, .external_lex_state = 9},
  [2288] = {.lex_state = 49, .external_lex_state = 11},
  [2289] = {.lex_state = 3, .external_lex_state = 13},
  [2290] = {.lex_state = 9, .external_lex_state = 13},
  [2291] = {.lex_state = 3, .external_lex_state = 13},
  [2292] = {.lex_state = 50, .external_lex_state = 9},
  [2293] = {.lex_state = 51, .external_lex_state = 9},
  [2294] = {.lex_state = 3, .external_lex_state = 13},
  [2295] = {.lex_state = 50, .external_lex_state = 9},
  [2296] = {.lex_state = 50, .external_lex_state = 9},
  [2297] = {.lex_state = 50, .external_lex_state = 9},
  [2298] = {.lex_state = 49, .external_lex_state = 13},
  [2299] = {.lex_state = 4, .external_lex_state = 9},
  [2300] = {.lex_state = 4, .external_lex_state = 9},
  [2301] = {.lex_state = 50, .external_lex_state = 9},
  [2302] = {.lex_state = 54, .external_lex_state = 11},
  [2303] = {.lex_state = 49, .external_lex_state = 13},
  [2304] = {.lex_state = 50, .external_lex_state = 9},
  [2305] = {.lex_state = 3, .external_lex_state = 9},
  [2306] = {.lex_state = 50, .external_lex_state = 9},
  [2307] = {.lex_state = 49, .external_lex_state = 13},
  [2308] = {.lex_state = 49, .external_lex_state = 13},
  [2309] = {.lex_state = 50, .external_lex_state = 9},
  [2310] = {.lex_state = 49, .external_lex_state = 13},
  [2311] = {.lex_state = 50, .external_lex_state = 9},
  [2312] = {.lex_state = 50, .external_lex_state = 9},
  [2313] = {.lex_state = 49, .external_lex_state = 13},
  [2314] = {.lex_state = 49, .external_lex_state = 13},
  [2315] = {.lex_state = 50, .external_lex_state = 9},
  [2316] = {.lex_state = 49, .external_lex_state = 13},
  [2317] = {.lex_state = 49, .external_lex_state = 13},
  [2318] = {.lex_state = 49, .external_lex_state = 13},
  [2319] = {.lex_state = 4, .external_lex_state = 9},
  [2320] = {.lex_state = 51, .external_lex_state = 9},
  [2321] = {.lex_state = 51, .external_lex_state = 9},
  [2322] = {.lex_state = 51, .external_lex_state = 9},
  [2323] = {.lex_state = 51, .external_lex_state = 9},
  [2324] = {.lex_state = 51, .external_lex_state = 9},
  [2325] = {.lex_state = 51, .external_lex_state = 9},
  [2326] = {.lex_state = 51, .external_lex_state = 9},
  [2327] = {.lex_state = 51, .external_lex_state = 9},
  [2328] = {.lex_state = 51, .external_lex_state = 9},
  [2329] = {.lex_state = 51, .external_lex_state = 9},
  [2330] = {.lex_state = 51, .external_lex_state = 9},
  [2331] = {.lex_state = 51, .external_lex_state = 9},
  [2332] = {.lex_state = 51, .external_lex_state = 9},
  [2333] = {.lex_state = 51, .external_lex_state = 9},
  [2334] = {.lex_state = 51, .external_lex_state = 9},
  [2335] = {.lex_state = 51, .external_lex_state = 9},
  [2336] = {.lex_state = 49, .external_lex_state = 13},
  [2337] = {.lex_state = 49, .external_lex_state = 13},
  [2338] = {.lex_state = 49, .external_lex_state = 13},
  [2339] = {.lex_state = 3, .external_lex_state = 13},
  [2340] = {.lex_state = 50, .external_lex_state = 9},
  [2341] = {.lex_state = 50, .external_lex_state = 9},
  [2342] = {.lex_state = 50, .external_lex_state = 9},
  [2343] = {.lex_state = 9, .external_lex_state = 13},
  [2344] = {.lex_state = 3, .external_lex_state = 13},
  [2345] = {.lex_state = 51, .external_lex_state = 9},
  [2346] = {.lex_state = 3, .external_lex_state = 13},
  [2347] = {.lex_state = 3, .external_lex_state = 13},
  [2348] = {.lex_state = 3, .external_lex_state = 9},
  [2349] = {.lex_state = 50, .external_lex_state = 9},
  [2350] = {.lex_state = 3, .external_lex_state = 9},
  [2351] = {.lex_state = 3, .external_lex_state = 13},
  [2352] = {.lex_state = 49, .external_lex_state = 14},
  [2353] = {.lex_state = 54, .external_lex_state = 13},
  [2354] = {.lex_state = 3, .external_lex_state = 13},
  [2355] = {.lex_state = 49, .external_lex_state = 13},
  [2356] = {.lex_state = 49, .external_lex_state = 13},
  [2357] = {.lex_state = 51, .external_lex_state = 9},
  [2358] = {.lex_state = 51, .external_lex_state = 9},
  [2359] = {.lex_state = 50, .external_lex_state = 9},
  [2360] = {.lex_state = 50, .external_lex_state = 9},
  [2361] = {.lex_state = 49, .external_lex_state = 13},
  [2362] = {.lex_state = 50, .external_lex_state = 9},
  [2363] = {.lex_state = 4, .external_lex_state = 9},
  [2364] = {.lex_state = 4, .external_lex_state = 9},
  [2365] = {.lex_state = 54, .external_lex_state = 13},
  [2366] = {.lex_state = 50, .external_lex_state = 9},
  [2367] = {.lex_state = 50, .external_lex_state = 9},
  [2368] = {.lex_state = 3, .external_lex_state = 9},
  [2369] = {.lex_state = 54, .external_lex_state = 13},
  [2370] = {.lex_state = 18, .external_lex_state = 13},
  [2371] = {.lex_state = 49, .external_lex_state = 11},
  [2372] = {.lex_state = 59, .external_lex_state = 13},
  [2373] = {.lex_state = 3, .external_lex_state = 13},
  [2374] = {.lex_state = 50, .external_lex_state = 9},
  [2375] = {.lex_state = 4, .external_lex_state = 9},
  [2376] = {.lex_state = 3, .external_lex_state = 13},
  [2377] = {.lex_state = 4, .external_lex_state = 9},
  [2378] = {.lex_state = 9, .external_lex_state = 13},
  [2379] = {.lex_state = 54, .external_lex_state = 13},
  [2380] = {.lex_state = 146, .external_lex_state = 2},
  [2381] = {.lex_state = 2, .external_lex_state = 11},
  [2382] = {.lex_state = 51, .external_lex_state = 9},
  [2383] = {.lex_state = 9, .external_lex_state = 13},
  [2384] = {.lex_state = 49, .external_lex_state = 13},
  [2385] = {.lex_state = 3, .external_lex_state = 9},
  [2386] = {.lex_state = 49, .external_lex_state = 13},
  [2387] = {.lex_state = 4, .external_lex_state = 9},
  [2388] = {.lex_state = 4, .external_lex_state = 9},
  [2389] = {.lex_state = 4, .external_lex_state = 9},
  [2390] = {.lex_state = 4, .external_lex_state = 9},
  [2391] = {.lex_state = 3, .external_lex_state = 9},
  [2392] = {.lex_state = 3, .external_lex_state = 9},
  [2393] = {.lex_state = 4, .external_lex_state = 9},
  [2394] = {.lex_state = 51, .external_lex_state = 9},
  [2395] = {.lex_state = 4, .external_lex_state = 9},
  [2396] = {.lex_state = 18, .external_lex_state = 13},
  [2397] = {.lex_state = 3, .external_lex_state = 13},
  [2398] = {.lex_state = 59, .external_lex_state = 13},
  [2399] = {.lex_state = 59, .external_lex_state = 13},
  [2400] = {.lex_state = 50, .external_lex_state = 9},
  [2401] = {.lex_state = 2, .external_lex_state = 11},
  [2402] = {.lex_state = 4, .external_lex_state = 9},
  [2403] = {.lex_state = 49, .external_lex_state = 13},
  [2404] = {.lex_state = 4, .external_lex_state = 9},
  [2405] = {.lex_state = 18, .external_lex_state = 13},
  [2406] = {.lex_state = 3, .external_lex_state = 13},
  [2407] = {.lex_state = 18, .external_lex_state = 13},
  [2408] = {.lex_state = 3, .external_lex_state = 13},
  [2409] = {.lex_state = 49, .external_lex_state = 13},
  [2410] = {.lex_state = 3, .external_lex_state = 13},
  [2411] = {.lex_state = 4, .external_lex_state = 9},
  [2412] = {.lex_state = 3, .external_lex_state = 13},
  [2413] = {.lex_state = 59, .external_lex_state = 13},
  [2414] = {.lex_state = 50, .external_lex_state = 9},
  [2415] = {.lex_state = 49, .external_lex_state = 14},
  [2416] = {.lex_state = 54, .external_lex_state = 11},
  [2417] = {.lex_state = 3, .external_lex_state = 14},
  [2418] = {.lex_state = 3, .external_lex_state = 9},
  [2419] = {.lex_state = 146, .external_lex_state = 2},
  [2420] = {.lex_state = 49, .external_lex_state = 13},
  [2421] = {.lex_state = 146, .external_lex_state = 2},
  [2422] = {.lex_state = 16, .external_lex_state = 11},
  [2423] = {.lex_state = 51, .external_lex_state = 9},
  [2424] = {.lex_state = 49, .external_lex_state = 11},
  [2425] = {.lex_state = 3, .external_lex_state = 9},
  [2426] = {.lex_state = 3, .external_lex_state = 9},
  [2427] = {.lex_state = 3, .external_lex_state = 9},
  [2428] = {.lex_state = 3, .external_lex_state = 9},
  [2429] = {.lex_state = 49, .external_lex_state = 14},
  [2430] = {.lex_state = 3, .external_lex_state = 9},
  [2431] = {.lex_state = 3, .external_lex_state = 9},
  [2432] = {.lex_state = 3, .external_lex_state = 9},
  [2433] = {.lex_state = 3, .external_lex_state = 13},
  [2434] = {.lex_state = 3, .external_lex_state = 9},
  [2435] = {.lex_state = 3, .external_lex_state = 9},
  [2436] = {.lex_state = 3, .external_lex_state = 9},
  [2437] = {.lex_state = 51, .external_lex_state = 9},
  [2438] = {.lex_state = 51, .external_lex_state = 9},
  [2439] = {.lex_state = 51, .external_lex_state = 9},
  [2440] = {.lex_state = 51, .external_lex_state = 9},
  [2441] = {.lex_state = 51, .external_lex_state = 9},
  [2442] = {.lex_state = 51, .external_lex_state = 9},
  [2443] = {.lex_state = 51, .external_lex_state = 9},
  [2444] = {.lex_state = 51, .external_lex_state = 9},
  [2445] = {.lex_state = 51, .external_lex_state = 9},
  [2446] = {.lex_state = 51, .external_lex_state = 9},
  [2447] = {.lex_state = 51, .external_lex_state = 9},
  [2448] = {.lex_state = 51, .external_lex_state = 9},
  [2449] = {.lex_state = 51, .external_lex_state = 9},
  [2450] = {.lex_state = 51, .external_lex_state = 9},
  [2451] = {.lex_state = 3, .external_lex_state = 13},
  [2452] = {.lex_state = 49, .external_lex_state = 13},
  [2453] = {.lex_state = 3, .external_lex_state = 9},
  [2454] = {.lex_state = 3, .external_lex_state = 9},
  [2455] = {.lex_state = 3, .external_lex_state = 9},
  [2456] = {.lex_state = 3, .external_lex_state = 13},
  [2457] = {.lex_state = 3, .external_lex_state = 13},
  [2458] = {.lex_state = 3, .external_lex_state = 13},
  [2459] = {.lex_state = 3, .external_lex_state = 9},
  [2460] = {.lex_state = 3, .external_lex_state = 13},
  [2461] = {.lex_state = 3, .external_lex_state = 9},
  [2462] = {.lex_state = 49, .external_lex_state = 13},
  [2463] = {.lex_state = 59, .external_lex_state = 13},
  [2464] = {.lex_state = 59, .external_lex_state = 13},
  [2465] = {.lex_state = 3, .external_lex_state = 13},
  [2466] = {.lex_state = 49, .external_lex_state = 14},
  [2467] = {.lex_state = 49, .external_lex_state = 14},
  [2468] = {.lex_state = 3, .external_lex_state = 13},
  [2469] = {.lex_state = 3, .external_lex_state = 9},
  [2470] = {.lex_state = 3, .external_lex_state = 9},
  [2471] = {.lex_state = 3, .external_lex_state = 9},
  [2472] = {.lex_state = 3, .external_lex_state = 9},
  [2473] = {.lex_state = 3, .external_lex_state = 9},
  [2474] = {.lex_state = 3, .external_lex_state = 9},
  [2475] = {.lex_state = 3, .external_lex_state = 9},
  [2476] = {.lex_state = 3, .external_lex_state = 9},
  [2477] = {.lex_state = 3, .external_lex_state = 9},
  [2478] = {.lex_state = 3, .external_lex_state = 9},
  [2479] = {.lex_state = 3, .external_lex_state = 9},
  [2480] = {.lex_state = 3, .external_lex_state = 13},
  [2481] = {.lex_state = 3, .external_lex_state = 14},
  [2482] = {.lex_state = 18, .external_lex_state = 13},
  [2483] = {.lex_state = 51, .external_lex_state = 9},
  [2484] = {.lex_state = 3, .external_lex_state = 14},
  [2485] = {.lex_state = 3, .external_lex_state = 9},
  [2486] = {.lex_state = 3, .external_lex_state = 14},
  [2487] = {.lex_state = 18, .external_lex_state = 13},
  [2488] = {.lex_state = 3, .external_lex_state = 9},
  [2489] = {.lex_state = 49, .external_lex_state = 13},
  [2490] = {.lex_state = 50, .external_lex_state = 9},
  [2491] = {.lex_state = 50, .external_lex_state = 9},
  [2492] = {.lex_state = 3, .external_lex_state = 9},
  [2493] = {.lex_state = 3, .external_lex_state = 9},
  [2494] = {.lex_state = 3, .external_lex_state = 9},
  [2495] = {.lex_state = 3, .external_lex_state = 13},
  [2496] = {.lex_state = 3, .external_lex_state = 13},
  [2497] = {.lex_state = 3, .external_lex_state = 13},
  [2498] = {.lex_state = 3, .external_lex_state = 9},
  [2499] = {.lex_state = 3, .external_lex_state = 9},
  [2500] = {.lex_state = 2, .external_lex_state = 11},
  [2501] = {.lex_state = 51, .external_lex_state = 9},
  [2502] = {.lex_state = 51, .external_lex_state = 9},
  [2503] = {.lex_state = 51, .external_lex_state = 9},
  [2504] = {.lex_state = 51, .external_lex_state = 9},
  [2505] = {.lex_state = 3, .external_lex_state = 13},
  [2506] = {.lex_state = 51, .external_lex_state = 9},
  [2507] = {.lex_state = 51, .external_lex_state = 9},
  [2508] = {.lex_state = 3, .external_lex_state = 13},
  [2509] = {.lex_state = 3, .external_lex_state = 9},
  [2510] = {.lex_state = 3, .external_lex_state = 13},
  [2511] = {.lex_state = 3, .external_lex_state = 9},
  [2512] = {.lex_state = 3, .external_lex_state = 9},
  [2513] = {.lex_state = 3, .external_lex_state = 13},
  [2514] = {.lex_state = 3, .external_lex_state = 9},
  [2515] = {.lex_state = 146, .external_lex_state = 2},
  [2516] = {.lex_state = 49, .external_lex_state = 14},
  [2517] = {.lex_state = 3, .external_lex_state = 14},
  [2518] = {.lex_state = 3, .external_lex_state = 13},
  [2519] = {.lex_state = 3, .external_lex_state = 9},
  [2520] = {.lex_state = 49, .external_lex_state = 13},
  [2521] = {.lex_state = 146, .external_lex_state = 2},
  [2522] = {.lex_state = 146, .external_lex_state = 2},
  [2523] = {.lex_state = 49, .external_lex_state = 13},
  [2524] = {.lex_state = 49, .external_lex_state = 13},
  [2525] = {.lex_state = 49, .external_lex_state = 13},
  [2526] = {.lex_state = 49, .external_lex_state = 13},
  [2527] = {.lex_state = 49, .external_lex_state = 13},
  [2528] = {.lex_state = 49, .external_lex_state = 13},
  [2529] = {.lex_state = 49, .external_lex_state = 13},
  [2530] = {.lex_state = 49, .external_lex_state = 13},
  [2531] = {.lex_state = 49, .external_lex_state = 13},
  [2532] = {.lex_state = 49, .external_lex_state = 13},
  [2533] = {.lex_state = 49, .external_lex_state = 13},
  [2534] = {.lex_state = 49, .external_lex_state = 13},
  [2535] = {.lex_state = 49, .external_lex_state = 13},
  [2536] = {.lex_state = 49, .external_lex_state = 13},
  [2537] = {.lex_state = 49, .external_lex_state = 13},
  [2538] = {.lex_state = 3, .external_lex_state = 13},
  [2539] = {.lex_state = 49, .external_lex_state = 13},
  [2540] = {.lex_state = 49, .external_lex_state = 13},
  [2541] = {.lex_state = 49, .external_lex_state = 13},
  [2542] = {.lex_state = 3, .external_lex_state = 13},
  [2543] = {.lex_state = 146, .external_lex_state = 2},
  [2544] = {.lex_state = 49, .external_lex_state = 13},
  [2545] = {.lex_state = 3, .external_lex_state = 9},
  [2546] = {.lex_state = 4, .external_lex_state = 9},
  [2547] = {.lex_state = 3, .external_lex_state = 13},
  [2548] = {.lex_state = 49, .external_lex_state = 13},
  [2549] = {.lex_state = 49, .external_lex_state = 13},
  [2550] = {.lex_state = 4, .external_lex_state = 9},
  [2551] = {.lex_state = 49, .external_lex_state = 13},
  [2552] = {.lex_state = 3, .external_lex_state = 13},
  [2553] = {.lex_state = 49, .external_lex_state = 13},
  [2554] = {.lex_state = 49, .external_lex_state = 13},
  [2555] = {.lex_state = 3, .external_lex_state = 13},
  [2556] = {.lex_state = 49, .external_lex_state = 13},
  [2557] = {.lex_state = 4, .external_lex_state = 9},
  [2558] = {.lex_state = 3, .external_lex_state = 13},
  [2559] = {.lex_state = 3, .external_lex_state = 13},
  [2560] = {.lex_state = 3, .external_lex_state = 13},
  [2561] = {.lex_state = 49, .external_lex_state = 13},
  [2562] = {.lex_state = 4, .external_lex_state = 9},
  [2563] = {.lex_state = 146, .external_lex_state = 2},
  [2564] = {.lex_state = 49, .external_lex_state = 13},
  [2565] = {.lex_state = 49, .external_lex_state = 13},
  [2566] = {.lex_state = 4, .external_lex_state = 9},
  [2567] = {.lex_state = 49, .external_lex_state = 13},
  [2568] = {.lex_state = 49, .external_lex_state = 13},
  [2569] = {.lex_state = 49, .external_lex_state = 13},
  [2570] = {.lex_state = 49, .external_lex_state = 13},
  [2571] = {.lex_state = 49, .external_lex_state = 13},
  [2572] = {.lex_state = 4, .external_lex_state = 9},
  [2573] = {.lex_state = 3, .external_lex_state = 9},
  [2574] = {.lex_state = 4, .external_lex_state = 9},
  [2575] = {.lex_state = 3, .external_lex_state = 13},
  [2576] = {.lex_state = 4, .external_lex_state = 9},
  [2577] = {.lex_state = 3, .external_lex_state = 13},
  [2578] = {.lex_state = 4, .external_lex_state = 9},
  [2579] = {.lex_state = 3, .external_lex_state = 13},
  [2580] = {.lex_state = 3, .external_lex_state = 13},
  [2581] = {.lex_state = 3, .external_lex_state = 13},
  [2582] = {.lex_state = 49, .external_lex_state = 13},
  [2583] = {.lex_state = 3, .external_lex_state = 9},
  [2584] = {.lex_state = 3, .external_lex_state = 13},
  [2585] = {.lex_state = 146, .external_lex_state = 2},
  [2586] = {.lex_state = 146, .external_lex_state = 2},
  [2587] = {.lex_state = 49, .external_lex_state = 13},
  [2588] = {.lex_state = 146, .external_lex_state = 2},
  [2589] = {.lex_state = 49, .external_lex_state = 13},
  [2590] = {.lex_state = 49, .external_lex_state = 13},
  [2591] = {.lex_state = 49, .external_lex_state = 13},
  [2592] = {.lex_state = 49, .external_lex_state = 13},
  [2593] = {.lex_state = 49, .external_lex_state = 13},
  [2594] = {.lex_state = 49, .external_lex_state = 13},
  [2595] = {.lex_state = 3, .external_lex_state = 13},
  [2596] = {.lex_state = 3, .external_lex_state = 9},
  [2597] = {.lex_state = 3, .external_lex_state = 13},
  [2598] = {.lex_state = 3, .external_lex_state = 13},
  [2599] = {.lex_state = 3, .external_lex_state = 9},
  [2600] = {.lex_state = 3, .external_lex_state = 9},
  [2601] = {.lex_state = 3, .external_lex_state = 13},
  [2602] = {.lex_state = 49, .external_lex_state = 13},
  [2603] = {.lex_state = 3, .external_lex_state = 13},
  [2604] = {.lex_state = 49, .external_lex_state = 13},
  [2605] = {.lex_state = 49, .external_lex_state = 13},
  [2606] = {.lex_state = 49, .external_lex_state = 13},
  [2607] = {.lex_state = 49, .external_lex_state = 13},
  [2608] = {.lex_state = 3, .external_lex_state = 13},
  [2609] = {.lex_state = 48, .external_lex_state = 8},
  [2610] = {.lex_state = 3, .external_lex_state = 13},
  [2611] = {.lex_state = 49, .external_lex_state = 13},
  [2612] = {.lex_state = 3, .external_lex_state = 9},
  [2613] = {.lex_state = 4, .external_lex_state = 9},
  [2614] = {.lex_state = 146, .external_lex_state = 2},
  [2615] = {.lex_state = 146, .external_lex_state = 2},
  [2616] = {.lex_state = 3, .external_lex_state = 13},
  [2617] = {.lex_state = 4, .external_lex_state = 9},
  [2618] = {.lex_state = 146, .external_lex_state = 2},
  [2619] = {.lex_state = 146, .external_lex_state = 2},
  [2620] = {.lex_state = 146, .external_lex_state = 2},
  [2621] = {.lex_state = 146, .external_lex_state = 2},
  [2622] = {.lex_state = 146, .external_lex_state = 2},
  [2623] = {.lex_state = 146, .external_lex_state = 2},
  [2624] = {.lex_state = 146, .external_lex_state = 2},
  [2625] = {.lex_state = 146, .external_lex_state = 2},
  [2626] = {.lex_state = 146, .external_lex_state = 2},
  [2627] = {.lex_state = 146, .external_lex_state = 2},
  [2628] = {.lex_state = 146, .external_lex_state = 2},
  [2629] = {.lex_state = 49, .external_lex_state = 13},
  [2630] = {.lex_state = 146, .external_lex_state = 2},
  [2631] = {.lex_state = 146, .external_lex_state = 2},
  [2632] = {.lex_state = 146, .external_lex_state = 2},
  [2633] = {.lex_state = 146, .external_lex_state = 2},
  [2634] = {.lex_state = 146, .external_lex_state = 2},
  [2635] = {.lex_state = 146, .external_lex_state = 2},
  [2636] = {.lex_state = 146, .external_lex_state = 2},
  [2637] = {.lex_state = 146, .external_lex_state = 2},
  [2638] = {.lex_state = 146, .external_lex_state = 2},
  [2639] = {.lex_state = 146, .external_lex_state = 2},
  [2640] = {.lex_state = 146, .external_lex_state = 2},
  [2641] = {.lex_state = 3, .external_lex_state = 9},
  [2642] = {.lex_state = 146, .external_lex_state = 2},
  [2643] = {.lex_state = 146, .external_lex_state = 2},
  [2644] = {.lex_state = 146, .external_lex_state = 2},
  [2645] = {.lex_state = 146, .external_lex_state = 2},
  [2646] = {.lex_state = 146, .external_lex_state = 2},
  [2647] = {.lex_state = 50, .external_lex_state = 9},
  [2648] = {.lex_state = 146, .external_lex_state = 2},
  [2649] = {.lex_state = 146, .external_lex_state = 2},
  [2650] = {.lex_state = 146, .external_lex_state = 2},
  [2651] = {.lex_state = 50, .external_lex_state = 9},
  [2652] = {.lex_state = 49, .external_lex_state = 13},
  [2653] = {.lex_state = 146, .external_lex_state = 2},
  [2654] = {.lex_state = 146, .external_lex_state = 2},
  [2655] = {.lex_state = 146, .external_lex_state = 2},
  [2656] = {.lex_state = 49, .external_lex_state = 13},
  [2657] = {.lex_state = 146, .external_lex_state = 2},
  [2658] = {.lex_state = 146, .external_lex_state = 2},
  [2659] = {.lex_state = 146, .external_lex_state = 2},
  [2660] = {.lex_state = 146, .external_lex_state = 2},
  [2661] = {.lex_state = 49, .external_lex_state = 13},
  [2662] = {.lex_state = 146, .external_lex_state = 2},
  [2663] = {.lex_state = 146, .external_lex_state = 2},
  [2664] = {.lex_state = 146, .external_lex_state = 2},
  [2665] = {.lex_state = 3, .external_lex_state = 9},
  [2666] = {.lex_state = 146, .external_lex_state = 2},
  [2667] = {.lex_state = 146, .external_lex_state = 2},
  [2668] = {.lex_state = 146, .external_lex_state = 2},
  [2669] = {.lex_state = 146, .external_lex_state = 2},
  [2670] = {.lex_state = 146, .external_lex_state = 2},
  [2671] = {.lex_state = 146, .external_lex_state = 2},
  [2672] = {.lex_state = 146, .external_lex_state = 2},
  [2673] = {.lex_state = 146, .external_lex_state = 2},
  [2674] = {.lex_state = 146, .external_lex_state = 2},
  [2675] = {.lex_state = 146, .external_lex_state = 2},
  [2676] = {.lex_state = 146, .external_lex_state = 2},
  [2677] = {.lex_state = 146, .external_lex_state = 2},
  [2678] = {.lex_state = 3, .external_lex_state = 13},
  [2679] = {.lex_state = 146, .external_lex_state = 2},
  [2680] = {.lex_state = 146, .external_lex_state = 2},
  [2681] = {.lex_state = 146, .external_lex_state = 2},
  [2682] = {.lex_state = 146, .external_lex_state = 2},
  [2683] = {.lex_state = 146, .external_lex_state = 2},
  [2684] = {.lex_state = 146, .external_lex_state = 2},
  [2685] = {.lex_state = 146, .external_lex_state = 2},
  [2686] = {.lex_state = 146, .external_lex_state = 2},
  [2687] = {.lex_state = 63},
  [2688] = {.lex_state = 3, .external_lex_state = 9},
  [2689] = {.lex_state = 146, .external_lex_state = 2},
  [2690] = {.lex_state = 146, .external_lex_state = 2},
  [2691] = {.lex_state = 146, .external_lex_state = 2},
  [2692] = {.lex_state = 146, .external_lex_state = 2},
  [2693] = {.lex_state = 146, .external_lex_state = 2},
  [2694] = {.lex_state = 146, .external_lex_state = 2},
  [2695] = {.lex_state = 146, .external_lex_state = 2},
  [2696] = {.lex_state = 146, .external_lex_state = 2},
  [2697] = {.lex_state = 146, .external_lex_state = 2},
  [2698] = {.lex_state = 146, .external_lex_state = 2},
  [2699] = {.lex_state = 146, .external_lex_state = 2},
  [2700] = {.lex_state = 70},
  [2701] = {.lex_state = 70},
  [2702] = {.lex_state = 49, .external_lex_state = 13},
  [2703] = {.lex_state = 63},
  [2704] = {.lex_state = 63},
  [2705] = {.lex_state = 63},
  [2706] = {.lex_state = 85, .external_lex_state = 2},
  [2707] = {.lex_state = 146, .external_lex_state = 2},
  [2708] = {.lex_state = 49, .external_lex_state = 13},
  [2709] = {.lex_state = 70},
  [2710] = {.lex_state = 70},
  [2711] = {.lex_state = 70},
  [2712] = {.lex_state = 63},
  [2713] = {.lex_state = 63},
  [2714] = {.lex_state = 146, .external_lex_state = 2},
  [2715] = {.lex_state = 63},
  [2716] = {.lex_state = 63},
  [2717] = {.lex_state = 70},
  [2718] = {.lex_state = 70},
  [2719] = {.lex_state = 70},
  [2720] = {.lex_state = 70},
  [2721] = {.lex_state = 70},
  [2722] = {.lex_state = 70},
  [2723] = {.lex_state = 70},
  [2724] = {.lex_state = 70},
  [2725] = {.lex_state = 70},
  [2726] = {.lex_state = 70},
  [2727] = {.lex_state = 70},
  [2728] = {.lex_state = 70},
  [2729] = {.lex_state = 70},
  [2730] = {.lex_state = 63},
  [2731] = {.lex_state = 70},
  [2732] = {.lex_state = 70},
  [2733] = {.lex_state = 70},
  [2734] = {.lex_state = 70},
  [2735] = {.lex_state = 70},
  [2736] = {.lex_state = 29, .external_lex_state = 15},
  [2737] = {.lex_state = 70},
  [2738] = {.lex_state = 70},
  [2739] = {.lex_state = 70},
  [2740] = {.lex_state = 70},
  [2741] = {.lex_state = 70},
  [2742] = {.lex_state = 70},
  [2743] = {.lex_state = 70},
  [2744] = {.lex_state = 70},
  [2745] = {.lex_state = 70},
  [2746] = {.lex_state = 70},
  [2747] = {.lex_state = 70},
  [2748] = {.lex_state = 70},
  [2749] = {.lex_state = 70},
  [2750] = {.lex_state = 70},
  [2751] = {.lex_state = 29, .external_lex_state = 15},
  [2752] = {.lex_state = 70},
  [2753] = {.lex_state = 70},
  [2754] = {.lex_state = 70},
  [2755] = {.lex_state = 70},
  [2756] = {.lex_state = 70},
  [2757] = {.lex_state = 70},
  [2758] = {.lex_state = 70},
  [2759] = {.lex_state = 70},
  [2760] = {.lex_state = 70},
  [2761] = {.lex_state = 70},
  [2762] = {.lex_state = 70},
  [2763] = {.lex_state = 70},
  [2764] = {.lex_state = 70},
  [2765] = {.lex_state = 70},
  [2766] = {.lex_state = 70},
  [2767] = {.lex_state = 70},
  [2768] = {.lex_state = 70},
  [2769] = {.lex_state = 70},
  [2770] = {.lex_state = 70},
  [2771] = {.lex_state = 29, .external_lex_state = 15},
  [2772] = {.lex_state = 70},
  [2773] = {.lex_state = 29, .external_lex_state = 15},
  [2774] = {.lex_state = 70},
  [2775] = {.lex_state = 70},
  [2776] = {.lex_state = 70},
  [2777] = {.lex_state = 70},
  [2778] = {.lex_state = 70},
  [2779] = {.lex_state = 70},
  [2780] = {.lex_state = 70},
  [2781] = {.lex_state = 70},
  [2782] = {.lex_state = 70},
  [2783] = {.lex_state = 70},
  [2784] = {.lex_state = 70},
  [2785] = {.lex_state = 70},
  [2786] = {.lex_state = 29, .external_lex_state = 15},
  [2787] = {.lex_state = 70},
  [2788] = {.lex_state = 30, .external_lex_state = 16},
  [2789] = {.lex_state = 54, .external_lex_state = 15},
  [2790] = {.lex_state = 54, .external_lex_state = 15},
  [2791] = {.lex_state = 70},
  [2792] = {.lex_state = 54, .external_lex_state = 15},
  [2793] = {.lex_state = 54, .external_lex_state = 15},
  [2794] = {.lex_state = 54, .external_lex_state = 15},
  [2795] = {.lex_state = 58},
  [2796] = {.lex_state = 58},
  [2797] = {.lex_state = 58},
  [2798] = {.lex_state = 58},
  [2799] = {.lex_state = 58},
  [2800] = {.lex_state = 58},
  [2801] = {.lex_state = 58},
  [2802] = {.lex_state = 58},
  [2803] = {.lex_state = 58},
  [2804] = {.lex_state = 70, .external_lex_state = 17},
  [2805] = {.lex_state = 2},
  [2806] = {.lex_state = 2},
  [2807] = {.lex_state = 2},
  [2808] = {.lex_state = 2},
  [2809] = {.lex_state = 2},
  [2810] = {.lex_state = 2},
  [2811] = {.lex_state = 70},
  [2812] = {.lex_state = 70},
  [2813] = {.lex_state = 70},
  [2814] = {.lex_state = 2},
  [2815] = {.lex_state = 70},
  [2816] = {.lex_state = 33, .external_lex_state = 15},
  [2817] = {.lex_state = 70},
  [2818] = {.lex_state = 70},
  [2819] = {.lex_state = 2},
  [2820] = {.lex_state = 33, .external_lex_state = 15},
  [2821] = {.lex_state = 2},
  [2822] = {.lex_state = 58},
  [2823] = {.lex_state = 63},
  [2824] = {.lex_state = 58},
  [2825] = {.lex_state = 58},
  [2826] = {.lex_state = 70},
  [2827] = {.lex_state = 58},
  [2828] = {.lex_state = 2},
  [2829] = {.lex_state = 58},
  [2830] = {.lex_state = 2},
  [2831] = {.lex_state = 58},
  [2832] = {.lex_state = 2},
  [2833] = {.lex_state = 58},
  [2834] = {.lex_state = 70},
  [2835] = {.lex_state = 58},
  [2836] = {.lex_state = 2},
  [2837] = {.lex_state = 2},
  [2838] = {.lex_state = 63},
  [2839] = {.lex_state = 70},
  [2840] = {.lex_state = 2},
  [2841] = {.lex_state = 52},
  [2842] = {.lex_state = 32, .external_lex_state = 15},
  [2843] = {.lex_state = 52},
  [2844] = {.lex_state = 55, .external_lex_state = 15},
  [2845] = {.lex_state = 52},
  [2846] = {.lex_state = 52},
  [2847] = {.lex_state = 55, .external_lex_state = 15},
  [2848] = {.lex_state = 52},
  [2849] = {.lex_state = 32, .external_lex_state = 15},
  [2850] = {.lex_state = 52},
  [2851] = {.lex_state = 52},
  [2852] = {.lex_state = 2},
  [2853] = {.lex_state = 52},
  [2854] = {.lex_state = 52},
  [2855] = {.lex_state = 52},
  [2856] = {.lex_state = 52},
  [2857] = {.lex_state = 63},
  [2858] = {.lex_state = 2},
  [2859] = {.lex_state = 70},
  [2860] = {.lex_state = 52},
  [2861] = {.lex_state = 52},
  [2862] = {.lex_state = 52},
  [2863] = {.lex_state = 32, .external_lex_state = 15},
  [2864] = {.lex_state = 52},
  [2865] = {.lex_state = 70},
  [2866] = {.lex_state = 2},
  [2867] = {.lex_state = 70},
  [2868] = {.lex_state = 2},
  [2869] = {.lex_state = 2},
  [2870] = {.lex_state = 52},
  [2871] = {.lex_state = 52},
  [2872] = {.lex_state = 52},
  [2873] = {.lex_state = 52},
  [2874] = {.lex_state = 52},
  [2875] = {.lex_state = 52},
  [2876] = {.lex_state = 2},
  [2877] = {.lex_state = 52},
  [2878] = {.lex_state = 2},
  [2879] = {.lex_state = 2},
  [2880] = {.lex_state = 34, .external_lex_state = 15},
  [2881] = {.lex_state = 58, .external_lex_state = 15},
  [2882] = {.lex_state = 32, .external_lex_state = 15},
  [2883] = {.lex_state = 32, .external_lex_state = 15},
  [2884] = {.lex_state = 32, .external_lex_state = 15},
  [2885] = {.lex_state = 58, .external_lex_state = 15},
  [2886] = {.lex_state = 58, .external_lex_state = 15},
  [2887] = {.lex_state = 58, .external_lex_state = 15},
  [2888] = {.lex_state = 34, .external_lex_state = 15},
  [2889] = {.lex_state = 58, .external_lex_state = 15},
  [2890] = {.lex_state = 34, .external_lex_state = 15},
  [2891] = {.lex_state = 34, .external_lex_state = 15},
  [2892] = {.lex_state = 34, .external_lex_state = 15},
  [2893] = {.lex_state = 49},
  [2894] = {.lex_state = 34, .external_lex_state = 15},
  [2895] = {.lex_state = 34, .external_lex_state = 15},
  [2896] = {.lex_state = 34, .external_lex_state = 15},
  [2897] = {.lex_state = 34, .external_lex_state = 15},
  [2898] = {.lex_state = 34, .external_lex_state = 15},
  [2899] = {.lex_state = 34, .external_lex_state = 15},
  [2900] = {.lex_state = 34, .external_lex_state = 15},
  [2901] = {.lex_state = 70},
  [2902] = {.lex_state = 70},
  [2903] = {.lex_state = 34, .external_lex_state = 15},
  [2904] = {.lex_state = 70},
  [2905] = {.lex_state = 70},
  [2906] = {.lex_state = 70},
  [2907] = {.lex_state = 34, .external_lex_state = 15},
  [2908] = {.lex_state = 70},
  [2909] = {.lex_state = 34, .external_lex_state = 15},
  [2910] = {.lex_state = 34, .external_lex_state = 15},
  [2911] = {.lex_state = 70},
  [2912] = {.lex_state = 34, .external_lex_state = 15},
  [2913] = {.lex_state = 34, .external_lex_state = 15},
  [2914] = {.lex_state = 34, .external_lex_state = 15},
  [2915] = {.lex_state = 34, .external_lex_state = 15},
  [2916] = {.lex_state = 34, .external_lex_state = 15},
  [2917] = {.lex_state = 58},
  [2918] = {.lex_state = 34, .external_lex_state = 15},
  [2919] = {.lex_state = 34, .external_lex_state = 15},
  [2920] = {.lex_state = 32, .external_lex_state = 15},
  [2921] = {.lex_state = 34, .external_lex_state = 15},
  [2922] = {.lex_state = 34, .external_lex_state = 15},
  [2923] = {.lex_state = 34, .external_lex_state = 15},
  [2924] = {.lex_state = 34, .external_lex_state = 15},
  [2925] = {.lex_state = 34, .external_lex_state = 15},
  [2926] = {.lex_state = 34, .external_lex_state = 15},
  [2927] = {.lex_state = 49},
  [2928] = {.lex_state = 34, .external_lex_state = 15},
  [2929] = {.lex_state = 34, .external_lex_state = 15},
  [2930] = {.lex_state = 34, .external_lex_state = 15},
  [2931] = {.lex_state = 34, .external_lex_state = 15},
  [2932] = {.lex_state = 34, .external_lex_state = 15},
  [2933] = {.lex_state = 34, .external_lex_state = 15},
  [2934] = {.lex_state = 34, .external_lex_state = 15},
  [2935] = {.lex_state = 34, .external_lex_state = 15},
  [2936] = {.lex_state = 34, .external_lex_state = 15},
  [2937] = {.lex_state = 34, .external_lex_state = 15},
  [2938] = {.lex_state = 34, .external_lex_state = 15},
  [2939] = {.lex_state = 70},
  [2940] = {.lex_state = 34, .external_lex_state = 15},
  [2941] = {.lex_state = 34, .external_lex_state = 15},
  [2942] = {.lex_state = 34, .external_lex_state = 15},
  [2943] = {.lex_state = 34, .external_lex_state = 15},
  [2944] = {.lex_state = 34, .external_lex_state = 15},
  [2945] = {.lex_state = 34, .external_lex_state = 15},
  [2946] = {.lex_state = 70},
  [2947] = {.lex_state = 34, .external_lex_state = 15},
  [2948] = {.lex_state = 70},
  [2949] = {.lex_state = 34, .external_lex_state = 15},
  [2950] = {.lex_state = 34, .external_lex_state = 15},
  [2951] = {.lex_state = 58, .external_lex_state = 15},
  [2952] = {.lex_state = 58, .external_lex_state = 15},
  [2953] = {.lex_state = 34, .external_lex_state = 15},
  [2954] = {.lex_state = 60, .external_lex_state = 15},
  [2955] = {.lex_state = 60, .external_lex_state = 15},
  [2956] = {.lex_state = 31, .external_lex_state = 15},
  [2957] = {.lex_state = 60, .external_lex_state = 15},
  [2958] = {.lex_state = 60, .external_lex_state = 15},
  [2959] = {.lex_state = 60, .external_lex_state = 15},
  [2960] = {.lex_state = 60, .external_lex_state = 15},
  [2961] = {.lex_state = 60, .external_lex_state = 15},
  [2962] = {.lex_state = 60, .external_lex_state = 15},
  [2963] = {.lex_state = 60, .external_lex_state = 15},
  [2964] = {.lex_state = 60, .external_lex_state = 15},
  [2965] = {.lex_state = 60, .external_lex_state = 15},
  [2966] = {.lex_state = 60, .external_lex_state = 15},
  [2967] = {.lex_state = 60, .external_lex_state = 15},
  [2968] = {.lex_state = 60, .external_lex_state = 15},
  [2969] = {.lex_state = 60, .external_lex_state = 15},
  [2970] = {.lex_state = 60, .external_lex_state = 15},
  [2971] = {.lex_state = 60, .external_lex_state = 15},
  [2972] = {.lex_state = 60, .external_lex_state = 15},
  [2973] = {.lex_state = 34, .external_lex_state = 15},
  [2974] = {.lex_state = 60, .external_lex_state = 15},
  [2975] = {.lex_state = 60, .external_lex_state = 15},
  [2976] = {.lex_state = 60, .external_lex_state = 15},
  [2977] = {.lex_state = 60, .external_lex_state = 15},
  [2978] = {.lex_state = 60, .external_lex_state = 15},
  [2979] = {.lex_state = 60, .external_lex_state = 15},
  [2980] = {.lex_state = 60, .external_lex_state = 15},
  [2981] = {.lex_state = 60, .external_lex_state = 15},
  [2982] = {.lex_state = 60, .external_lex_state = 15},
  [2983] = {.lex_state = 60, .external_lex_state = 15},
  [2984] = {.lex_state = 70, .external_lex_state = 17},
  [2985] = {.lex_state = 34, .external_lex_state = 15},
  [2986] = {.lex_state = 60, .external_lex_state = 15},
  [2987] = {.lex_state = 60, .external_lex_state = 15},
  [2988] = {.lex_state = 60, .external_lex_state = 15},
  [2989] = {.lex_state = 60, .external_lex_state = 15},
  [2990] = {.lex_state = 60, .external_lex_state = 15},
  [2991] = {.lex_state = 49},
  [2992] = {.lex_state = 60, .external_lex_state = 15},
  [2993] = {.lex_state = 86},
  [2994] = {.lex_state = 49},
  [2995] = {.lex_state = 60, .external_lex_state = 15},
  [2996] = {.lex_state = 60, .external_lex_state = 15},
  [2997] = {.lex_state = 60, .external_lex_state = 15},
  [2998] = {.lex_state = 60, .external_lex_state = 15},
  [2999] = {.lex_state = 31, .external_lex_state = 15},
  [3000] = {.lex_state = 60, .external_lex_state = 15},
  [3001] = {.lex_state = 60, .external_lex_state = 15},
  [3002] = {.lex_state = 60, .external_lex_state = 15},
  [3003] = {.lex_state = 60, .external_lex_state = 15},
  [3004] = {.lex_state = 60, .external_lex_state = 15},
  [3005] = {.lex_state = 60, .external_lex_state = 15},
  [3006] = {.lex_state = 60, .external_lex_state = 15},
  [3007] = {.lex_state = 60, .external_lex_state = 15},
  [3008] = {.lex_state = 34, .external_lex_state = 15},
  [3009] = {.lex_state = 34, .external_lex_state = 15},
  [3010] = {.lex_state = 34, .external_lex_state = 15},
  [3011] = {.lex_state = 34, .external_lex_state = 15},
  [3012] = {.lex_state = 34, .external_lex_state = 15},
  [3013] = {.lex_state = 60, .external_lex_state = 15},
  [3014] = {.lex_state = 60, .external_lex_state = 15},
  [3015] = {.lex_state = 60, .external_lex_state = 15},
  [3016] = {.lex_state = 60, .external_lex_state = 15},
  [3017] = {.lex_state = 60, .external_lex_state = 15},
  [3018] = {.lex_state = 31, .external_lex_state = 15},
  [3019] = {.lex_state = 32, .external_lex_state = 15},
  [3020] = {.lex_state = 32, .external_lex_state = 15},
  [3021] = {.lex_state = 58},
  [3022] = {.lex_state = 58, .external_lex_state = 15},
  [3023] = {.lex_state = 58, .external_lex_state = 15},
  [3024] = {.lex_state = 86},
  [3025] = {.lex_state = 31, .external_lex_state = 15},
  [3026] = {.lex_state = 60, .external_lex_state = 15},
  [3027] = {.lex_state = 60, .external_lex_state = 15},
  [3028] = {.lex_state = 60, .external_lex_state = 15},
  [3029] = {.lex_state = 60, .external_lex_state = 15},
  [3030] = {.lex_state = 31, .external_lex_state = 15},
  [3031] = {.lex_state = 58},
  [3032] = {.lex_state = 60, .external_lex_state = 15},
  [3033] = {.lex_state = 58},
  [3034] = {.lex_state = 60, .external_lex_state = 15},
  [3035] = {.lex_state = 58, .external_lex_state = 15},
  [3036] = {.lex_state = 59, .external_lex_state = 15},
  [3037] = {.lex_state = 31, .external_lex_state = 15},
  [3038] = {.lex_state = 31, .external_lex_state = 15},
  [3039] = {.lex_state = 31, .external_lex_state = 15},
  [3040] = {.lex_state = 32, .external_lex_state = 15},
  [3041] = {.lex_state = 59, .external_lex_state = 15},
  [3042] = {.lex_state = 31, .external_lex_state = 15},
  [3043] = {.lex_state = 12, .external_lex_state = 15},
  [3044] = {.lex_state = 30},
  [3045] = {.lex_state = 12, .external_lex_state = 15},
  [3046] = {.lex_state = 71, .external_lex_state = 15},
  [3047] = {.lex_state = 59, .external_lex_state = 15},
  [3048] = {.lex_state = 12, .external_lex_state = 15},
  [3049] = {.lex_state = 59, .external_lex_state = 15},
  [3050] = {.lex_state = 12, .external_lex_state = 15},
  [3051] = {.lex_state = 34, .external_lex_state = 15},
  [3052] = {.lex_state = 58},
  [3053] = {.lex_state = 34, .external_lex_state = 15},
  [3054] = {.lex_state = 59, .external_lex_state = 15},
  [3055] = {.lex_state = 34, .external_lex_state = 15},
  [3056] = {.lex_state = 59, .external_lex_state = 15},
  [3057] = {.lex_state = 59, .external_lex_state = 15},
  [3058] = {.lex_state = 12, .external_lex_state = 15},
  [3059] = {.lex_state = 59, .external_lex_state = 15},
  [3060] = {.lex_state = 12, .external_lex_state = 15},
  [3061] = {.lex_state = 30},
  [3062] = {.lex_state = 59, .external_lex_state = 15},
  [3063] = {.lex_state = 49},
  [3064] = {.lex_state = 55, .external_lex_state = 15},
  [3065] = {.lex_state = 58, .external_lex_state = 15},
  [3066] = {.lex_state = 58},
  [3067] = {.lex_state = 29},
  [3068] = {.lex_state = 29},
  [3069] = {.lex_state = 29},
  [3070] = {.lex_state = 55, .external_lex_state = 15},
  [3071] = {.lex_state = 29},
  [3072] = {.lex_state = 63},
  [3073] = {.lex_state = 58},
  [3074] = {.lex_state = 29},
  [3075] = {.lex_state = 29},
  [3076] = {.lex_state = 29},
  [3077] = {.lex_state = 29},
  [3078] = {.lex_state = 29},
  [3079] = {.lex_state = 29},
  [3080] = {.lex_state = 29},
  [3081] = {.lex_state = 55, .external_lex_state = 15},
  [3082] = {.lex_state = 29},
  [3083] = {.lex_state = 29},
  [3084] = {.lex_state = 29},
  [3085] = {.lex_state = 29},
  [3086] = {.lex_state = 55, .external_lex_state = 15},
  [3087] = {.lex_state = 58},
  [3088] = {.lex_state = 29},
  [3089] = {.lex_state = 29},
  [3090] = {.lex_state = 60, .external_lex_state = 15},
  [3091] = {.lex_state = 29},
  [3092] = {.lex_state = 31, .external_lex_state = 15},
  [3093] = {.lex_state = 29},
  [3094] = {.lex_state = 29},
  [3095] = {.lex_state = 55, .external_lex_state = 15},
  [3096] = {.lex_state = 29},
  [3097] = {.lex_state = 31, .external_lex_state = 15},
  [3098] = {.lex_state = 29},
  [3099] = {.lex_state = 29},
  [3100] = {.lex_state = 58},
  [3101] = {.lex_state = 29},
  [3102] = {.lex_state = 29},
  [3103] = {.lex_state = 29},
  [3104] = {.lex_state = 29},
  [3105] = {.lex_state = 26},
  [3106] = {.lex_state = 26},
  [3107] = {.lex_state = 29},
  [3108] = {.lex_state = 29},
  [3109] = {.lex_state = 26},
  [3110] = {.lex_state = 26},
  [3111] = {.lex_state = 29},
  [3112] = {.lex_state = 29},
  [3113] = {.lex_state = 29},
  [3114] = {.lex_state = 31, .external_lex_state = 15},
  [3115] = {.lex_state = 29},
  [3116] = {.lex_state = 29},
  [3117] = {.lex_state = 29},
  [3118] = {.lex_state = 55, .external_lex_state = 15},
  [3119] = {.lex_state = 29},
  [3120] = {.lex_state = 29},
  [3121] = {.lex_state = 29},
  [3122] = {.lex_state = 60, .external_lex_state = 15},
  [3123] = {.lex_state = 29},
  [3124] = {.lex_state = 29},
  [3125] = {.lex_state = 26},
  [3126] = {.lex_state = 55, .external_lex_state = 15},
  [3127] = {.lex_state = 26},
  [3128] = {.lex_state = 29},
  [3129] = {.lex_state = 29},
  [3130] = {.lex_state = 63},
  [3131] = {.lex_state = 26},
  [3132] = {.lex_state = 60, .external_lex_state = 15},
  [3133] = {.lex_state = 29},
  [3134] = {.lex_state = 29},
  [3135] = {.lex_state = 29},
  [3136] = {.lex_state = 71, .external_lex_state = 15},
  [3137] = {.lex_state = 26},
  [3138] = {.lex_state = 26},
  [3139] = {.lex_state = 26},
  [3140] = {.lex_state = 29},
  [3141] = {.lex_state = 58},
  [3142] = {.lex_state = 29},
  [3143] = {.lex_state = 55, .external_lex_state = 15},
  [3144] = {.lex_state = 2, .external_lex_state = 15},
  [3145] = {.lex_state = 29},
  [3146] = {.lex_state = 26},
  [3147] = {.lex_state = 26},
  [3148] = {.lex_state = 55, .external_lex_state = 15},
  [3149] = {.lex_state = 77, .external_lex_state = 18},
  [3150] = {.lex_state = 83, .external_lex_state = 15},
  [3151] = {.lex_state = 56},
  [3152] = {.lex_state = 56},
  [3153] = {.lex_state = 12, .external_lex_state = 15},
  [3154] = {.lex_state = 63},
  [3155] = {.lex_state = 56},
  [3156] = {.lex_state = 77, .external_lex_state = 18},
  [3157] = {.lex_state = 56},
  [3158] = {.lex_state = 58},
  [3159] = {.lex_state = 56},
  [3160] = {.lex_state = 59, .external_lex_state = 15},
  [3161] = {.lex_state = 77, .external_lex_state = 18},
  [3162] = {.lex_state = 29},
  [3163] = {.lex_state = 58},
  [3164] = {.lex_state = 58},
  [3165] = {.lex_state = 56},
  [3166] = {.lex_state = 59, .external_lex_state = 15},
  [3167] = {.lex_state = 26},
  [3168] = {.lex_state = 56},
  [3169] = {.lex_state = 83, .external_lex_state = 15},
  [3170] = {.lex_state = 146},
  [3171] = {.lex_state = 56},
  [3172] = {.lex_state = 83, .external_lex_state = 15},
  [3173] = {.lex_state = 83, .external_lex_state = 15},
  [3174] = {.lex_state = 83, .external_lex_state = 15},
  [3175] = {.lex_state = 83, .external_lex_state = 15},
  [3176] = {.lex_state = 83, .external_lex_state = 15},
  [3177] = {.lex_state = 83, .external_lex_state = 15},
  [3178] = {.lex_state = 83, .external_lex_state = 15},
  [3179] = {.lex_state = 83, .external_lex_state = 15},
  [3180] = {.lex_state = 83, .external_lex_state = 15},
  [3181] = {.lex_state = 56},
  [3182] = {.lex_state = 31},
  [3183] = {.lex_state = 56},
  [3184] = {.lex_state = 56},
  [3185] = {.lex_state = 12, .external_lex_state = 15},
  [3186] = {.lex_state = 77, .external_lex_state = 18},
  [3187] = {.lex_state = 56},
  [3188] = {.lex_state = 56},
  [3189] = {.lex_state = 56},
  [3190] = {.lex_state = 56},
  [3191] = {.lex_state = 56},
  [3192] = {.lex_state = 12, .external_lex_state = 15},
  [3193] = {.lex_state = 77, .external_lex_state = 18},
  [3194] = {.lex_state = 77, .external_lex_state = 18},
  [3195] = {.lex_state = 31},
  [3196] = {.lex_state = 83, .external_lex_state = 15},
  [3197] = {.lex_state = 83, .external_lex_state = 15},
  [3198] = {.lex_state = 83, .external_lex_state = 15},
  [3199] = {.lex_state = 83, .external_lex_state = 15},
  [3200] = {.lex_state = 83, .external_lex_state = 15},
  [3201] = {.lex_state = 83, .external_lex_state = 15},
  [3202] = {.lex_state = 83, .external_lex_state = 15},
  [3203] = {.lex_state = 83, .external_lex_state = 15},
  [3204] = {.lex_state = 83, .external_lex_state = 15},
  [3205] = {.lex_state = 83, .external_lex_state = 15},
  [3206] = {.lex_state = 58, .external_lex_state = 15},
  [3207] = {.lex_state = 77, .external_lex_state = 18},
  [3208] = {.lex_state = 83, .external_lex_state = 15},
  [3209] = {.lex_state = 83, .external_lex_state = 15},
  [3210] = {.lex_state = 83, .external_lex_state = 15},
  [3211] = {.lex_state = 77, .external_lex_state = 18},
  [3212] = {.lex_state = 83, .external_lex_state = 15},
  [3213] = {.lex_state = 83, .external_lex_state = 15},
  [3214] = {.lex_state = 83, .external_lex_state = 15},
  [3215] = {.lex_state = 83, .external_lex_state = 15},
  [3216] = {.lex_state = 83, .external_lex_state = 15},
  [3217] = {.lex_state = 83, .external_lex_state = 15},
  [3218] = {.lex_state = 83, .external_lex_state = 15},
  [3219] = {.lex_state = 83, .external_lex_state = 15},
  [3220] = {.lex_state = 83, .external_lex_state = 15},
  [3221] = {.lex_state = 83, .external_lex_state = 15},
  [3222] = {.lex_state = 83, .external_lex_state = 15},
  [3223] = {.lex_state = 31},
  [3224] = {.lex_state = 49},
  [3225] = {.lex_state = 12},
  [3226] = {.lex_state = 83, .external_lex_state = 15},
  [3227] = {.lex_state = 58},
  [3228] = {.lex_state = 77, .external_lex_state = 18},
  [3229] = {.lex_state = 56},
  [3230] = {.lex_state = 56},
  [3231] = {.lex_state = 35},
  [3232] = {.lex_state = 29},
  [3233] = {.lex_state = 77, .external_lex_state = 18},
  [3234] = {.lex_state = 83, .external_lex_state = 15},
  [3235] = {.lex_state = 29},
  [3236] = {.lex_state = 83, .external_lex_state = 15},
  [3237] = {.lex_state = 83, .external_lex_state = 15},
  [3238] = {.lex_state = 83, .external_lex_state = 15},
  [3239] = {.lex_state = 83, .external_lex_state = 15},
  [3240] = {.lex_state = 83, .external_lex_state = 15},
  [3241] = {.lex_state = 83, .external_lex_state = 15},
  [3242] = {.lex_state = 83, .external_lex_state = 15},
  [3243] = {.lex_state = 83, .external_lex_state = 15},
  [3244] = {.lex_state = 49},
  [3245] = {.lex_state = 29},
  [3246] = {.lex_state = 29},
  [3247] = {.lex_state = 56},
  [3248] = {.lex_state = 56},
  [3249] = {.lex_state = 58, .external_lex_state = 15},
  [3250] = {.lex_state = 77, .external_lex_state = 18},
  [3251] = {.lex_state = 58},
  [3252] = {.lex_state = 56},
  [3253] = {.lex_state = 56},
  [3254] = {.lex_state = 83, .external_lex_state = 15},
  [3255] = {.lex_state = 77, .external_lex_state = 18},
  [3256] = {.lex_state = 29},
  [3257] = {.lex_state = 83, .external_lex_state = 15},
  [3258] = {.lex_state = 83, .external_lex_state = 15},
  [3259] = {.lex_state = 83, .external_lex_state = 15},
  [3260] = {.lex_state = 83, .external_lex_state = 15},
  [3261] = {.lex_state = 83, .external_lex_state = 15},
  [3262] = {.lex_state = 83, .external_lex_state = 15},
  [3263] = {.lex_state = 83, .external_lex_state = 15},
  [3264] = {.lex_state = 83, .external_lex_state = 15},
  [3265] = {.lex_state = 77, .external_lex_state = 18},
  [3266] = {.lex_state = 56},
  [3267] = {.lex_state = 56},
  [3268] = {.lex_state = 77, .external_lex_state = 18},
  [3269] = {.lex_state = 77, .external_lex_state = 18},
  [3270] = {.lex_state = 56},
  [3271] = {.lex_state = 63},
  [3272] = {.lex_state = 77, .external_lex_state = 18},
  [3273] = {.lex_state = 83, .external_lex_state = 15},
  [3274] = {.lex_state = 56},
  [3275] = {.lex_state = 56},
  [3276] = {.lex_state = 77, .external_lex_state = 18},
  [3277] = {.lex_state = 29},
  [3278] = {.lex_state = 29},
  [3279] = {.lex_state = 56},
  [3280] = {.lex_state = 29},
  [3281] = {.lex_state = 29},
  [3282] = {.lex_state = 29},
  [3283] = {.lex_state = 56},
  [3284] = {.lex_state = 29},
  [3285] = {.lex_state = 12, .external_lex_state = 15},
  [3286] = {.lex_state = 83, .external_lex_state = 15},
  [3287] = {.lex_state = 77, .external_lex_state = 18},
  [3288] = {.lex_state = 29},
  [3289] = {.lex_state = 39},
  [3290] = {.lex_state = 83, .external_lex_state = 15},
  [3291] = {.lex_state = 56},
  [3292] = {.lex_state = 29},
  [3293] = {.lex_state = 56},
  [3294] = {.lex_state = 58},
  [3295] = {.lex_state = 56},
  [3296] = {.lex_state = 12},
  [3297] = {.lex_state = 77, .external_lex_state = 18},
  [3298] = {.lex_state = 83, .external_lex_state = 15},
  [3299] = {.lex_state = 56},
  [3300] = {.lex_state = 56},
  [3301] = {.lex_state = 56},
  [3302] = {.lex_state = 2, .external_lex_state = 15},
  [3303] = {.lex_state = 56},
  [3304] = {.lex_state = 83, .external_lex_state = 15},
  [3305] = {.lex_state = 56},
  [3306] = {.lex_state = 56},
  [3307] = {.lex_state = 146},
  [3308] = {.lex_state = 63},
  [3309] = {.lex_state = 56},
  [3310] = {.lex_state = 56},
  [3311] = {.lex_state = 83, .external_lex_state = 15},
  [3312] = {.lex_state = 56},
  [3313] = {.lex_state = 56},
  [3314] = {.lex_state = 29},
  [3315] = {.lex_state = 83, .external_lex_state = 15},
  [3316] = {.lex_state = 29},
  [3317] = {.lex_state = 29},
  [3318] = {.lex_state = 29},
  [3319] = {.lex_state = 56},
  [3320] = {.lex_state = 83, .external_lex_state = 15},
  [3321] = {.lex_state = 29},
  [3322] = {.lex_state = 56},
  [3323] = {.lex_state = 29},
  [3324] = {.lex_state = 29},
  [3325] = {.lex_state = 56},
  [3326] = {.lex_state = 77, .external_lex_state = 18},
  [3327] = {.lex_state = 83, .external_lex_state = 15},
  [3328] = {.lex_state = 29},
  [3329] = {.lex_state = 56},
  [3330] = {.lex_state = 83, .external_lex_state = 15},
  [3331] = {.lex_state = 83, .external_lex_state = 15},
  [3332] = {.lex_state = 26},
  [3333] = {.lex_state = 83, .external_lex_state = 15},
  [3334] = {.lex_state = 83, .external_lex_state = 15},
  [3335] = {.lex_state = 83, .external_lex_state = 15},
  [3336] = {.lex_state = 83, .external_lex_state = 15},
  [3337] = {.lex_state = 83, .external_lex_state = 15},
  [3338] = {.lex_state = 83, .external_lex_state = 15},
  [3339] = {.lex_state = 77, .external_lex_state = 18},
  [3340] = {.lex_state = 56},
  [3341] = {.lex_state = 59, .external_lex_state = 15},
  [3342] = {.lex_state = 29},
  [3343] = {.lex_state = 49},
  [3344] = {.lex_state = 29},
  [3345] = {.lex_state = 31},
  [3346] = {.lex_state = 83, .external_lex_state = 15},
  [3347] = {.lex_state = 56},
  [3348] = {.lex_state = 49},
  [3349] = {.lex_state = 55, .external_lex_state = 15},
  [3350] = {.lex_state = 84, .external_lex_state = 15},
  [3351] = {.lex_state = 84, .external_lex_state = 15},
  [3352] = {.lex_state = 49},
  [3353] = {.lex_state = 49},
  [3354] = {.lex_state = 82, .external_lex_state = 15},
  [3355] = {.lex_state = 58, .external_lex_state = 15},
  [3356] = {.lex_state = 49},
  [3357] = {.lex_state = 12},
  [3358] = {.lex_state = 49},
  [3359] = {.lex_state = 55, .external_lex_state = 15},
  [3360] = {.lex_state = 55, .external_lex_state = 15},
  [3361] = {.lex_state = 49},
  [3362] = {.lex_state = 49},
  [3363] = {.lex_state = 49},
  [3364] = {.lex_state = 49},
  [3365] = {.lex_state = 49},
  [3366] = {.lex_state = 62},
  [3367] = {.lex_state = 58},
  [3368] = {.lex_state = 49},
  [3369] = {.lex_state = 55, .external_lex_state = 15},
  [3370] = {.lex_state = 58},
  [3371] = {.lex_state = 58},
  [3372] = {.lex_state = 55, .external_lex_state = 15},
  [3373] = {.lex_state = 49},
  [3374] = {.lex_state = 58},
  [3375] = {.lex_state = 58},
  [3376] = {.lex_state = 49},
  [3377] = {.lex_state = 49},
  [3378] = {.lex_state = 146},
  [3379] = {.lex_state = 63},
  [3380] = {.lex_state = 84, .external_lex_state = 15},
  [3381] = {.lex_state = 84, .external_lex_state = 15},
  [3382] = {.lex_state = 49},
  [3383] = {.lex_state = 55, .external_lex_state = 15},
  [3384] = {.lex_state = 56},
  [3385] = {.lex_state = 49},
  [3386] = {.lex_state = 49},
  [3387] = {.lex_state = 49},
  [3388] = {.lex_state = 49},
  [3389] = {.lex_state = 49},
  [3390] = {.lex_state = 49},
  [3391] = {.lex_state = 62},
  [3392] = {.lex_state = 55, .external_lex_state = 15},
  [3393] = {.lex_state = 146},
  [3394] = {.lex_state = 55, .external_lex_state = 15},
  [3395] = {.lex_state = 63},
  [3396] = {.lex_state = 49},
  [3397] = {.lex_state = 55, .external_lex_state = 15},
  [3398] = {.lex_state = 55, .external_lex_state = 15},
  [3399] = {.lex_state = 146},
  [3400] = {.lex_state = 49},
  [3401] = {.lex_state = 49},
  [3402] = {.lex_state = 49},
  [3403] = {.lex_state = 55, .external_lex_state = 15},
  [3404] = {.lex_state = 84, .external_lex_state = 15},
  [3405] = {.lex_state = 55, .external_lex_state = 15},
  [3406] = {.lex_state = 55, .external_lex_state = 15},
  [3407] = {.lex_state = 49},
  [3408] = {.lex_state = 31},
  [3409] = {.lex_state = 62},
  [3410] = {.lex_state = 49},
  [3411] = {.lex_state = 49},
  [3412] = {.lex_state = 84, .external_lex_state = 15},
  [3413] = {.lex_state = 49},
  [3414] = {.lex_state = 86},
  [3415] = {.lex_state = 49},
  [3416] = {.lex_state = 56},
  [3417] = {.lex_state = 84, .external_lex_state = 15},
  [3418] = {.lex_state = 86},
  [3419] = {.lex_state = 49},
  [3420] = {.lex_state = 55, .external_lex_state = 15},
  [3421] = {.lex_state = 84, .external_lex_state = 15},
  [3422] = {.lex_state = 55, .external_lex_state = 15},
  [3423] = {.lex_state = 62},
  [3424] = {.lex_state = 63},
  [3425] = {.lex_state = 49},
  [3426] = {.lex_state = 84, .external_lex_state = 15},
  [3427] = {.lex_state = 56},
  [3428] = {.lex_state = 49},
  [3429] = {.lex_state = 49},
  [3430] = {.lex_state = 146},
  [3431] = {.lex_state = 146},
  [3432] = {.lex_state = 84, .external_lex_state = 15},
  [3433] = {.lex_state = 84, .external_lex_state = 15},
  [3434] = {.lex_state = 63},
  [3435] = {.lex_state = 84, .external_lex_state = 15},
  [3436] = {.lex_state = 84, .external_lex_state = 15},
  [3437] = {.lex_state = 84, .external_lex_state = 15},
  [3438] = {.lex_state = 84, .external_lex_state = 15},
  [3439] = {.lex_state = 31},
  [3440] = {.lex_state = 84, .external_lex_state = 15},
  [3441] = {.lex_state = 84, .external_lex_state = 15},
  [3442] = {.lex_state = 84, .external_lex_state = 15},
  [3443] = {.lex_state = 55, .external_lex_state = 15},
  [3444] = {.lex_state = 55, .external_lex_state = 15},
  [3445] = {.lex_state = 56},
  [3446] = {.lex_state = 49, .external_lex_state = 15},
  [3447] = {.lex_state = 55, .external_lex_state = 15},
  [3448] = {.lex_state = 49},
  [3449] = {.lex_state = 49},
  [3450] = {.lex_state = 146},
  [3451] = {.lex_state = 146},
  [3452] = {.lex_state = 146},
  [3453] = {.lex_state = 29},
  [3454] = {.lex_state = 29},
  [3455] = {.lex_state = 29},
  [3456] = {.lex_state = 49},
  [3457] = {.lex_state = 146},
  [3458] = {.lex_state = 146},
  [3459] = {.lex_state = 146},
  [3460] = {.lex_state = 49},
  [3461] = {.lex_state = 49},
  [3462] = {.lex_state = 49},
  [3463] = {.lex_state = 146},
  [3464] = {.lex_state = 77, .external_lex_state = 18},
  [3465] = {.lex_state = 29},
  [3466] = {.lex_state = 146},
  [3467] = {.lex_state = 29},
  [3468] = {.lex_state = 58},
  [3469] = {.lex_state = 63},
  [3470] = {.lex_state = 49},
  [3471] = {.lex_state = 146},
  [3472] = {.lex_state = 49},
  [3473] = {.lex_state = 49},
  [3474] = {.lex_state = 146},
  [3475] = {.lex_state = 49},
  [3476] = {.lex_state = 49},
  [3477] = {.lex_state = 146},
  [3478] = {.lex_state = 49},
  [3479] = {.lex_state = 49},
  [3480] = {.lex_state = 146},
  [3481] = {.lex_state = 49},
  [3482] = {.lex_state = 49},
  [3483] = {.lex_state = 49},
  [3484] = {.lex_state = 29},
  [3485] = {.lex_state = 63},
  [3486] = {.lex_state = 63},
  [3487] = {.lex_state = 49},
  [3488] = {.lex_state = 146},
  [3489] = {.lex_state = 29},
  [3490] = {.lex_state = 146},
  [3491] = {.lex_state = 29},
  [3492] = {.lex_state = 70, .external_lex_state = 15},
  [3493] = {.lex_state = 146},
  [3494] = {.lex_state = 58},
  [3495] = {.lex_state = 49, .external_lex_state = 15},
  [3496] = {.lex_state = 29},
  [3497] = {.lex_state = 49},
  [3498] = {.lex_state = 29},
  [3499] = {.lex_state = 49},
  [3500] = {.lex_state = 146},
  [3501] = {.lex_state = 146},
  [3502] = {.lex_state = 49},
  [3503] = {.lex_state = 49},
  [3504] = {.lex_state = 61, .external_lex_state = 15},
  [3505] = {.lex_state = 146},
  [3506] = {.lex_state = 146},
  [3507] = {.lex_state = 63},
  [3508] = {.lex_state = 29},
  [3509] = {.lex_state = 49},
  [3510] = {.lex_state = 63},
  [3511] = {.lex_state = 63},
  [3512] = {.lex_state = 49},
  [3513] = {.lex_state = 49},
  [3514] = {.lex_state = 49},
  [3515] = {.lex_state = 49},
  [3516] = {.lex_state = 146},
  [3517] = {.lex_state = 71, .external_lex_state = 15},
  [3518] = {.lex_state = 146},
  [3519] = {.lex_state = 49},
  [3520] = {.lex_state = 49},
  [3521] = {.lex_state = 49},
  [3522] = {.lex_state = 49},
  [3523] = {.lex_state = 63},
  [3524] = {.lex_state = 49},
  [3525] = {.lex_state = 49},
  [3526] = {.lex_state = 49},
  [3527] = {.lex_state = 146},
  [3528] = {.lex_state = 63},
  [3529] = {.lex_state = 49},
  [3530] = {.lex_state = 49},
  [3531] = {.lex_state = 49},
  [3532] = {.lex_state = 49},
  [3533] = {.lex_state = 49},
  [3534] = {.lex_state = 49},
  [3535] = {.lex_state = 63},
  [3536] = {.lex_state = 61, .external_lex_state = 15},
  [3537] = {.lex_state = 29},
  [3538] = {.lex_state = 49},
  [3539] = {.lex_state = 63},
  [3540] = {.lex_state = 63},
  [3541] = {.lex_state = 49},
  [3542] = {.lex_state = 146},
  [3543] = {.lex_state = 63},
  [3544] = {.lex_state = 63},
  [3545] = {.lex_state = 63},
  [3546] = {.lex_state = 146},
  [3547] = {.lex_state = 49},
  [3548] = {.lex_state = 29},
  [3549] = {.lex_state = 49},
  [3550] = {.lex_state = 49},
  [3551] = {.lex_state = 49},
  [3552] = {.lex_state = 29},
  [3553] = {.lex_state = 146},
  [3554] = {.lex_state = 29},
  [3555] = {.lex_state = 146},
  [3556] = {.lex_state = 146},
  [3557] = {.lex_state = 70, .external_lex_state = 15},
  [3558] = {.lex_state = 146},
  [3559] = {.lex_state = 146},
  [3560] = {.lex_state = 39},
  [3561] = {.lex_state = 49},
  [3562] = {.lex_state = 49},
  [3563] = {.lex_state = 39},
  [3564] = {.lex_state = 146},
  [3565] = {.lex_state = 146},
  [3566] = {.lex_state = 49},
  [3567] = {.lex_state = 29},
  [3568] = {.lex_state = 49},
  [3569] = {.lex_state = 49},
  [3570] = {.lex_state = 49},
  [3571] = {.lex_state = 62},
  [3572] = {.lex_state = 77, .external_lex_state = 18},
  [3573] = {.lex_state = 146},
  [3574] = {.lex_state = 29},
  [3575] = {.lex_state = 29},
  [3576] = {.lex_state = 29},
  [3577] = {.lex_state = 29},
  [3578] = {.lex_state = 62},
  [3579] = {.lex_state = 29},
  [3580] = {.lex_state = 146},
  [3581] = {.lex_state = 63},
  [3582] = {.lex_state = 63},
  [3583] = {.lex_state = 63},
  [3584] = {.lex_state = 63},
  [3585] = {.lex_state = 49},
  [3586] = {.lex_state = 63},
  [3587] = {.lex_state = 63},
  [3588] = {.lex_state = 146},
  [3589] = {.lex_state = 146},
  [3590] = {.lex_state = 63},
  [3591] = {.lex_state = 63},
  [3592] = {.lex_state = 63},
  [3593] = {.lex_state = 146},
  [3594] = {.lex_state = 63},
  [3595] = {.lex_state = 63},
  [3596] = {.lex_state = 63},
  [3597] = {.lex_state = 29},
  [3598] = {.lex_state = 63},
  [3599] = {.lex_state = 58, .external_lex_state = 15},
  [3600] = {.lex_state = 22},
  [3601] = {.lex_state = 146},
  [3602] = {.lex_state = 49},
  [3603] = {.lex_state = 72},
  [3604] = {.lex_state = 49},
  [3605] = {.lex_state = 49},
  [3606] = {.lex_state = 49, .external_lex_state = 15},
  [3607] = {.lex_state = 72},
  [3608] = {.lex_state = 146},
  [3609] = {.lex_state = 49},
  [3610] = {.lex_state = 146},
  [3611] = {.lex_state = 49},
  [3612] = {.lex_state = 49},
  [3613] = {.lex_state = 58},
  [3614] = {.lex_state = 146},
  [3615] = {.lex_state = 72},
  [3616] = {.lex_state = 49},
  [3617] = {.lex_state = 146},
  [3618] = {.lex_state = 72},
  [3619] = {.lex_state = 49},
  [3620] = {.lex_state = 49},
  [3621] = {.lex_state = 49},
  [3622] = {.lex_state = 49},
  [3623] = {.lex_state = 146},
  [3624] = {.lex_state = 49},
  [3625] = {.lex_state = 49},
  [3626] = {.lex_state = 63},
  [3627] = {.lex_state = 49},
  [3628] = {.lex_state = 49},
  [3629] = {.lex_state = 49},
  [3630] = {.lex_state = 146},
  [3631] = {.lex_state = 72},
  [3632] = {.lex_state = 49},
  [3633] = {.lex_state = 61, .external_lex_state = 15},
  [3634] = {.lex_state = 49},
  [3635] = {.lex_state = 49},
  [3636] = {.lex_state = 49},
  [3637] = {.lex_state = 49},
  [3638] = {.lex_state = 49},
  [3639] = {.lex_state = 146},
  [3640] = {.lex_state = 86},
  [3641] = {.lex_state = 49},
  [3642] = {.lex_state = 61, .external_lex_state = 15},
  [3643] = {.lex_state = 72},
  [3644] = {.lex_state = 72},
  [3645] = {.lex_state = 49},
  [3646] = {.lex_state = 72},
  [3647] = {.lex_state = 22},
  [3648] = {.lex_state = 72},
  [3649] = {.lex_state = 49},
  [3650] = {.lex_state = 58, .external_lex_state = 15},
  [3651] = {.lex_state = 49},
  [3652] = {.lex_state = 49},
  [3653] = {.lex_state = 63},
  [3654] = {.lex_state = 63},
  [3655] = {.lex_state = 63},
  [3656] = {.lex_state = 63},
  [3657] = {.lex_state = 63},
  [3658] = {.lex_state = 63},
  [3659] = {.lex_state = 146},
  [3660] = {.lex_state = 63},
  [3661] = {.lex_state = 49},
  [3662] = {.lex_state = 49},
  [3663] = {.lex_state = 146},
  [3664] = {.lex_state = 72},
  [3665] = {.lex_state = 146},
  [3666] = {.lex_state = 146},
  [3667] = {.lex_state = 146},
  [3668] = {.lex_state = 146},
  [3669] = {.lex_state = 63},
  [3670] = {.lex_state = 49},
  [3671] = {.lex_state = 146},
  [3672] = {.lex_state = 63},
  [3673] = {.lex_state = 49},
  [3674] = {.lex_state = 63},
  [3675] = {.lex_state = 63},
  [3676] = {.lex_state = 72},
  [3677] = {.lex_state = 72},
  [3678] = {.lex_state = 72},
  [3679] = {.lex_state = 58, .external_lex_state = 15},
  [3680] = {.lex_state = 49},
  [3681] = {.lex_state = 58, .external_lex_state = 15},
  [3682] = {.lex_state = 72},
  [3683] = {.lex_state = 146},
  [3684] = {.lex_state = 49},
  [3685] = {.lex_state = 49},
  [3686] = {.lex_state = 49},
  [3687] = {.lex_state = 146},
  [3688] = {.lex_state = 72},
  [3689] = {.lex_state = 146},
  [3690] = {.lex_state = 146},
  [3691] = {.lex_state = 146},
  [3692] = {.lex_state = 72},
  [3693] = {.lex_state = 61, .external_lex_state = 15},
  [3694] = {.lex_state = 146},
  [3695] = {.lex_state = 49},
  [3696] = {.lex_state = 63},
  [3697] = {.lex_state = 63},
  [3698] = {.lex_state = 49},
  [3699] = {.lex_state = 63},
  [3700] = {.lex_state = 49},
  [3701] = {.lex_state = 146},
  [3702] = {.lex_state = 146},
  [3703] = {.lex_state = 146},
  [3704] = {.lex_state = 72},
  [3705] = {.lex_state = 146},
  [3706] = {.lex_state = 146},
  [3707] = {.lex_state = 49},
  [3708] = {.lex_state = 63},
  [3709] = {.lex_state = 72},
  [3710] = {.lex_state = 72},
  [3711] = {.lex_state = 49},
  [3712] = {.lex_state = 61, .external_lex_state = 15},
  [3713] = {.lex_state = 146},
  [3714] = {.lex_state = 49},
  [3715] = {.lex_state = 49},
  [3716] = {.lex_state = 49},
  [3717] = {.lex_state = 49},
  [3718] = {.lex_state = 49},
  [3719] = {.lex_state = 49},
  [3720] = {.lex_state = 49},
  [3721] = {.lex_state = 49},
  [3722] = {.lex_state = 49},
  [3723] = {.lex_state = 49},
  [3724] = {.lex_state = 49},
  [3725] = {.lex_state = 49},
  [3726] = {.lex_state = 49},
  [3727] = {.lex_state = 49},
  [3728] = {.lex_state = 146},
  [3729] = {.lex_state = 63},
  [3730] = {.lex_state = 49},
  [3731] = {.lex_state = 49},
  [3732] = {.lex_state = 49},
  [3733] = {.lex_state = 49},
  [3734] = {.lex_state = 146},
  [3735] = {.lex_state = 146},
  [3736] = {.lex_state = 49},
  [3737] = {.lex_state = 49},
  [3738] = {.lex_state = 49},
  [3739] = {.lex_state = 49},
  [3740] = {.lex_state = 49},
  [3741] = {.lex_state = 146},
  [3742] = {.lex_state = 49},
  [3743] = {.lex_state = 49},
  [3744] = {.lex_state = 49},
  [3745] = {.lex_state = 49},
  [3746] = {.lex_state = 49},
  [3747] = {.lex_state = 49},
  [3748] = {.lex_state = 49},
  [3749] = {.lex_state = 49},
  [3750] = {.lex_state = 49},
  [3751] = {.lex_state = 63},
  [3752] = {.lex_state = 49},
  [3753] = {.lex_state = 146},
  [3754] = {.lex_state = 49},
  [3755] = {.lex_state = 49},
  [3756] = {.lex_state = 61, .external_lex_state = 15},
  [3757] = {.lex_state = 146},
  [3758] = {.lex_state = 49},
  [3759] = {.lex_state = 61, .external_lex_state = 15},
  [3760] = {.lex_state = 49},
  [3761] = {.lex_state = 49},
  [3762] = {.lex_state = 49},
  [3763] = {.lex_state = 146},
  [3764] = {.lex_state = 49},
  [3765] = {.lex_state = 49},
  [3766] = {.lex_state = 49},
  [3767] = {.lex_state = 49},
  [3768] = {.lex_state = 63},
  [3769] = {.lex_state = 49},
  [3770] = {.lex_state = 49},
  [3771] = {.lex_state = 49},
  [3772] = {.lex_state = 49},
  [3773] = {.lex_state = 49},
  [3774] = {.lex_state = 49},
  [3775] = {.lex_state = 49},
  [3776] = {.lex_state = 49},
  [3777] = {.lex_state = 49},
  [3778] = {.lex_state = 49},
  [3779] = {.lex_state = 49},
  [3780] = {.lex_state = 49},
  [3781] = {.lex_state = 49},
  [3782] = {.lex_state = 49},
  [3783] = {.lex_state = 63},
  [3784] = {.lex_state = 63},
  [3785] = {.lex_state = 146},
  [3786] = {.lex_state = 63},
  [3787] = {.lex_state = 63},
  [3788] = {.lex_state = 63},
  [3789] = {.lex_state = 49},
  [3790] = {.lex_state = 63},
  [3791] = {.lex_state = 49},
  [3792] = {.lex_state = 63},
  [3793] = {.lex_state = 146},
  [3794] = {.lex_state = 63},
  [3795] = {.lex_state = 63},
  [3796] = {.lex_state = 63},
  [3797] = {.lex_state = 63},
  [3798] = {.lex_state = 63},
  [3799] = {.lex_state = 63},
  [3800] = {.lex_state = 63},
  [3801] = {.lex_state = 63},
  [3802] = {.lex_state = 63},
  [3803] = {.lex_state = 63},
  [3804] = {.lex_state = 63},
  [3805] = {.lex_state = 63},
  [3806] = {.lex_state = 63},
  [3807] = {.lex_state = 63},
  [3808] = {.lex_state = 63},
  [3809] = {.lex_state = 63},
  [3810] = {.lex_state = 63},
  [3811] = {.lex_state = 63},
  [3812] = {.lex_state = 63},
  [3813] = {.lex_state = 63},
  [3814] = {.lex_state = 63},
  [3815] = {.lex_state = 63},
  [3816] = {.lex_state = 63},
  [3817] = {.lex_state = 63},
  [3818] = {.lex_state = 3},
  [3819] = {.lex_state = 29},
  [3820] = {.lex_state = 146},
  [3821] = {.lex_state = 49},
  [3822] = {.lex_state = 49},
  [3823] = {.lex_state = 49},
  [3824] = {.lex_state = 49},
  [3825] = {.lex_state = 49},
  [3826] = {.lex_state = 146},
  [3827] = {.lex_state = 49},
  [3828] = {.lex_state = 146},
  [3829] = {.lex_state = 49},
  [3830] = {.lex_state = 49},
  [3831] = {.lex_state = 146},
  [3832] = {.lex_state = 49},
  [3833] = {.lex_state = 63},
  [3834] = {.lex_state = 49},
  [3835] = {.lex_state = 49},
  [3836] = {.lex_state = 49},
  [3837] = {.lex_state = 146},
  [3838] = {.lex_state = 49},
  [3839] = {.lex_state = 49},
  [3840] = {.lex_state = 49},
  [3841] = {.lex_state = 49},
  [3842] = {.lex_state = 49},
  [3843] = {.lex_state = 146},
  [3844] = {.lex_state = 49},
  [3845] = {.lex_state = 49},
  [3846] = {.lex_state = 49},
  [3847] = {.lex_state = 49},
  [3848] = {.lex_state = 49},
  [3849] = {.lex_state = 49},
  [3850] = {.lex_state = 49},
  [3851] = {.lex_state = 58},
  [3852] = {.lex_state = 146},
  [3853] = {.lex_state = 49},
  [3854] = {.lex_state = 85},
  [3855] = {.lex_state = 49},
  [3856] = {.lex_state = 49},
  [3857] = {.lex_state = 49},
  [3858] = {.lex_state = 49},
  [3859] = {.lex_state = 49},
  [3860] = {.lex_state = 146},
  [3861] = {.lex_state = 49},
  [3862] = {.lex_state = 49},
  [3863] = {.lex_state = 49},
  [3864] = {.lex_state = 49},
  [3865] = {.lex_state = 146},
  [3866] = {.lex_state = 49},
  [3867] = {.lex_state = 146},
  [3868] = {.lex_state = 49},
  [3869] = {.lex_state = 49},
  [3870] = {.lex_state = 49},
  [3871] = {.lex_state = 49},
  [3872] = {.lex_state = 146},
  [3873] = {.lex_state = 49},
  [3874] = {.lex_state = 49},
  [3875] = {.lex_state = 146},
  [3876] = {.lex_state = 146},
  [3877] = {.lex_state = 49},
  [3878] = {.lex_state = 146},
  [3879] = {.lex_state = 63},
  [3880] = {.lex_state = 49},
  [3881] = {.lex_state = 49},
  [3882] = {.lex_state = 49},
  [3883] = {.lex_state = 146},
  [3884] = {.lex_state = 63},
  [3885] = {.lex_state = 146},
  [3886] = {.lex_state = 146},
  [3887] = {.lex_state = 49},
  [3888] = {.lex_state = 49},
  [3889] = {.lex_state = 49},
  [3890] = {.lex_state = 49},
  [3891] = {.lex_state = 146},
  [3892] = {.lex_state = 3},
  [3893] = {.lex_state = 146},
  [3894] = {.lex_state = 49},
  [3895] = {.lex_state = 146},
  [3896] = {.lex_state = 146},
  [3897] = {.lex_state = 49},
  [3898] = {.lex_state = 49},
  [3899] = {.lex_state = 49},
  [3900] = {.lex_state = 49},
  [3901] = {.lex_state = 49},
  [3902] = {.lex_state = 49},
  [3903] = {.lex_state = 49},
  [3904] = {.lex_state = 49},
  [3905] = {.lex_state = 49},
  [3906] = {.lex_state = 49},
  [3907] = {.lex_state = 49},
  [3908] = {.lex_state = 49},
  [3909] = {.lex_state = 63},
  [3910] = {.lex_state = 49},
  [3911] = {.lex_state = 49},
  [3912] = {.lex_state = 49},
  [3913] = {.lex_state = 146},
  [3914] = {.lex_state = 49},
  [3915] = {.lex_state = 49},
  [3916] = {.lex_state = 146},
  [3917] = {.lex_state = 49},
  [3918] = {.lex_state = 49},
  [3919] = {.lex_state = 146},
  [3920] = {.lex_state = 146},
  [3921] = {.lex_state = 49},
  [3922] = {.lex_state = 49},
  [3923] = {.lex_state = 146},
  [3924] = {.lex_state = 146},
  [3925] = {.lex_state = 63},
  [3926] = {.lex_state = 63},
  [3927] = {.lex_state = 49},
  [3928] = {.lex_state = 49},
  [3929] = {.lex_state = 49},
  [3930] = {.lex_state = 49},
  [3931] = {.lex_state = 49},
  [3932] = {.lex_state = 63},
  [3933] = {.lex_state = 146},
  [3934] = {.lex_state = 63},
  [3935] = {.lex_state = 49},
  [3936] = {.lex_state = 49},
  [3937] = {.lex_state = 49},
  [3938] = {.lex_state = 29},
  [3939] = {.lex_state = 49},
  [3940] = {.lex_state = 49},
  [3941] = {.lex_state = 49},
  [3942] = {.lex_state = 63},
  [3943] = {.lex_state = 146},
  [3944] = {.lex_state = 49},
  [3945] = {.lex_state = 146},
  [3946] = {.lex_state = 63},
  [3947] = {.lex_state = 146},
  [3948] = {.lex_state = 49},
  [3949] = {.lex_state = 146},
  [3950] = {.lex_state = 49},
  [3951] = {.lex_state = 49},
  [3952] = {.lex_state = 49},
  [3953] = {.lex_state = 49},
  [3954] = {.lex_state = 63},
  [3955] = {.lex_state = 146},
  [3956] = {.lex_state = 49},
  [3957] = {.lex_state = 49},
  [3958] = {.lex_state = 49},
  [3959] = {.lex_state = 49},
  [3960] = {.lex_state = 2, .external_lex_state = 15},
  [3961] = {.lex_state = 146},
  [3962] = {.lex_state = 2, .external_lex_state = 15},
  [3963] = {.lex_state = 63},
  [3964] = {.lex_state = 2, .external_lex_state = 15},
  [3965] = {.lex_state = 2, .external_lex_state = 15},
  [3966] = {.lex_state = 49},
  [3967] = {.lex_state = 2, .external_lex_state = 15},
  [3968] = {.lex_state = 63},
  [3969] = {.lex_state = 2, .external_lex_state = 15},
  [3970] = {.lex_state = 146},
  [3971] = {.lex_state = 2, .external_lex_state = 15},
  [3972] = {.lex_state = 63},
  [3973] = {.lex_state = 2, .external_lex_state = 15},
  [3974] = {.lex_state = 63},
  [3975] = {.lex_state = 2, .external_lex_state = 15},
  [3976] = {.lex_state = 2, .external_lex_state = 15},
  [3977] = {.lex_state = 2, .external_lex_state = 15},
  [3978] = {.lex_state = 49},
  [3979] = {.lex_state = 49},
  [3980] = {.lex_state = 49},
  [3981] = {.lex_state = 146},
  [3982] = {.lex_state = 49},
  [3983] = {.lex_state = 2, .external_lex_state = 15},
  [3984] = {.lex_state = 49},
  [3985] = {.lex_state = 111},
  [3986] = {.lex_state = 146},
  [3987] = {.lex_state = 112},
  [3988] = {.lex_state = 3},
  [3989] = {.lex_state = 2, .external_lex_state = 15},
  [3990] = {.lex_state = 49},
  [3991] = {.lex_state = 146},
  [3992] = {.lex_state = 146},
  [3993] = {.lex_state = 2, .external_lex_state = 15},
  [3994] = {.lex_state = 3},
  [3995] = {.lex_state = 49},
  [3996] = {.lex_state = 3},
  [3997] = {.lex_state = 49},
  [3998] = {.lex_state = 2, .external_lex_state = 15},
  [3999] = {.lex_state = 49},
  [4000] = {.lex_state = 63},
  [4001] = {.lex_state = 146, .external_lex_state = 9},
  [4002] = {.lex_state = 146},
  [4003] = {.lex_state = 112},
  [4004] = {.lex_state = 49},
  [4005] = {.lex_state = 49},
  [4006] = {.lex_state = 49},
  [4007] = {.lex_state = 146},
  [4008] = {.lex_state = 146},
  [4009] = {.lex_state = 146},
  [4010] = {.lex_state = 146},
  [4011] = {.lex_state = 49},
  [4012] = {.lex_state = 49},
  [4013] = {.lex_state = 146},
  [4014] = {.lex_state = 49},
  [4015] = {.lex_state = 49},
  [4016] = {.lex_state = 146},
  [4017] = {.lex_state = 49},
  [4018] = {.lex_state = 2, .external_lex_state = 15},
  [4019] = {.lex_state = 49},
  [4020] = {.lex_state = 2, .external_lex_state = 15},
  [4021] = {.lex_state = 63},
  [4022] = {.lex_state = 146},
  [4023] = {.lex_state = 49},
  [4024] = {.lex_state = 49},
  [4025] = {.lex_state = 111},
  [4026] = {.lex_state = 49},
  [4027] = {.lex_state = 112},
  [4028] = {.lex_state = 49},
  [4029] = {.lex_state = 146},
  [4030] = {.lex_state = 146},
  [4031] = {.lex_state = 146},
  [4032] = {.lex_state = 146},
  [4033] = {.lex_state = 49},
  [4034] = {.lex_state = 146},
  [4035] = {.lex_state = 112},
  [4036] = {.lex_state = 2, .external_lex_state = 15},
  [4037] = {.lex_state = 146},
  [4038] = {.lex_state = 112},
  [4039] = {.lex_state = 146},
  [4040] = {.lex_state = 2, .external_lex_state = 15},
  [4041] = {.lex_state = 112},
  [4042] = {.lex_state = 146, .external_lex_state = 9},
  [4043] = {.lex_state = 112},
  [4044] = {.lex_state = 49},
  [4045] = {.lex_state = 112},
  [4046] = {.lex_state = 2, .external_lex_state = 15},
  [4047] = {.lex_state = 112},
  [4048] = {.lex_state = 49},
  [4049] = {.lex_state = 146},
  [4050] = {.lex_state = 2, .external_lex_state = 15},
  [4051] = {.lex_state = 49},
  [4052] = {.lex_state = 146},
  [4053] = {.lex_state = 2, .external_lex_state = 15},
  [4054] = {.lex_state = 2, .external_lex_state = 15},
  [4055] = {.lex_state = 49},
  [4056] = {.lex_state = 49},
  [4057] = {.lex_state = 49},
  [4058] = {.lex_state = 146},
  [4059] = {.lex_state = 49},
  [4060] = {.lex_state = 146},
  [4061] = {.lex_state = 146},
  [4062] = {.lex_state = 146},
  [4063] = {.lex_state = 146},
  [4064] = {.lex_state = 146, .external_lex_state = 9},
  [4065] = {.lex_state = 146},
  [4066] = {.lex_state = 146},
  [4067] = {.lex_state = 49},
  [4068] = {.lex_state = 49},
  [4069] = {.lex_state = 49},
  [4070] = {.lex_state = 49},
  [4071] = {.lex_state = 49},
  [4072] = {.lex_state = 3},
  [4073] = {.lex_state = 49},
  [4074] = {.lex_state = 2, .external_lex_state = 15},
  [4075] = {.lex_state = 146},
  [4076] = {.lex_state = 146, .external_lex_state = 9},
  [4077] = {.lex_state = 49},
  [4078] = {.lex_state = 49},
  [4079] = {.lex_state = 2, .external_lex_state = 15},
  [4080] = {.lex_state = 146},
  [4081] = {.lex_state = 2, .external_lex_state = 15},
  [4082] = {.lex_state = 49},
  [4083] = {.lex_state = 49},
  [4084] = {.lex_state = 111},
  [4085] = {.lex_state = 2, .external_lex_state = 15},
  [4086] = {.lex_state = 146},
  [4087] = {.lex_state = 49},
  [4088] = {.lex_state = 146},
  [4089] = {.lex_state = 2, .external_lex_state = 15},
  [4090] = {.lex_state = 3},
  [4091] = {.lex_state = 2, .external_lex_state = 15},
  [4092] = {.lex_state = 2, .external_lex_state = 15},
  [4093] = {.lex_state = 2, .external_lex_state = 15},
  [4094] = {.lex_state = 49},
  [4095] = {.lex_state = 3},
  [4096] = {.lex_state = 49},
  [4097] = {.lex_state = 49},
  [4098] = {.lex_state = 3},
  [4099] = {.lex_state = 49},
  [4100] = {.lex_state = 49},
  [4101] = {.lex_state = 146},
  [4102] = {.lex_state = 63},
  [4103] = {.lex_state = 146},
  [4104] = {.lex_state = 146},
  [4105] = {.lex_state = 146},
  [4106] = {.lex_state = 146},
  [4107] = {.lex_state = 146},
  [4108] = {.lex_state = 0, .external_lex_state = 19},
  [4109] = {.lex_state = 63},
  [4110] = {.lex_state = 146},
  [4111] = {.lex_state = 146},
  [4112] = {.lex_state = 146},
  [4113] = {.lex_state = 63},
  [4114] = {.lex_state = 146},
  [4115] = {.lex_state = 146},
  [4116] = {.lex_state = 63},
  [4117] = {.lex_state = 63},
  [4118] = {.lex_state = 0, .external_lex_state = 20},
  [4119] = {.lex_state = 146},
  [4120] = {.lex_state = 146},
  [4121] = {.lex_state = 49},
  [4122] = {.lex_state = 49},
  [4123] = {.lex_state = 146},
  [4124] = {.lex_state = 146},
  [4125] = {.lex_state = 49},
  [4126] = {.lex_state = 0, .external_lex_state = 17},
  [4127] = {.lex_state = 146},
  [4128] = {.lex_state = 146},
  [4129] = {.lex_state = 146},
  [4130] = {.lex_state = 0, .external_lex_state = 20},
  [4131] = {.lex_state = 146},
  [4132] = {.lex_state = 63},
  [4133] = {.lex_state = 146},
  [4134] = {.lex_state = 63},
  [4135] = {.lex_state = 63},
  [4136] = {.lex_state = 146},
  [4137] = {.lex_state = 146},
  [4138] = {.lex_state = 146},
  [4139] = {.lex_state = 146},
  [4140] = {.lex_state = 146},
  [4141] = {.lex_state = 146},
  [4142] = {.lex_state = 146},
  [4143] = {.lex_state = 146},
  [4144] = {.lex_state = 63},
  [4145] = {.lex_state = 63},
  [4146] = {.lex_state = 146},
  [4147] = {.lex_state = 146},
  [4148] = {.lex_state = 63},
  [4149] = {.lex_state = 63},
  [4150] = {.lex_state = 0, .external_lex_state = 20},
  [4151] = {.lex_state = 63},
  [4152] = {.lex_state = 63},
  [4153] = {.lex_state = 146},
  [4154] = {.lex_state = 146},
  [4155] = {.lex_state = 146},
  [4156] = {.lex_state = 146},
  [4157] = {.lex_state = 0, .external_lex_state = 20},
  [4158] = {.lex_state = 63},
  [4159] = {.lex_state = 63},
  [4160] = {.lex_state = 146},
  [4161] = {.lex_state = 146},
  [4162] = {.lex_state = 49},
  [4163] = {.lex_state = 63},
  [4164] = {.lex_state = 63},
  [4165] = {.lex_state = 63},
  [4166] = {.lex_state = 146},
  [4167] = {.lex_state = 0, .external_lex_state = 20},
  [4168] = {.lex_state = 63},
  [4169] = {.lex_state = 63},
  [4170] = {.lex_state = 146},
  [4171] = {.lex_state = 146},
  [4172] = {.lex_state = 0, .external_lex_state = 20},
  [4173] = {.lex_state = 63},
  [4174] = {.lex_state = 63},
  [4175] = {.lex_state = 146},
  [4176] = {.lex_state = 146},
  [4177] = {.lex_state = 63},
  [4178] = {.lex_state = 63},
  [4179] = {.lex_state = 49},
  [4180] = {.lex_state = 0, .external_lex_state = 19},
  [4181] = {.lex_state = 63},
  [4182] = {.lex_state = 63},
  [4183] = {.lex_state = 63},
  [4184] = {.lex_state = 63},
  [4185] = {.lex_state = 63},
  [4186] = {.lex_state = 0, .external_lex_state = 20},
  [4187] = {.lex_state = 63},
  [4188] = {.lex_state = 63},
  [4189] = {.lex_state = 63},
  [4190] = {.lex_state = 63},
  [4191] = {.lex_state = 63},
  [4192] = {.lex_state = 63},
  [4193] = {.lex_state = 63},
  [4194] = {.lex_state = 63},
  [4195] = {.lex_state = 63},
  [4196] = {.lex_state = 63},
  [4197] = {.lex_state = 63},
  [4198] = {.lex_state = 63},
  [4199] = {.lex_state = 63},
  [4200] = {.lex_state = 63},
  [4201] = {.lex_state = 63},
  [4202] = {.lex_state = 63},
  [4203] = {.lex_state = 63},
  [4204] = {.lex_state = 63},
  [4205] = {.lex_state = 63},
  [4206] = {.lex_state = 63},
  [4207] = {.lex_state = 63},
  [4208] = {.lex_state = 63},
  [4209] = {.lex_state = 63},
  [4210] = {.lex_state = 63},
  [4211] = {.lex_state = 63},
  [4212] = {.lex_state = 63},
  [4213] = {.lex_state = 63},
  [4214] = {.lex_state = 63},
  [4215] = {.lex_state = 63},
  [4216] = {.lex_state = 63},
  [4217] = {.lex_state = 63},
  [4218] = {.lex_state = 63},
  [4219] = {.lex_state = 63},
  [4220] = {.lex_state = 63},
  [4221] = {.lex_state = 63},
  [4222] = {.lex_state = 63},
  [4223] = {.lex_state = 63},
  [4224] = {.lex_state = 63},
  [4225] = {.lex_state = 0, .external_lex_state = 17},
  [4226] = {.lex_state = 146},
  [4227] = {.lex_state = 63},
  [4228] = {.lex_state = 63},
  [4229] = {.lex_state = 63},
  [4230] = {.lex_state = 63},
  [4231] = {.lex_state = 63},
  [4232] = {.lex_state = 63},
  [4233] = {.lex_state = 63},
  [4234] = {.lex_state = 63},
  [4235] = {.lex_state = 63},
  [4236] = {.lex_state = 63},
  [4237] = {.lex_state = 63},
  [4238] = {.lex_state = 63},
  [4239] = {.lex_state = 63},
  [4240] = {.lex_state = 63},
  [4241] = {.lex_state = 146},
  [4242] = {.lex_state = 146},
  [4243] = {.lex_state = 146},
  [4244] = {.lex_state = 63},
  [4245] = {.lex_state = 146},
  [4246] = {.lex_state = 63},
  [4247] = {.lex_state = 0},
  [4248] = {.lex_state = 146},
  [4249] = {.lex_state = 63},
  [4250] = {.lex_state = 146},
  [4251] = {.lex_state = 146},
  [4252] = {.lex_state = 146},
  [4253] = {.lex_state = 49},
  [4254] = {.lex_state = 49},
  [4255] = {.lex_state = 49},
  [4256] = {.lex_state = 146},
  [4257] = {.lex_state = 146},
  [4258] = {.lex_state = 146},
  [4259] = {.lex_state = 146},
  [4260] = {.lex_state = 146},
  [4261] = {.lex_state = 146},
  [4262] = {.lex_state = 146},
  [4263] = {.lex_state = 49},
  [4264] = {.lex_state = 146},
  [4265] = {.lex_state = 146},
  [4266] = {.lex_state = 0, .external_lex_state = 19},
  [4267] = {.lex_state = 63},
  [4268] = {.lex_state = 146},
  [4269] = {.lex_state = 146},
  [4270] = {.lex_state = 146},
  [4271] = {.lex_state = 0, .external_lex_state = 20},
  [4272] = {.lex_state = 146},
  [4273] = {.lex_state = 0, .external_lex_state = 20},
  [4274] = {.lex_state = 52},
  [4275] = {.lex_state = 0, .external_lex_state = 20},
  [4276] = {.lex_state = 146},
  [4277] = {.lex_state = 146},
  [4278] = {.lex_state = 146},
  [4279] = {.lex_state = 146},
  [4280] = {.lex_state = 146},
  [4281] = {.lex_state = 146},
  [4282] = {.lex_state = 0, .external_lex_state = 17},
  [4283] = {.lex_state = 146},
  [4284] = {.lex_state = 146},
  [4285] = {.lex_state = 146},
  [4286] = {.lex_state = 146},
  [4287] = {.lex_state = 63},
  [4288] = {.lex_state = 0, .external_lex_state = 17},
  [4289] = {.lex_state = 146},
  [4290] = {.lex_state = 146},
  [4291] = {.lex_state = 146},
  [4292] = {.lex_state = 146},
  [4293] = {.lex_state = 3},
  [4294] = {.lex_state = 146},
  [4295] = {.lex_state = 146},
  [4296] = {.lex_state = 146},
  [4297] = {.lex_state = 146},
  [4298] = {.lex_state = 146},
  [4299] = {.lex_state = 63},
  [4300] = {.lex_state = 63},
  [4301] = {.lex_state = 146},
  [4302] = {.lex_state = 146},
  [4303] = {.lex_state = 0, .external_lex_state = 19},
  [4304] = {.lex_state = 146},
  [4305] = {.lex_state = 146},
  [4306] = {.lex_state = 146},
  [4307] = {.lex_state = 146},
  [4308] = {.lex_state = 146},
  [4309] = {.lex_state = 146},
  [4310] = {.lex_state = 146},
  [4311] = {.lex_state = 146},
  [4312] = {.lex_state = 146},
  [4313] = {.lex_state = 63},
  [4314] = {.lex_state = 146},
  [4315] = {.lex_state = 146},
  [4316] = {.lex_state = 146},
  [4317] = {.lex_state = 146},
  [4318] = {.lex_state = 146},
  [4319] = {.lex_state = 146},
  [4320] = {.lex_state = 0, .external_lex_state = 17},
  [4321] = {.lex_state = 146},
  [4322] = {.lex_state = 146},
  [4323] = {.lex_state = 146},
  [4324] = {.lex_state = 0, .external_lex_state = 20},
  [4325] = {.lex_state = 146},
  [4326] = {.lex_state = 146},
  [4327] = {.lex_state = 146},
  [4328] = {.lex_state = 63},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym_subroutine_block_token1] = ACTIONS(1),
    [aux_sym_if_block_token1] = ACTIONS(1),
    [aux_sym_elif_block_token1] = ACTIONS(1),
    [aux_sym_while_block_token1] = ACTIONS(1),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [aux_sym_parameter_declaration_token1] = ACTIONS(1),
    [aux_sym_parameter_declaration_token2] = ACTIONS(1),
    [aux_sym_parameter_declaration_token3] = ACTIONS(1),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(1),
    [aux_sym_macro_definition_command_token1] = ACTIONS(1),
    [aux_sym_macro_definition_command_token2] = ACTIONS(1),
    [aux_sym_macro_definition_command_token3] = ACTIONS(1),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [aux_sym__host_command_argument_list_default_format_token1] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token2] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token3] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token4] = ACTIONS(1),
    [aux_sym__hll_non_default_format_var_command_token5] = ACTIONS(1),
    [aux_sym__var_command_with_non_hll_format_token2] = ACTIONS(1),
    [aux_sym__var_command_with_non_hll_format_token3] = ACTIONS(1),
    [aux_sym__hll_var_definition_command_expression_token1] = ACTIONS(1),
    [aux_sym__hll_var_definition_command_expression_token2] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [aux_sym_hll_char_literal_token1] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_signed] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [sym_hll_primitive_type] = ACTIONS(1),
    [aux_sym_character_token2] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_POUND] = ACTIONS(1),
    [sym__blank_line] = ACTIONS(1),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(1),
    [sym_label_identifier] = ACTIONS(1),
    [sym__and_operator_pre_hook] = ACTIONS(1),
    [sym__decimal_number] = ACTIONS(1),
    [sym__decimal_number_pre_hook] = ACTIONS(1),
    [sym_hll_number_literal] = ACTIONS(1),
    [sym__hll_number_literal_pre_hook] = ACTIONS(1),
    [sym_path] = ACTIONS(1),
    [sym__ampersand_char] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_script] = STATE(4247),
    [sym_block] = STATE(260),
    [sym__statement] = STATE(260),
    [sym__non_labeled_statement] = STATE(260),
    [sym_labeled_expression] = STATE(260),
    [sym_subroutine_block] = STATE(260),
    [sym_if_block] = STATE(260),
    [sym_while_block] = STATE(260),
    [sym_repeat_block] = STATE(260),
    [sym__repeat_block_pre_condition_format] = STATE(2691),
    [sym__repeat_block_post_condition_format] = STATE(2697),
    [sym_macro_assignment_expression] = STATE(260),
    [sym__label] = STATE(316),
    [sym_macro_definition] = STATE(260),
    [sym_parameter_declaration] = STATE(260),
    [sym_subroutine_call_expression] = STATE(260),
    [sym_macro] = STATE(3936),
    [sym_recursive_macro_expansion] = STATE(2515),
    [sym_macro_definition_command] = STATE(3939),
    [sym_command_expression] = STATE(260),
    [sym__host_command] = STATE(4088),
    [sym__host_command_with_default_format] = STATE(4094),
    [sym__other_command] = STATE(4030),
    [sym__command_identifier] = STATE(3668),
    [sym__var_command] = STATE(4062),
    [sym__hll_var_command] = STATE(4080),
    [sym__hll_default_format_var_command] = STATE(3986),
    [sym__hll_non_default_format_var_command] = STATE(4016),
    [sym__non_hll_var_command] = STATE(4013),
    [sym__hll_var_definition_command] = STATE(4063),
    [sym__hll_var_command_with_default_format] = STATE(3639),
    [sym__var_command_with_non_hll_format] = STATE(3683),
    [sym__hll_var_definition_command_expression] = STATE(4073),
    [sym__hll_var_if_command] = STATE(4083),
    [aux_sym_script_repeat1] = STATE(260),
    [aux_sym_block_repeat1] = STATE(332),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_block_token1] = ACTIONS(9),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(13),
    [aux_sym_while_block_token1] = ACTIONS(15),
    [aux_sym_while_block_token2] = ACTIONS(17),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(19),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(39),
    [sym__blank_line] = ACTIONS(39),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(41),
    [sym_label_identifier] = ACTIONS(43),
  },
  [STATE(2)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(549),
    [sym_memory_space] = STATE(223),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(549),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(45),
    [anon_sym_LPAREN] = ACTIONS(48),
    [anon_sym_LBRACE] = ACTIONS(51),
    [aux_sym_subroutine_block_token1] = ACTIONS(53),
    [aux_sym_if_block_token1] = ACTIONS(53),
    [aux_sym_while_block_token1] = ACTIONS(53),
    [aux_sym_while_block_token2] = ACTIONS(55),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(53),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(53),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP_AMP] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(70),
    [aux_sym_macro_definition_token1] = ACTIONS(53),
    [aux_sym_parameter_declaration_token1] = ACTIONS(53),
    [aux_sym_parameter_declaration_token2] = ACTIONS(53),
    [aux_sym_parameter_declaration_token3] = ACTIONS(53),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(53),
    [aux_sym_macro_definition_command_token1] = ACTIONS(53),
    [aux_sym_macro_definition_command_token2] = ACTIONS(53),
    [aux_sym_macro_definition_command_token3] = ACTIONS(53),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(53),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(73),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym_comment] = ACTIONS(55),
    [sym__blank_line] = ACTIONS(55),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(53),
    [sym_label_identifier] = ACTIONS(55),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(3)] = {
    [sym__parenthesized_expression] = STATE(706),
    [sym__path_expression] = STATE(706),
    [sym_unary_expression] = STATE(706),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(706),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(706),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(706),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(706),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(706),
    [sym_string] = STATE(706),
    [sym_character] = STATE(706),
    [sym_symbol] = STATE(706),
    [sym__special_command_operator] = STATE(706),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(706),
    [sym__expression] = STATE(706),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(706),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [aux_sym_subroutine_block_token1] = ACTIONS(112),
    [aux_sym_if_block_token1] = ACTIONS(112),
    [aux_sym_while_block_token1] = ACTIONS(112),
    [aux_sym_while_block_token2] = ACTIONS(114),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(112),
    [anon_sym_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(116),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_CARET_CARET] = ACTIONS(114),
    [anon_sym_PIPE_PIPE] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_SLASH] = ACTIONS(112),
    [anon_sym_PERCENT] = ACTIONS(114),
    [anon_sym_PIPE] = ACTIONS(112),
    [anon_sym_CARET] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(114),
    [anon_sym_BANG_EQ] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(114),
    [anon_sym_LT_EQ] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(112),
    [anon_sym_LT_LT] = ACTIONS(114),
    [anon_sym_GT_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(114),
    [anon_sym_AMP_AMP] = ACTIONS(114),
    [anon_sym_AMP] = ACTIONS(124),
    [aux_sym_macro_definition_token1] = ACTIONS(112),
    [aux_sym_parameter_declaration_token1] = ACTIONS(112),
    [aux_sym_parameter_declaration_token2] = ACTIONS(112),
    [aux_sym_parameter_declaration_token3] = ACTIONS(112),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(112),
    [aux_sym_macro_definition_command_token1] = ACTIONS(112),
    [aux_sym_macro_definition_command_token2] = ACTIONS(112),
    [aux_sym_macro_definition_command_token3] = ACTIONS(112),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(112),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(134),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(148),
    [sym_time] = ACTIONS(134),
    [sym_frequency] = ACTIONS(134),
    [sym_percentage] = ACTIONS(148),
    [anon_sym_POUND] = ACTIONS(150),
    [sym_comment] = ACTIONS(114),
    [sym__blank_line] = ACTIONS(114),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(112),
    [sym_label_identifier] = ACTIONS(114),
    [sym__and_operator_pre_hook] = ACTIONS(114),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(148),
  },
  [STATE(4)] = {
    [sym__parenthesized_expression] = STATE(2410),
    [sym__path_expression] = STATE(2410),
    [sym_unary_expression] = STATE(2410),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2410),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2410),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2410),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2410),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2410),
    [sym_string] = STATE(2410),
    [sym_character] = STATE(2410),
    [sym_symbol] = STATE(2410),
    [sym__special_command_operator] = STATE(2410),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2410),
    [sym__expression] = STATE(2410),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(158),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_CARET_CARET] = ACTIONS(114),
    [anon_sym_PIPE_PIPE] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_SLASH] = ACTIONS(112),
    [anon_sym_PERCENT] = ACTIONS(114),
    [anon_sym_PIPE] = ACTIONS(112),
    [anon_sym_CARET] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(114),
    [anon_sym_BANG_EQ] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(114),
    [anon_sym_LT_EQ] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(112),
    [anon_sym_LT_LT] = ACTIONS(114),
    [anon_sym_GT_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(114),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(114),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(176),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(190),
    [sym_time] = ACTIONS(176),
    [sym_frequency] = ACTIONS(176),
    [sym_percentage] = ACTIONS(190),
    [anon_sym_POUND] = ACTIONS(192),
    [sym_comment] = ACTIONS(114),
    [sym__blank_line] = ACTIONS(114),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(112),
    [sym__and_operator_pre_hook] = ACTIONS(114),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(5)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2173),
    [sym_memory_space] = STATE(203),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2173),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(55),
    [anon_sym_LPAREN] = ACTIONS(200),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_RBRACE] = ACTIONS(55),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(55),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(205),
    [anon_sym_COMMA] = ACTIONS(55),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(55),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(6)] = {
    [sym__parenthesized_expression] = STATE(2317),
    [sym__path_expression] = STATE(2317),
    [sym_unary_expression] = STATE(2317),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2317),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2317),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2317),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2317),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2317),
    [sym_string] = STATE(2317),
    [sym_character] = STATE(2317),
    [sym_symbol] = STATE(2317),
    [sym__special_command_operator] = STATE(2317),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2317),
    [sym__expression] = STATE(2317),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(114),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_RBRACE] = ACTIONS(114),
    [anon_sym_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(219),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_CARET_CARET] = ACTIONS(114),
    [anon_sym_PIPE_PIPE] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_PERCENT] = ACTIONS(114),
    [anon_sym_PIPE] = ACTIONS(112),
    [anon_sym_CARET] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(114),
    [anon_sym_BANG_EQ] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(114),
    [anon_sym_LT_EQ] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(112),
    [anon_sym_LT_LT] = ACTIONS(114),
    [anon_sym_GT_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(114),
    [anon_sym_AMP] = ACTIONS(205),
    [anon_sym_COMMA] = ACTIONS(114),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(227),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(229),
    [sym_time] = ACTIONS(227),
    [sym_frequency] = ACTIONS(227),
    [sym_percentage] = ACTIONS(229),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(114),
    [sym__and_operator_pre_hook] = ACTIONS(114),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(7)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2247),
    [sym_memory_space] = STATE(234),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2247),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(233),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(53),
    [anon_sym_PLUS] = ACTIONS(57),
    [anon_sym_DASH] = ACTIONS(57),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(64),
    [anon_sym_DASH_DASH] = ACTIONS(64),
    [anon_sym_CARET_CARET] = ACTIONS(55),
    [anon_sym_PIPE_PIPE] = ACTIONS(55),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_SLASH] = ACTIONS(53),
    [anon_sym_PERCENT] = ACTIONS(55),
    [anon_sym_PIPE] = ACTIONS(53),
    [anon_sym_CARET] = ACTIONS(53),
    [anon_sym_EQ_EQ] = ACTIONS(55),
    [anon_sym_BANG_EQ] = ACTIONS(55),
    [anon_sym_GT] = ACTIONS(53),
    [anon_sym_GT_EQ] = ACTIONS(55),
    [anon_sym_LT_EQ] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(53),
    [anon_sym_LT_LT] = ACTIONS(55),
    [anon_sym_GT_GT] = ACTIONS(55),
    [anon_sym_DOT_DOT] = ACTIONS(55),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(55),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym_comment] = ACTIONS(55),
    [sym__blank_line] = ACTIONS(55),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(53),
    [sym__and_operator_pre_hook] = ACTIONS(55),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(8)] = {
    [sym__parenthesized_expression] = STATE(2594),
    [sym__path_expression] = STATE(2594),
    [sym_unary_expression] = STATE(2594),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2594),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2594),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2594),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2594),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2594),
    [sym_string] = STATE(2594),
    [sym_character] = STATE(2594),
    [sym_symbol] = STATE(2594),
    [sym__special_command_operator] = STATE(2594),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2594),
    [sym__expression] = STATE(2594),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_EQ] = ACTIONS(112),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(62),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_CARET_CARET] = ACTIONS(114),
    [anon_sym_PIPE_PIPE] = ACTIONS(114),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_SLASH] = ACTIONS(114),
    [anon_sym_PERCENT] = ACTIONS(114),
    [anon_sym_PIPE] = ACTIONS(112),
    [anon_sym_CARET] = ACTIONS(112),
    [anon_sym_EQ_EQ] = ACTIONS(114),
    [anon_sym_BANG_EQ] = ACTIONS(114),
    [anon_sym_GT] = ACTIONS(112),
    [anon_sym_GT_EQ] = ACTIONS(114),
    [anon_sym_LT_EQ] = ACTIONS(114),
    [anon_sym_LT] = ACTIONS(112),
    [anon_sym_LT_LT] = ACTIONS(114),
    [anon_sym_GT_GT] = ACTIONS(114),
    [anon_sym_DOT_DOT] = ACTIONS(114),
    [anon_sym_AMP] = ACTIONS(205),
    [anon_sym_COMMA] = ACTIONS(114),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(244),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(246),
    [sym_time] = ACTIONS(244),
    [sym_frequency] = ACTIONS(244),
    [sym_percentage] = ACTIONS(246),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(114),
    [sym__and_operator_pre_hook] = ACTIONS(114),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(9)] = {
    [sym__statement] = STATE(2628),
    [sym__non_labeled_statement] = STATE(2628),
    [sym_labeled_expression] = STATE(2628),
    [sym_subroutine_block] = STATE(2628),
    [sym_if_block] = STATE(2628),
    [sym_while_block] = STATE(2628),
    [sym_repeat_block] = STATE(2628),
    [sym__repeat_block_pre_condition_format] = STATE(2691),
    [sym__repeat_block_post_condition_format] = STATE(2697),
    [sym_macro_assignment_expression] = STATE(2628),
    [sym__label] = STATE(314),
    [sym_macro_definition] = STATE(2628),
    [sym_parameter_declaration] = STATE(2628),
    [sym_subroutine_call_expression] = STATE(2628),
    [sym_macro] = STATE(3936),
    [sym_recursive_macro_expansion] = STATE(2515),
    [sym_macro_definition_command] = STATE(3939),
    [sym_command_expression] = STATE(2628),
    [sym__host_command] = STATE(4088),
    [sym__host_command_with_default_format] = STATE(4094),
    [sym__other_command] = STATE(4030),
    [sym__command_identifier] = STATE(3668),
    [sym_argument_list] = STATE(555),
    [sym__var_command] = STATE(4062),
    [sym__hll_var_command] = STATE(4080),
    [sym__hll_default_format_var_command] = STATE(3986),
    [sym__hll_non_default_format_var_command] = STATE(4016),
    [sym__non_hll_var_command] = STATE(4013),
    [sym__hll_var_definition_command] = STATE(4063),
    [sym__hll_var_command_with_default_format] = STATE(3639),
    [sym__var_command_with_non_hll_format] = STATE(3683),
    [sym__hll_var_definition_command_expression] = STATE(4073),
    [sym__hll_var_if_command] = STATE(4071),
    [aux_sym_block_repeat1] = STATE(325),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(248),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(250),
    [aux_sym_while_block_token1] = ACTIONS(252),
    [aux_sym_while_block_token2] = ACTIONS(254),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_PLUS] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(260),
    [anon_sym_PLUS_PLUS] = ACTIONS(262),
    [anon_sym_DASH_DASH] = ACTIONS(262),
    [anon_sym_CARET_CARET] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(266),
    [anon_sym_STAR] = ACTIONS(268),
    [anon_sym_SLASH] = ACTIONS(270),
    [anon_sym_PERCENT] = ACTIONS(268),
    [anon_sym_PIPE] = ACTIONS(272),
    [anon_sym_CARET] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(276),
    [anon_sym_BANG_EQ] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(276),
    [anon_sym_LT_EQ] = ACTIONS(276),
    [anon_sym_LT] = ACTIONS(278),
    [anon_sym_LT_LT] = ACTIONS(280),
    [anon_sym_GT_GT] = ACTIONS(280),
    [anon_sym_DOT_DOT] = ACTIONS(282),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(286),
    [sym__blank_line] = ACTIONS(286),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(288),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(290),
  },
  [STATE(10)] = {
    [sym__statement] = STATE(2628),
    [sym__non_labeled_statement] = STATE(2628),
    [sym_labeled_expression] = STATE(2628),
    [sym_subroutine_block] = STATE(2628),
    [sym_if_block] = STATE(2628),
    [sym_while_block] = STATE(2628),
    [sym_repeat_block] = STATE(2628),
    [sym__repeat_block_pre_condition_format] = STATE(2691),
    [sym__repeat_block_post_condition_format] = STATE(2697),
    [sym_macro_assignment_expression] = STATE(2628),
    [sym__label] = STATE(316),
    [sym_macro_definition] = STATE(2628),
    [sym_parameter_declaration] = STATE(2628),
    [sym_subroutine_call_expression] = STATE(2628),
    [sym_macro] = STATE(3936),
    [sym_recursive_macro_expansion] = STATE(2515),
    [sym_macro_definition_command] = STATE(3939),
    [sym_command_expression] = STATE(2628),
    [sym__host_command] = STATE(4088),
    [sym__host_command_with_default_format] = STATE(4094),
    [sym__other_command] = STATE(4030),
    [sym__command_identifier] = STATE(3668),
    [sym_argument_list] = STATE(555),
    [sym__var_command] = STATE(4062),
    [sym__hll_var_command] = STATE(4080),
    [sym__hll_default_format_var_command] = STATE(3986),
    [sym__hll_non_default_format_var_command] = STATE(4016),
    [sym__non_hll_var_command] = STATE(4013),
    [sym__hll_var_definition_command] = STATE(4063),
    [sym__hll_var_command_with_default_format] = STATE(3639),
    [sym__var_command_with_non_hll_format] = STATE(3683),
    [sym__hll_var_definition_command_expression] = STATE(4073),
    [sym__hll_var_if_command] = STATE(4083),
    [aux_sym_block_repeat1] = STATE(329),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(248),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(13),
    [aux_sym_while_block_token1] = ACTIONS(15),
    [aux_sym_while_block_token2] = ACTIONS(17),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(19),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_PLUS] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(260),
    [anon_sym_PLUS_PLUS] = ACTIONS(262),
    [anon_sym_DASH_DASH] = ACTIONS(262),
    [anon_sym_CARET_CARET] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(266),
    [anon_sym_STAR] = ACTIONS(268),
    [anon_sym_SLASH] = ACTIONS(270),
    [anon_sym_PERCENT] = ACTIONS(268),
    [anon_sym_PIPE] = ACTIONS(272),
    [anon_sym_CARET] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(276),
    [anon_sym_BANG_EQ] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(276),
    [anon_sym_LT_EQ] = ACTIONS(276),
    [anon_sym_LT] = ACTIONS(278),
    [anon_sym_LT_LT] = ACTIONS(280),
    [anon_sym_GT_GT] = ACTIONS(280),
    [anon_sym_DOT_DOT] = ACTIONS(282),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(292),
    [sym__blank_line] = ACTIONS(292),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(294),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(290),
  },
  [STATE(11)] = {
    [sym__hll_expression] = STATE(1373),
    [sym_hll_call_expression] = STATE(1518),
    [sym_hll_field_expression] = STATE(1518),
    [sym_hll_subscript_expression] = STATE(1518),
    [sym_hll_cast_expression] = STATE(1373),
    [sym_hll_sizeof_expression] = STATE(1373),
    [sym_hll_pointer_expression] = STATE(1518),
    [sym_hll_update_expression] = STATE(1373),
    [sym_hll_unary_expression] = STATE(1373),
    [sym_hll_binary_expression] = STATE(1373),
    [sym_hll_assignment_expression] = STATE(1373),
    [sym__hll_assignment_left_expression] = STATE(2846),
    [sym_hll_conditional_expression] = STATE(1373),
    [sym_hll_char_literal] = STATE(1373),
    [sym_hll_string_literal] = STATE(1373),
    [sym_hll_parenthesized_expression] = STATE(1518),
    [sym_symbol] = STATE(1518),
    [sym_identifier] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(298),
    [anon_sym_LPAREN] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_PLUS] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(306),
    [anon_sym_BANG] = ACTIONS(304),
    [anon_sym_PLUS_PLUS] = ACTIONS(308),
    [anon_sym_DASH_DASH] = ACTIONS(308),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_DOT_DOT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_RBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(312),
    [anon_sym_STAR_EQ] = ACTIONS(298),
    [anon_sym_SLASH_EQ] = ACTIONS(298),
    [anon_sym_PERCENT_EQ] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(298),
    [anon_sym_DASH_EQ] = ACTIONS(298),
    [anon_sym_LT_LT_EQ] = ACTIONS(298),
    [anon_sym_GT_GT_EQ] = ACTIONS(298),
    [anon_sym_AMP_EQ] = ACTIONS(298),
    [anon_sym_CARET_EQ] = ACTIONS(298),
    [anon_sym_PIPE_EQ] = ACTIONS(298),
    [anon_sym_L_SQUOTE] = ACTIONS(314),
    [anon_sym_u_SQUOTE] = ACTIONS(314),
    [anon_sym_U_SQUOTE] = ACTIONS(314),
    [anon_sym_u8_SQUOTE] = ACTIONS(314),
    [anon_sym_SQUOTE] = ACTIONS(314),
    [anon_sym_L_DQUOTE] = ACTIONS(316),
    [anon_sym_u_DQUOTE] = ACTIONS(316),
    [anon_sym_U_DQUOTE] = ACTIONS(316),
    [anon_sym_u8_DQUOTE] = ACTIONS(316),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(298),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(12)] = {
    [sym__hll_expression] = STATE(1404),
    [sym_hll_call_expression] = STATE(1518),
    [sym_hll_field_expression] = STATE(1518),
    [sym_hll_subscript_expression] = STATE(1518),
    [sym_hll_cast_expression] = STATE(1404),
    [sym_hll_sizeof_expression] = STATE(1404),
    [sym_hll_pointer_expression] = STATE(1518),
    [sym_hll_update_expression] = STATE(1404),
    [sym_hll_unary_expression] = STATE(1404),
    [sym_hll_binary_expression] = STATE(1404),
    [sym_hll_assignment_expression] = STATE(1404),
    [sym__hll_assignment_left_expression] = STATE(2846),
    [sym_hll_conditional_expression] = STATE(1404),
    [sym_hll_char_literal] = STATE(1404),
    [sym_hll_string_literal] = STATE(1404),
    [sym_hll_parenthesized_expression] = STATE(1518),
    [sym_symbol] = STATE(1518),
    [sym_identifier] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(306),
    [anon_sym_BANG] = ACTIONS(304),
    [anon_sym_PLUS_PLUS] = ACTIONS(308),
    [anon_sym_DASH_DASH] = ACTIONS(308),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_DOT_DOT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(330),
    [anon_sym_DOT] = ACTIONS(332),
    [anon_sym_COMMA] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(312),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(314),
    [anon_sym_u_SQUOTE] = ACTIONS(314),
    [anon_sym_U_SQUOTE] = ACTIONS(314),
    [anon_sym_u8_SQUOTE] = ACTIONS(314),
    [anon_sym_SQUOTE] = ACTIONS(314),
    [anon_sym_L_DQUOTE] = ACTIONS(316),
    [anon_sym_u_DQUOTE] = ACTIONS(316),
    [anon_sym_U_DQUOTE] = ACTIONS(316),
    [anon_sym_u8_DQUOTE] = ACTIONS(316),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(330),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(13)] = {
    [sym__hll_expression] = STATE(1371),
    [sym_hll_call_expression] = STATE(1518),
    [sym_hll_field_expression] = STATE(1518),
    [sym_hll_subscript_expression] = STATE(1518),
    [sym_hll_cast_expression] = STATE(1371),
    [sym_hll_sizeof_expression] = STATE(1371),
    [sym_hll_pointer_expression] = STATE(1518),
    [sym_hll_update_expression] = STATE(1371),
    [sym_hll_unary_expression] = STATE(1371),
    [sym_hll_binary_expression] = STATE(1371),
    [sym_hll_assignment_expression] = STATE(1371),
    [sym__hll_assignment_left_expression] = STATE(2846),
    [sym_hll_conditional_expression] = STATE(1371),
    [sym_hll_char_literal] = STATE(1371),
    [sym_hll_string_literal] = STATE(1371),
    [sym_hll_parenthesized_expression] = STATE(1518),
    [sym_symbol] = STATE(1518),
    [sym_identifier] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(306),
    [anon_sym_BANG] = ACTIONS(304),
    [anon_sym_PLUS_PLUS] = ACTIONS(308),
    [anon_sym_DASH_DASH] = ACTIONS(308),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_DOT_DOT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(334),
    [anon_sym_DOT] = ACTIONS(336),
    [anon_sym_COMMA] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(312),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(314),
    [anon_sym_u_SQUOTE] = ACTIONS(314),
    [anon_sym_U_SQUOTE] = ACTIONS(314),
    [anon_sym_u8_SQUOTE] = ACTIONS(314),
    [anon_sym_SQUOTE] = ACTIONS(314),
    [anon_sym_L_DQUOTE] = ACTIONS(316),
    [anon_sym_u_DQUOTE] = ACTIONS(316),
    [anon_sym_U_DQUOTE] = ACTIONS(316),
    [anon_sym_u8_DQUOTE] = ACTIONS(316),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(334),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(14)] = {
    [sym__hll_expression] = STATE(1372),
    [sym_hll_call_expression] = STATE(1518),
    [sym_hll_field_expression] = STATE(1518),
    [sym_hll_subscript_expression] = STATE(1518),
    [sym_hll_cast_expression] = STATE(1372),
    [sym_hll_sizeof_expression] = STATE(1372),
    [sym_hll_pointer_expression] = STATE(1518),
    [sym_hll_update_expression] = STATE(1372),
    [sym_hll_unary_expression] = STATE(1372),
    [sym_hll_binary_expression] = STATE(1372),
    [sym_hll_assignment_expression] = STATE(1372),
    [sym__hll_assignment_left_expression] = STATE(2846),
    [sym_hll_conditional_expression] = STATE(1372),
    [sym_hll_char_literal] = STATE(1372),
    [sym_hll_string_literal] = STATE(1372),
    [sym_hll_parenthesized_expression] = STATE(1518),
    [sym_symbol] = STATE(1518),
    [sym_identifier] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(306),
    [anon_sym_BANG] = ACTIONS(304),
    [anon_sym_PLUS_PLUS] = ACTIONS(308),
    [anon_sym_DASH_DASH] = ACTIONS(308),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_DOT_DOT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(338),
    [anon_sym_DOT] = ACTIONS(340),
    [anon_sym_COMMA] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(312),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(314),
    [anon_sym_u_SQUOTE] = ACTIONS(314),
    [anon_sym_U_SQUOTE] = ACTIONS(314),
    [anon_sym_u8_SQUOTE] = ACTIONS(314),
    [anon_sym_SQUOTE] = ACTIONS(314),
    [anon_sym_L_DQUOTE] = ACTIONS(316),
    [anon_sym_u_DQUOTE] = ACTIONS(316),
    [anon_sym_U_DQUOTE] = ACTIONS(316),
    [anon_sym_u8_DQUOTE] = ACTIONS(316),
    [anon_sym_DQUOTE] = ACTIONS(316),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(338),
    [sym__hll_number_literal_pre_hook] = ACTIONS(328),
  },
  [STATE(15)] = {
    [sym__statement] = STATE(2628),
    [sym__non_labeled_statement] = STATE(2628),
    [sym_labeled_expression] = STATE(2628),
    [sym_subroutine_block] = STATE(2628),
    [sym_if_block] = STATE(2628),
    [sym_while_block] = STATE(2628),
    [sym_repeat_block] = STATE(2628),
    [sym__repeat_block_pre_condition_format] = STATE(2691),
    [sym__repeat_block_post_condition_format] = STATE(2697),
    [sym_macro_assignment_expression] = STATE(2628),
    [sym__label] = STATE(315),
    [sym_macro_definition] = STATE(2628),
    [sym_parameter_declaration] = STATE(2628),
    [sym_subroutine_call_expression] = STATE(2628),
    [sym_macro] = STATE(3936),
    [sym_recursive_macro_expansion] = STATE(2515),
    [sym_macro_definition_command] = STATE(3939),
    [sym_command_expression] = STATE(2628),
    [sym__host_command] = STATE(4088),
    [sym__host_command_with_default_format] = STATE(4094),
    [sym__other_command] = STATE(4030),
    [sym__command_identifier] = STATE(3668),
    [sym_argument_list] = STATE(555),
    [sym__var_command] = STATE(4062),
    [sym__hll_var_command] = STATE(4080),
    [sym__hll_default_format_var_command] = STATE(3986),
    [sym__hll_non_default_format_var_command] = STATE(4016),
    [sym__non_hll_var_command] = STATE(4013),
    [sym__hll_var_definition_command] = STATE(4063),
    [sym__hll_var_command_with_default_format] = STATE(3639),
    [sym__var_command_with_non_hll_format] = STATE(3683),
    [sym__hll_var_definition_command_expression] = STATE(4073),
    [sym__hll_var_if_command] = STATE(4059),
    [aux_sym_block_repeat1] = STATE(337),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(248),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(342),
    [aux_sym_while_block_token1] = ACTIONS(344),
    [aux_sym_while_block_token2] = ACTIONS(346),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(348),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_PLUS] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(260),
    [anon_sym_PLUS_PLUS] = ACTIONS(262),
    [anon_sym_DASH_DASH] = ACTIONS(262),
    [anon_sym_CARET_CARET] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(266),
    [anon_sym_STAR] = ACTIONS(268),
    [anon_sym_SLASH] = ACTIONS(270),
    [anon_sym_PERCENT] = ACTIONS(268),
    [anon_sym_PIPE] = ACTIONS(272),
    [anon_sym_CARET] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(276),
    [anon_sym_BANG_EQ] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(276),
    [anon_sym_LT_EQ] = ACTIONS(276),
    [anon_sym_LT] = ACTIONS(278),
    [anon_sym_LT_LT] = ACTIONS(280),
    [anon_sym_GT_GT] = ACTIONS(280),
    [anon_sym_DOT_DOT] = ACTIONS(282),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(350),
    [sym__blank_line] = ACTIONS(350),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(352),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(290),
  },
  [STATE(16)] = {
    [sym__statement] = STATE(2628),
    [sym__non_labeled_statement] = STATE(2628),
    [sym_labeled_expression] = STATE(2628),
    [sym_subroutine_block] = STATE(2628),
    [sym_if_block] = STATE(2628),
    [sym_while_block] = STATE(2628),
    [sym_repeat_block] = STATE(2628),
    [sym__repeat_block_pre_condition_format] = STATE(2691),
    [sym__repeat_block_post_condition_format] = STATE(2697),
    [sym_macro_assignment_expression] = STATE(2628),
    [sym__label] = STATE(313),
    [sym_macro_definition] = STATE(2628),
    [sym_parameter_declaration] = STATE(2628),
    [sym_subroutine_call_expression] = STATE(2628),
    [sym_macro] = STATE(3936),
    [sym_recursive_macro_expansion] = STATE(2515),
    [sym_macro_definition_command] = STATE(3939),
    [sym_command_expression] = STATE(2628),
    [sym__host_command] = STATE(4088),
    [sym__host_command_with_default_format] = STATE(4094),
    [sym__other_command] = STATE(4030),
    [sym__command_identifier] = STATE(3668),
    [sym_argument_list] = STATE(555),
    [sym__var_command] = STATE(4062),
    [sym__hll_var_command] = STATE(4080),
    [sym__hll_default_format_var_command] = STATE(3986),
    [sym__hll_non_default_format_var_command] = STATE(4016),
    [sym__non_hll_var_command] = STATE(4013),
    [sym__hll_var_definition_command] = STATE(4063),
    [sym__hll_var_command_with_default_format] = STATE(3639),
    [sym__var_command_with_non_hll_format] = STATE(3683),
    [sym__hll_var_definition_command_expression] = STATE(4073),
    [sym__hll_var_if_command] = STATE(4069),
    [aux_sym_block_repeat1] = STATE(340),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(248),
    [aux_sym_subroutine_block_token1] = ACTIONS(11),
    [aux_sym_if_block_token1] = ACTIONS(354),
    [aux_sym_while_block_token1] = ACTIONS(356),
    [aux_sym_while_block_token2] = ACTIONS(358),
    [aux_sym__repeat_block_pre_condition_format_token1] = ACTIONS(360),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_PLUS] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(260),
    [anon_sym_PLUS_PLUS] = ACTIONS(262),
    [anon_sym_DASH_DASH] = ACTIONS(262),
    [anon_sym_CARET_CARET] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(266),
    [anon_sym_STAR] = ACTIONS(268),
    [anon_sym_SLASH] = ACTIONS(270),
    [anon_sym_PERCENT] = ACTIONS(268),
    [anon_sym_PIPE] = ACTIONS(272),
    [anon_sym_CARET] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(276),
    [anon_sym_BANG_EQ] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(276),
    [anon_sym_LT_EQ] = ACTIONS(276),
    [anon_sym_LT] = ACTIONS(278),
    [anon_sym_LT_LT] = ACTIONS(280),
    [anon_sym_GT_GT] = ACTIONS(280),
    [anon_sym_DOT_DOT] = ACTIONS(282),
    [anon_sym_AMP_AMP] = ACTIONS(21),
    [anon_sym_AMP] = ACTIONS(23),
    [aux_sym_macro_definition_token1] = ACTIONS(25),
    [aux_sym_parameter_declaration_token1] = ACTIONS(27),
    [aux_sym_parameter_declaration_token2] = ACTIONS(27),
    [aux_sym_parameter_declaration_token3] = ACTIONS(29),
    [aux_sym_subroutine_call_expression_token1] = ACTIONS(31),
    [aux_sym_macro_definition_command_token1] = ACTIONS(33),
    [aux_sym_macro_definition_command_token2] = ACTIONS(33),
    [aux_sym_macro_definition_command_token3] = ACTIONS(33),
    [aux_sym__host_command_with_default_format_token1] = ACTIONS(35),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(37),
    [sym_comment] = ACTIONS(362),
    [sym__blank_line] = ACTIONS(362),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(364),
    [sym_label_identifier] = ACTIONS(43),
    [sym__and_operator_pre_hook] = ACTIONS(290),
  },
  [STATE(17)] = {
    [sym__hll_expression] = STATE(1496),
    [sym_hll_call_expression] = STATE(1594),
    [sym_hll_field_expression] = STATE(1594),
    [sym_hll_subscript_expression] = STATE(1594),
    [sym_hll_cast_expression] = STATE(1496),
    [sym_hll_sizeof_expression] = STATE(1496),
    [sym_hll_pointer_expression] = STATE(1594),
    [sym_hll_update_expression] = STATE(1496),
    [sym_hll_unary_expression] = STATE(1496),
    [sym_hll_binary_expression] = STATE(1496),
    [sym_hll_assignment_expression] = STATE(1496),
    [sym__hll_assignment_left_expression] = STATE(2872),
    [sym_hll_conditional_expression] = STATE(1496),
    [sym_hll_char_literal] = STATE(1496),
    [sym_hll_string_literal] = STATE(1496),
    [sym_hll_parenthesized_expression] = STATE(1594),
    [sym_symbol] = STATE(1594),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(368),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(370),
    [anon_sym_DASH] = ACTIONS(370),
    [anon_sym_TILDE] = ACTIONS(372),
    [anon_sym_BANG] = ACTIONS(370),
    [anon_sym_PLUS_PLUS] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(374),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(378),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(380),
    [anon_sym_u_SQUOTE] = ACTIONS(380),
    [anon_sym_U_SQUOTE] = ACTIONS(380),
    [anon_sym_u8_SQUOTE] = ACTIONS(380),
    [anon_sym_SQUOTE] = ACTIONS(380),
    [anon_sym_L_DQUOTE] = ACTIONS(382),
    [anon_sym_u_DQUOTE] = ACTIONS(382),
    [anon_sym_U_DQUOTE] = ACTIONS(382),
    [anon_sym_u8_DQUOTE] = ACTIONS(382),
    [anon_sym_DQUOTE] = ACTIONS(382),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(340),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(394),
  },
  [STATE(18)] = {
    [sym__hll_expression] = STATE(1432),
    [sym_hll_call_expression] = STATE(1594),
    [sym_hll_field_expression] = STATE(1594),
    [sym_hll_subscript_expression] = STATE(1594),
    [sym_hll_cast_expression] = STATE(1432),
    [sym_hll_sizeof_expression] = STATE(1432),
    [sym_hll_pointer_expression] = STATE(1594),
    [sym_hll_update_expression] = STATE(1432),
    [sym_hll_unary_expression] = STATE(1432),
    [sym_hll_binary_expression] = STATE(1432),
    [sym_hll_assignment_expression] = STATE(1432),
    [sym__hll_assignment_left_expression] = STATE(2872),
    [sym_hll_conditional_expression] = STATE(1432),
    [sym_hll_char_literal] = STATE(1432),
    [sym_hll_string_literal] = STATE(1432),
    [sym_hll_parenthesized_expression] = STATE(1594),
    [sym_symbol] = STATE(1594),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(368),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(370),
    [anon_sym_DASH] = ACTIONS(370),
    [anon_sym_TILDE] = ACTIONS(372),
    [anon_sym_BANG] = ACTIONS(370),
    [anon_sym_PLUS_PLUS] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(374),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(378),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(380),
    [anon_sym_u_SQUOTE] = ACTIONS(380),
    [anon_sym_U_SQUOTE] = ACTIONS(380),
    [anon_sym_u8_SQUOTE] = ACTIONS(380),
    [anon_sym_SQUOTE] = ACTIONS(380),
    [anon_sym_L_DQUOTE] = ACTIONS(382),
    [anon_sym_u_DQUOTE] = ACTIONS(382),
    [anon_sym_U_DQUOTE] = ACTIONS(382),
    [anon_sym_u8_DQUOTE] = ACTIONS(382),
    [anon_sym_DQUOTE] = ACTIONS(382),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(332),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(394),
  },
  [STATE(19)] = {
    [sym__hll_expression] = STATE(1495),
    [sym_hll_call_expression] = STATE(1594),
    [sym_hll_field_expression] = STATE(1594),
    [sym_hll_subscript_expression] = STATE(1594),
    [sym_hll_cast_expression] = STATE(1495),
    [sym_hll_sizeof_expression] = STATE(1495),
    [sym_hll_pointer_expression] = STATE(1594),
    [sym_hll_update_expression] = STATE(1495),
    [sym_hll_unary_expression] = STATE(1495),
    [sym_hll_binary_expression] = STATE(1495),
    [sym_hll_assignment_expression] = STATE(1495),
    [sym__hll_assignment_left_expression] = STATE(2872),
    [sym_hll_conditional_expression] = STATE(1495),
    [sym_hll_char_literal] = STATE(1495),
    [sym_hll_string_literal] = STATE(1495),
    [sym_hll_parenthesized_expression] = STATE(1594),
    [sym_symbol] = STATE(1594),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(368),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(370),
    [anon_sym_DASH] = ACTIONS(370),
    [anon_sym_TILDE] = ACTIONS(372),
    [anon_sym_BANG] = ACTIONS(370),
    [anon_sym_PLUS_PLUS] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(374),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(378),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(380),
    [anon_sym_u_SQUOTE] = ACTIONS(380),
    [anon_sym_U_SQUOTE] = ACTIONS(380),
    [anon_sym_u8_SQUOTE] = ACTIONS(380),
    [anon_sym_SQUOTE] = ACTIONS(380),
    [anon_sym_L_DQUOTE] = ACTIONS(382),
    [anon_sym_u_DQUOTE] = ACTIONS(382),
    [anon_sym_U_DQUOTE] = ACTIONS(382),
    [anon_sym_u8_DQUOTE] = ACTIONS(382),
    [anon_sym_DQUOTE] = ACTIONS(382),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(336),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(394),
  },
  [STATE(20)] = {
    [sym__hll_expression] = STATE(1529),
    [sym_hll_call_expression] = STATE(1594),
    [sym_hll_field_expression] = STATE(1594),
    [sym_hll_subscript_expression] = STATE(1594),
    [sym_hll_cast_expression] = STATE(1529),
    [sym_hll_sizeof_expression] = STATE(1529),
    [sym_hll_pointer_expression] = STATE(1594),
    [sym_hll_update_expression] = STATE(1529),
    [sym_hll_unary_expression] = STATE(1529),
    [sym_hll_binary_expression] = STATE(1529),
    [sym_hll_assignment_expression] = STATE(1529),
    [sym__hll_assignment_left_expression] = STATE(2872),
    [sym_hll_conditional_expression] = STATE(1529),
    [sym_hll_char_literal] = STATE(1529),
    [sym_hll_string_literal] = STATE(1529),
    [sym_hll_parenthesized_expression] = STATE(1594),
    [sym_symbol] = STATE(1594),
    [sym_identifier] = ACTIONS(366),
    [anon_sym_LPAREN] = ACTIONS(368),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_PLUS] = ACTIONS(370),
    [anon_sym_DASH] = ACTIONS(370),
    [anon_sym_TILDE] = ACTIONS(372),
    [anon_sym_BANG] = ACTIONS(370),
    [anon_sym_PLUS_PLUS] = ACTIONS(374),
    [anon_sym_DASH_DASH] = ACTIONS(374),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(376),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(378),
    [anon_sym_STAR_EQ] = ACTIONS(298),
    [anon_sym_SLASH_EQ] = ACTIONS(298),
    [anon_sym_PERCENT_EQ] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(298),
    [anon_sym_DASH_EQ] = ACTIONS(298),
    [anon_sym_LT_LT_EQ] = ACTIONS(298),
    [anon_sym_GT_GT_EQ] = ACTIONS(298),
    [anon_sym_AMP_EQ] = ACTIONS(298),
    [anon_sym_CARET_EQ] = ACTIONS(298),
    [anon_sym_PIPE_EQ] = ACTIONS(298),
    [anon_sym_L_SQUOTE] = ACTIONS(380),
    [anon_sym_u_SQUOTE] = ACTIONS(380),
    [anon_sym_U_SQUOTE] = ACTIONS(380),
    [anon_sym_u8_SQUOTE] = ACTIONS(380),
    [anon_sym_SQUOTE] = ACTIONS(380),
    [anon_sym_L_DQUOTE] = ACTIONS(382),
    [anon_sym_u_DQUOTE] = ACTIONS(382),
    [anon_sym_U_DQUOTE] = ACTIONS(382),
    [anon_sym_u8_DQUOTE] = ACTIONS(382),
    [anon_sym_DQUOTE] = ACTIONS(382),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(298),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(302),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(298),
    [sym__blank_line] = ACTIONS(298),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(394),
  },
  [STATE(21)] = {
    [sym__parenthesized_expression] = STATE(2347),
    [sym__path_expression] = STATE(2347),
    [sym_unary_expression] = STATE(2347),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2347),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2347),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym__command_arguments] = STATE(3981),
    [sym__command_argument] = STATE(3516),
    [sym_option_expression] = STATE(3518),
    [sym_format_expression] = STATE(3516),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2347),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2347),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2347),
    [sym_string] = STATE(2347),
    [sym_character] = STATE(2347),
    [sym_symbol] = STATE(2347),
    [sym__special_command_operator] = STATE(2347),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2347),
    [sym__expression] = STATE(2347),
    [aux_sym_block_repeat1] = STATE(1770),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [aux_sym__command_arguments_repeat1] = STATE(32),
    [aux_sym__command_arguments_repeat2] = STATE(3728),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_SLASH] = ACTIONS(396),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(400),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(402),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(404),
    [sym_time] = ACTIONS(402),
    [sym_frequency] = ACTIONS(402),
    [sym_percentage] = ACTIONS(404),
    [anon_sym_POUND] = ACTIONS(192),
    [sym_comment] = ACTIONS(406),
    [sym__blank_line] = ACTIONS(406),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(408),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(22)] = {
    [sym__hll_expression] = STATE(1689),
    [sym_hll_call_expression] = STATE(1700),
    [sym_hll_field_expression] = STATE(1700),
    [sym_hll_subscript_expression] = STATE(1700),
    [sym_hll_cast_expression] = STATE(1689),
    [sym_hll_sizeof_expression] = STATE(1689),
    [sym_hll_pointer_expression] = STATE(1700),
    [sym_hll_update_expression] = STATE(1689),
    [sym_hll_unary_expression] = STATE(1689),
    [sym_hll_binary_expression] = STATE(1689),
    [sym_hll_assignment_expression] = STATE(1689),
    [sym__hll_assignment_left_expression] = STATE(2856),
    [sym_hll_conditional_expression] = STATE(1689),
    [sym_hll_char_literal] = STATE(1689),
    [sym_hll_string_literal] = STATE(1689),
    [sym_hll_parenthesized_expression] = STATE(1700),
    [sym_symbol] = STATE(1700),
    [sym_identifier] = ACTIONS(410),
    [anon_sym_LPAREN] = ACTIONS(412),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_TILDE] = ACTIONS(416),
    [anon_sym_BANG] = ACTIONS(414),
    [anon_sym_PLUS_PLUS] = ACTIONS(418),
    [anon_sym_DASH_DASH] = ACTIONS(418),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(424),
    [anon_sym_u_SQUOTE] = ACTIONS(424),
    [anon_sym_U_SQUOTE] = ACTIONS(424),
    [anon_sym_u8_SQUOTE] = ACTIONS(424),
    [anon_sym_SQUOTE] = ACTIONS(424),
    [anon_sym_L_DQUOTE] = ACTIONS(426),
    [anon_sym_u_DQUOTE] = ACTIONS(426),
    [anon_sym_U_DQUOTE] = ACTIONS(426),
    [anon_sym_u8_DQUOTE] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(426),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(438),
  },
  [STATE(23)] = {
    [sym__hll_expression] = STATE(1695),
    [sym_hll_call_expression] = STATE(1700),
    [sym_hll_field_expression] = STATE(1700),
    [sym_hll_subscript_expression] = STATE(1700),
    [sym_hll_cast_expression] = STATE(1695),
    [sym_hll_sizeof_expression] = STATE(1695),
    [sym_hll_pointer_expression] = STATE(1700),
    [sym_hll_update_expression] = STATE(1695),
    [sym_hll_unary_expression] = STATE(1695),
    [sym_hll_binary_expression] = STATE(1695),
    [sym_hll_assignment_expression] = STATE(1695),
    [sym__hll_assignment_left_expression] = STATE(2856),
    [sym_hll_conditional_expression] = STATE(1695),
    [sym_hll_char_literal] = STATE(1695),
    [sym_hll_string_literal] = STATE(1695),
    [sym_hll_parenthesized_expression] = STATE(1700),
    [sym_symbol] = STATE(1700),
    [sym_identifier] = ACTIONS(410),
    [anon_sym_LPAREN] = ACTIONS(412),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_TILDE] = ACTIONS(416),
    [anon_sym_BANG] = ACTIONS(414),
    [anon_sym_PLUS_PLUS] = ACTIONS(418),
    [anon_sym_DASH_DASH] = ACTIONS(418),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(424),
    [anon_sym_u_SQUOTE] = ACTIONS(424),
    [anon_sym_U_SQUOTE] = ACTIONS(424),
    [anon_sym_u8_SQUOTE] = ACTIONS(424),
    [anon_sym_SQUOTE] = ACTIONS(424),
    [anon_sym_L_DQUOTE] = ACTIONS(426),
    [anon_sym_u_DQUOTE] = ACTIONS(426),
    [anon_sym_U_DQUOTE] = ACTIONS(426),
    [anon_sym_u8_DQUOTE] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(426),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(438),
  },
  [STATE(24)] = {
    [sym__hll_expression] = STATE(1696),
    [sym_hll_call_expression] = STATE(1700),
    [sym_hll_field_expression] = STATE(1700),
    [sym_hll_subscript_expression] = STATE(1700),
    [sym_hll_cast_expression] = STATE(1696),
    [sym_hll_sizeof_expression] = STATE(1696),
    [sym_hll_pointer_expression] = STATE(1700),
    [sym_hll_update_expression] = STATE(1696),
    [sym_hll_unary_expression] = STATE(1696),
    [sym_hll_binary_expression] = STATE(1696),
    [sym_hll_assignment_expression] = STATE(1696),
    [sym__hll_assignment_left_expression] = STATE(2856),
    [sym_hll_conditional_expression] = STATE(1696),
    [sym_hll_char_literal] = STATE(1696),
    [sym_hll_string_literal] = STATE(1696),
    [sym_hll_parenthesized_expression] = STATE(1700),
    [sym_symbol] = STATE(1700),
    [sym_identifier] = ACTIONS(410),
    [anon_sym_LPAREN] = ACTIONS(412),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_TILDE] = ACTIONS(416),
    [anon_sym_BANG] = ACTIONS(414),
    [anon_sym_PLUS_PLUS] = ACTIONS(418),
    [anon_sym_DASH_DASH] = ACTIONS(418),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(298),
    [anon_sym_SLASH_EQ] = ACTIONS(298),
    [anon_sym_PERCENT_EQ] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(298),
    [anon_sym_DASH_EQ] = ACTIONS(298),
    [anon_sym_LT_LT_EQ] = ACTIONS(298),
    [anon_sym_GT_GT_EQ] = ACTIONS(298),
    [anon_sym_AMP_EQ] = ACTIONS(298),
    [anon_sym_CARET_EQ] = ACTIONS(298),
    [anon_sym_PIPE_EQ] = ACTIONS(298),
    [anon_sym_L_SQUOTE] = ACTIONS(424),
    [anon_sym_u_SQUOTE] = ACTIONS(424),
    [anon_sym_U_SQUOTE] = ACTIONS(424),
    [anon_sym_u8_SQUOTE] = ACTIONS(424),
    [anon_sym_SQUOTE] = ACTIONS(424),
    [anon_sym_L_DQUOTE] = ACTIONS(426),
    [anon_sym_u_DQUOTE] = ACTIONS(426),
    [anon_sym_U_DQUOTE] = ACTIONS(426),
    [anon_sym_u8_DQUOTE] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(426),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(298),
    [sym__blank_line] = ACTIONS(298),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(438),
  },
  [STATE(25)] = {
    [sym__hll_expression] = STATE(1694),
    [sym_hll_call_expression] = STATE(1700),
    [sym_hll_field_expression] = STATE(1700),
    [sym_hll_subscript_expression] = STATE(1700),
    [sym_hll_cast_expression] = STATE(1694),
    [sym_hll_sizeof_expression] = STATE(1694),
    [sym_hll_pointer_expression] = STATE(1700),
    [sym_hll_update_expression] = STATE(1694),
    [sym_hll_unary_expression] = STATE(1694),
    [sym_hll_binary_expression] = STATE(1694),
    [sym_hll_assignment_expression] = STATE(1694),
    [sym__hll_assignment_left_expression] = STATE(2856),
    [sym_hll_conditional_expression] = STATE(1694),
    [sym_hll_char_literal] = STATE(1694),
    [sym_hll_string_literal] = STATE(1694),
    [sym_hll_parenthesized_expression] = STATE(1700),
    [sym_symbol] = STATE(1700),
    [sym_identifier] = ACTIONS(410),
    [anon_sym_LPAREN] = ACTIONS(412),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(414),
    [anon_sym_DASH] = ACTIONS(414),
    [anon_sym_TILDE] = ACTIONS(416),
    [anon_sym_BANG] = ACTIONS(414),
    [anon_sym_PLUS_PLUS] = ACTIONS(418),
    [anon_sym_DASH_DASH] = ACTIONS(418),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(420),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(422),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(424),
    [anon_sym_u_SQUOTE] = ACTIONS(424),
    [anon_sym_U_SQUOTE] = ACTIONS(424),
    [anon_sym_u8_SQUOTE] = ACTIONS(424),
    [anon_sym_SQUOTE] = ACTIONS(424),
    [anon_sym_L_DQUOTE] = ACTIONS(426),
    [anon_sym_u_DQUOTE] = ACTIONS(426),
    [anon_sym_U_DQUOTE] = ACTIONS(426),
    [anon_sym_u8_DQUOTE] = ACTIONS(426),
    [anon_sym_DQUOTE] = ACTIONS(426),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(438),
  },
  [STATE(26)] = {
    [sym__hll_expression] = STATE(1643),
    [sym_hll_call_expression] = STATE(1698),
    [sym_hll_field_expression] = STATE(1698),
    [sym_hll_subscript_expression] = STATE(1698),
    [sym_hll_cast_expression] = STATE(1643),
    [sym_hll_sizeof_expression] = STATE(1643),
    [sym_hll_pointer_expression] = STATE(1698),
    [sym_hll_update_expression] = STATE(1643),
    [sym_hll_unary_expression] = STATE(1643),
    [sym_hll_binary_expression] = STATE(1643),
    [sym_hll_assignment_expression] = STATE(1643),
    [sym__hll_assignment_left_expression] = STATE(2875),
    [sym_hll_conditional_expression] = STATE(1643),
    [sym_hll_char_literal] = STATE(1643),
    [sym_hll_string_literal] = STATE(1643),
    [sym_hll_parenthesized_expression] = STATE(1698),
    [sym_symbol] = STATE(1698),
    [sym_identifier] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_TILDE] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(448),
    [anon_sym_DASH_DASH] = ACTIONS(448),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(450),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(302),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(302),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(302),
    [anon_sym_GT_GT] = ACTIONS(302),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_STAR_EQ] = ACTIONS(298),
    [anon_sym_SLASH_EQ] = ACTIONS(298),
    [anon_sym_PERCENT_EQ] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(298),
    [anon_sym_DASH_EQ] = ACTIONS(298),
    [anon_sym_LT_LT_EQ] = ACTIONS(298),
    [anon_sym_GT_GT_EQ] = ACTIONS(298),
    [anon_sym_AMP_EQ] = ACTIONS(298),
    [anon_sym_CARET_EQ] = ACTIONS(298),
    [anon_sym_PIPE_EQ] = ACTIONS(298),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(298),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(298),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(468),
  },
  [STATE(27)] = {
    [sym__hll_expression] = STATE(1642),
    [sym_hll_call_expression] = STATE(1698),
    [sym_hll_field_expression] = STATE(1698),
    [sym_hll_subscript_expression] = STATE(1698),
    [sym_hll_cast_expression] = STATE(1642),
    [sym_hll_sizeof_expression] = STATE(1642),
    [sym_hll_pointer_expression] = STATE(1698),
    [sym_hll_update_expression] = STATE(1642),
    [sym_hll_unary_expression] = STATE(1642),
    [sym_hll_binary_expression] = STATE(1642),
    [sym_hll_assignment_expression] = STATE(1642),
    [sym__hll_assignment_left_expression] = STATE(2875),
    [sym_hll_conditional_expression] = STATE(1642),
    [sym_hll_char_literal] = STATE(1642),
    [sym_hll_string_literal] = STATE(1642),
    [sym_hll_parenthesized_expression] = STATE(1698),
    [sym_symbol] = STATE(1698),
    [sym_identifier] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_EQ] = ACTIONS(340),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_TILDE] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(448),
    [anon_sym_DASH_DASH] = ACTIONS(448),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(450),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(340),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(340),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(340),
    [anon_sym_GT_GT] = ACTIONS(340),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_STAR_EQ] = ACTIONS(338),
    [anon_sym_SLASH_EQ] = ACTIONS(338),
    [anon_sym_PERCENT_EQ] = ACTIONS(338),
    [anon_sym_PLUS_EQ] = ACTIONS(338),
    [anon_sym_DASH_EQ] = ACTIONS(338),
    [anon_sym_LT_LT_EQ] = ACTIONS(338),
    [anon_sym_GT_GT_EQ] = ACTIONS(338),
    [anon_sym_AMP_EQ] = ACTIONS(338),
    [anon_sym_CARET_EQ] = ACTIONS(338),
    [anon_sym_PIPE_EQ] = ACTIONS(338),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(338),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(468),
  },
  [STATE(28)] = {
    [sym__hll_expression] = STATE(1639),
    [sym_hll_call_expression] = STATE(1698),
    [sym_hll_field_expression] = STATE(1698),
    [sym_hll_subscript_expression] = STATE(1698),
    [sym_hll_cast_expression] = STATE(1639),
    [sym_hll_sizeof_expression] = STATE(1639),
    [sym_hll_pointer_expression] = STATE(1698),
    [sym_hll_update_expression] = STATE(1639),
    [sym_hll_unary_expression] = STATE(1639),
    [sym_hll_binary_expression] = STATE(1639),
    [sym_hll_assignment_expression] = STATE(1639),
    [sym__hll_assignment_left_expression] = STATE(2875),
    [sym_hll_conditional_expression] = STATE(1639),
    [sym_hll_char_literal] = STATE(1639),
    [sym_hll_string_literal] = STATE(1639),
    [sym_hll_parenthesized_expression] = STATE(1698),
    [sym_symbol] = STATE(1698),
    [sym_identifier] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_EQ] = ACTIONS(332),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_TILDE] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(448),
    [anon_sym_DASH_DASH] = ACTIONS(448),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(450),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(332),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(332),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(332),
    [anon_sym_GT_GT] = ACTIONS(332),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_STAR_EQ] = ACTIONS(330),
    [anon_sym_SLASH_EQ] = ACTIONS(330),
    [anon_sym_PERCENT_EQ] = ACTIONS(330),
    [anon_sym_PLUS_EQ] = ACTIONS(330),
    [anon_sym_DASH_EQ] = ACTIONS(330),
    [anon_sym_LT_LT_EQ] = ACTIONS(330),
    [anon_sym_GT_GT_EQ] = ACTIONS(330),
    [anon_sym_AMP_EQ] = ACTIONS(330),
    [anon_sym_CARET_EQ] = ACTIONS(330),
    [anon_sym_PIPE_EQ] = ACTIONS(330),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(330),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(468),
  },
  [STATE(29)] = {
    [sym__hll_expression] = STATE(1641),
    [sym_hll_call_expression] = STATE(1698),
    [sym_hll_field_expression] = STATE(1698),
    [sym_hll_subscript_expression] = STATE(1698),
    [sym_hll_cast_expression] = STATE(1641),
    [sym_hll_sizeof_expression] = STATE(1641),
    [sym_hll_pointer_expression] = STATE(1698),
    [sym_hll_update_expression] = STATE(1641),
    [sym_hll_unary_expression] = STATE(1641),
    [sym_hll_binary_expression] = STATE(1641),
    [sym_hll_assignment_expression] = STATE(1641),
    [sym__hll_assignment_left_expression] = STATE(2875),
    [sym_hll_conditional_expression] = STATE(1641),
    [sym_hll_char_literal] = STATE(1641),
    [sym_hll_string_literal] = STATE(1641),
    [sym_hll_parenthesized_expression] = STATE(1698),
    [sym_symbol] = STATE(1698),
    [sym_identifier] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(442),
    [anon_sym_EQ] = ACTIONS(336),
    [anon_sym_PLUS] = ACTIONS(444),
    [anon_sym_DASH] = ACTIONS(444),
    [anon_sym_TILDE] = ACTIONS(446),
    [anon_sym_BANG] = ACTIONS(444),
    [anon_sym_PLUS_PLUS] = ACTIONS(448),
    [anon_sym_DASH_DASH] = ACTIONS(448),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(450),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(336),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(336),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(336),
    [anon_sym_GT_GT] = ACTIONS(336),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(452),
    [anon_sym_STAR_EQ] = ACTIONS(334),
    [anon_sym_SLASH_EQ] = ACTIONS(334),
    [anon_sym_PERCENT_EQ] = ACTIONS(334),
    [anon_sym_PLUS_EQ] = ACTIONS(334),
    [anon_sym_DASH_EQ] = ACTIONS(334),
    [anon_sym_LT_LT_EQ] = ACTIONS(334),
    [anon_sym_GT_GT_EQ] = ACTIONS(334),
    [anon_sym_AMP_EQ] = ACTIONS(334),
    [anon_sym_CARET_EQ] = ACTIONS(334),
    [anon_sym_PIPE_EQ] = ACTIONS(334),
    [anon_sym_L_SQUOTE] = ACTIONS(454),
    [anon_sym_u_SQUOTE] = ACTIONS(454),
    [anon_sym_U_SQUOTE] = ACTIONS(454),
    [anon_sym_u8_SQUOTE] = ACTIONS(454),
    [anon_sym_SQUOTE] = ACTIONS(454),
    [anon_sym_L_DQUOTE] = ACTIONS(456),
    [anon_sym_u_DQUOTE] = ACTIONS(456),
    [anon_sym_U_DQUOTE] = ACTIONS(456),
    [anon_sym_u8_DQUOTE] = ACTIONS(456),
    [anon_sym_DQUOTE] = ACTIONS(456),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(334),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(468),
  },
  [STATE(30)] = {
    [sym__parenthesized_expression] = STATE(2347),
    [sym__path_expression] = STATE(2347),
    [sym_unary_expression] = STATE(2347),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2347),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2347),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym__command_arguments] = STATE(3992),
    [sym__command_argument] = STATE(3516),
    [sym_option_expression] = STATE(3518),
    [sym_format_expression] = STATE(3516),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2347),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2347),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2347),
    [sym_string] = STATE(2347),
    [sym_character] = STATE(2347),
    [sym_symbol] = STATE(2347),
    [sym__special_command_operator] = STATE(2347),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2347),
    [sym__expression] = STATE(2347),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [aux_sym__command_arguments_repeat1] = STATE(32),
    [aux_sym__command_arguments_repeat2] = STATE(3728),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(400),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(402),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(404),
    [sym_time] = ACTIONS(402),
    [sym_frequency] = ACTIONS(402),
    [sym_percentage] = ACTIONS(404),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(31)] = {
    [sym__parenthesized_expression] = STATE(2347),
    [sym__path_expression] = STATE(2347),
    [sym_unary_expression] = STATE(2347),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2347),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2347),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym__command_arguments] = STATE(3991),
    [sym__command_argument] = STATE(3516),
    [sym_option_expression] = STATE(3518),
    [sym_format_expression] = STATE(3516),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2347),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2347),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2347),
    [sym_string] = STATE(2347),
    [sym_character] = STATE(2347),
    [sym_symbol] = STATE(2347),
    [sym__special_command_operator] = STATE(2347),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2347),
    [sym__expression] = STATE(2347),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [aux_sym__command_arguments_repeat1] = STATE(32),
    [aux_sym__command_arguments_repeat2] = STATE(3728),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_SLASH] = ACTIONS(470),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(400),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(402),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(404),
    [sym_time] = ACTIONS(402),
    [sym_frequency] = ACTIONS(402),
    [sym_percentage] = ACTIONS(404),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(32)] = {
    [sym__parenthesized_expression] = STATE(2347),
    [sym__path_expression] = STATE(2347),
    [sym_unary_expression] = STATE(2347),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2347),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2347),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym__command_argument] = STATE(3463),
    [sym_format_expression] = STATE(3463),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2347),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2347),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2347),
    [sym_string] = STATE(2347),
    [sym_character] = STATE(2347),
    [sym_symbol] = STATE(2347),
    [sym__special_command_operator] = STATE(2347),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2347),
    [sym__expression] = STATE(2347),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [aux_sym__command_arguments_repeat1] = STATE(33),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_PERCENT] = ACTIONS(398),
    [anon_sym_AMP] = ACTIONS(166),
    [anon_sym_COMMA] = ACTIONS(474),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(402),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(404),
    [sym_time] = ACTIONS(402),
    [sym_frequency] = ACTIONS(402),
    [sym_percentage] = ACTIONS(404),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(33)] = {
    [sym__parenthesized_expression] = STATE(2587),
    [sym__path_expression] = STATE(2587),
    [sym_unary_expression] = STATE(2587),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2587),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2587),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym__command_argument] = STATE(3935),
    [sym_format_expression] = STATE(3935),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2587),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2587),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2587),
    [sym_string] = STATE(2587),
    [sym_character] = STATE(2587),
    [sym_symbol] = STATE(2587),
    [sym__special_command_operator] = STATE(2587),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2587),
    [sym__expression] = STATE(2587),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [aux_sym__command_arguments_repeat1] = STATE(33),
    [sym_identifier] = ACTIONS(476),
    [anon_sym_LPAREN] = ACTIONS(479),
    [anon_sym_LBRACE] = ACTIONS(482),
    [anon_sym_PLUS] = ACTIONS(485),
    [anon_sym_DASH] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(488),
    [anon_sym_BANG] = ACTIONS(488),
    [anon_sym_PLUS_PLUS] = ACTIONS(491),
    [anon_sym_DASH_DASH] = ACTIONS(491),
    [anon_sym_STAR] = ACTIONS(494),
    [anon_sym_PERCENT] = ACTIONS(497),
    [anon_sym_AMP] = ACTIONS(500),
    [anon_sym_COMMA] = ACTIONS(503),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(506),
    [anon_sym_SQUOTE] = ACTIONS(509),
    [anon_sym_DQUOTE] = ACTIONS(512),
    [sym_access_class] = ACTIONS(515),
    [aux_sym_integer_token1] = ACTIONS(518),
    [aux_sym_integer_token2] = ACTIONS(518),
    [sym_float] = ACTIONS(521),
    [aux_sym_bitmask_token1] = ACTIONS(524),
    [aux_sym_bitmask_token2] = ACTIONS(524),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(527),
    [aux_sym_symbol_token1] = ACTIONS(530),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(533),
    [anon_sym_BSLASH] = ACTIONS(536),
    [aux_sym_symbol_token5] = ACTIONS(539),
    [sym__composed_name] = ACTIONS(542),
    [sym_time] = ACTIONS(521),
    [sym_frequency] = ACTIONS(521),
    [sym_percentage] = ACTIONS(542),
    [anon_sym_POUND] = ACTIONS(545),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(548),
    [sym_path] = ACTIONS(551),
  },
  [STATE(34)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2708),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2708),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1987),
    [sym_macro_text_expansion] = STATE(2589),
    [sym__option_value] = STATE(4121),
    [sym__parenthesized_option_value] = STATE(4121),
    [sym_call_expression] = STATE(2589),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2708),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2708),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2708),
    [sym_string] = STATE(2708),
    [sym_character] = STATE(2708),
    [sym_symbol] = STATE(2708),
    [sym__special_command_operator] = STATE(2708),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2708),
    [sym__expression] = STATE(2652),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(554),
    [anon_sym_LPAREN] = ACTIONS(556),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(558),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(560),
    [sym_time] = ACTIONS(558),
    [sym_frequency] = ACTIONS(558),
    [sym_percentage] = ACTIONS(560),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(35)] = {
    [sym__parenthesized_expression] = STATE(2656),
    [sym__path_expression] = STATE(2656),
    [sym_unary_expression] = STATE(2678),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2678),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2656),
    [sym_macro] = STATE(1878),
    [sym_macro_text_expansion] = STATE(2260),
    [sym__option_value] = STATE(3867),
    [sym__parenthesized_option_value] = STATE(3867),
    [sym_call_expression] = STATE(2260),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2678),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2678),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2678),
    [sym_string] = STATE(2678),
    [sym_character] = STATE(2678),
    [sym_symbol] = STATE(2678),
    [sym__special_command_operator] = STATE(2678),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2678),
    [sym__expression] = STATE(2656),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(562),
    [anon_sym_LPAREN] = ACTIONS(564),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(566),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(568),
    [sym_time] = ACTIONS(566),
    [sym_frequency] = ACTIONS(566),
    [sym_percentage] = ACTIONS(568),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(36)] = {
    [sym__hll_option_value] = STATE(4137),
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1760),
    [sym_hll_field_expression] = STATE(1760),
    [sym_hll_subscript_expression] = STATE(1760),
    [sym_hll_cast_expression] = STATE(2490),
    [sym_hll_sizeof_expression] = STATE(2490),
    [sym_hll_pointer_expression] = STATE(1760),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2490),
    [sym_hll_unary_expression] = STATE(2490),
    [sym_hll_binary_expression] = STATE(2490),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2490),
    [sym_hll_char_literal] = STATE(2490),
    [sym_hll_string_literal] = STATE(2490),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3888),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1760),
    [aux_sym_block_repeat1] = STATE(91),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(600),
    [sym__hll_number_literal_pre_hook] = ACTIONS(602),
  },
  [STATE(37)] = {
    [sym__hll_option_value] = STATE(4137),
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1760),
    [sym_hll_field_expression] = STATE(1760),
    [sym_hll_subscript_expression] = STATE(1760),
    [sym_hll_cast_expression] = STATE(2490),
    [sym_hll_sizeof_expression] = STATE(2490),
    [sym_hll_pointer_expression] = STATE(1760),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2490),
    [sym_hll_unary_expression] = STATE(2490),
    [sym_hll_binary_expression] = STATE(2490),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2490),
    [sym_hll_char_literal] = STATE(2490),
    [sym_hll_string_literal] = STATE(2490),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3773),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1760),
    [aux_sym_block_repeat1] = STATE(89),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(604),
    [sym__hll_number_literal_pre_hook] = ACTIONS(602),
  },
  [STATE(38)] = {
    [sym__hll_option_value] = STATE(4160),
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1760),
    [sym_hll_field_expression] = STATE(1760),
    [sym_hll_subscript_expression] = STATE(1760),
    [sym_hll_cast_expression] = STATE(2490),
    [sym_hll_sizeof_expression] = STATE(2490),
    [sym_hll_pointer_expression] = STATE(1760),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2490),
    [sym_hll_unary_expression] = STATE(2490),
    [sym_hll_binary_expression] = STATE(2490),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2490),
    [sym_hll_char_literal] = STATE(2490),
    [sym_hll_string_literal] = STATE(2490),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3889),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1760),
    [aux_sym_block_repeat1] = STATE(67),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(570),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(606),
    [sym__hll_number_literal_pre_hook] = ACTIONS(602),
  },
  [STATE(39)] = {
    [sym__hll_expression] = STATE(2059),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2059),
    [sym_hll_sizeof_expression] = STATE(2059),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3718),
    [sym_hll_update_expression] = STATE(2059),
    [sym_hll_unary_expression] = STATE(2059),
    [sym_hll_binary_expression] = STATE(2059),
    [sym_hll_assignment_expression] = STATE(2059),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2059),
    [sym_hll_char_literal] = STATE(2059),
    [sym_hll_string_literal] = STATE(2059),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3755),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(40)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3929),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(41)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3822),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(42)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3888),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(41),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(616),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(43)] = {
    [sym__hll_expression] = STATE(2051),
    [sym_hll_call_expression] = STATE(1623),
    [sym_hll_field_expression] = STATE(1623),
    [sym_hll_subscript_expression] = STATE(1623),
    [sym_hll_cast_expression] = STATE(2051),
    [sym_hll_sizeof_expression] = STATE(2051),
    [sym_hll_pointer_expression] = STATE(1623),
    [sym_hll_update_expression] = STATE(2051),
    [sym_hll_unary_expression] = STATE(2051),
    [sym_hll_binary_expression] = STATE(2051),
    [sym_hll_assignment_expression] = STATE(2051),
    [sym__hll_assignment_left_expression] = STATE(2855),
    [sym_hll_conditional_expression] = STATE(2051),
    [sym_hll_char_literal] = STATE(2051),
    [sym_hll_string_literal] = STATE(2051),
    [sym_hll_parenthesized_expression] = STATE(1623),
    [sym_symbol] = STATE(1623),
    [sym_identifier] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(622),
    [anon_sym_DASH] = ACTIONS(622),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_BANG] = ACTIONS(622),
    [anon_sym_PLUS_PLUS] = ACTIONS(626),
    [anon_sym_DASH_DASH] = ACTIONS(626),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(628),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(630),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(332),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(44)] = {
    [sym__hll_expression] = STATE(1989),
    [sym_hll_call_expression] = STATE(1623),
    [sym_hll_field_expression] = STATE(1623),
    [sym_hll_subscript_expression] = STATE(1623),
    [sym_hll_cast_expression] = STATE(1989),
    [sym_hll_sizeof_expression] = STATE(1989),
    [sym_hll_pointer_expression] = STATE(1623),
    [sym_hll_update_expression] = STATE(1989),
    [sym_hll_unary_expression] = STATE(1989),
    [sym_hll_binary_expression] = STATE(1989),
    [sym_hll_assignment_expression] = STATE(1989),
    [sym__hll_assignment_left_expression] = STATE(2855),
    [sym_hll_conditional_expression] = STATE(1989),
    [sym_hll_char_literal] = STATE(1989),
    [sym_hll_string_literal] = STATE(1989),
    [sym_hll_parenthesized_expression] = STATE(1623),
    [sym_symbol] = STATE(1623),
    [sym_identifier] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(622),
    [anon_sym_DASH] = ACTIONS(622),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_BANG] = ACTIONS(622),
    [anon_sym_PLUS_PLUS] = ACTIONS(626),
    [anon_sym_DASH_DASH] = ACTIONS(626),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(628),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(630),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(336),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(45)] = {
    [sym__hll_expression] = STATE(1990),
    [sym_hll_call_expression] = STATE(1623),
    [sym_hll_field_expression] = STATE(1623),
    [sym_hll_subscript_expression] = STATE(1623),
    [sym_hll_cast_expression] = STATE(1990),
    [sym_hll_sizeof_expression] = STATE(1990),
    [sym_hll_pointer_expression] = STATE(1623),
    [sym_hll_update_expression] = STATE(1990),
    [sym_hll_unary_expression] = STATE(1990),
    [sym_hll_binary_expression] = STATE(1990),
    [sym_hll_assignment_expression] = STATE(1990),
    [sym__hll_assignment_left_expression] = STATE(2855),
    [sym_hll_conditional_expression] = STATE(1990),
    [sym_hll_char_literal] = STATE(1990),
    [sym_hll_string_literal] = STATE(1990),
    [sym_hll_parenthesized_expression] = STATE(1623),
    [sym_symbol] = STATE(1623),
    [sym_identifier] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(622),
    [anon_sym_DASH] = ACTIONS(622),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_BANG] = ACTIONS(622),
    [anon_sym_PLUS_PLUS] = ACTIONS(626),
    [anon_sym_DASH_DASH] = ACTIONS(626),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(628),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(630),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(340),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(46)] = {
    [sym__hll_expression] = STATE(1991),
    [sym_hll_call_expression] = STATE(1623),
    [sym_hll_field_expression] = STATE(1623),
    [sym_hll_subscript_expression] = STATE(1623),
    [sym_hll_cast_expression] = STATE(1991),
    [sym_hll_sizeof_expression] = STATE(1991),
    [sym_hll_pointer_expression] = STATE(1623),
    [sym_hll_update_expression] = STATE(1991),
    [sym_hll_unary_expression] = STATE(1991),
    [sym_hll_binary_expression] = STATE(1991),
    [sym_hll_assignment_expression] = STATE(1991),
    [sym__hll_assignment_left_expression] = STATE(2855),
    [sym_hll_conditional_expression] = STATE(1991),
    [sym_hll_char_literal] = STATE(1991),
    [sym_hll_string_literal] = STATE(1991),
    [sym_hll_parenthesized_expression] = STATE(1623),
    [sym_symbol] = STATE(1623),
    [sym_identifier] = ACTIONS(618),
    [anon_sym_LPAREN] = ACTIONS(620),
    [anon_sym_PLUS] = ACTIONS(622),
    [anon_sym_DASH] = ACTIONS(622),
    [anon_sym_TILDE] = ACTIONS(624),
    [anon_sym_BANG] = ACTIONS(622),
    [anon_sym_PLUS_PLUS] = ACTIONS(626),
    [anon_sym_DASH_DASH] = ACTIONS(626),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(628),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(376),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(630),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(298),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(302),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(384),
    [aux_sym_symbol_token1] = ACTIONS(386),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(388),
    [anon_sym_BSLASH] = ACTIONS(390),
    [aux_sym_symbol_token5] = ACTIONS(392),
    [sym_comment] = ACTIONS(298),
    [sym__blank_line] = ACTIONS(298),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(47)] = {
    [sym__hll_expression] = STATE(2023),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2023),
    [sym_hll_sizeof_expression] = STATE(2023),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_update_expression] = STATE(2023),
    [sym_hll_unary_expression] = STATE(2023),
    [sym_hll_binary_expression] = STATE(2023),
    [sym_hll_assignment_expression] = STATE(2023),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2023),
    [sym_hll_char_literal] = STATE(2023),
    [sym_hll_string_literal] = STATE(2023),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_symbol] = STATE(1581),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(574),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_DOT_DOT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_DOT] = ACTIONS(332),
    [anon_sym_COMMA] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(330),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(48)] = {
    [sym__hll_expression] = STATE(2037),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2037),
    [sym_hll_sizeof_expression] = STATE(2037),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_update_expression] = STATE(2037),
    [sym_hll_unary_expression] = STATE(2037),
    [sym_hll_binary_expression] = STATE(2037),
    [sym_hll_assignment_expression] = STATE(2037),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2037),
    [sym_hll_char_literal] = STATE(2037),
    [sym_hll_string_literal] = STATE(2037),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_symbol] = STATE(1581),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(574),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_DOT_DOT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_DOT] = ACTIONS(336),
    [anon_sym_COMMA] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(334),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(49)] = {
    [sym__hll_expression] = STATE(2039),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2039),
    [sym_hll_sizeof_expression] = STATE(2039),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_update_expression] = STATE(2039),
    [sym_hll_unary_expression] = STATE(2039),
    [sym_hll_binary_expression] = STATE(2039),
    [sym_hll_assignment_expression] = STATE(2039),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2039),
    [sym_hll_char_literal] = STATE(2039),
    [sym_hll_string_literal] = STATE(2039),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_symbol] = STATE(1581),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(574),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_DOT_DOT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_DOT] = ACTIONS(340),
    [anon_sym_COMMA] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(338),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(50)] = {
    [sym__hll_expression] = STATE(2047),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2047),
    [sym_hll_sizeof_expression] = STATE(2047),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_update_expression] = STATE(2047),
    [sym_hll_unary_expression] = STATE(2047),
    [sym_hll_binary_expression] = STATE(2047),
    [sym_hll_assignment_expression] = STATE(2047),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2047),
    [sym_hll_char_literal] = STATE(2047),
    [sym_hll_string_literal] = STATE(2047),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_symbol] = STATE(1581),
    [sym_identifier] = ACTIONS(638),
    [anon_sym_RPAREN] = ACTIONS(298),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(574),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_DOT_DOT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_DOT] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_RBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(298),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(51)] = {
    [sym__hll_expression] = STATE(2217),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2217),
    [sym_hll_sizeof_expression] = STATE(2217),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3911),
    [sym_hll_update_expression] = STATE(2217),
    [sym_hll_unary_expression] = STATE(2217),
    [sym_hll_binary_expression] = STATE(2217),
    [sym_hll_assignment_expression] = STATE(2217),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2217),
    [sym_hll_char_literal] = STATE(2217),
    [sym_hll_string_literal] = STATE(2217),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3724),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(39),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(640),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(52)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3877),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(53),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(642),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(53)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3918),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(54)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3717),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(55),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(644),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(55)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3721),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(56)] = {
    [sym__hll_expression] = STATE(2217),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2217),
    [sym_hll_sizeof_expression] = STATE(2217),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3911),
    [sym_hll_update_expression] = STATE(2217),
    [sym_hll_unary_expression] = STATE(2217),
    [sym_hll_binary_expression] = STATE(2217),
    [sym_hll_assignment_expression] = STATE(2217),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2217),
    [sym_hll_char_literal] = STATE(2217),
    [sym_hll_string_literal] = STATE(2217),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3912),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(57),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(646),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(57)] = {
    [sym__hll_expression] = STATE(2059),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2059),
    [sym_hll_sizeof_expression] = STATE(2059),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3718),
    [sym_hll_update_expression] = STATE(2059),
    [sym_hll_unary_expression] = STATE(2059),
    [sym_hll_binary_expression] = STATE(2059),
    [sym_hll_assignment_expression] = STATE(2059),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2059),
    [sym_hll_char_literal] = STATE(2059),
    [sym_hll_string_literal] = STATE(2059),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3723),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(58)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3842),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(59),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(648),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(59)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3870),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(60)] = {
    [sym__hll_expression] = STATE(2217),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2217),
    [sym_hll_sizeof_expression] = STATE(2217),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3911),
    [sym_hll_update_expression] = STATE(2217),
    [sym_hll_unary_expression] = STATE(2217),
    [sym_hll_binary_expression] = STATE(2217),
    [sym_hll_assignment_expression] = STATE(2217),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2217),
    [sym_hll_char_literal] = STATE(2217),
    [sym_hll_string_literal] = STATE(2217),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3733),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(61),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(650),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(61)] = {
    [sym__hll_expression] = STATE(2059),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2059),
    [sym_hll_sizeof_expression] = STATE(2059),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3718),
    [sym_hll_update_expression] = STATE(2059),
    [sym_hll_unary_expression] = STATE(2059),
    [sym_hll_binary_expression] = STATE(2059),
    [sym_hll_assignment_expression] = STATE(2059),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2059),
    [sym_hll_char_literal] = STATE(2059),
    [sym_hll_string_literal] = STATE(2059),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3738),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(62)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3850),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(92),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(652),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(63)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3863),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(40),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(654),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(64)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3745),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(65),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(656),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(65)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3749),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(66)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3889),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(67),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(606),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(67)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3873),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(68)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3778),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(69),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(658),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(69)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3781),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(70)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3900),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(71),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(660),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(71)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3906),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(72)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3762),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(73),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(662),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(73)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3766),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(74)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3789),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(75),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(664),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(75)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3841),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(76)] = {
    [sym__hll_expression] = STATE(2217),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2217),
    [sym_hll_sizeof_expression] = STATE(2217),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3911),
    [sym_hll_update_expression] = STATE(2217),
    [sym_hll_unary_expression] = STATE(2217),
    [sym_hll_binary_expression] = STATE(2217),
    [sym_hll_assignment_expression] = STATE(2217),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2217),
    [sym_hll_char_literal] = STATE(2217),
    [sym_hll_string_literal] = STATE(2217),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3956),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(77),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(666),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(77)] = {
    [sym__hll_expression] = STATE(2059),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2059),
    [sym_hll_sizeof_expression] = STATE(2059),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3718),
    [sym_hll_update_expression] = STATE(2059),
    [sym_hll_unary_expression] = STATE(2059),
    [sym_hll_binary_expression] = STATE(2059),
    [sym_hll_assignment_expression] = STATE(2059),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2059),
    [sym_hll_char_literal] = STATE(2059),
    [sym_hll_string_literal] = STATE(2059),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3732),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(78)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3840),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(79),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(668),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(79)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3848),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(80)] = {
    [sym__hll_expression] = STATE(2113),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2113),
    [sym_hll_sizeof_expression] = STATE(2113),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3887),
    [sym_hll_update_expression] = STATE(2113),
    [sym_hll_unary_expression] = STATE(2113),
    [sym_hll_binary_expression] = STATE(2113),
    [sym_hll_assignment_expression] = STATE(2113),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2113),
    [sym_hll_char_literal] = STATE(2113),
    [sym_hll_string_literal] = STATE(2113),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3894),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(81),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(670),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(81)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3899),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(82)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3953),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(83),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(672),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(83)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3716),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(84)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3739),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(85),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(674),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(85)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3744),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(86)] = {
    [sym__hll_expression] = STATE(2064),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2064),
    [sym_hll_sizeof_expression] = STATE(2064),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3775),
    [sym_hll_update_expression] = STATE(2064),
    [sym_hll_unary_expression] = STATE(2064),
    [sym_hll_binary_expression] = STATE(2064),
    [sym_hll_assignment_expression] = STATE(2064),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2064),
    [sym_hll_char_literal] = STATE(2064),
    [sym_hll_string_literal] = STATE(2064),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3758),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(87),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(676),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(87)] = {
    [sym__hll_expression] = STATE(2067),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2067),
    [sym_hll_sizeof_expression] = STATE(2067),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3839),
    [sym_hll_update_expression] = STATE(2067),
    [sym_hll_unary_expression] = STATE(2067),
    [sym_hll_binary_expression] = STATE(2067),
    [sym_hll_assignment_expression] = STATE(2067),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2067),
    [sym_hll_char_literal] = STATE(2067),
    [sym_hll_string_literal] = STATE(2067),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3761),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(88)] = {
    [sym__hll_expression] = STATE(2153),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2153),
    [sym_hll_sizeof_expression] = STATE(2153),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3750),
    [sym_hll_update_expression] = STATE(2153),
    [sym_hll_unary_expression] = STATE(2153),
    [sym_hll_binary_expression] = STATE(2153),
    [sym_hll_assignment_expression] = STATE(2153),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2153),
    [sym_hll_char_literal] = STATE(2153),
    [sym_hll_string_literal] = STATE(2153),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3773),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2797),
    [sym_hll_struct_specifier] = STATE(2797),
    [sym_hll_union_specifier] = STATE(2797),
    [sym_hll_enum_specifier] = STATE(2797),
    [sym_hll_sized_type_specifier] = STATE(2797),
    [sym__hll_type_identifier] = STATE(2797),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(90),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(598),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(678),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(89)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3777),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(90)] = {
    [sym__hll_expression] = STATE(2101),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2101),
    [sym_hll_sizeof_expression] = STATE(2101),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3821),
    [sym_hll_update_expression] = STATE(2101),
    [sym_hll_unary_expression] = STATE(2101),
    [sym_hll_binary_expression] = STATE(2101),
    [sym_hll_assignment_expression] = STATE(2101),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2101),
    [sym_hll_char_literal] = STATE(2101),
    [sym_hll_string_literal] = STATE(2101),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3777),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(91)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3822),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(92)] = {
    [sym__hll_expression] = STATE(2129),
    [sym_hll_call_expression] = STATE(1581),
    [sym_hll_field_expression] = STATE(1581),
    [sym_hll_subscript_expression] = STATE(1581),
    [sym_hll_cast_expression] = STATE(2129),
    [sym_hll_sizeof_expression] = STATE(2129),
    [sym_hll_pointer_expression] = STATE(1581),
    [sym_hll_comma_expression] = STATE(3871),
    [sym_hll_update_expression] = STATE(2129),
    [sym_hll_unary_expression] = STATE(2129),
    [sym_hll_binary_expression] = STATE(2129),
    [sym_hll_assignment_expression] = STATE(2129),
    [sym__hll_assignment_left_expression] = STATE(2864),
    [sym_hll_conditional_expression] = STATE(2129),
    [sym_hll_char_literal] = STATE(2129),
    [sym_hll_string_literal] = STATE(2129),
    [sym_hll_parenthesized_expression] = STATE(1581),
    [sym_hll_type_descriptor] = STATE(3856),
    [sym_hll_type_qualifier] = STATE(2713),
    [sym__hll_type_specifier] = STATE(2798),
    [sym_hll_struct_specifier] = STATE(2798),
    [sym_hll_union_specifier] = STATE(2798),
    [sym_hll_enum_specifier] = STATE(2798),
    [sym_hll_sized_type_specifier] = STATE(2798),
    [sym__hll_type_identifier] = STATE(2798),
    [sym_symbol] = STATE(1581),
    [aux_sym_block_repeat1] = STATE(822),
    [aux_sym_hll_type_descriptor_repeat1] = STATE(2713),
    [aux_sym_hll_sized_type_specifier_repeat1] = STATE(3308),
    [sym_identifier] = ACTIONS(608),
    [anon_sym_LPAREN] = ACTIONS(572),
    [anon_sym_PLUS] = ACTIONS(574),
    [anon_sym_DASH] = ACTIONS(574),
    [anon_sym_TILDE] = ACTIONS(576),
    [anon_sym_BANG] = ACTIONS(576),
    [anon_sym_PLUS_PLUS] = ACTIONS(578),
    [anon_sym_DASH_DASH] = ACTIONS(578),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_AMP] = ACTIONS(580),
    [anon_sym_sizeof] = ACTIONS(582),
    [anon_sym_L_SQUOTE] = ACTIONS(584),
    [anon_sym_u_SQUOTE] = ACTIONS(584),
    [anon_sym_U_SQUOTE] = ACTIONS(584),
    [anon_sym_u8_SQUOTE] = ACTIONS(584),
    [anon_sym_SQUOTE] = ACTIONS(584),
    [anon_sym_L_DQUOTE] = ACTIONS(586),
    [anon_sym_u_DQUOTE] = ACTIONS(586),
    [anon_sym_U_DQUOTE] = ACTIONS(586),
    [anon_sym_u8_DQUOTE] = ACTIONS(586),
    [anon_sym_DQUOTE] = ACTIONS(586),
    [anon_sym_const] = ACTIONS(588),
    [anon_sym_volatile] = ACTIONS(588),
    [anon_sym_struct] = ACTIONS(590),
    [anon_sym_union] = ACTIONS(592),
    [anon_sym_enum] = ACTIONS(594),
    [anon_sym_signed] = ACTIONS(596),
    [anon_sym_unsigned] = ACTIONS(596),
    [anon_sym_long] = ACTIONS(596),
    [anon_sym_short] = ACTIONS(596),
    [sym_hll_primitive_type] = ACTIONS(610),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(612),
    [sym__hll_number_literal_pre_hook] = ACTIONS(614),
  },
  [STATE(93)] = {
    [sym__parenthesized_expression] = STATE(2520),
    [sym__path_expression] = STATE(2520),
    [sym_unary_expression] = STATE(2520),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2520),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2520),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2520),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2520),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2520),
    [sym_string] = STATE(2520),
    [sym_character] = STATE(2520),
    [sym_symbol] = STATE(2520),
    [sym__special_command_operator] = STATE(2520),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2520),
    [sym__expression] = STATE(2520),
    [aux_sym_block_repeat1] = STATE(115),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(680),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(682),
    [sym_time] = ACTIONS(680),
    [sym_frequency] = ACTIONS(680),
    [sym_percentage] = ACTIONS(682),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(684),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(94)] = {
    [sym__parenthesized_expression] = STATE(2513),
    [sym__path_expression] = STATE(2513),
    [sym_unary_expression] = STATE(2513),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2513),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2513),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2513),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2513),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2513),
    [sym_string] = STATE(2513),
    [sym_character] = STATE(2513),
    [sym_symbol] = STATE(2513),
    [sym__special_command_operator] = STATE(2513),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2513),
    [sym__expression] = STATE(2513),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(686),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(688),
    [sym_time] = ACTIONS(686),
    [sym_frequency] = ACTIONS(686),
    [sym_percentage] = ACTIONS(688),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(95)] = {
    [sym__parenthesized_expression] = STATE(2462),
    [sym__path_expression] = STATE(2462),
    [sym_unary_expression] = STATE(2462),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2462),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2462),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2462),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2462),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2462),
    [sym_string] = STATE(2462),
    [sym_character] = STATE(2462),
    [sym_symbol] = STATE(2462),
    [sym__special_command_operator] = STATE(2462),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2462),
    [sym__expression] = STATE(2462),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(690),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(692),
    [sym_time] = ACTIONS(690),
    [sym_frequency] = ACTIONS(690),
    [sym_percentage] = ACTIONS(692),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(96)] = {
    [sym__parenthesized_expression] = STATE(2465),
    [sym__path_expression] = STATE(2465),
    [sym_unary_expression] = STATE(2465),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2465),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2465),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2465),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2465),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2465),
    [sym_string] = STATE(2465),
    [sym_character] = STATE(2465),
    [sym_symbol] = STATE(2465),
    [sym__special_command_operator] = STATE(2465),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2465),
    [sym__expression] = STATE(2465),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(694),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(696),
    [sym_time] = ACTIONS(694),
    [sym_frequency] = ACTIONS(694),
    [sym_percentage] = ACTIONS(696),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(97)] = {
    [sym__parenthesized_expression] = STATE(10),
    [sym__path_expression] = STATE(10),
    [sym_unary_expression] = STATE(10),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(10),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(10),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(10),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(10),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(10),
    [sym_string] = STATE(10),
    [sym_character] = STATE(10),
    [sym_symbol] = STATE(10),
    [sym__special_command_operator] = STATE(10),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(10),
    [sym__expression] = STATE(10),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(10),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(700),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(702),
    [sym_time] = ACTIONS(700),
    [sym_frequency] = ACTIONS(700),
    [sym_percentage] = ACTIONS(702),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(702),
  },
  [STATE(98)] = {
    [sym__parenthesized_expression] = STATE(702),
    [sym__path_expression] = STATE(702),
    [sym_unary_expression] = STATE(702),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(702),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(702),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(702),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(702),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(702),
    [sym_string] = STATE(702),
    [sym_character] = STATE(702),
    [sym_symbol] = STATE(702),
    [sym__special_command_operator] = STATE(702),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(702),
    [sym__expression] = STATE(702),
    [aux_sym_block_repeat1] = STATE(100),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(702),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(704),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(706),
    [sym_time] = ACTIONS(704),
    [sym_frequency] = ACTIONS(704),
    [sym_percentage] = ACTIONS(706),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(708),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(706),
  },
  [STATE(99)] = {
    [sym__parenthesized_expression] = STATE(15),
    [sym__path_expression] = STATE(15),
    [sym_unary_expression] = STATE(15),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(15),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(15),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(15),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(15),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(15),
    [sym_string] = STATE(15),
    [sym_character] = STATE(15),
    [sym_symbol] = STATE(15),
    [sym__special_command_operator] = STATE(15),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(15),
    [sym__expression] = STATE(15),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(15),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(710),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(712),
    [sym_time] = ACTIONS(710),
    [sym_frequency] = ACTIONS(710),
    [sym_percentage] = ACTIONS(712),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(712),
  },
  [STATE(100)] = {
    [sym__parenthesized_expression] = STATE(727),
    [sym__path_expression] = STATE(727),
    [sym_unary_expression] = STATE(727),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(727),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(727),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(727),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(727),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(727),
    [sym_string] = STATE(727),
    [sym_character] = STATE(727),
    [sym_symbol] = STATE(727),
    [sym__special_command_operator] = STATE(727),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(727),
    [sym__expression] = STATE(727),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(727),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(714),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(716),
    [sym_time] = ACTIONS(714),
    [sym_frequency] = ACTIONS(714),
    [sym_percentage] = ACTIONS(716),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(716),
  },
  [STATE(101)] = {
    [sym__parenthesized_expression] = STATE(728),
    [sym__path_expression] = STATE(728),
    [sym_unary_expression] = STATE(728),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(728),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(728),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(728),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(728),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(728),
    [sym_string] = STATE(728),
    [sym_character] = STATE(728),
    [sym_symbol] = STATE(728),
    [sym__special_command_operator] = STATE(728),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(728),
    [sym__expression] = STATE(728),
    [aux_sym_block_repeat1] = STATE(103),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(728),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(718),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(720),
    [sym_time] = ACTIONS(718),
    [sym_frequency] = ACTIONS(718),
    [sym_percentage] = ACTIONS(720),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(722),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(720),
  },
  [STATE(102)] = {
    [sym__parenthesized_expression] = STATE(2344),
    [sym__path_expression] = STATE(2344),
    [sym_unary_expression] = STATE(2344),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2344),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2344),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2344),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2344),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2344),
    [sym_string] = STATE(2344),
    [sym_character] = STATE(2344),
    [sym_symbol] = STATE(2344),
    [sym__special_command_operator] = STATE(2344),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2344),
    [sym__expression] = STATE(2344),
    [aux_sym_block_repeat1] = STATE(107),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(724),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(726),
    [sym_time] = ACTIONS(724),
    [sym_frequency] = ACTIONS(724),
    [sym_percentage] = ACTIONS(726),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(728),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(103)] = {
    [sym__parenthesized_expression] = STATE(729),
    [sym__path_expression] = STATE(729),
    [sym_unary_expression] = STATE(729),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(729),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(729),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(729),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(729),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(729),
    [sym_string] = STATE(729),
    [sym_character] = STATE(729),
    [sym_symbol] = STATE(729),
    [sym__special_command_operator] = STATE(729),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(729),
    [sym__expression] = STATE(729),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(729),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(730),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(732),
    [sym_time] = ACTIONS(730),
    [sym_frequency] = ACTIONS(730),
    [sym_percentage] = ACTIONS(732),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(732),
  },
  [STATE(104)] = {
    [sym__parenthesized_expression] = STATE(2480),
    [sym__path_expression] = STATE(2480),
    [sym_unary_expression] = STATE(2480),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2480),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2480),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2480),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2480),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2480),
    [sym_string] = STATE(2480),
    [sym_character] = STATE(2480),
    [sym_symbol] = STATE(2480),
    [sym__special_command_operator] = STATE(2480),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2480),
    [sym__expression] = STATE(2480),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(734),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(736),
    [sym_time] = ACTIONS(734),
    [sym_frequency] = ACTIONS(734),
    [sym_percentage] = ACTIONS(736),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(105)] = {
    [sym__parenthesized_expression] = STATE(2497),
    [sym__path_expression] = STATE(2497),
    [sym_unary_expression] = STATE(2497),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2497),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2497),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2497),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2497),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2497),
    [sym_string] = STATE(2497),
    [sym_character] = STATE(2497),
    [sym_symbol] = STATE(2497),
    [sym__special_command_operator] = STATE(2497),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2497),
    [sym__expression] = STATE(2497),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(738),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(740),
    [sym_time] = ACTIONS(738),
    [sym_frequency] = ACTIONS(738),
    [sym_percentage] = ACTIONS(740),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(106)] = {
    [sym__parenthesized_expression] = STATE(2294),
    [sym__path_expression] = STATE(2294),
    [sym_unary_expression] = STATE(2294),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2294),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2294),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2294),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2294),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2294),
    [sym_string] = STATE(2294),
    [sym_character] = STATE(2294),
    [sym_symbol] = STATE(2294),
    [sym__special_command_operator] = STATE(2294),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2294),
    [sym__expression] = STATE(2294),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(742),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(744),
    [sym_time] = ACTIONS(742),
    [sym_frequency] = ACTIONS(742),
    [sym_percentage] = ACTIONS(744),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(107)] = {
    [sym__parenthesized_expression] = STATE(2351),
    [sym__path_expression] = STATE(2351),
    [sym_unary_expression] = STATE(2351),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2351),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2351),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2351),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2351),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2351),
    [sym_string] = STATE(2351),
    [sym_character] = STATE(2351),
    [sym_symbol] = STATE(2351),
    [sym__special_command_operator] = STATE(2351),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2351),
    [sym__expression] = STATE(2351),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(746),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(748),
    [sym_time] = ACTIONS(746),
    [sym_frequency] = ACTIONS(746),
    [sym_percentage] = ACTIONS(748),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(108)] = {
    [sym__parenthesized_expression] = STATE(2468),
    [sym__path_expression] = STATE(2468),
    [sym_unary_expression] = STATE(2468),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2468),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2468),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2468),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2468),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2468),
    [sym_string] = STATE(2468),
    [sym_character] = STATE(2468),
    [sym_symbol] = STATE(2468),
    [sym__special_command_operator] = STATE(2468),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2468),
    [sym__expression] = STATE(2468),
    [aux_sym_block_repeat1] = STATE(110),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(750),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(752),
    [sym_time] = ACTIONS(750),
    [sym_frequency] = ACTIONS(750),
    [sym_percentage] = ACTIONS(752),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(754),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(109)] = {
    [sym__parenthesized_expression] = STATE(2307),
    [sym__path_expression] = STATE(2307),
    [sym_unary_expression] = STATE(2307),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2307),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2307),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2307),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2307),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2307),
    [sym_string] = STATE(2307),
    [sym_character] = STATE(2307),
    [sym_symbol] = STATE(2307),
    [sym__special_command_operator] = STATE(2307),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2307),
    [sym__expression] = STATE(2307),
    [aux_sym_block_repeat1] = STATE(111),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(756),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(758),
    [sym_time] = ACTIONS(756),
    [sym_frequency] = ACTIONS(756),
    [sym_percentage] = ACTIONS(758),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(760),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(110)] = {
    [sym__parenthesized_expression] = STATE(2456),
    [sym__path_expression] = STATE(2456),
    [sym_unary_expression] = STATE(2456),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2456),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2456),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2456),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2456),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2456),
    [sym_string] = STATE(2456),
    [sym_character] = STATE(2456),
    [sym_symbol] = STATE(2456),
    [sym__special_command_operator] = STATE(2456),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2456),
    [sym__expression] = STATE(2456),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(762),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(764),
    [sym_time] = ACTIONS(762),
    [sym_frequency] = ACTIONS(762),
    [sym_percentage] = ACTIONS(764),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(111)] = {
    [sym__parenthesized_expression] = STATE(2313),
    [sym__path_expression] = STATE(2313),
    [sym_unary_expression] = STATE(2313),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2313),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2313),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2313),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2313),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2313),
    [sym_string] = STATE(2313),
    [sym_character] = STATE(2313),
    [sym_symbol] = STATE(2313),
    [sym__special_command_operator] = STATE(2313),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2313),
    [sym__expression] = STATE(2313),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(766),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(768),
    [sym_time] = ACTIONS(766),
    [sym_frequency] = ACTIONS(766),
    [sym_percentage] = ACTIONS(768),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(112)] = {
    [sym__parenthesized_expression] = STATE(2316),
    [sym__path_expression] = STATE(2316),
    [sym_unary_expression] = STATE(2316),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2316),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2316),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2316),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2316),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2316),
    [sym_string] = STATE(2316),
    [sym_character] = STATE(2316),
    [sym_symbol] = STATE(2316),
    [sym__special_command_operator] = STATE(2316),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2316),
    [sym__expression] = STATE(2316),
    [aux_sym_block_repeat1] = STATE(113),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(770),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(772),
    [sym_time] = ACTIONS(770),
    [sym_frequency] = ACTIONS(770),
    [sym_percentage] = ACTIONS(772),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(774),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(113)] = {
    [sym__parenthesized_expression] = STATE(2303),
    [sym__path_expression] = STATE(2303),
    [sym_unary_expression] = STATE(2303),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2303),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2303),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2303),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2303),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2303),
    [sym_string] = STATE(2303),
    [sym_character] = STATE(2303),
    [sym_symbol] = STATE(2303),
    [sym__special_command_operator] = STATE(2303),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2303),
    [sym__expression] = STATE(2303),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(776),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(778),
    [sym_time] = ACTIONS(776),
    [sym_frequency] = ACTIONS(776),
    [sym_percentage] = ACTIONS(778),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(114)] = {
    [sym__parenthesized_expression] = STATE(2433),
    [sym__path_expression] = STATE(2433),
    [sym_unary_expression] = STATE(2433),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2433),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2433),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2433),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2433),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2433),
    [sym_string] = STATE(2433),
    [sym_character] = STATE(2433),
    [sym_symbol] = STATE(2433),
    [sym__special_command_operator] = STATE(2433),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2433),
    [sym__expression] = STATE(2433),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(780),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(782),
    [sym_time] = ACTIONS(780),
    [sym_frequency] = ACTIONS(780),
    [sym_percentage] = ACTIONS(782),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(115)] = {
    [sym__parenthesized_expression] = STATE(2452),
    [sym__path_expression] = STATE(2452),
    [sym_unary_expression] = STATE(2452),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2452),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2452),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2452),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2452),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2452),
    [sym_string] = STATE(2452),
    [sym_character] = STATE(2452),
    [sym_symbol] = STATE(2452),
    [sym__special_command_operator] = STATE(2452),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2452),
    [sym__expression] = STATE(2452),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(784),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(786),
    [sym_time] = ACTIONS(784),
    [sym_frequency] = ACTIONS(784),
    [sym_percentage] = ACTIONS(786),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(116)] = {
    [sym__parenthesized_expression] = STATE(2457),
    [sym__path_expression] = STATE(2457),
    [sym_unary_expression] = STATE(2457),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2457),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2457),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2457),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2457),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2457),
    [sym_string] = STATE(2457),
    [sym_character] = STATE(2457),
    [sym_symbol] = STATE(2457),
    [sym__special_command_operator] = STATE(2457),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2457),
    [sym__expression] = STATE(2457),
    [aux_sym_block_repeat1] = STATE(104),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(788),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(790),
    [sym_time] = ACTIONS(788),
    [sym_frequency] = ACTIONS(788),
    [sym_percentage] = ACTIONS(790),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(792),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(117)] = {
    [sym__parenthesized_expression] = STATE(2458),
    [sym__path_expression] = STATE(2458),
    [sym_unary_expression] = STATE(2458),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2458),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2458),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2458),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2458),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2458),
    [sym_string] = STATE(2458),
    [sym_character] = STATE(2458),
    [sym_symbol] = STATE(2458),
    [sym__special_command_operator] = STATE(2458),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2458),
    [sym__expression] = STATE(2458),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(794),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(796),
    [sym_time] = ACTIONS(794),
    [sym_frequency] = ACTIONS(794),
    [sym_percentage] = ACTIONS(796),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(118)] = {
    [sym__parenthesized_expression] = STATE(2406),
    [sym__path_expression] = STATE(2406),
    [sym_unary_expression] = STATE(2406),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2406),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2406),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2406),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2406),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2406),
    [sym_string] = STATE(2406),
    [sym_character] = STATE(2406),
    [sym_symbol] = STATE(2406),
    [sym__special_command_operator] = STATE(2406),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2406),
    [sym__expression] = STATE(2406),
    [aux_sym_block_repeat1] = STATE(106),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(798),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(800),
    [sym_time] = ACTIONS(798),
    [sym_frequency] = ACTIONS(798),
    [sym_percentage] = ACTIONS(800),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(802),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(119)] = {
    [sym__parenthesized_expression] = STATE(2460),
    [sym__path_expression] = STATE(2460),
    [sym_unary_expression] = STATE(2460),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2460),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2460),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2460),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2460),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2460),
    [sym_string] = STATE(2460),
    [sym_character] = STATE(2460),
    [sym_symbol] = STATE(2460),
    [sym__special_command_operator] = STATE(2460),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2460),
    [sym__expression] = STATE(2460),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(804),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(806),
    [sym_time] = ACTIONS(804),
    [sym_frequency] = ACTIONS(804),
    [sym_percentage] = ACTIONS(806),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(120)] = {
    [sym__parenthesized_expression] = STATE(2524),
    [sym__path_expression] = STATE(2524),
    [sym_unary_expression] = STATE(2524),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2524),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2524),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2524),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2524),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2524),
    [sym_string] = STATE(2524),
    [sym_character] = STATE(2524),
    [sym_symbol] = STATE(2524),
    [sym__special_command_operator] = STATE(2524),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2524),
    [sym__expression] = STATE(2524),
    [aux_sym_block_repeat1] = STATE(121),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(808),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(810),
    [sym_time] = ACTIONS(808),
    [sym_frequency] = ACTIONS(808),
    [sym_percentage] = ACTIONS(810),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(812),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(121)] = {
    [sym__parenthesized_expression] = STATE(2535),
    [sym__path_expression] = STATE(2535),
    [sym_unary_expression] = STATE(2535),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2535),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2535),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2535),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2535),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2535),
    [sym_string] = STATE(2535),
    [sym_character] = STATE(2535),
    [sym_symbol] = STATE(2535),
    [sym__special_command_operator] = STATE(2535),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2535),
    [sym__expression] = STATE(2535),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(814),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(816),
    [sym_time] = ACTIONS(814),
    [sym_frequency] = ACTIONS(814),
    [sym_percentage] = ACTIONS(816),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(122)] = {
    [sym__parenthesized_expression] = STATE(2536),
    [sym__path_expression] = STATE(2536),
    [sym_unary_expression] = STATE(2536),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2536),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2536),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2536),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2536),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2536),
    [sym_string] = STATE(2536),
    [sym_character] = STATE(2536),
    [sym_symbol] = STATE(2536),
    [sym__special_command_operator] = STATE(2536),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2536),
    [sym__expression] = STATE(2536),
    [aux_sym_block_repeat1] = STATE(123),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(818),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(820),
    [sym_time] = ACTIONS(818),
    [sym_frequency] = ACTIONS(818),
    [sym_percentage] = ACTIONS(820),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(822),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(123)] = {
    [sym__parenthesized_expression] = STATE(2539),
    [sym__path_expression] = STATE(2539),
    [sym_unary_expression] = STATE(2539),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2539),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2539),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2539),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2539),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2539),
    [sym_string] = STATE(2539),
    [sym_character] = STATE(2539),
    [sym_symbol] = STATE(2539),
    [sym__special_command_operator] = STATE(2539),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2539),
    [sym__expression] = STATE(2539),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(824),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(826),
    [sym_time] = ACTIONS(824),
    [sym_frequency] = ACTIONS(824),
    [sym_percentage] = ACTIONS(826),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(124)] = {
    [sym__parenthesized_expression] = STATE(2495),
    [sym__path_expression] = STATE(2495),
    [sym_unary_expression] = STATE(2495),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2495),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2495),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2495),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2495),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2495),
    [sym_string] = STATE(2495),
    [sym_character] = STATE(2495),
    [sym_symbol] = STATE(2495),
    [sym__special_command_operator] = STATE(2495),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2495),
    [sym__expression] = STATE(2495),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(828),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(830),
    [sym_time] = ACTIONS(828),
    [sym_frequency] = ACTIONS(828),
    [sym_percentage] = ACTIONS(830),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(125)] = {
    [sym__parenthesized_expression] = STATE(2496),
    [sym__path_expression] = STATE(2496),
    [sym_unary_expression] = STATE(2496),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2496),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2496),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2496),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2496),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2496),
    [sym_string] = STATE(2496),
    [sym_character] = STATE(2496),
    [sym_symbol] = STATE(2496),
    [sym__special_command_operator] = STATE(2496),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2496),
    [sym__expression] = STATE(2496),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(832),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(834),
    [sym_time] = ACTIONS(832),
    [sym_frequency] = ACTIONS(832),
    [sym_percentage] = ACTIONS(834),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(126)] = {
    [sym__parenthesized_expression] = STATE(2505),
    [sym__path_expression] = STATE(2505),
    [sym_unary_expression] = STATE(2505),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2505),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2505),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2505),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2505),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2505),
    [sym_string] = STATE(2505),
    [sym_character] = STATE(2505),
    [sym_symbol] = STATE(2505),
    [sym__special_command_operator] = STATE(2505),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2505),
    [sym__expression] = STATE(2505),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(836),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(838),
    [sym_time] = ACTIONS(836),
    [sym_frequency] = ACTIONS(836),
    [sym_percentage] = ACTIONS(838),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(127)] = {
    [sym__parenthesized_expression] = STATE(2508),
    [sym__path_expression] = STATE(2508),
    [sym_unary_expression] = STATE(2508),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2508),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2508),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2508),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2508),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2508),
    [sym_string] = STATE(2508),
    [sym_character] = STATE(2508),
    [sym_symbol] = STATE(2508),
    [sym__special_command_operator] = STATE(2508),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2508),
    [sym__expression] = STATE(2508),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(840),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(842),
    [sym_time] = ACTIONS(840),
    [sym_frequency] = ACTIONS(840),
    [sym_percentage] = ACTIONS(842),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(128)] = {
    [sym__parenthesized_expression] = STATE(2510),
    [sym__path_expression] = STATE(2510),
    [sym_unary_expression] = STATE(2510),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2510),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2510),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2510),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2510),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2510),
    [sym_string] = STATE(2510),
    [sym_character] = STATE(2510),
    [sym_symbol] = STATE(2510),
    [sym__special_command_operator] = STATE(2510),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2510),
    [sym__expression] = STATE(2510),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(844),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(846),
    [sym_time] = ACTIONS(844),
    [sym_frequency] = ACTIONS(844),
    [sym_percentage] = ACTIONS(846),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(129)] = {
    [sym__parenthesized_expression] = STATE(2451),
    [sym__path_expression] = STATE(2451),
    [sym_unary_expression] = STATE(2451),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2451),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2451),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2451),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2451),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2451),
    [sym_string] = STATE(2451),
    [sym_character] = STATE(2451),
    [sym_symbol] = STATE(2451),
    [sym__special_command_operator] = STATE(2451),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2451),
    [sym__expression] = STATE(2451),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(848),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(850),
    [sym_time] = ACTIONS(848),
    [sym_frequency] = ACTIONS(848),
    [sym_percentage] = ACTIONS(850),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(130)] = {
    [sym__parenthesized_expression] = STATE(16),
    [sym__path_expression] = STATE(16),
    [sym_unary_expression] = STATE(16),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(16),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(16),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(16),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(16),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(16),
    [sym_string] = STATE(16),
    [sym_character] = STATE(16),
    [sym_symbol] = STATE(16),
    [sym__special_command_operator] = STATE(16),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(16),
    [sym__expression] = STATE(16),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(16),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(852),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(854),
    [sym_time] = ACTIONS(852),
    [sym_frequency] = ACTIONS(852),
    [sym_percentage] = ACTIONS(854),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(854),
  },
  [STATE(131)] = {
    [sym__parenthesized_expression] = STATE(9),
    [sym__path_expression] = STATE(9),
    [sym_unary_expression] = STATE(9),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(9),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(9),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(9),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(9),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(9),
    [sym_string] = STATE(9),
    [sym_character] = STATE(9),
    [sym_symbol] = STATE(9),
    [sym__special_command_operator] = STATE(9),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(9),
    [sym__expression] = STATE(9),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(9),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(856),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(858),
    [sym_time] = ACTIONS(856),
    [sym_frequency] = ACTIONS(856),
    [sym_percentage] = ACTIONS(858),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(858),
  },
  [STATE(132)] = {
    [sym__parenthesized_expression] = STATE(2518),
    [sym__path_expression] = STATE(2518),
    [sym_unary_expression] = STATE(2518),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2518),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2518),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2518),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2518),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2518),
    [sym_string] = STATE(2518),
    [sym_character] = STATE(2518),
    [sym_symbol] = STATE(2518),
    [sym__special_command_operator] = STATE(2518),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2518),
    [sym__expression] = STATE(2518),
    [aux_sym_block_repeat1] = STATE(1787),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(860),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(862),
    [sym_time] = ACTIONS(860),
    [sym_frequency] = ACTIONS(860),
    [sym_percentage] = ACTIONS(862),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(472),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(133)] = {
    [sym__parenthesized_expression] = STATE(2452),
    [sym__path_expression] = STATE(2452),
    [sym_unary_expression] = STATE(2452),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2452),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2452),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2452),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2452),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2452),
    [sym_string] = STATE(2452),
    [sym_character] = STATE(2452),
    [sym_symbol] = STATE(2452),
    [sym__special_command_operator] = STATE(2452),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2452),
    [sym__expression] = STATE(2452),
    [aux_sym_block_repeat1] = STATE(95),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(784),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(786),
    [sym_time] = ACTIONS(784),
    [sym_frequency] = ACTIONS(784),
    [sym_percentage] = ACTIONS(786),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(864),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(134)] = {
    [sym__hll_expression] = STATE(2357),
    [sym_hll_call_expression] = STATE(1775),
    [sym_hll_field_expression] = STATE(1775),
    [sym_hll_subscript_expression] = STATE(1775),
    [sym_hll_cast_expression] = STATE(2357),
    [sym_hll_sizeof_expression] = STATE(2357),
    [sym_hll_pointer_expression] = STATE(1775),
    [sym_hll_update_expression] = STATE(2357),
    [sym_hll_unary_expression] = STATE(2357),
    [sym_hll_binary_expression] = STATE(2357),
    [sym_hll_assignment_expression] = STATE(2357),
    [sym__hll_assignment_left_expression] = STATE(2841),
    [sym_hll_conditional_expression] = STATE(2357),
    [sym_hll_char_literal] = STATE(2357),
    [sym_hll_string_literal] = STATE(2357),
    [sym_hll_parenthesized_expression] = STATE(1775),
    [sym_symbol] = STATE(1775),
    [sym_identifier] = ACTIONS(866),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_PLUS] = ACTIONS(870),
    [anon_sym_DASH] = ACTIONS(870),
    [anon_sym_TILDE] = ACTIONS(872),
    [anon_sym_BANG] = ACTIONS(870),
    [anon_sym_PLUS_PLUS] = ACTIONS(874),
    [anon_sym_DASH_DASH] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(878),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(334),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(135)] = {
    [sym__hll_expression] = STATE(2358),
    [sym_hll_call_expression] = STATE(1775),
    [sym_hll_field_expression] = STATE(1775),
    [sym_hll_subscript_expression] = STATE(1775),
    [sym_hll_cast_expression] = STATE(2358),
    [sym_hll_sizeof_expression] = STATE(2358),
    [sym_hll_pointer_expression] = STATE(1775),
    [sym_hll_update_expression] = STATE(2358),
    [sym_hll_unary_expression] = STATE(2358),
    [sym_hll_binary_expression] = STATE(2358),
    [sym_hll_assignment_expression] = STATE(2358),
    [sym__hll_assignment_left_expression] = STATE(2841),
    [sym_hll_conditional_expression] = STATE(2358),
    [sym_hll_char_literal] = STATE(2358),
    [sym_hll_string_literal] = STATE(2358),
    [sym_hll_parenthesized_expression] = STATE(1775),
    [sym_symbol] = STATE(1775),
    [sym_identifier] = ACTIONS(866),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_PLUS] = ACTIONS(870),
    [anon_sym_DASH] = ACTIONS(870),
    [anon_sym_TILDE] = ACTIONS(872),
    [anon_sym_BANG] = ACTIONS(870),
    [anon_sym_PLUS_PLUS] = ACTIONS(874),
    [anon_sym_DASH_DASH] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(878),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(338),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(136)] = {
    [sym__hll_expression] = STATE(2382),
    [sym_hll_call_expression] = STATE(1775),
    [sym_hll_field_expression] = STATE(1775),
    [sym_hll_subscript_expression] = STATE(1775),
    [sym_hll_cast_expression] = STATE(2382),
    [sym_hll_sizeof_expression] = STATE(2382),
    [sym_hll_pointer_expression] = STATE(1775),
    [sym_hll_update_expression] = STATE(2382),
    [sym_hll_unary_expression] = STATE(2382),
    [sym_hll_binary_expression] = STATE(2382),
    [sym_hll_assignment_expression] = STATE(2382),
    [sym__hll_assignment_left_expression] = STATE(2841),
    [sym_hll_conditional_expression] = STATE(2382),
    [sym_hll_char_literal] = STATE(2382),
    [sym_hll_string_literal] = STATE(2382),
    [sym_hll_parenthesized_expression] = STATE(1775),
    [sym_symbol] = STATE(1775),
    [sym_identifier] = ACTIONS(866),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_PLUS] = ACTIONS(870),
    [anon_sym_DASH] = ACTIONS(870),
    [anon_sym_TILDE] = ACTIONS(872),
    [anon_sym_BANG] = ACTIONS(870),
    [anon_sym_PLUS_PLUS] = ACTIONS(874),
    [anon_sym_DASH_DASH] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(878),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(298),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(298),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(137)] = {
    [sym__hll_expression] = STATE(2263),
    [sym_hll_call_expression] = STATE(1679),
    [sym_hll_field_expression] = STATE(1679),
    [sym_hll_subscript_expression] = STATE(1679),
    [sym_hll_cast_expression] = STATE(2263),
    [sym_hll_sizeof_expression] = STATE(2263),
    [sym_hll_pointer_expression] = STATE(1679),
    [sym_hll_update_expression] = STATE(2263),
    [sym_hll_unary_expression] = STATE(2263),
    [sym_hll_binary_expression] = STATE(2263),
    [sym_hll_assignment_expression] = STATE(2263),
    [sym__hll_assignment_left_expression] = STATE(2851),
    [sym_hll_conditional_expression] = STATE(2263),
    [sym_hll_char_literal] = STATE(2263),
    [sym_hll_string_literal] = STATE(2263),
    [sym_hll_parenthesized_expression] = STATE(1679),
    [sym_symbol] = STATE(1679),
    [sym_identifier] = ACTIONS(886),
    [anon_sym_RPAREN] = ACTIONS(330),
    [anon_sym_LPAREN] = ACTIONS(888),
    [anon_sym_PLUS] = ACTIONS(890),
    [anon_sym_DASH] = ACTIONS(890),
    [anon_sym_TILDE] = ACTIONS(892),
    [anon_sym_BANG] = ACTIONS(890),
    [anon_sym_PLUS_PLUS] = ACTIONS(894),
    [anon_sym_DASH_DASH] = ACTIONS(894),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(330),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_RBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(896),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(138)] = {
    [sym__hll_expression] = STATE(2265),
    [sym_hll_call_expression] = STATE(1679),
    [sym_hll_field_expression] = STATE(1679),
    [sym_hll_subscript_expression] = STATE(1679),
    [sym_hll_cast_expression] = STATE(2265),
    [sym_hll_sizeof_expression] = STATE(2265),
    [sym_hll_pointer_expression] = STATE(1679),
    [sym_hll_update_expression] = STATE(2265),
    [sym_hll_unary_expression] = STATE(2265),
    [sym_hll_binary_expression] = STATE(2265),
    [sym_hll_assignment_expression] = STATE(2265),
    [sym__hll_assignment_left_expression] = STATE(2851),
    [sym_hll_conditional_expression] = STATE(2265),
    [sym_hll_char_literal] = STATE(2265),
    [sym_hll_string_literal] = STATE(2265),
    [sym_hll_parenthesized_expression] = STATE(1679),
    [sym_symbol] = STATE(1679),
    [sym_identifier] = ACTIONS(886),
    [anon_sym_RPAREN] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(888),
    [anon_sym_PLUS] = ACTIONS(890),
    [anon_sym_DASH] = ACTIONS(890),
    [anon_sym_TILDE] = ACTIONS(892),
    [anon_sym_BANG] = ACTIONS(890),
    [anon_sym_PLUS_PLUS] = ACTIONS(894),
    [anon_sym_DASH_DASH] = ACTIONS(894),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(334),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_RBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(896),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(139)] = {
    [sym__hll_expression] = STATE(2266),
    [sym_hll_call_expression] = STATE(1679),
    [sym_hll_field_expression] = STATE(1679),
    [sym_hll_subscript_expression] = STATE(1679),
    [sym_hll_cast_expression] = STATE(2266),
    [sym_hll_sizeof_expression] = STATE(2266),
    [sym_hll_pointer_expression] = STATE(1679),
    [sym_hll_update_expression] = STATE(2266),
    [sym_hll_unary_expression] = STATE(2266),
    [sym_hll_binary_expression] = STATE(2266),
    [sym_hll_assignment_expression] = STATE(2266),
    [sym__hll_assignment_left_expression] = STATE(2851),
    [sym_hll_conditional_expression] = STATE(2266),
    [sym_hll_char_literal] = STATE(2266),
    [sym_hll_string_literal] = STATE(2266),
    [sym_hll_parenthesized_expression] = STATE(1679),
    [sym_symbol] = STATE(1679),
    [sym_identifier] = ACTIONS(886),
    [anon_sym_RPAREN] = ACTIONS(338),
    [anon_sym_LPAREN] = ACTIONS(888),
    [anon_sym_PLUS] = ACTIONS(890),
    [anon_sym_DASH] = ACTIONS(890),
    [anon_sym_TILDE] = ACTIONS(892),
    [anon_sym_BANG] = ACTIONS(890),
    [anon_sym_PLUS_PLUS] = ACTIONS(894),
    [anon_sym_DASH_DASH] = ACTIONS(894),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(338),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_RBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(896),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(140)] = {
    [sym__hll_expression] = STATE(2267),
    [sym_hll_call_expression] = STATE(1679),
    [sym_hll_field_expression] = STATE(1679),
    [sym_hll_subscript_expression] = STATE(1679),
    [sym_hll_cast_expression] = STATE(2267),
    [sym_hll_sizeof_expression] = STATE(2267),
    [sym_hll_pointer_expression] = STATE(1679),
    [sym_hll_update_expression] = STATE(2267),
    [sym_hll_unary_expression] = STATE(2267),
    [sym_hll_binary_expression] = STATE(2267),
    [sym_hll_assignment_expression] = STATE(2267),
    [sym__hll_assignment_left_expression] = STATE(2851),
    [sym_hll_conditional_expression] = STATE(2267),
    [sym_hll_char_literal] = STATE(2267),
    [sym_hll_string_literal] = STATE(2267),
    [sym_hll_parenthesized_expression] = STATE(1679),
    [sym_symbol] = STATE(1679),
    [sym_identifier] = ACTIONS(886),
    [anon_sym_RPAREN] = ACTIONS(298),
    [anon_sym_LPAREN] = ACTIONS(888),
    [anon_sym_PLUS] = ACTIONS(890),
    [anon_sym_DASH] = ACTIONS(890),
    [anon_sym_TILDE] = ACTIONS(892),
    [anon_sym_BANG] = ACTIONS(890),
    [anon_sym_PLUS_PLUS] = ACTIONS(894),
    [anon_sym_DASH_DASH] = ACTIONS(894),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(580),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(310),
    [anon_sym_COLON] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_RBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(896),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(318),
    [aux_sym_symbol_token1] = ACTIONS(320),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(322),
    [anon_sym_BSLASH] = ACTIONS(324),
    [aux_sym_symbol_token5] = ACTIONS(326),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(141)] = {
    [sym__parenthesized_expression] = STATE(2403),
    [sym__path_expression] = STATE(2403),
    [sym_unary_expression] = STATE(2403),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2403),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2403),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2403),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2403),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2403),
    [sym_string] = STATE(2403),
    [sym_character] = STATE(2403),
    [sym_symbol] = STATE(2403),
    [sym__special_command_operator] = STATE(2403),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2403),
    [sym__expression] = STATE(2403),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(898),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(900),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(902),
    [sym_time] = ACTIONS(900),
    [sym_frequency] = ACTIONS(900),
    [sym_percentage] = ACTIONS(902),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(142)] = {
    [sym__parenthesized_expression] = STATE(2420),
    [sym__path_expression] = STATE(2420),
    [sym_unary_expression] = STATE(2420),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2420),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2420),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2420),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2420),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2420),
    [sym_string] = STATE(2420),
    [sym_character] = STATE(2420),
    [sym_symbol] = STATE(2420),
    [sym__special_command_operator] = STATE(2420),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2420),
    [sym__expression] = STATE(2420),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(904),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(906),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(908),
    [sym_time] = ACTIONS(906),
    [sym_frequency] = ACTIONS(906),
    [sym_percentage] = ACTIONS(908),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(143)] = {
    [sym__hll_expression] = STATE(2385),
    [sym_hll_call_expression] = STATE(1722),
    [sym_hll_field_expression] = STATE(1722),
    [sym_hll_subscript_expression] = STATE(1722),
    [sym_hll_cast_expression] = STATE(2385),
    [sym_hll_sizeof_expression] = STATE(2385),
    [sym_hll_pointer_expression] = STATE(1722),
    [sym_hll_update_expression] = STATE(2385),
    [sym_hll_unary_expression] = STATE(2385),
    [sym_hll_binary_expression] = STATE(2385),
    [sym_hll_assignment_expression] = STATE(2385),
    [sym__hll_assignment_left_expression] = STATE(2853),
    [sym_hll_conditional_expression] = STATE(2385),
    [sym_hll_char_literal] = STATE(2385),
    [sym_hll_string_literal] = STATE(2385),
    [sym_hll_parenthesized_expression] = STATE(1722),
    [sym_symbol] = STATE(1722),
    [sym_identifier] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_PLUS] = ACTIONS(914),
    [anon_sym_DASH] = ACTIONS(914),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(914),
    [anon_sym_PLUS_PLUS] = ACTIONS(918),
    [anon_sym_DASH_DASH] = ACTIONS(918),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(922),
    [anon_sym_L_SQUOTE] = ACTIONS(924),
    [anon_sym_u_SQUOTE] = ACTIONS(924),
    [anon_sym_U_SQUOTE] = ACTIONS(924),
    [anon_sym_u8_SQUOTE] = ACTIONS(924),
    [anon_sym_SQUOTE] = ACTIONS(924),
    [anon_sym_L_DQUOTE] = ACTIONS(926),
    [anon_sym_u_DQUOTE] = ACTIONS(926),
    [anon_sym_U_DQUOTE] = ACTIONS(926),
    [anon_sym_u8_DQUOTE] = ACTIONS(926),
    [anon_sym_DQUOTE] = ACTIONS(926),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(928),
  },
  [STATE(144)] = {
    [sym__hll_expression] = STATE(2391),
    [sym_hll_call_expression] = STATE(1722),
    [sym_hll_field_expression] = STATE(1722),
    [sym_hll_subscript_expression] = STATE(1722),
    [sym_hll_cast_expression] = STATE(2391),
    [sym_hll_sizeof_expression] = STATE(2391),
    [sym_hll_pointer_expression] = STATE(1722),
    [sym_hll_update_expression] = STATE(2391),
    [sym_hll_unary_expression] = STATE(2391),
    [sym_hll_binary_expression] = STATE(2391),
    [sym_hll_assignment_expression] = STATE(2391),
    [sym__hll_assignment_left_expression] = STATE(2853),
    [sym_hll_conditional_expression] = STATE(2391),
    [sym_hll_char_literal] = STATE(2391),
    [sym_hll_string_literal] = STATE(2391),
    [sym_hll_parenthesized_expression] = STATE(1722),
    [sym_symbol] = STATE(1722),
    [sym_identifier] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_PLUS] = ACTIONS(914),
    [anon_sym_DASH] = ACTIONS(914),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(914),
    [anon_sym_PLUS_PLUS] = ACTIONS(918),
    [anon_sym_DASH_DASH] = ACTIONS(918),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(922),
    [anon_sym_L_SQUOTE] = ACTIONS(924),
    [anon_sym_u_SQUOTE] = ACTIONS(924),
    [anon_sym_U_SQUOTE] = ACTIONS(924),
    [anon_sym_u8_SQUOTE] = ACTIONS(924),
    [anon_sym_SQUOTE] = ACTIONS(924),
    [anon_sym_L_DQUOTE] = ACTIONS(926),
    [anon_sym_u_DQUOTE] = ACTIONS(926),
    [anon_sym_U_DQUOTE] = ACTIONS(926),
    [anon_sym_u8_DQUOTE] = ACTIONS(926),
    [anon_sym_DQUOTE] = ACTIONS(926),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(336),
    [sym__hll_number_literal_pre_hook] = ACTIONS(928),
  },
  [STATE(145)] = {
    [sym__hll_expression] = STATE(2392),
    [sym_hll_call_expression] = STATE(1722),
    [sym_hll_field_expression] = STATE(1722),
    [sym_hll_subscript_expression] = STATE(1722),
    [sym_hll_cast_expression] = STATE(2392),
    [sym_hll_sizeof_expression] = STATE(2392),
    [sym_hll_pointer_expression] = STATE(1722),
    [sym_hll_update_expression] = STATE(2392),
    [sym_hll_unary_expression] = STATE(2392),
    [sym_hll_binary_expression] = STATE(2392),
    [sym_hll_assignment_expression] = STATE(2392),
    [sym__hll_assignment_left_expression] = STATE(2853),
    [sym_hll_conditional_expression] = STATE(2392),
    [sym_hll_char_literal] = STATE(2392),
    [sym_hll_string_literal] = STATE(2392),
    [sym_hll_parenthesized_expression] = STATE(1722),
    [sym_symbol] = STATE(1722),
    [sym_identifier] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_PLUS] = ACTIONS(914),
    [anon_sym_DASH] = ACTIONS(914),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(914),
    [anon_sym_PLUS_PLUS] = ACTIONS(918),
    [anon_sym_DASH_DASH] = ACTIONS(918),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(922),
    [anon_sym_L_SQUOTE] = ACTIONS(924),
    [anon_sym_u_SQUOTE] = ACTIONS(924),
    [anon_sym_U_SQUOTE] = ACTIONS(924),
    [anon_sym_u8_SQUOTE] = ACTIONS(924),
    [anon_sym_SQUOTE] = ACTIONS(924),
    [anon_sym_L_DQUOTE] = ACTIONS(926),
    [anon_sym_u_DQUOTE] = ACTIONS(926),
    [anon_sym_U_DQUOTE] = ACTIONS(926),
    [anon_sym_u8_DQUOTE] = ACTIONS(926),
    [anon_sym_DQUOTE] = ACTIONS(926),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(340),
    [sym__hll_number_literal_pre_hook] = ACTIONS(928),
  },
  [STATE(146)] = {
    [sym__hll_expression] = STATE(2305),
    [sym_hll_call_expression] = STATE(1722),
    [sym_hll_field_expression] = STATE(1722),
    [sym_hll_subscript_expression] = STATE(1722),
    [sym_hll_cast_expression] = STATE(2305),
    [sym_hll_sizeof_expression] = STATE(2305),
    [sym_hll_pointer_expression] = STATE(1722),
    [sym_hll_update_expression] = STATE(2305),
    [sym_hll_unary_expression] = STATE(2305),
    [sym_hll_binary_expression] = STATE(2305),
    [sym_hll_assignment_expression] = STATE(2305),
    [sym__hll_assignment_left_expression] = STATE(2853),
    [sym_hll_conditional_expression] = STATE(2305),
    [sym_hll_char_literal] = STATE(2305),
    [sym_hll_string_literal] = STATE(2305),
    [sym_hll_parenthesized_expression] = STATE(1722),
    [sym_symbol] = STATE(1722),
    [sym_identifier] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(912),
    [anon_sym_PLUS] = ACTIONS(914),
    [anon_sym_DASH] = ACTIONS(914),
    [anon_sym_TILDE] = ACTIONS(916),
    [anon_sym_BANG] = ACTIONS(914),
    [anon_sym_PLUS_PLUS] = ACTIONS(918),
    [anon_sym_DASH_DASH] = ACTIONS(918),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(922),
    [anon_sym_L_SQUOTE] = ACTIONS(924),
    [anon_sym_u_SQUOTE] = ACTIONS(924),
    [anon_sym_U_SQUOTE] = ACTIONS(924),
    [anon_sym_u8_SQUOTE] = ACTIONS(924),
    [anon_sym_SQUOTE] = ACTIONS(924),
    [anon_sym_L_DQUOTE] = ACTIONS(926),
    [anon_sym_u_DQUOTE] = ACTIONS(926),
    [anon_sym_U_DQUOTE] = ACTIONS(926),
    [anon_sym_u8_DQUOTE] = ACTIONS(926),
    [anon_sym_DQUOTE] = ACTIONS(926),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(298),
    [sym__blank_line] = ACTIONS(298),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(302),
    [sym__hll_number_literal_pre_hook] = ACTIONS(928),
  },
  [STATE(147)] = {
    [sym__parenthesized_expression] = STATE(2258),
    [sym__path_expression] = STATE(2258),
    [sym_unary_expression] = STATE(2258),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2258),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2258),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2258),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2258),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2258),
    [sym_string] = STATE(2258),
    [sym_character] = STATE(2258),
    [sym_symbol] = STATE(2258),
    [sym__special_command_operator] = STATE(2258),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2258),
    [sym__expression] = STATE(2258),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_RPAREN] = ACTIONS(930),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(932),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(934),
    [sym_time] = ACTIONS(932),
    [sym_frequency] = ACTIONS(932),
    [sym_percentage] = ACTIONS(934),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(148)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2702),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2702),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1947),
    [sym_macro_text_expansion] = STATE(2489),
    [sym__option_value] = STATE(4270),
    [sym_call_expression] = STATE(2489),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2702),
    [sym__address_expression] = STATE(2840),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2702),
    [sym__parenthesized_address_expression] = STATE(2840),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2702),
    [sym_string] = STATE(2702),
    [sym_character] = STATE(2702),
    [sym_symbol] = STATE(2702),
    [sym__special_command_operator] = STATE(2702),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2702),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(936),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(938),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(940),
    [sym_time] = ACTIONS(938),
    [sym_frequency] = ACTIONS(938),
    [sym_percentage] = ACTIONS(940),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(149)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2702),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2702),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1947),
    [sym_macro_text_expansion] = STATE(2489),
    [sym__option_value] = STATE(4154),
    [sym_call_expression] = STATE(2489),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2702),
    [sym__address_expression] = STATE(2840),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2702),
    [sym__parenthesized_address_expression] = STATE(2840),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2702),
    [sym_string] = STATE(2702),
    [sym_character] = STATE(2702),
    [sym_symbol] = STATE(2702),
    [sym__special_command_operator] = STATE(2702),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2702),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(936),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(938),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(940),
    [sym_time] = ACTIONS(938),
    [sym_frequency] = ACTIONS(938),
    [sym_percentage] = ACTIONS(940),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(150)] = {
    [sym__hll_expression] = STATE(2293),
    [sym_hll_call_expression] = STATE(1775),
    [sym_hll_field_expression] = STATE(1775),
    [sym_hll_subscript_expression] = STATE(1775),
    [sym_hll_cast_expression] = STATE(2293),
    [sym_hll_sizeof_expression] = STATE(2293),
    [sym_hll_pointer_expression] = STATE(1775),
    [sym_hll_update_expression] = STATE(2293),
    [sym_hll_unary_expression] = STATE(2293),
    [sym_hll_binary_expression] = STATE(2293),
    [sym_hll_assignment_expression] = STATE(2293),
    [sym__hll_assignment_left_expression] = STATE(2841),
    [sym_hll_conditional_expression] = STATE(2293),
    [sym_hll_char_literal] = STATE(2293),
    [sym_hll_string_literal] = STATE(2293),
    [sym_hll_parenthesized_expression] = STATE(1775),
    [sym_symbol] = STATE(1775),
    [sym_identifier] = ACTIONS(866),
    [anon_sym_LPAREN] = ACTIONS(868),
    [anon_sym_PLUS] = ACTIONS(870),
    [anon_sym_DASH] = ACTIONS(870),
    [anon_sym_TILDE] = ACTIONS(872),
    [anon_sym_BANG] = ACTIONS(870),
    [anon_sym_PLUS_PLUS] = ACTIONS(874),
    [anon_sym_DASH_DASH] = ACTIONS(874),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(878),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(330),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__blank] = ACTIONS(332),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(151)] = {
    [sym__parenthesized_expression] = STATE(2376),
    [sym__path_expression] = STATE(2376),
    [sym_unary_expression] = STATE(2376),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2376),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2376),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2376),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2376),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2376),
    [sym_string] = STATE(2376),
    [sym_character] = STATE(2376),
    [sym_symbol] = STATE(2376),
    [sym__special_command_operator] = STATE(2376),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2376),
    [sym__expression] = STATE(2376),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(942),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(944),
    [sym_time] = ACTIONS(942),
    [sym_frequency] = ACTIONS(942),
    [sym_percentage] = ACTIONS(944),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(152)] = {
    [sym__parenthesized_expression] = STATE(710),
    [sym__path_expression] = STATE(710),
    [sym_unary_expression] = STATE(710),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(710),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(710),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(710),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(710),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(710),
    [sym_string] = STATE(710),
    [sym_character] = STATE(710),
    [sym_symbol] = STATE(710),
    [sym__special_command_operator] = STATE(710),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(710),
    [sym__expression] = STATE(710),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(710),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(946),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(948),
    [sym_time] = ACTIONS(946),
    [sym_frequency] = ACTIONS(946),
    [sym_percentage] = ACTIONS(948),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(948),
  },
  [STATE(153)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1890),
    [sym_macro_text_expansion] = STATE(2386),
    [sym_call_expression] = STATE(2386),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2807),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2807),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2384),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(154)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1890),
    [sym_macro_text_expansion] = STATE(2386),
    [sym_call_expression] = STATE(2386),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2805),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2805),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2384),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(155)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1890),
    [sym_macro_text_expansion] = STATE(2386),
    [sym_call_expression] = STATE(2386),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2808),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2808),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2384),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(156)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1890),
    [sym_macro_text_expansion] = STATE(2386),
    [sym_call_expression] = STATE(2386),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2809),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2809),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2384),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(157)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1890),
    [sym_macro_text_expansion] = STATE(2386),
    [sym_call_expression] = STATE(2386),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2810),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2810),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2384),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(158)] = {
    [sym__parenthesized_expression] = STATE(711),
    [sym__path_expression] = STATE(711),
    [sym_unary_expression] = STATE(711),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(711),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(711),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(711),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(711),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(711),
    [sym_string] = STATE(711),
    [sym_character] = STATE(711),
    [sym_symbol] = STATE(711),
    [sym__special_command_operator] = STATE(711),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(711),
    [sym__expression] = STATE(711),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(711),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(950),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(952),
    [sym_time] = ACTIONS(950),
    [sym_frequency] = ACTIONS(950),
    [sym_percentage] = ACTIONS(952),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(952),
  },
  [STATE(159)] = {
    [sym__parenthesized_expression] = STATE(2339),
    [sym__path_expression] = STATE(2339),
    [sym_unary_expression] = STATE(2339),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2339),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2339),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2339),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2339),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2339),
    [sym_string] = STATE(2339),
    [sym_character] = STATE(2339),
    [sym_symbol] = STATE(2339),
    [sym__special_command_operator] = STATE(2339),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2339),
    [sym__expression] = STATE(2339),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(954),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(956),
    [sym_time] = ACTIONS(954),
    [sym_frequency] = ACTIONS(954),
    [sym_percentage] = ACTIONS(956),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(160)] = {
    [sym__parenthesized_expression] = STATE(2592),
    [sym__path_expression] = STATE(2592),
    [sym_unary_expression] = STATE(2592),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2592),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2592),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2592),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2592),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2592),
    [sym_string] = STATE(2592),
    [sym_character] = STATE(2592),
    [sym_symbol] = STATE(2592),
    [sym__special_command_operator] = STATE(2592),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2592),
    [sym__expression] = STATE(2592),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(958),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(960),
    [sym_time] = ACTIONS(958),
    [sym_frequency] = ACTIONS(958),
    [sym_percentage] = ACTIONS(960),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(161)] = {
    [sym__parenthesized_expression] = STATE(2593),
    [sym__path_expression] = STATE(2593),
    [sym_unary_expression] = STATE(2593),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2593),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2593),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2593),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2593),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2593),
    [sym_string] = STATE(2593),
    [sym_character] = STATE(2593),
    [sym_symbol] = STATE(2593),
    [sym__special_command_operator] = STATE(2593),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2593),
    [sym__expression] = STATE(2593),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(962),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(964),
    [sym_time] = ACTIONS(962),
    [sym_frequency] = ACTIONS(962),
    [sym_percentage] = ACTIONS(964),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(162)] = {
    [sym__parenthesized_expression] = STATE(712),
    [sym__path_expression] = STATE(712),
    [sym_unary_expression] = STATE(712),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(712),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(712),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(712),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(712),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(712),
    [sym_string] = STATE(712),
    [sym_character] = STATE(712),
    [sym_symbol] = STATE(712),
    [sym__special_command_operator] = STATE(712),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(712),
    [sym__expression] = STATE(712),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(712),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(966),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(968),
    [sym_time] = ACTIONS(966),
    [sym_frequency] = ACTIONS(966),
    [sym_percentage] = ACTIONS(968),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(968),
  },
  [STATE(163)] = {
    [sym__parenthesized_expression] = STATE(2525),
    [sym__path_expression] = STATE(2525),
    [sym_unary_expression] = STATE(2525),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2525),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2525),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2525),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2525),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2525),
    [sym_string] = STATE(2525),
    [sym_character] = STATE(2525),
    [sym_symbol] = STATE(2525),
    [sym__special_command_operator] = STATE(2525),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2525),
    [sym__expression] = STATE(2525),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(970),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(972),
    [sym_time] = ACTIONS(970),
    [sym_frequency] = ACTIONS(970),
    [sym_percentage] = ACTIONS(972),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(164)] = {
    [sym__parenthesized_expression] = STATE(2286),
    [sym__path_expression] = STATE(2286),
    [sym_unary_expression] = STATE(2286),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2286),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2286),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2286),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2286),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2286),
    [sym_string] = STATE(2286),
    [sym_character] = STATE(2286),
    [sym_symbol] = STATE(2286),
    [sym__special_command_operator] = STATE(2286),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2286),
    [sym__expression] = STATE(2286),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(974),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(976),
    [sym_time] = ACTIONS(974),
    [sym_frequency] = ACTIONS(974),
    [sym_percentage] = ACTIONS(976),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(165)] = {
    [sym__parenthesized_expression] = STATE(2526),
    [sym__path_expression] = STATE(2526),
    [sym_unary_expression] = STATE(2526),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2526),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2526),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2526),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2526),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2526),
    [sym_string] = STATE(2526),
    [sym_character] = STATE(2526),
    [sym_symbol] = STATE(2526),
    [sym__special_command_operator] = STATE(2526),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2526),
    [sym__expression] = STATE(2526),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(978),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(980),
    [sym_time] = ACTIONS(978),
    [sym_frequency] = ACTIONS(978),
    [sym_percentage] = ACTIONS(980),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(166)] = {
    [sym__parenthesized_expression] = STATE(2527),
    [sym__path_expression] = STATE(2527),
    [sym_unary_expression] = STATE(2527),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2527),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2527),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2527),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2527),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2527),
    [sym_string] = STATE(2527),
    [sym_character] = STATE(2527),
    [sym_symbol] = STATE(2527),
    [sym__special_command_operator] = STATE(2527),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2527),
    [sym__expression] = STATE(2527),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(982),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(984),
    [sym_time] = ACTIONS(982),
    [sym_frequency] = ACTIONS(982),
    [sym_percentage] = ACTIONS(984),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(167)] = {
    [sym__parenthesized_expression] = STATE(2528),
    [sym__path_expression] = STATE(2528),
    [sym_unary_expression] = STATE(2528),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2528),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2528),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2528),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2528),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2528),
    [sym_string] = STATE(2528),
    [sym_character] = STATE(2528),
    [sym_symbol] = STATE(2528),
    [sym__special_command_operator] = STATE(2528),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2528),
    [sym__expression] = STATE(2528),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(986),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(988),
    [sym_time] = ACTIONS(986),
    [sym_frequency] = ACTIONS(986),
    [sym_percentage] = ACTIONS(988),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(168)] = {
    [sym__parenthesized_expression] = STATE(2529),
    [sym__path_expression] = STATE(2529),
    [sym_unary_expression] = STATE(2529),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2529),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2529),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2529),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2529),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2529),
    [sym_string] = STATE(2529),
    [sym_character] = STATE(2529),
    [sym_symbol] = STATE(2529),
    [sym__special_command_operator] = STATE(2529),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2529),
    [sym__expression] = STATE(2529),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(990),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(992),
    [sym_time] = ACTIONS(990),
    [sym_frequency] = ACTIONS(990),
    [sym_percentage] = ACTIONS(992),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(169)] = {
    [sym__parenthesized_expression] = STATE(2530),
    [sym__path_expression] = STATE(2530),
    [sym_unary_expression] = STATE(2530),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2530),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2530),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2530),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2530),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2530),
    [sym_string] = STATE(2530),
    [sym_character] = STATE(2530),
    [sym_symbol] = STATE(2530),
    [sym__special_command_operator] = STATE(2530),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2530),
    [sym__expression] = STATE(2530),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(994),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(996),
    [sym_time] = ACTIONS(994),
    [sym_frequency] = ACTIONS(994),
    [sym_percentage] = ACTIONS(996),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(170)] = {
    [sym__parenthesized_expression] = STATE(2531),
    [sym__path_expression] = STATE(2531),
    [sym_unary_expression] = STATE(2531),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2531),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2531),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2531),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2531),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2531),
    [sym_string] = STATE(2531),
    [sym_character] = STATE(2531),
    [sym_symbol] = STATE(2531),
    [sym__special_command_operator] = STATE(2531),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2531),
    [sym__expression] = STATE(2531),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(998),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1000),
    [sym_time] = ACTIONS(998),
    [sym_frequency] = ACTIONS(998),
    [sym_percentage] = ACTIONS(1000),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(171)] = {
    [sym__parenthesized_expression] = STATE(2532),
    [sym__path_expression] = STATE(2532),
    [sym_unary_expression] = STATE(2532),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2532),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2532),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2532),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2532),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2532),
    [sym_string] = STATE(2532),
    [sym_character] = STATE(2532),
    [sym_symbol] = STATE(2532),
    [sym__special_command_operator] = STATE(2532),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2532),
    [sym__expression] = STATE(2532),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1002),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1004),
    [sym_time] = ACTIONS(1002),
    [sym_frequency] = ACTIONS(1002),
    [sym_percentage] = ACTIONS(1004),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(172)] = {
    [sym__parenthesized_expression] = STATE(2594),
    [sym__path_expression] = STATE(2594),
    [sym_unary_expression] = STATE(2594),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2594),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2594),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2594),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2594),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2594),
    [sym_string] = STATE(2594),
    [sym_character] = STATE(2594),
    [sym_symbol] = STATE(2594),
    [sym__special_command_operator] = STATE(2594),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2594),
    [sym__expression] = STATE(2594),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(244),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(246),
    [sym_time] = ACTIONS(244),
    [sym_frequency] = ACTIONS(244),
    [sym_percentage] = ACTIONS(246),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(173)] = {
    [sym__parenthesized_expression] = STATE(2533),
    [sym__path_expression] = STATE(2533),
    [sym_unary_expression] = STATE(2533),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2533),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2533),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2533),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2533),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2533),
    [sym_string] = STATE(2533),
    [sym_character] = STATE(2533),
    [sym_symbol] = STATE(2533),
    [sym__special_command_operator] = STATE(2533),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2533),
    [sym__expression] = STATE(2533),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1006),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1008),
    [sym_time] = ACTIONS(1006),
    [sym_frequency] = ACTIONS(1006),
    [sym_percentage] = ACTIONS(1008),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(174)] = {
    [sym__parenthesized_expression] = STATE(2534),
    [sym__path_expression] = STATE(2534),
    [sym_unary_expression] = STATE(2534),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2534),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2534),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2534),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2534),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2534),
    [sym_string] = STATE(2534),
    [sym_character] = STATE(2534),
    [sym_symbol] = STATE(2534),
    [sym__special_command_operator] = STATE(2534),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2534),
    [sym__expression] = STATE(2534),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1010),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1012),
    [sym_time] = ACTIONS(1010),
    [sym_frequency] = ACTIONS(1010),
    [sym_percentage] = ACTIONS(1012),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(175)] = {
    [sym__parenthesized_expression] = STATE(713),
    [sym__path_expression] = STATE(713),
    [sym_unary_expression] = STATE(713),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(713),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(713),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(713),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(713),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(713),
    [sym_string] = STATE(713),
    [sym_character] = STATE(713),
    [sym_symbol] = STATE(713),
    [sym__special_command_operator] = STATE(713),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(713),
    [sym__expression] = STATE(713),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(713),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1014),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1016),
    [sym_time] = ACTIONS(1014),
    [sym_frequency] = ACTIONS(1014),
    [sym_percentage] = ACTIONS(1016),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1016),
  },
  [STATE(176)] = {
    [sym__parenthesized_expression] = STATE(714),
    [sym__path_expression] = STATE(714),
    [sym_unary_expression] = STATE(714),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(714),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(714),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(714),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(714),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(714),
    [sym_string] = STATE(714),
    [sym_character] = STATE(714),
    [sym_symbol] = STATE(714),
    [sym__special_command_operator] = STATE(714),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(714),
    [sym__expression] = STATE(714),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(714),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1018),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1020),
    [sym_time] = ACTIONS(1018),
    [sym_frequency] = ACTIONS(1018),
    [sym_percentage] = ACTIONS(1020),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1020),
  },
  [STATE(177)] = {
    [sym__parenthesized_expression] = STATE(706),
    [sym__path_expression] = STATE(706),
    [sym_unary_expression] = STATE(706),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(706),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(706),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(706),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(706),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(706),
    [sym_string] = STATE(706),
    [sym_character] = STATE(706),
    [sym_symbol] = STATE(706),
    [sym__special_command_operator] = STATE(706),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(706),
    [sym__expression] = STATE(706),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(706),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(134),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(148),
    [sym_time] = ACTIONS(134),
    [sym_frequency] = ACTIONS(134),
    [sym_percentage] = ACTIONS(148),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(148),
  },
  [STATE(178)] = {
    [sym__parenthesized_expression] = STATE(725),
    [sym__path_expression] = STATE(725),
    [sym_unary_expression] = STATE(725),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(725),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(725),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(725),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(725),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(725),
    [sym_string] = STATE(725),
    [sym_character] = STATE(725),
    [sym_symbol] = STATE(725),
    [sym__special_command_operator] = STATE(725),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(725),
    [sym__expression] = STATE(725),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(725),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1022),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1024),
    [sym_time] = ACTIONS(1022),
    [sym_frequency] = ACTIONS(1022),
    [sym_percentage] = ACTIONS(1024),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1024),
  },
  [STATE(179)] = {
    [sym__parenthesized_expression] = STATE(726),
    [sym__path_expression] = STATE(726),
    [sym_unary_expression] = STATE(726),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(726),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(726),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(726),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(726),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(726),
    [sym_string] = STATE(726),
    [sym_character] = STATE(726),
    [sym_symbol] = STATE(726),
    [sym__special_command_operator] = STATE(726),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(726),
    [sym__expression] = STATE(726),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(726),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1026),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1028),
    [sym_time] = ACTIONS(1026),
    [sym_frequency] = ACTIONS(1026),
    [sym_percentage] = ACTIONS(1028),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1028),
  },
  [STATE(180)] = {
    [sym__parenthesized_expression] = STATE(2553),
    [sym__path_expression] = STATE(2553),
    [sym_unary_expression] = STATE(2553),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2553),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2553),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2553),
    [sym__address_expression] = STATE(2840),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2553),
    [sym__parenthesized_address_expression] = STATE(2840),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2553),
    [sym_string] = STATE(2553),
    [sym_character] = STATE(2553),
    [sym_symbol] = STATE(2553),
    [sym__special_command_operator] = STATE(2553),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2553),
    [sym__expression] = STATE(2553),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1030),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1032),
    [sym_time] = ACTIONS(1030),
    [sym_frequency] = ACTIONS(1030),
    [sym_percentage] = ACTIONS(1032),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(181)] = {
    [sym__parenthesized_expression] = STATE(2354),
    [sym__path_expression] = STATE(2354),
    [sym_unary_expression] = STATE(2354),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2354),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2354),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2354),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2354),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2354),
    [sym_string] = STATE(2354),
    [sym_character] = STATE(2354),
    [sym_symbol] = STATE(2354),
    [sym__special_command_operator] = STATE(2354),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2354),
    [sym__expression] = STATE(2354),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1034),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1036),
    [sym_time] = ACTIONS(1034),
    [sym_frequency] = ACTIONS(1034),
    [sym_percentage] = ACTIONS(1036),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(182)] = {
    [sym__parenthesized_expression] = STATE(2289),
    [sym__path_expression] = STATE(2289),
    [sym_unary_expression] = STATE(2289),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2289),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2289),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2289),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2289),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2289),
    [sym_string] = STATE(2289),
    [sym_character] = STATE(2289),
    [sym_symbol] = STATE(2289),
    [sym__special_command_operator] = STATE(2289),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2289),
    [sym__expression] = STATE(2289),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1038),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1040),
    [sym_time] = ACTIONS(1038),
    [sym_frequency] = ACTIONS(1038),
    [sym_percentage] = ACTIONS(1040),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(183)] = {
    [sym__parenthesized_expression] = STATE(2554),
    [sym__path_expression] = STATE(2554),
    [sym_unary_expression] = STATE(2554),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2554),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2554),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2554),
    [sym__address_expression] = STATE(2821),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2554),
    [sym__parenthesized_address_expression] = STATE(2821),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2554),
    [sym_string] = STATE(2554),
    [sym_character] = STATE(2554),
    [sym_symbol] = STATE(2554),
    [sym__special_command_operator] = STATE(2554),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2554),
    [sym__expression] = STATE(2554),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1042),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1044),
    [sym_time] = ACTIONS(1042),
    [sym_frequency] = ACTIONS(1042),
    [sym_percentage] = ACTIONS(1044),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(184)] = {
    [sym__hll_expression] = STATE(2426),
    [sym_hll_call_expression] = STATE(1757),
    [sym_hll_field_expression] = STATE(1757),
    [sym_hll_subscript_expression] = STATE(1757),
    [sym_hll_cast_expression] = STATE(2426),
    [sym_hll_sizeof_expression] = STATE(2426),
    [sym_hll_pointer_expression] = STATE(1757),
    [sym_hll_update_expression] = STATE(2426),
    [sym_hll_unary_expression] = STATE(2426),
    [sym_hll_binary_expression] = STATE(2426),
    [sym_hll_assignment_expression] = STATE(2426),
    [sym__hll_assignment_left_expression] = STATE(2850),
    [sym_hll_conditional_expression] = STATE(2426),
    [sym_hll_char_literal] = STATE(2426),
    [sym_hll_string_literal] = STATE(2426),
    [sym_hll_parenthesized_expression] = STATE(1757),
    [sym_symbol] = STATE(1757),
    [sym_identifier] = ACTIONS(1046),
    [anon_sym_LPAREN] = ACTIONS(1048),
    [anon_sym_PLUS] = ACTIONS(1050),
    [anon_sym_DASH] = ACTIONS(1050),
    [anon_sym_TILDE] = ACTIONS(1052),
    [anon_sym_BANG] = ACTIONS(1050),
    [anon_sym_PLUS_PLUS] = ACTIONS(1054),
    [anon_sym_DASH_DASH] = ACTIONS(1054),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(336),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(1056),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(334),
    [sym__blank_line] = ACTIONS(334),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(185)] = {
    [sym__hll_expression] = STATE(2430),
    [sym_hll_call_expression] = STATE(1757),
    [sym_hll_field_expression] = STATE(1757),
    [sym_hll_subscript_expression] = STATE(1757),
    [sym_hll_cast_expression] = STATE(2430),
    [sym_hll_sizeof_expression] = STATE(2430),
    [sym_hll_pointer_expression] = STATE(1757),
    [sym_hll_update_expression] = STATE(2430),
    [sym_hll_unary_expression] = STATE(2430),
    [sym_hll_binary_expression] = STATE(2430),
    [sym_hll_assignment_expression] = STATE(2430),
    [sym__hll_assignment_left_expression] = STATE(2850),
    [sym_hll_conditional_expression] = STATE(2430),
    [sym_hll_char_literal] = STATE(2430),
    [sym_hll_string_literal] = STATE(2430),
    [sym_hll_parenthesized_expression] = STATE(1757),
    [sym_symbol] = STATE(1757),
    [sym_identifier] = ACTIONS(1046),
    [anon_sym_LPAREN] = ACTIONS(1048),
    [anon_sym_PLUS] = ACTIONS(1050),
    [anon_sym_DASH] = ACTIONS(1050),
    [anon_sym_TILDE] = ACTIONS(1052),
    [anon_sym_BANG] = ACTIONS(1050),
    [anon_sym_PLUS_PLUS] = ACTIONS(1054),
    [anon_sym_DASH_DASH] = ACTIONS(1054),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(340),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(1056),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(338),
    [sym__blank_line] = ACTIONS(338),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(186)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(529),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(529),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(187)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(530),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(530),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(188)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(532),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(532),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(189)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(533),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(533),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(190)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(536),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(536),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(191)] = {
    [sym__parenthesized_expression] = STATE(2373),
    [sym__path_expression] = STATE(2373),
    [sym_unary_expression] = STATE(2373),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2373),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2373),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2373),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2373),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2373),
    [sym_string] = STATE(2373),
    [sym_character] = STATE(2373),
    [sym_symbol] = STATE(2373),
    [sym__special_command_operator] = STATE(2373),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2373),
    [sym__expression] = STATE(2373),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1062),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1064),
    [sym_time] = ACTIONS(1062),
    [sym_frequency] = ACTIONS(1062),
    [sym_percentage] = ACTIONS(1064),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(192)] = {
    [sym__parenthesized_expression] = STATE(2409),
    [sym__path_expression] = STATE(2409),
    [sym_unary_expression] = STATE(2409),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2409),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2409),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2409),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2409),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2409),
    [sym_string] = STATE(2409),
    [sym_character] = STATE(2409),
    [sym_symbol] = STATE(2409),
    [sym__special_command_operator] = STATE(2409),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2409),
    [sym__expression] = STATE(2409),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1066),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1068),
    [sym_time] = ACTIONS(1066),
    [sym_frequency] = ACTIONS(1066),
    [sym_percentage] = ACTIONS(1068),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(193)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2085),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2085),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(194)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2098),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2098),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(195)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2102),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2102),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(196)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2107),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2107),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(197)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2116),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2116),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(198)] = {
    [sym__parenthesized_expression] = STATE(2298),
    [sym__path_expression] = STATE(2298),
    [sym_unary_expression] = STATE(2298),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2298),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2298),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2298),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2298),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2298),
    [sym_string] = STATE(2298),
    [sym_character] = STATE(2298),
    [sym_symbol] = STATE(2298),
    [sym__special_command_operator] = STATE(2298),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2298),
    [sym__expression] = STATE(2298),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1072),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1074),
    [sym_time] = ACTIONS(1072),
    [sym_frequency] = ACTIONS(1072),
    [sym_percentage] = ACTIONS(1074),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(199)] = {
    [sym__parenthesized_expression] = STATE(2291),
    [sym__path_expression] = STATE(2291),
    [sym_unary_expression] = STATE(2291),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2291),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2291),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2291),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2291),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2291),
    [sym_string] = STATE(2291),
    [sym_character] = STATE(2291),
    [sym_symbol] = STATE(2291),
    [sym__special_command_operator] = STATE(2291),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2291),
    [sym__expression] = STATE(2291),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1076),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1078),
    [sym_time] = ACTIONS(1076),
    [sym_frequency] = ACTIONS(1076),
    [sym_percentage] = ACTIONS(1078),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(200)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2120),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2120),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(201)] = {
    [sym__parenthesized_expression] = STATE(2590),
    [sym__path_expression] = STATE(2590),
    [sym_unary_expression] = STATE(2590),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2590),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2590),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2590),
    [sym__address_expression] = STATE(2840),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2590),
    [sym__parenthesized_address_expression] = STATE(2840),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2590),
    [sym_string] = STATE(2590),
    [sym_character] = STATE(2590),
    [sym_symbol] = STATE(2590),
    [sym__special_command_operator] = STATE(2590),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2590),
    [sym__expression] = STATE(2590),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1080),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1082),
    [sym_time] = ACTIONS(1080),
    [sym_frequency] = ACTIONS(1080),
    [sym_percentage] = ACTIONS(1082),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(202)] = {
    [sym__parenthesized_expression] = STATE(2591),
    [sym__path_expression] = STATE(2591),
    [sym_unary_expression] = STATE(2591),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2591),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2591),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2591),
    [sym__address_expression] = STATE(2821),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2591),
    [sym__parenthesized_address_expression] = STATE(2821),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2591),
    [sym_string] = STATE(2591),
    [sym_character] = STATE(2591),
    [sym_symbol] = STATE(2591),
    [sym__special_command_operator] = STATE(2591),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2591),
    [sym__expression] = STATE(2591),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1084),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1086),
    [sym_time] = ACTIONS(1084),
    [sym_frequency] = ACTIONS(1084),
    [sym_percentage] = ACTIONS(1086),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(203)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1812),
    [sym_macro_text_expansion] = STATE(2212),
    [sym_call_expression] = STATE(2212),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2203),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2203),
    [sym__address_binary_expression] = STATE(2251),
    [sym_integer] = STATE(2238),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(1070),
    [anon_sym_LBRACE] = ACTIONS(203),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(204)] = {
    [sym__hll_expression] = STATE(2459),
    [sym_hll_call_expression] = STATE(1757),
    [sym_hll_field_expression] = STATE(1757),
    [sym_hll_subscript_expression] = STATE(1757),
    [sym_hll_cast_expression] = STATE(2459),
    [sym_hll_sizeof_expression] = STATE(2459),
    [sym_hll_pointer_expression] = STATE(1757),
    [sym_hll_update_expression] = STATE(2459),
    [sym_hll_unary_expression] = STATE(2459),
    [sym_hll_binary_expression] = STATE(2459),
    [sym_hll_assignment_expression] = STATE(2459),
    [sym__hll_assignment_left_expression] = STATE(2850),
    [sym_hll_conditional_expression] = STATE(2459),
    [sym_hll_char_literal] = STATE(2459),
    [sym_hll_string_literal] = STATE(2459),
    [sym_hll_parenthesized_expression] = STATE(1757),
    [sym_symbol] = STATE(1757),
    [sym_identifier] = ACTIONS(1046),
    [anon_sym_LPAREN] = ACTIONS(1048),
    [anon_sym_PLUS] = ACTIONS(1050),
    [anon_sym_DASH] = ACTIONS(1050),
    [anon_sym_TILDE] = ACTIONS(1052),
    [anon_sym_BANG] = ACTIONS(1050),
    [anon_sym_PLUS_PLUS] = ACTIONS(1054),
    [anon_sym_DASH_DASH] = ACTIONS(1054),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(1056),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(298),
    [sym__blank_line] = ACTIONS(298),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(205)] = {
    [sym__parenthesized_expression] = STATE(2314),
    [sym__path_expression] = STATE(2314),
    [sym_unary_expression] = STATE(2314),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2314),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2314),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2314),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2314),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2314),
    [sym_string] = STATE(2314),
    [sym_character] = STATE(2314),
    [sym_symbol] = STATE(2314),
    [sym__special_command_operator] = STATE(2314),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2314),
    [sym__expression] = STATE(2314),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1088),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1090),
    [sym_time] = ACTIONS(1088),
    [sym_frequency] = ACTIONS(1088),
    [sym_percentage] = ACTIONS(1090),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(206)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2868),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2868),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1092),
    [anon_sym_LPAREN] = ACTIONS(1096),
    [anon_sym_LBRACE] = ACTIONS(1100),
    [anon_sym_PLUS] = ACTIONS(1104),
    [anon_sym_DASH] = ACTIONS(1104),
    [anon_sym_TILDE] = ACTIONS(1108),
    [anon_sym_BANG] = ACTIONS(1108),
    [anon_sym_PLUS_PLUS] = ACTIONS(1112),
    [anon_sym_DASH_DASH] = ACTIONS(1112),
    [anon_sym_STAR] = ACTIONS(1116),
    [anon_sym_AMP] = ACTIONS(1120),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(1124),
    [anon_sym_SQUOTE] = ACTIONS(1128),
    [anon_sym_DQUOTE] = ACTIONS(1132),
    [sym_access_class] = ACTIONS(1136),
    [aux_sym_integer_token1] = ACTIONS(1140),
    [aux_sym_integer_token2] = ACTIONS(1140),
    [sym_float] = ACTIONS(1144),
    [aux_sym_bitmask_token1] = ACTIONS(1148),
    [aux_sym_bitmask_token2] = ACTIONS(1148),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(1152),
    [aux_sym_symbol_token1] = ACTIONS(1156),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(1160),
    [anon_sym_BSLASH] = ACTIONS(1164),
    [aux_sym_symbol_token5] = ACTIONS(1168),
    [sym__composed_name] = ACTIONS(1172),
    [sym_time] = ACTIONS(1144),
    [sym_frequency] = ACTIONS(1144),
    [sym_percentage] = ACTIONS(1172),
    [anon_sym_POUND] = ACTIONS(1176),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(1180),
    [sym_path] = ACTIONS(1184),
  },
  [STATE(207)] = {
    [sym__parenthesized_expression] = STATE(2318),
    [sym__path_expression] = STATE(2318),
    [sym_unary_expression] = STATE(2318),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2318),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2318),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2318),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2318),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2318),
    [sym_string] = STATE(2318),
    [sym_character] = STATE(2318),
    [sym_symbol] = STATE(2318),
    [sym__special_command_operator] = STATE(2318),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2318),
    [sym__expression] = STATE(2318),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1188),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1190),
    [sym_time] = ACTIONS(1188),
    [sym_frequency] = ACTIONS(1188),
    [sym_percentage] = ACTIONS(1190),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(208)] = {
    [sym__parenthesized_expression] = STATE(2346),
    [sym__path_expression] = STATE(2346),
    [sym_unary_expression] = STATE(2346),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2346),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2346),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2346),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2346),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2346),
    [sym_string] = STATE(2346),
    [sym_character] = STATE(2346),
    [sym_symbol] = STATE(2346),
    [sym__special_command_operator] = STATE(2346),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2346),
    [sym__expression] = STATE(2346),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1192),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1194),
    [sym_time] = ACTIONS(1192),
    [sym_frequency] = ACTIONS(1192),
    [sym_percentage] = ACTIONS(1194),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(209)] = {
    [sym__parenthesized_expression] = STATE(2397),
    [sym__path_expression] = STATE(2397),
    [sym_unary_expression] = STATE(2397),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2397),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2397),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2397),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2397),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2397),
    [sym_string] = STATE(2397),
    [sym_character] = STATE(2397),
    [sym_symbol] = STATE(2397),
    [sym__special_command_operator] = STATE(2397),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2397),
    [sym__expression] = STATE(2397),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1196),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1198),
    [sym_time] = ACTIONS(1196),
    [sym_frequency] = ACTIONS(1196),
    [sym_percentage] = ACTIONS(1198),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(210)] = {
    [sym__parenthesized_expression] = STATE(2337),
    [sym__path_expression] = STATE(2337),
    [sym_unary_expression] = STATE(2337),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2337),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2337),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2337),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2337),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2337),
    [sym_string] = STATE(2337),
    [sym_character] = STATE(2337),
    [sym_symbol] = STATE(2337),
    [sym__special_command_operator] = STATE(2337),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2337),
    [sym__expression] = STATE(2337),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1200),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1202),
    [sym_time] = ACTIONS(1200),
    [sym_frequency] = ACTIONS(1200),
    [sym_percentage] = ACTIONS(1202),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(211)] = {
    [sym__parenthesized_expression] = STATE(2338),
    [sym__path_expression] = STATE(2338),
    [sym_unary_expression] = STATE(2338),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2338),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2338),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2338),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2338),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2338),
    [sym_string] = STATE(2338),
    [sym_character] = STATE(2338),
    [sym_symbol] = STATE(2338),
    [sym__special_command_operator] = STATE(2338),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2338),
    [sym__expression] = STATE(2338),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1204),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1206),
    [sym_time] = ACTIONS(1204),
    [sym_frequency] = ACTIONS(1204),
    [sym_percentage] = ACTIONS(1206),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(212)] = {
    [sym__parenthesized_expression] = STATE(2355),
    [sym__path_expression] = STATE(2355),
    [sym_unary_expression] = STATE(2355),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2355),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2355),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2355),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2355),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2355),
    [sym_string] = STATE(2355),
    [sym_character] = STATE(2355),
    [sym_symbol] = STATE(2355),
    [sym__special_command_operator] = STATE(2355),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2355),
    [sym__expression] = STATE(2355),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1208),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1210),
    [sym_time] = ACTIONS(1208),
    [sym_frequency] = ACTIONS(1208),
    [sym_percentage] = ACTIONS(1210),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(213)] = {
    [sym__parenthesized_expression] = STATE(2356),
    [sym__path_expression] = STATE(2356),
    [sym_unary_expression] = STATE(2356),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2356),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2356),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2356),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2356),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2356),
    [sym_string] = STATE(2356),
    [sym_character] = STATE(2356),
    [sym_symbol] = STATE(2356),
    [sym__special_command_operator] = STATE(2356),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2356),
    [sym__expression] = STATE(2356),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1212),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1214),
    [sym_time] = ACTIONS(1212),
    [sym_frequency] = ACTIONS(1212),
    [sym_percentage] = ACTIONS(1214),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(214)] = {
    [sym__parenthesized_expression] = STATE(2361),
    [sym__path_expression] = STATE(2361),
    [sym_unary_expression] = STATE(2361),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2361),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2361),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2361),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2361),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2361),
    [sym_string] = STATE(2361),
    [sym_character] = STATE(2361),
    [sym_symbol] = STATE(2361),
    [sym__special_command_operator] = STATE(2361),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2361),
    [sym__expression] = STATE(2361),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1216),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1218),
    [sym_time] = ACTIONS(1216),
    [sym_frequency] = ACTIONS(1216),
    [sym_percentage] = ACTIONS(1218),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(215)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2540),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2540),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2540),
    [sym__address_expression] = STATE(2840),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2540),
    [sym__parenthesized_address_expression] = STATE(2840),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2540),
    [sym_string] = STATE(2540),
    [sym_character] = STATE(2540),
    [sym_symbol] = STATE(2540),
    [sym__special_command_operator] = STATE(2540),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2540),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1220),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1222),
    [sym_time] = ACTIONS(1220),
    [sym_frequency] = ACTIONS(1220),
    [sym_percentage] = ACTIONS(1222),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(216)] = {
    [sym__parenthesized_expression] = STATE(2541),
    [sym__path_expression] = STATE(2541),
    [sym_unary_expression] = STATE(2541),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2541),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2541),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2541),
    [sym__address_expression] = STATE(2821),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2541),
    [sym__parenthesized_address_expression] = STATE(2821),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2541),
    [sym_string] = STATE(2541),
    [sym_character] = STATE(2541),
    [sym_symbol] = STATE(2541),
    [sym__special_command_operator] = STATE(2541),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2541),
    [sym__expression] = STATE(2541),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1224),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1226),
    [sym_time] = ACTIONS(1224),
    [sym_frequency] = ACTIONS(1224),
    [sym_percentage] = ACTIONS(1226),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(217)] = {
    [sym__parenthesized_expression] = STATE(2317),
    [sym__path_expression] = STATE(2317),
    [sym_unary_expression] = STATE(2317),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2317),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2317),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2317),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2317),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2317),
    [sym_string] = STATE(2317),
    [sym_character] = STATE(2317),
    [sym_symbol] = STATE(2317),
    [sym__special_command_operator] = STATE(2317),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2317),
    [sym__expression] = STATE(2317),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(227),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(229),
    [sym_time] = ACTIONS(227),
    [sym_frequency] = ACTIONS(227),
    [sym_percentage] = ACTIONS(229),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(218)] = {
    [sym__parenthesized_expression] = STATE(2308),
    [sym__path_expression] = STATE(2308),
    [sym_unary_expression] = STATE(2308),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2308),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2308),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2308),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2308),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2308),
    [sym_string] = STATE(2308),
    [sym_character] = STATE(2308),
    [sym_symbol] = STATE(2308),
    [sym__special_command_operator] = STATE(2308),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2308),
    [sym__expression] = STATE(2308),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1228),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1230),
    [sym_time] = ACTIONS(1228),
    [sym_frequency] = ACTIONS(1228),
    [sym_percentage] = ACTIONS(1230),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(219)] = {
    [sym__parenthesized_expression] = STATE(2310),
    [sym__path_expression] = STATE(2310),
    [sym_unary_expression] = STATE(2310),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2310),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2310),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2310),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2310),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2310),
    [sym_string] = STATE(2310),
    [sym_character] = STATE(2310),
    [sym_symbol] = STATE(2310),
    [sym__special_command_operator] = STATE(2310),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2310),
    [sym__expression] = STATE(2310),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1232),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1234),
    [sym_time] = ACTIONS(1232),
    [sym_frequency] = ACTIONS(1232),
    [sym_percentage] = ACTIONS(1234),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(220)] = {
    [sym__parenthesized_expression] = STATE(680),
    [sym__path_expression] = STATE(680),
    [sym_unary_expression] = STATE(680),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(680),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(680),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(680),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(680),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(680),
    [sym_string] = STATE(680),
    [sym_character] = STATE(680),
    [sym_symbol] = STATE(680),
    [sym__special_command_operator] = STATE(680),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(680),
    [sym__expression] = STATE(680),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(680),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1236),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1238),
    [sym_time] = ACTIONS(1236),
    [sym_frequency] = ACTIONS(1236),
    [sym_percentage] = ACTIONS(1238),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1238),
  },
  [STATE(221)] = {
    [sym__parenthesized_expression] = STATE(682),
    [sym__path_expression] = STATE(682),
    [sym_unary_expression] = STATE(682),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(682),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(682),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(682),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(682),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(682),
    [sym_string] = STATE(682),
    [sym_character] = STATE(682),
    [sym_symbol] = STATE(682),
    [sym__special_command_operator] = STATE(682),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(682),
    [sym__expression] = STATE(682),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(682),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1240),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1242),
    [sym_time] = ACTIONS(1240),
    [sym_frequency] = ACTIONS(1240),
    [sym_percentage] = ACTIONS(1242),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1242),
  },
  [STATE(222)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(561),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(561),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(223)] = {
    [sym__parenthesized_expression] = STATE(2629),
    [sym__path_expression] = STATE(2629),
    [sym_unary_expression] = STATE(2629),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2629),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2629),
    [sym_macro] = STATE(374),
    [sym_macro_text_expansion] = STATE(586),
    [sym_call_expression] = STATE(586),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(2629),
    [sym__address_expression] = STATE(568),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2629),
    [sym__parenthesized_address_expression] = STATE(568),
    [sym__address_binary_expression] = STATE(599),
    [sym_integer] = STATE(587),
    [sym_bitmask] = STATE(2629),
    [sym_string] = STATE(2629),
    [sym_character] = STATE(2629),
    [sym_symbol] = STATE(2629),
    [sym__special_command_operator] = STATE(2629),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2629),
    [sym__expression] = STATE(2629),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1058),
    [anon_sym_LPAREN] = ACTIONS(1060),
    [anon_sym_LBRACE] = ACTIONS(51),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(84),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(98),
    [sym_time] = ACTIONS(84),
    [sym_frequency] = ACTIONS(84),
    [sym_percentage] = ACTIONS(98),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(104),
  },
  [STATE(224)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2540),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2540),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2540),
    [sym__address_expression] = STATE(2819),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2540),
    [sym__parenthesized_address_expression] = STATE(2819),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2540),
    [sym_string] = STATE(2540),
    [sym_character] = STATE(2540),
    [sym_symbol] = STATE(2540),
    [sym__special_command_operator] = STATE(2540),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2540),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1220),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1222),
    [sym_time] = ACTIONS(1220),
    [sym_frequency] = ACTIONS(1220),
    [sym_percentage] = ACTIONS(1222),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(225)] = {
    [sym__parenthesized_expression] = STATE(2541),
    [sym__path_expression] = STATE(2541),
    [sym_unary_expression] = STATE(2541),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2541),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2541),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2541),
    [sym__address_expression] = STATE(2830),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2541),
    [sym__parenthesized_address_expression] = STATE(2830),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2541),
    [sym_string] = STATE(2541),
    [sym_character] = STATE(2541),
    [sym_symbol] = STATE(2541),
    [sym__special_command_operator] = STATE(2541),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2541),
    [sym__expression] = STATE(2541),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1224),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1226),
    [sym_time] = ACTIONS(1224),
    [sym_frequency] = ACTIONS(1224),
    [sym_percentage] = ACTIONS(1226),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(226)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2172),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2172),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(227)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2175),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2175),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(228)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2540),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2540),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2540),
    [sym__address_expression] = STATE(2836),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2540),
    [sym__parenthesized_address_expression] = STATE(2836),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2540),
    [sym_string] = STATE(2540),
    [sym_character] = STATE(2540),
    [sym_symbol] = STATE(2540),
    [sym__special_command_operator] = STATE(2540),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2540),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1220),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1222),
    [sym_time] = ACTIONS(1220),
    [sym_frequency] = ACTIONS(1220),
    [sym_percentage] = ACTIONS(1222),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(229)] = {
    [sym__parenthesized_expression] = STATE(2541),
    [sym__path_expression] = STATE(2541),
    [sym_unary_expression] = STATE(2541),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2541),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2541),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2541),
    [sym__address_expression] = STATE(2837),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2541),
    [sym__parenthesized_address_expression] = STATE(2837),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2541),
    [sym_string] = STATE(2541),
    [sym_character] = STATE(2541),
    [sym_symbol] = STATE(2541),
    [sym__special_command_operator] = STATE(2541),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2541),
    [sym__expression] = STATE(2541),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1224),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1226),
    [sym_time] = ACTIONS(1224),
    [sym_frequency] = ACTIONS(1224),
    [sym_percentage] = ACTIONS(1226),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(230)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2177),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2177),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(231)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2182),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2182),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(232)] = {
    [sym__parenthesized_expression] = STATE(2540),
    [sym__path_expression] = STATE(2540),
    [sym_unary_expression] = STATE(2540),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2540),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2540),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2540),
    [sym__address_expression] = STATE(2828),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2540),
    [sym__parenthesized_address_expression] = STATE(2828),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2540),
    [sym_string] = STATE(2540),
    [sym_character] = STATE(2540),
    [sym_symbol] = STATE(2540),
    [sym__special_command_operator] = STATE(2540),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2540),
    [sym__expression] = STATE(2540),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1220),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1222),
    [sym_time] = ACTIONS(1220),
    [sym_frequency] = ACTIONS(1220),
    [sym_percentage] = ACTIONS(1222),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(233)] = {
    [sym__parenthesized_expression] = STATE(2541),
    [sym__path_expression] = STATE(2541),
    [sym_unary_expression] = STATE(2541),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2541),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2541),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2541),
    [sym__address_expression] = STATE(2832),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2541),
    [sym__parenthesized_address_expression] = STATE(2832),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2541),
    [sym_string] = STATE(2541),
    [sym_character] = STATE(2541),
    [sym_symbol] = STATE(2541),
    [sym__special_command_operator] = STATE(2541),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2541),
    [sym__expression] = STATE(2541),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1224),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1226),
    [sym_time] = ACTIONS(1224),
    [sym_frequency] = ACTIONS(1224),
    [sym_percentage] = ACTIONS(1226),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(234)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2161),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2161),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(235)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2185),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2185),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(236)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2876),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2876),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(237)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2805),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2805),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(238)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2878),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2878),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(239)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2852),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2852),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(240)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2866),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2866),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(209),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(211),
    [sym_time] = ACTIONS(209),
    [sym_frequency] = ACTIONS(209),
    [sym_percentage] = ACTIONS(211),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
  [STATE(241)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2858),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2858),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1246),
    [anon_sym_LPAREN] = ACTIONS(1249),
    [anon_sym_LBRACE] = ACTIONS(1252),
    [anon_sym_PLUS] = ACTIONS(1255),
    [anon_sym_DASH] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1258),
    [anon_sym_BANG] = ACTIONS(1258),
    [anon_sym_PLUS_PLUS] = ACTIONS(1261),
    [anon_sym_DASH_DASH] = ACTIONS(1261),
    [anon_sym_STAR] = ACTIONS(1264),
    [anon_sym_AMP] = ACTIONS(1267),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(1270),
    [anon_sym_SQUOTE] = ACTIONS(1273),
    [anon_sym_DQUOTE] = ACTIONS(1276),
    [sym_access_class] = ACTIONS(1279),
    [aux_sym_integer_token1] = ACTIONS(1282),
    [aux_sym_integer_token2] = ACTIONS(1282),
    [sym_float] = ACTIONS(1285),
    [aux_sym_bitmask_token1] = ACTIONS(1288),
    [aux_sym_bitmask_token2] = ACTIONS(1288),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(1291),
    [aux_sym_symbol_token1] = ACTIONS(1294),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(1297),
    [anon_sym_BSLASH] = ACTIONS(1300),
    [aux_sym_symbol_token5] = ACTIONS(1303),
    [sym__composed_name] = ACTIONS(1306),
    [sym_time] = ACTIONS(1285),
    [sym_frequency] = ACTIONS(1285),
    [sym_percentage] = ACTIONS(1306),
    [anon_sym_POUND] = ACTIONS(1309),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(1312),
    [sym_path] = ACTIONS(1315),
  },
  [STATE(242)] = {
    [sym__parenthesized_expression] = STATE(2652),
    [sym__path_expression] = STATE(2652),
    [sym_unary_expression] = STATE(2652),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2652),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2652),
    [sym_macro] = STATE(1811),
    [sym_macro_text_expansion] = STATE(2244),
    [sym_call_expression] = STATE(2244),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2652),
    [sym__address_expression] = STATE(2879),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2652),
    [sym__parenthesized_address_expression] = STATE(2879),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2082),
    [sym_bitmask] = STATE(2652),
    [sym_string] = STATE(2652),
    [sym_character] = STATE(2652),
    [sym_symbol] = STATE(2652),
    [sym__special_command_operator] = STATE(2652),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2652),
    [sym__expression] = STATE(2652),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(1318),
    [anon_sym_LPAREN] = ACTIONS(1321),
    [anon_sym_LBRACE] = ACTIONS(1324),
    [anon_sym_PLUS] = ACTIONS(1327),
    [anon_sym_DASH] = ACTIONS(1327),
    [anon_sym_TILDE] = ACTIONS(1330),
    [anon_sym_BANG] = ACTIONS(1330),
    [anon_sym_PLUS_PLUS] = ACTIONS(1333),
    [anon_sym_DASH_DASH] = ACTIONS(1333),
    [anon_sym_STAR] = ACTIONS(1336),
    [anon_sym_AMP] = ACTIONS(1339),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(1342),
    [anon_sym_SQUOTE] = ACTIONS(1345),
    [anon_sym_DQUOTE] = ACTIONS(1348),
    [sym_access_class] = ACTIONS(1351),
    [aux_sym_integer_token1] = ACTIONS(1354),
    [aux_sym_integer_token2] = ACTIONS(1354),
    [sym_float] = ACTIONS(1357),
    [aux_sym_bitmask_token1] = ACTIONS(1360),
    [aux_sym_bitmask_token2] = ACTIONS(1360),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(1363),
    [aux_sym_symbol_token1] = ACTIONS(1366),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(1369),
    [anon_sym_BSLASH] = ACTIONS(1372),
    [aux_sym_symbol_token5] = ACTIONS(1375),
    [sym__composed_name] = ACTIONS(1378),
    [sym_time] = ACTIONS(1357),
    [sym_frequency] = ACTIONS(1357),
    [sym_percentage] = ACTIONS(1378),
    [anon_sym_POUND] = ACTIONS(1381),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(1384),
    [sym_path] = ACTIONS(1387),
  },
  [STATE(243)] = {
    [sym__hll_expression] = STATE(2293),
    [sym_hll_call_expression] = STATE(1738),
    [sym_hll_field_expression] = STATE(1738),
    [sym_hll_subscript_expression] = STATE(1738),
    [sym_hll_cast_expression] = STATE(2293),
    [sym_hll_sizeof_expression] = STATE(2293),
    [sym_hll_pointer_expression] = STATE(1738),
    [sym_hll_update_expression] = STATE(2293),
    [sym_hll_unary_expression] = STATE(2293),
    [sym_hll_binary_expression] = STATE(2293),
    [sym_hll_assignment_expression] = STATE(2293),
    [sym__hll_assignment_left_expression] = STATE(2870),
    [sym_hll_conditional_expression] = STATE(2293),
    [sym_hll_char_literal] = STATE(2293),
    [sym_hll_string_literal] = STATE(2293),
    [sym_hll_parenthesized_expression] = STATE(1738),
    [sym_symbol] = STATE(1738),
    [sym_identifier] = ACTIONS(1390),
    [anon_sym_LPAREN] = ACTIONS(1392),
    [anon_sym_PLUS] = ACTIONS(1394),
    [anon_sym_DASH] = ACTIONS(1394),
    [anon_sym_TILDE] = ACTIONS(1396),
    [anon_sym_BANG] = ACTIONS(1394),
    [anon_sym_PLUS_PLUS] = ACTIONS(1398),
    [anon_sym_DASH_DASH] = ACTIONS(1398),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(330),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(1400),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(330),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(330),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(244)] = {
    [sym__hll_expression] = STATE(2357),
    [sym_hll_call_expression] = STATE(1738),
    [sym_hll_field_expression] = STATE(1738),
    [sym_hll_subscript_expression] = STATE(1738),
    [sym_hll_cast_expression] = STATE(2357),
    [sym_hll_sizeof_expression] = STATE(2357),
    [sym_hll_pointer_expression] = STATE(1738),
    [sym_hll_update_expression] = STATE(2357),
    [sym_hll_unary_expression] = STATE(2357),
    [sym_hll_binary_expression] = STATE(2357),
    [sym_hll_assignment_expression] = STATE(2357),
    [sym__hll_assignment_left_expression] = STATE(2870),
    [sym_hll_conditional_expression] = STATE(2357),
    [sym_hll_char_literal] = STATE(2357),
    [sym_hll_string_literal] = STATE(2357),
    [sym_hll_parenthesized_expression] = STATE(1738),
    [sym_symbol] = STATE(1738),
    [sym_identifier] = ACTIONS(1390),
    [anon_sym_LPAREN] = ACTIONS(1392),
    [anon_sym_PLUS] = ACTIONS(1394),
    [anon_sym_DASH] = ACTIONS(1394),
    [anon_sym_TILDE] = ACTIONS(1396),
    [anon_sym_BANG] = ACTIONS(1394),
    [anon_sym_PLUS_PLUS] = ACTIONS(1398),
    [anon_sym_DASH_DASH] = ACTIONS(1398),
    [anon_sym_PIPE_PIPE] = ACTIONS(334),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(334),
    [anon_sym_PERCENT] = ACTIONS(334),
    [anon_sym_PIPE] = ACTIONS(336),
    [anon_sym_CARET] = ACTIONS(334),
    [anon_sym_EQ_EQ] = ACTIONS(334),
    [anon_sym_BANG_EQ] = ACTIONS(334),
    [anon_sym_GT] = ACTIONS(336),
    [anon_sym_GT_EQ] = ACTIONS(334),
    [anon_sym_LT_EQ] = ACTIONS(334),
    [anon_sym_LT] = ACTIONS(336),
    [anon_sym_LT_LT] = ACTIONS(334),
    [anon_sym_GT_GT] = ACTIONS(334),
    [anon_sym_AMP_AMP] = ACTIONS(334),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(334),
    [anon_sym_QMARK] = ACTIONS(334),
    [anon_sym_DASH_GT] = ACTIONS(334),
    [anon_sym_LBRACK] = ACTIONS(334),
    [anon_sym_sizeof] = ACTIONS(1400),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(334),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(334),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(245)] = {
    [sym__hll_expression] = STATE(2358),
    [sym_hll_call_expression] = STATE(1738),
    [sym_hll_field_expression] = STATE(1738),
    [sym_hll_subscript_expression] = STATE(1738),
    [sym_hll_cast_expression] = STATE(2358),
    [sym_hll_sizeof_expression] = STATE(2358),
    [sym_hll_pointer_expression] = STATE(1738),
    [sym_hll_update_expression] = STATE(2358),
    [sym_hll_unary_expression] = STATE(2358),
    [sym_hll_binary_expression] = STATE(2358),
    [sym_hll_assignment_expression] = STATE(2358),
    [sym__hll_assignment_left_expression] = STATE(2870),
    [sym_hll_conditional_expression] = STATE(2358),
    [sym_hll_char_literal] = STATE(2358),
    [sym_hll_string_literal] = STATE(2358),
    [sym_hll_parenthesized_expression] = STATE(1738),
    [sym_symbol] = STATE(1738),
    [sym_identifier] = ACTIONS(1390),
    [anon_sym_LPAREN] = ACTIONS(1392),
    [anon_sym_PLUS] = ACTIONS(1394),
    [anon_sym_DASH] = ACTIONS(1394),
    [anon_sym_TILDE] = ACTIONS(1396),
    [anon_sym_BANG] = ACTIONS(1394),
    [anon_sym_PLUS_PLUS] = ACTIONS(1398),
    [anon_sym_DASH_DASH] = ACTIONS(1398),
    [anon_sym_PIPE_PIPE] = ACTIONS(338),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(338),
    [anon_sym_PERCENT] = ACTIONS(338),
    [anon_sym_PIPE] = ACTIONS(340),
    [anon_sym_CARET] = ACTIONS(338),
    [anon_sym_EQ_EQ] = ACTIONS(338),
    [anon_sym_BANG_EQ] = ACTIONS(338),
    [anon_sym_GT] = ACTIONS(340),
    [anon_sym_GT_EQ] = ACTIONS(338),
    [anon_sym_LT_EQ] = ACTIONS(338),
    [anon_sym_LT] = ACTIONS(340),
    [anon_sym_LT_LT] = ACTIONS(338),
    [anon_sym_GT_GT] = ACTIONS(338),
    [anon_sym_AMP_AMP] = ACTIONS(338),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(338),
    [anon_sym_QMARK] = ACTIONS(338),
    [anon_sym_DASH_GT] = ACTIONS(338),
    [anon_sym_LBRACK] = ACTIONS(338),
    [anon_sym_sizeof] = ACTIONS(1400),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(338),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(338),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(246)] = {
    [sym__hll_expression] = STATE(2382),
    [sym_hll_call_expression] = STATE(1738),
    [sym_hll_field_expression] = STATE(1738),
    [sym_hll_subscript_expression] = STATE(1738),
    [sym_hll_cast_expression] = STATE(2382),
    [sym_hll_sizeof_expression] = STATE(2382),
    [sym_hll_pointer_expression] = STATE(1738),
    [sym_hll_update_expression] = STATE(2382),
    [sym_hll_unary_expression] = STATE(2382),
    [sym_hll_binary_expression] = STATE(2382),
    [sym_hll_assignment_expression] = STATE(2382),
    [sym__hll_assignment_left_expression] = STATE(2870),
    [sym_hll_conditional_expression] = STATE(2382),
    [sym_hll_char_literal] = STATE(2382),
    [sym_hll_string_literal] = STATE(2382),
    [sym_hll_parenthesized_expression] = STATE(1738),
    [sym_symbol] = STATE(1738),
    [sym_identifier] = ACTIONS(1390),
    [anon_sym_LPAREN] = ACTIONS(1392),
    [anon_sym_PLUS] = ACTIONS(1394),
    [anon_sym_DASH] = ACTIONS(1394),
    [anon_sym_TILDE] = ACTIONS(1396),
    [anon_sym_BANG] = ACTIONS(1394),
    [anon_sym_PLUS_PLUS] = ACTIONS(1398),
    [anon_sym_DASH_DASH] = ACTIONS(1398),
    [anon_sym_PIPE_PIPE] = ACTIONS(298),
    [anon_sym_STAR] = ACTIONS(876),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(298),
    [anon_sym_PIPE] = ACTIONS(302),
    [anon_sym_CARET] = ACTIONS(298),
    [anon_sym_EQ_EQ] = ACTIONS(298),
    [anon_sym_BANG_EQ] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_GT_EQ] = ACTIONS(298),
    [anon_sym_LT_EQ] = ACTIONS(298),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_LT_LT] = ACTIONS(298),
    [anon_sym_GT_GT] = ACTIONS(298),
    [anon_sym_AMP_AMP] = ACTIONS(298),
    [anon_sym_AMP] = ACTIONS(450),
    [anon_sym_DOT] = ACTIONS(298),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_DASH_GT] = ACTIONS(298),
    [anon_sym_LBRACK] = ACTIONS(298),
    [anon_sym_sizeof] = ACTIONS(1400),
    [anon_sym_L_SQUOTE] = ACTIONS(880),
    [anon_sym_u_SQUOTE] = ACTIONS(880),
    [anon_sym_U_SQUOTE] = ACTIONS(880),
    [anon_sym_u8_SQUOTE] = ACTIONS(880),
    [anon_sym_SQUOTE] = ACTIONS(880),
    [anon_sym_L_DQUOTE] = ACTIONS(882),
    [anon_sym_u_DQUOTE] = ACTIONS(882),
    [anon_sym_U_DQUOTE] = ACTIONS(882),
    [anon_sym_u8_DQUOTE] = ACTIONS(882),
    [anon_sym_DQUOTE] = ACTIONS(882),
    [aux_sym__hll_expression_separator_token1] = ACTIONS(298),
    [aux_sym__hll_expression_separator_token2] = ACTIONS(298),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(458),
    [aux_sym_symbol_token1] = ACTIONS(460),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(462),
    [anon_sym_BSLASH] = ACTIONS(464),
    [aux_sym_symbol_token5] = ACTIONS(466),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(884),
  },
  [STATE(247)] = {
    [sym__hll_expression] = STATE(2488),
    [sym_hll_call_expression] = STATE(1757),
    [sym_hll_field_expression] = STATE(1757),
    [sym_hll_subscript_expression] = STATE(1757),
    [sym_hll_cast_expression] = STATE(2488),
    [sym_hll_sizeof_expression] = STATE(2488),
    [sym_hll_pointer_expression] = STATE(1757),
    [sym_hll_update_expression] = STATE(2488),
    [sym_hll_unary_expression] = STATE(2488),
    [sym_hll_binary_expression] = STATE(2488),
    [sym_hll_assignment_expression] = STATE(2488),
    [sym__hll_assignment_left_expression] = STATE(2850),
    [sym_hll_conditional_expression] = STATE(2488),
    [sym_hll_char_literal] = STATE(2488),
    [sym_hll_string_literal] = STATE(2488),
    [sym_hll_parenthesized_expression] = STATE(1757),
    [sym_symbol] = STATE(1757),
    [sym_identifier] = ACTIONS(1046),
    [anon_sym_LPAREN] = ACTIONS(1048),
    [anon_sym_PLUS] = ACTIONS(1050),
    [anon_sym_DASH] = ACTIONS(1050),
    [anon_sym_TILDE] = ACTIONS(1052),
    [anon_sym_BANG] = ACTIONS(1050),
    [anon_sym_PLUS_PLUS] = ACTIONS(1054),
    [anon_sym_DASH_DASH] = ACTIONS(1054),
    [anon_sym_PIPE_PIPE] = ACTIONS(330),
    [anon_sym_STAR] = ACTIONS(920),
    [anon_sym_SLASH] = ACTIONS(332),
    [anon_sym_PERCENT] = ACTIONS(330),
    [anon_sym_PIPE] = ACTIONS(332),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_EQ_EQ] = ACTIONS(330),
    [anon_sym_BANG_EQ] = ACTIONS(330),
    [anon_sym_GT] = ACTIONS(332),
    [anon_sym_GT_EQ] = ACTIONS(330),
    [anon_sym_LT_EQ] = ACTIONS(330),
    [anon_sym_LT] = ACTIONS(332),
    [anon_sym_LT_LT] = ACTIONS(330),
    [anon_sym_GT_GT] = ACTIONS(330),
    [anon_sym_AMP_AMP] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(420),
    [anon_sym_DOT] = ACTIONS(330),
    [anon_sym_QMARK] = ACTIONS(330),
    [anon_sym_DASH_GT] = ACTIONS(330),
    [anon_sym_LBRACK] = ACTIONS(330),
    [anon_sym_sizeof] = ACTIONS(1056),
    [anon_sym_L_SQUOTE] = ACTIONS(632),
    [anon_sym_u_SQUOTE] = ACTIONS(632),
    [anon_sym_U_SQUOTE] = ACTIONS(632),
    [anon_sym_u8_SQUOTE] = ACTIONS(632),
    [anon_sym_SQUOTE] = ACTIONS(632),
    [anon_sym_L_DQUOTE] = ACTIONS(634),
    [anon_sym_u_DQUOTE] = ACTIONS(634),
    [anon_sym_U_DQUOTE] = ACTIONS(634),
    [anon_sym_u8_DQUOTE] = ACTIONS(634),
    [anon_sym_DQUOTE] = ACTIONS(634),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(428),
    [aux_sym_symbol_token1] = ACTIONS(430),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(432),
    [anon_sym_BSLASH] = ACTIONS(434),
    [aux_sym_symbol_token5] = ACTIONS(436),
    [sym_comment] = ACTIONS(330),
    [sym__blank_line] = ACTIONS(330),
    [sym__line_continuation] = ACTIONS(3),
    [sym__hll_number_literal_pre_hook] = ACTIONS(636),
  },
  [STATE(248)] = {
    [sym__parenthesized_expression] = STATE(2408),
    [sym__path_expression] = STATE(2408),
    [sym_unary_expression] = STATE(2408),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2408),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2408),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2408),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2408),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2408),
    [sym_string] = STATE(2408),
    [sym_character] = STATE(2408),
    [sym_symbol] = STATE(2408),
    [sym__special_command_operator] = STATE(2408),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2408),
    [sym__expression] = STATE(2408),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1402),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1404),
    [sym_time] = ACTIONS(1402),
    [sym_frequency] = ACTIONS(1402),
    [sym_percentage] = ACTIONS(1404),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(249)] = {
    [sym__parenthesized_expression] = STATE(2253),
    [sym__path_expression] = STATE(2253),
    [sym_unary_expression] = STATE(2253),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2253),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2253),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2253),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2253),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2253),
    [sym_string] = STATE(2253),
    [sym_character] = STATE(2253),
    [sym_symbol] = STATE(2253),
    [sym__special_command_operator] = STATE(2253),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2253),
    [sym__expression] = STATE(2253),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1406),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1408),
    [sym_time] = ACTIONS(1406),
    [sym_frequency] = ACTIONS(1406),
    [sym_percentage] = ACTIONS(1408),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(250)] = {
    [sym__parenthesized_expression] = STATE(2412),
    [sym__path_expression] = STATE(2412),
    [sym_unary_expression] = STATE(2412),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2412),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2412),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2412),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2412),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2412),
    [sym_string] = STATE(2412),
    [sym_character] = STATE(2412),
    [sym_symbol] = STATE(2412),
    [sym__special_command_operator] = STATE(2412),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2412),
    [sym__expression] = STATE(2412),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(1410),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(1412),
    [sym_time] = ACTIONS(1410),
    [sym_frequency] = ACTIONS(1410),
    [sym_percentage] = ACTIONS(1412),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(251)] = {
    [sym__parenthesized_expression] = STATE(705),
    [sym__path_expression] = STATE(705),
    [sym_unary_expression] = STATE(705),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(705),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(705),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(705),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(705),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(705),
    [sym_string] = STATE(705),
    [sym_character] = STATE(705),
    [sym_symbol] = STATE(705),
    [sym__special_command_operator] = STATE(705),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(705),
    [sym__expression] = STATE(705),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(705),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1414),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1416),
    [sym_time] = ACTIONS(1414),
    [sym_frequency] = ACTIONS(1414),
    [sym_percentage] = ACTIONS(1416),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1416),
  },
  [STATE(252)] = {
    [sym__parenthesized_expression] = STATE(2410),
    [sym__path_expression] = STATE(2410),
    [sym_unary_expression] = STATE(2410),
    [sym__unary_expression] = STATE(2597),
    [sym__prefix_postfix_expression] = STATE(2595),
    [sym_binary_expression] = STATE(2410),
    [sym__binary_expression] = STATE(2598),
    [sym__and_expression] = STATE(2542),
    [sym_assignment_expression] = STATE(2410),
    [sym_macro] = STATE(1803),
    [sym_macro_text_expansion] = STATE(2089),
    [sym_call_expression] = STATE(2089),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2410),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(253),
    [sym_address] = STATE(2410),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2125),
    [sym_bitmask] = STATE(2410),
    [sym_string] = STATE(2410),
    [sym_character] = STATE(2410),
    [sym_symbol] = STATE(2410),
    [sym__special_command_operator] = STATE(2410),
    [sym__file_dialog] = STATE(2601),
    [sym_file_handle] = STATE(2410),
    [sym__expression] = STATE(2410),
    [aux_sym__path_expression_repeat1] = STATE(2279),
    [aux_sym__path_expression_repeat2] = STATE(2233),
    [sym_identifier] = ACTIONS(152),
    [anon_sym_LPAREN] = ACTIONS(154),
    [anon_sym_LBRACE] = ACTIONS(156),
    [anon_sym_PLUS] = ACTIONS(158),
    [anon_sym_DASH] = ACTIONS(158),
    [anon_sym_TILDE] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(160),
    [anon_sym_PLUS_PLUS] = ACTIONS(162),
    [anon_sym_DASH_DASH] = ACTIONS(162),
    [anon_sym_STAR] = ACTIONS(164),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(168),
    [anon_sym_DQUOTE] = ACTIONS(170),
    [sym_access_class] = ACTIONS(172),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(176),
    [aux_sym_bitmask_token1] = ACTIONS(178),
    [aux_sym_bitmask_token2] = ACTIONS(178),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(180),
    [aux_sym_symbol_token1] = ACTIONS(182),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(184),
    [anon_sym_BSLASH] = ACTIONS(186),
    [aux_sym_symbol_token5] = ACTIONS(188),
    [sym__composed_name] = ACTIONS(190),
    [sym_time] = ACTIONS(176),
    [sym_frequency] = ACTIONS(176),
    [sym_percentage] = ACTIONS(190),
    [anon_sym_POUND] = ACTIONS(192),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(196),
  },
  [STATE(253)] = {
    [sym__parenthesized_expression] = STATE(2661),
    [sym__path_expression] = STATE(2661),
    [sym_unary_expression] = STATE(2661),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2661),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2661),
    [sym_macro] = STATE(1818),
    [sym_macro_text_expansion] = STATE(2250),
    [sym_call_expression] = STATE(2250),
    [sym__function_identifier] = STATE(4090),
    [sym__hll_var_call_expression_function] = STATE(3988),
    [sym__hll_var_call_expression] = STATE(2093),
    [sym__literal] = STATE(2661),
    [sym__address_expression] = STATE(2122),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2661),
    [sym__parenthesized_address_expression] = STATE(2122),
    [sym__address_binary_expression] = STATE(2243),
    [sym_integer] = STATE(2166),
    [sym_bitmask] = STATE(2661),
    [sym_string] = STATE(2661),
    [sym_character] = STATE(2661),
    [sym_symbol] = STATE(2661),
    [sym__special_command_operator] = STATE(2661),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2661),
    [sym__expression] = STATE(2661),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(231),
    [anon_sym_LPAREN] = ACTIONS(1244),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(62),
    [anon_sym_DASH] = ACTIONS(62),
    [anon_sym_TILDE] = ACTIONS(60),
    [anon_sym_BANG] = ACTIONS(60),
    [anon_sym_PLUS_PLUS] = ACTIONS(242),
    [anon_sym_DASH_DASH] = ACTIONS(242),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(166),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(174),
    [aux_sym_integer_token2] = ACTIONS(174),
    [sym_float] = ACTIONS(238),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(240),
    [sym_time] = ACTIONS(238),
    [sym_frequency] = ACTIONS(238),
    [sym_percentage] = ACTIONS(240),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(194),
    [sym_path] = ACTIONS(104),
  },
  [STATE(254)] = {
    [sym__parenthesized_expression] = STATE(708),
    [sym__path_expression] = STATE(708),
    [sym_unary_expression] = STATE(708),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(708),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(708),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(708),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(708),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(708),
    [sym_string] = STATE(708),
    [sym_character] = STATE(708),
    [sym_symbol] = STATE(708),
    [sym__special_command_operator] = STATE(708),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(708),
    [sym__expression] = STATE(708),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(708),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1418),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1420),
    [sym_time] = ACTIONS(1418),
    [sym_frequency] = ACTIONS(1418),
    [sym_percentage] = ACTIONS(1420),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1420),
  },
  [STATE(255)] = {
    [sym__parenthesized_expression] = STATE(709),
    [sym__path_expression] = STATE(709),
    [sym_unary_expression] = STATE(709),
    [sym__unary_expression] = STATE(958),
    [sym__prefix_postfix_expression] = STATE(960),
    [sym_binary_expression] = STATE(709),
    [sym__binary_expression] = STATE(961),
    [sym__and_expression] = STATE(963),
    [sym_assignment_expression] = STATE(709),
    [sym_macro] = STATE(354),
    [sym_macro_text_expansion] = STATE(523),
    [sym_call_expression] = STATE(523),
    [sym__function_identifier] = STATE(3994),
    [sym__hll_var_call_expression_function] = STATE(3996),
    [sym__hll_var_call_expression] = STATE(524),
    [sym__literal] = STATE(709),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(222),
    [sym_address] = STATE(709),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(526),
    [sym_bitmask] = STATE(709),
    [sym_string] = STATE(709),
    [sym_character] = STATE(709),
    [sym_symbol] = STATE(709),
    [sym__special_command_operator] = STATE(709),
    [sym__file_dialog] = STATE(855),
    [sym_file_handle] = STATE(709),
    [sym__expression] = STATE(709),
    [aux_sym__path_expression_repeat1] = STATE(650),
    [aux_sym__path_expression_repeat2] = STATE(709),
    [sym_identifier] = ACTIONS(106),
    [anon_sym_LPAREN] = ACTIONS(108),
    [anon_sym_LBRACE] = ACTIONS(110),
    [anon_sym_PLUS] = ACTIONS(116),
    [anon_sym_DASH] = ACTIONS(116),
    [anon_sym_TILDE] = ACTIONS(118),
    [anon_sym_BANG] = ACTIONS(118),
    [anon_sym_PLUS_PLUS] = ACTIONS(120),
    [anon_sym_DASH_DASH] = ACTIONS(120),
    [anon_sym_STAR] = ACTIONS(122),
    [anon_sym_AMP] = ACTIONS(698),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(128),
    [anon_sym_DQUOTE] = ACTIONS(130),
    [sym_access_class] = ACTIONS(132),
    [aux_sym_integer_token1] = ACTIONS(82),
    [aux_sym_integer_token2] = ACTIONS(82),
    [sym_float] = ACTIONS(1422),
    [aux_sym_bitmask_token1] = ACTIONS(136),
    [aux_sym_bitmask_token2] = ACTIONS(136),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(138),
    [aux_sym_symbol_token1] = ACTIONS(140),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(142),
    [anon_sym_BSLASH] = ACTIONS(144),
    [aux_sym_symbol_token5] = ACTIONS(146),
    [sym__composed_name] = ACTIONS(1424),
    [sym_time] = ACTIONS(1422),
    [sym_frequency] = ACTIONS(1422),
    [sym_percentage] = ACTIONS(1424),
    [anon_sym_POUND] = ACTIONS(150),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(102),
    [sym_path] = ACTIONS(1424),
  },
  [STATE(256)] = {
    [sym__parenthesized_expression] = STATE(2336),
    [sym__path_expression] = STATE(2336),
    [sym_unary_expression] = STATE(2336),
    [sym__unary_expression] = STATE(2604),
    [sym__prefix_postfix_expression] = STATE(2605),
    [sym_binary_expression] = STATE(2336),
    [sym__binary_expression] = STATE(2606),
    [sym__and_expression] = STATE(2607),
    [sym_assignment_expression] = STATE(2336),
    [sym_macro] = STATE(1817),
    [sym_macro_text_expansion] = STATE(2160),
    [sym_call_expression] = STATE(2160),
    [sym__function_identifier] = STATE(4095),
    [sym__hll_var_call_expression_function] = STATE(4098),
    [sym__hll_var_call_expression] = STATE(2249),
    [sym__literal] = STATE(2336),
    [sym__address_expression] = STATE(2869),
    [sym_memory_space] = STATE(200),
    [sym_address] = STATE(2336),
    [sym__parenthesized_address_expression] = STATE(2869),
    [sym__address_binary_expression] = STATE(2814),
    [sym_integer] = STATE(2162),
    [sym_bitmask] = STATE(2336),
    [sym_string] = STATE(2336),
    [sym_character] = STATE(2336),
    [sym_symbol] = STATE(2336),
    [sym__special_command_operator] = STATE(2336),
    [sym__file_dialog] = STATE(2611),
    [sym_file_handle] = STATE(2336),
    [sym__expression] = STATE(2336),
    [aux_sym__path_expression_repeat1] = STATE(2352),
    [aux_sym__path_expression_repeat2] = STATE(2096),
    [sym_identifier] = ACTIONS(198),
    [anon_sym_LPAREN] = ACTIONS(215),
    [anon_sym_LBRACE] = ACTIONS(217),
    [anon_sym_PLUS] = ACTIONS(219),
    [anon_sym_DASH] = ACTIONS(219),
    [anon_sym_TILDE] = ACTIONS(221),
    [anon_sym_BANG] = ACTIONS(221),
    [anon_sym_PLUS_PLUS] = ACTIONS(223),
    [anon_sym_DASH_DASH] = ACTIONS(223),
    [anon_sym_STAR] = ACTIONS(225),
    [anon_sym_AMP] = ACTIONS(205),
    [aux_sym__hll_non_default_format_var_command_token1] = ACTIONS(126),
    [anon_sym_SQUOTE] = ACTIONS(76),
    [anon_sym_DQUOTE] = ACTIONS(78),
    [sym_access_class] = ACTIONS(80),
    [aux_sym_integer_token1] = ACTIONS(207),
    [aux_sym_integer_token2] = ACTIONS(207),
    [sym_float] = ACTIONS(1426),
    [aux_sym_bitmask_token1] = ACTIONS(86),
    [aux_sym_bitmask_token2] = ACTIONS(86),
    [anon_sym_BSLASH_BSLASH_BSLASH] = ACTIONS(88),
    [aux_sym_symbol_token1] = ACTIONS(90),
    [anon_sym_BSLASH_BSLASH] = ACTIONS(92),
    [anon_sym_BSLASH] = ACTIONS(94),
    [aux_sym_symbol_token5] = ACTIONS(96),
    [sym__composed_name] = ACTIONS(1428),
    [sym_time] = ACTIONS(1426),
    [sym_frequency] = ACTIONS(1426),
    [sym_percentage] = ACTIONS(1428),
    [anon_sym_POUND] = ACTIONS(100),
    [sym__line_continuation] = ACTIONS(3),
    [sym__decimal_number_pre_hook] = ACTIONS(213),
    [sym_path] = ACTIONS(104),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1430), 1,
      anon_sym_RPAREN,
    ACTIONS(1434), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(319), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1432), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(258), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [147] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1436), 1,
      anon_sym_RPAREN,
    ACTIONS(1440), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(323), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1438), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(261), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [294] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1436), 1,
      anon_sym_RPAREN,
    ACTIONS(1440), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(323), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1442), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(263), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [441] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1444), 1,
      ts_builtin_sym_end,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1446), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(262), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_script_repeat1,
  [588] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1451), 1,
      aux_sym_block_token1,
    ACTIONS(1454), 1,
      anon_sym_RPAREN,
    ACTIONS(1456), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(1459), 1,
      aux_sym_if_block_token1,
    ACTIONS(1462), 1,
      aux_sym_while_block_token1,
    ACTIONS(1465), 1,
      aux_sym_while_block_token2,
    ACTIONS(1468), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1471), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1474), 1,
      anon_sym_AMP,
    ACTIONS(1477), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(1483), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(1486), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(1492), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(1495), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1501), 1,
      sym__blank,
    ACTIONS(1504), 1,
      sym_label_identifier,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(1480), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1498), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1489), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(261), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [735] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1507), 1,
      ts_builtin_sym_end,
    ACTIONS(1509), 1,
      sym_identifier,
    ACTIONS(1512), 1,
      aux_sym_block_token1,
    ACTIONS(1515), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(1518), 1,
      aux_sym_if_block_token1,
    ACTIONS(1521), 1,
      aux_sym_while_block_token1,
    ACTIONS(1524), 1,
      aux_sym_while_block_token2,
    ACTIONS(1527), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1530), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1533), 1,
      anon_sym_AMP,
    ACTIONS(1536), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(1542), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(1545), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(1551), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(1554), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(1560), 1,
      sym__blank,
    ACTIONS(1563), 1,
      sym_label_identifier,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(1539), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1557), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1548), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(262), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_script_repeat1,
  [882] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1566), 1,
      anon_sym_RPAREN,
    ACTIONS(1568), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(318), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1438), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(261), 14,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
      aux_sym_block_repeat2,
  [1029] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(301), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1570), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2624), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1175] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(269), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1574), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2224), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1321] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(270), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1576), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2624), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1467] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(282), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1580), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2637), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1613] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(272), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1582), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2640), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1759] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2170), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [1905] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2664), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2051] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(273), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1586), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2126), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2197] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2670), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2343] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2092), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2489] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(275), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1590), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2637), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2635] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2659), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2781] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(277), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1592), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2682), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [2927] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2695), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3073] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(287), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1594), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2543), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3219] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(280), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1596), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2178), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3365] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2180), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3511] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(306), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1598), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2640), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3657] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2659), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3803] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2075), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [3949] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(286), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1600), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2624), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4095] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2695), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4241] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2664), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4387] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2585), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4533] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(289), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1602), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2543), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4679] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2585), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4825] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(292), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1604), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2624), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [4971] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(293), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1606), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2640), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5117] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2664), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5263] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2670), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5409] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(295), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1608), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2637), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5555] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2659), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5701] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(299), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1610), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2543), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5847] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(298), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1612), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2543), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [5993] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2585), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6139] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1578), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(334), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2585), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6285] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(302), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1614), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2640), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6431] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2664), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6577] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2670), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6723] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(304), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1616), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2637), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [6869] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1572), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(341), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2659), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [7015] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(283), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1618), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2152), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [7161] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(41), 1,
      sym__blank,
    ACTIONS(43), 1,
      sym_label_identifier,
    STATE(316), 1,
      sym__label,
    STATE(332), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1584), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2670), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [7307] = 43,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1588), 1,
      sym__blank,
    STATE(285), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(313), 1,
      sym__label,
    STATE(336), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(1620), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2682), 13,
      sym_block,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [7453] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(1622), 1,
      sym_identifier,
    ACTIONS(1629), 1,
      anon_sym_AMP,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(1634), 1,
      aux_sym_symbol_token1,
    ACTIONS(1636), 1,
      aux_sym_symbol_token2,
    ACTIONS(1638), 1,
      anon_sym_BSLASH,
    ACTIONS(1640), 1,
      aux_sym_symbol_token3,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    STATE(399), 1,
      sym_macro,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(562), 1,
      sym_string,
    STATE(567), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_macro_definition_token1,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [7543] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1644), 1,
      sym_identifier,
    ACTIONS(1651), 1,
      anon_sym_AMP,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(1656), 1,
      aux_sym_symbol_token1,
    ACTIONS(1658), 1,
      aux_sym_symbol_token2,
    ACTIONS(1660), 1,
      anon_sym_BSLASH,
    ACTIONS(1662), 1,
      aux_sym_symbol_token3,
    STATE(381), 1,
      sym_macro,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(597), 1,
      sym_string,
    STATE(603), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_macro_definition_token1,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [7633] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1664), 1,
      sym_identifier,
    ACTIONS(1671), 1,
      anon_sym_AMP,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1676), 1,
      aux_sym_symbol_token1,
    ACTIONS(1678), 1,
      aux_sym_symbol_token2,
    ACTIONS(1680), 1,
      anon_sym_BSLASH,
    ACTIONS(1682), 1,
      aux_sym_symbol_token3,
    STATE(425), 1,
      sym_macro,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    STATE(553), 1,
      sym_macro_text_expansion,
    STATE(564), 1,
      sym_string,
    ACTIONS(1667), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_macro_definition_token1,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [7723] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1684), 1,
      sym_identifier,
    ACTIONS(1691), 1,
      anon_sym_AMP,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(1696), 1,
      aux_sym_symbol_token1,
    ACTIONS(1698), 1,
      aux_sym_symbol_token2,
    ACTIONS(1700), 1,
      anon_sym_BSLASH,
    ACTIONS(1702), 1,
      aux_sym_symbol_token3,
    STATE(392), 1,
      sym_macro,
    STATE(466), 1,
      sym_string,
    STATE(581), 1,
      sym_macro_text_expansion,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_macro_definition_token1,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [7813] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1704), 1,
      sym_identifier,
    ACTIONS(1711), 1,
      anon_sym_AMP,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1716), 1,
      aux_sym_symbol_token1,
    ACTIONS(1718), 1,
      aux_sym_symbol_token2,
    ACTIONS(1720), 1,
      anon_sym_BSLASH,
    ACTIONS(1722), 1,
      aux_sym_symbol_token3,
    STATE(436), 1,
      sym_macro,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(584), 1,
      sym_macro_text_expansion,
    STATE(589), 1,
      sym_string,
    ACTIONS(1707), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_macro_definition_token1,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [7903] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1724), 1,
      sym_comment,
    ACTIONS(1726), 1,
      sym__blank_line,
    ACTIONS(1728), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(349), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2666), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8044] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1724), 1,
      sym_comment,
    ACTIONS(1726), 1,
      sym__blank_line,
    ACTIONS(1730), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(344), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2666), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8185] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1724), 1,
      sym_comment,
    ACTIONS(1726), 1,
      sym__blank_line,
    ACTIONS(1732), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(347), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2666), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8326] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1724), 1,
      sym_comment,
    ACTIONS(1726), 1,
      sym__blank_line,
    ACTIONS(1734), 1,
      sym__blank,
    STATE(316), 1,
      sym__label,
    STATE(345), 1,
      aux_sym_block_repeat1,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2666), 12,
      sym__statement,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8467] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1738), 1,
      anon_sym_AMP,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(1745), 1,
      aux_sym_symbol_token1,
    ACTIONS(1747), 1,
      aux_sym_symbol_token2,
    ACTIONS(1749), 1,
      anon_sym_BSLASH,
    ACTIONS(1751), 1,
      aux_sym_symbol_token3,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    STATE(492), 1,
      sym_macro,
    STATE(832), 1,
      sym_string,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(1007), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [8555] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1757), 1,
      anon_sym_RPAREN,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8695] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1436), 1,
      anon_sym_RPAREN,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [8835] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1761), 1,
      anon_sym_AMP,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(1766), 1,
      aux_sym_symbol_token1,
    ACTIONS(1768), 1,
      aux_sym_symbol_token2,
    ACTIONS(1770), 1,
      anon_sym_BSLASH,
    ACTIONS(1772), 1,
      aux_sym_symbol_token3,
    STATE(463), 1,
      sym_macro,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(934), 1,
      sym_string,
    STATE(971), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [8923] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1774), 1,
      anon_sym_AMP,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(1779), 1,
      aux_sym_symbol_token1,
    ACTIONS(1781), 1,
      aux_sym_symbol_token2,
    ACTIONS(1783), 1,
      anon_sym_BSLASH,
    ACTIONS(1785), 1,
      aux_sym_symbol_token3,
    STATE(485), 1,
      sym_macro,
    STATE(919), 1,
      sym_macro_text_expansion,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    STATE(1016), 1,
      sym_string,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [9011] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1787), 1,
      anon_sym_AMP,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(1792), 1,
      aux_sym_symbol_token1,
    ACTIONS(1794), 1,
      aux_sym_symbol_token2,
    ACTIONS(1796), 1,
      anon_sym_BSLASH,
    ACTIONS(1798), 1,
      aux_sym_symbol_token3,
    STATE(510), 1,
      sym_macro,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(837), 1,
      sym_string,
    STATE(839), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [9099] = 42,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1566), 1,
      anon_sym_RPAREN,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [9239] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1800), 1,
      anon_sym_AMP,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(1805), 1,
      aux_sym_symbol_token1,
    ACTIONS(1807), 1,
      aux_sym_symbol_token2,
    ACTIONS(1809), 1,
      anon_sym_BSLASH,
    ACTIONS(1811), 1,
      aux_sym_symbol_token3,
    STATE(476), 1,
      sym_macro,
    STATE(1026), 1,
      sym_string,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    STATE(1038), 1,
      sym_macro_text_expansion,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [9327] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1759), 1,
      sym__blank,
    ACTIONS(1813), 1,
      anon_sym_EQ,
    STATE(314), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [9464] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1817), 1,
      anon_sym_AMP,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(1824), 1,
      aux_sym_symbol_token1,
    ACTIONS(1826), 1,
      aux_sym_symbol_token2,
    ACTIONS(1828), 1,
      anon_sym_BSLASH,
    ACTIONS(1830), 1,
      aux_sym_symbol_token3,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    STATE(620), 1,
      sym_macro,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    STATE(1069), 1,
      sym_macro_text_expansion,
    STATE(1070), 1,
      sym_string,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [9551] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1834), 1,
      anon_sym_AMP,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(1839), 1,
      aux_sym_symbol_token1,
    ACTIONS(1841), 1,
      aux_sym_symbol_token2,
    ACTIONS(1843), 1,
      anon_sym_BSLASH,
    ACTIONS(1845), 1,
      aux_sym_symbol_token3,
    STATE(664), 1,
      sym_macro,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(1104), 1,
      sym_string,
    STATE(1105), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [9638] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1847), 1,
      anon_sym_AMP,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(1852), 1,
      aux_sym_symbol_token1,
    ACTIONS(1854), 1,
      aux_sym_symbol_token2,
    ACTIONS(1856), 1,
      anon_sym_BSLASH,
    ACTIONS(1858), 1,
      aux_sym_symbol_token3,
    STATE(634), 1,
      sym_macro,
    STATE(1088), 1,
      sym_macro_text_expansion,
    STATE(1089), 1,
      sym_string,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [9725] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1759), 1,
      sym__blank,
    ACTIONS(1813), 1,
      anon_sym_EQ,
    STATE(316), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [9862] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1860), 1,
      anon_sym_AMP,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(1865), 1,
      aux_sym_symbol_token1,
    ACTIONS(1867), 1,
      aux_sym_symbol_token2,
    ACTIONS(1869), 1,
      anon_sym_BSLASH,
    ACTIONS(1871), 1,
      aux_sym_symbol_token3,
    STATE(625), 1,
      sym_macro,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(1078), 1,
      sym_macro_text_expansion,
    STATE(1080), 1,
      sym_string,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [9949] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1873), 1,
      anon_sym_AMP,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(1878), 1,
      aux_sym_symbol_token1,
    ACTIONS(1880), 1,
      aux_sym_symbol_token2,
    ACTIONS(1882), 1,
      anon_sym_BSLASH,
    ACTIONS(1884), 1,
      aux_sym_symbol_token3,
    STATE(649), 1,
      sym_macro,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(1095), 1,
      sym_string,
    STATE(1098), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [10036] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(316), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [10173] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1886), 1,
      sym_identifier,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    STATE(338), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1890), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
  [10240] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [10377] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(339), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1894), 27,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [10440] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [10577] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1759), 1,
      sym__blank,
    ACTIONS(1813), 1,
      anon_sym_EQ,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [10714] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(339), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1898), 27,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [10777] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1902), 1,
      sym_identifier,
    ACTIONS(1909), 1,
      anon_sym_AMP,
    STATE(339), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1907), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
  [10844] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1759), 1,
      sym__blank,
    ACTIONS(1813), 1,
      anon_sym_EQ,
    STATE(313), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [10981] = 41,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [11118] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1704), 1,
      sym_identifier,
    ACTIONS(1711), 1,
      anon_sym_AMP,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1912), 1,
      aux_sym_symbol_token1,
    ACTIONS(1914), 1,
      aux_sym_symbol_token2,
    ACTIONS(1916), 1,
      anon_sym_BSLASH,
    STATE(431), 1,
      sym_macro,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(579), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [11196] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1664), 1,
      sym_identifier,
    ACTIONS(1671), 1,
      anon_sym_AMP,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1918), 1,
      aux_sym_symbol_token1,
    ACTIONS(1920), 1,
      aux_sym_symbol_token2,
    ACTIONS(1922), 1,
      anon_sym_BSLASH,
    STATE(421), 1,
      sym_macro,
    STATE(547), 1,
      sym_macro_text_expansion,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [11274] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(250), 1,
      aux_sym_if_block_token1,
    ACTIONS(252), 1,
      aux_sym_while_block_token1,
    ACTIONS(254), 1,
      aux_sym_while_block_token2,
    ACTIONS(256), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(314), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4071), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [11408] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(13), 1,
      aux_sym_if_block_token1,
    ACTIONS(15), 1,
      aux_sym_while_block_token1,
    ACTIONS(17), 1,
      aux_sym_while_block_token2,
    ACTIONS(19), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(316), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4083), 1,
      sym__hll_var_if_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [11542] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1924), 28,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      aux_sym_file_handle_token1,
      sym_identifier,
      sym__blank,
  [11602] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(284), 1,
      anon_sym_AMP_AMP,
    ACTIONS(342), 1,
      aux_sym_if_block_token1,
    ACTIONS(344), 1,
      aux_sym_while_block_token1,
    ACTIONS(346), 1,
      aux_sym_while_block_token2,
    ACTIONS(348), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(315), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4059), 1,
      sym__hll_var_if_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [11736] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1928), 28,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      aux_sym_file_handle_token1,
      sym_identifier,
      sym__blank,
  [11796] = 40,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(11), 1,
      aux_sym_subroutine_block_token1,
    ACTIONS(21), 1,
      anon_sym_AMP_AMP,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      aux_sym_macro_definition_token1,
    ACTIONS(29), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(31), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(37), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    ACTIONS(43), 1,
      sym_label_identifier,
    ACTIONS(354), 1,
      aux_sym_if_block_token1,
    ACTIONS(356), 1,
      aux_sym_while_block_token1,
    ACTIONS(358), 1,
      aux_sym_while_block_token2,
    ACTIONS(360), 1,
      aux_sym__repeat_block_pre_condition_format_token1,
    ACTIONS(1759), 1,
      sym__blank,
    STATE(313), 1,
      sym__label,
    STATE(2515), 1,
      sym_recursive_macro_expansion,
    STATE(2691), 1,
      sym__repeat_block_pre_condition_format,
    STATE(2697), 1,
      sym__repeat_block_post_condition_format,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3936), 1,
      sym_macro,
    STATE(3939), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4030), 1,
      sym__other_command,
    STATE(4062), 1,
      sym__var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4069), 1,
      sym__hll_var_if_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4088), 1,
      sym__host_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(27), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
    STATE(2690), 11,
      sym__non_labeled_statement,
      sym_labeled_expression,
      sym_subroutine_block,
      sym_if_block,
      sym_while_block,
      sym_repeat_block,
      sym_macro_assignment_expression,
      sym_macro_definition,
      sym_parameter_declaration,
      sym_subroutine_call_expression,
      sym_command_expression,
  [11930] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1934), 1,
      anon_sym_AMP,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(1941), 1,
      aux_sym_symbol_token1,
    ACTIONS(1943), 1,
      aux_sym_symbol_token2,
    ACTIONS(1945), 1,
      anon_sym_BSLASH,
    ACTIONS(1947), 1,
      aux_sym_symbol_token3,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    STATE(989), 1,
      sym_macro,
    STATE(1511), 1,
      sym_macro_text_expansion,
    STATE(1513), 1,
      sym_string,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [12015] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(1951), 1,
      anon_sym_STAR,
    ACTIONS(1953), 1,
      anon_sym_RBRACK,
    ACTIONS(1957), 1,
      sym__blank,
    STATE(426), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(359), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12118] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(1959), 1,
      anon_sym_STAR,
    ACTIONS(1961), 1,
      anon_sym_RBRACK,
    ACTIONS(1963), 1,
      sym__blank,
    STATE(412), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2297), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12221] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(1965), 1,
      anon_sym_STAR,
    ACTIONS(1967), 1,
      anon_sym_RBRACK,
    ACTIONS(1969), 1,
      sym__blank,
    STATE(413), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2342), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12324] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1886), 1,
      sym_identifier,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1985), 1,
      sym_path,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(335), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [12399] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1989), 24,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
    ACTIONS(1987), 27,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [12458] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1993), 1,
      anon_sym_AMP,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2000), 1,
      aux_sym_symbol_token1,
    ACTIONS(2002), 1,
      aux_sym_symbol_token2,
    ACTIONS(2004), 1,
      anon_sym_BSLASH,
    ACTIONS(2006), 1,
      aux_sym_symbol_token3,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    STATE(850), 1,
      sym_macro,
    STATE(1497), 1,
      sym_string,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    STATE(1568), 1,
      sym_macro_text_expansion,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [12543] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2010), 1,
      anon_sym_STAR,
    ACTIONS(2012), 1,
      anon_sym_RBRACK,
    ACTIONS(2014), 1,
      sym__blank,
    STATE(430), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2400), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12646] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2016), 1,
      anon_sym_STAR,
    ACTIONS(2018), 1,
      anon_sym_RBRACK,
    ACTIONS(2020), 1,
      sym__blank,
    STATE(423), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(357), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2414), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12749] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2022), 1,
      anon_sym_STAR,
    ACTIONS(2024), 1,
      anon_sym_RBRACK,
    ACTIONS(2026), 1,
      sym__blank,
    STATE(439), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2374), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12852] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2028), 1,
      anon_sym_STAR,
    ACTIONS(2030), 1,
      anon_sym_RBRACK,
    ACTIONS(2032), 1,
      sym__blank,
    STATE(440), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(376), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2341), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [12955] = 26,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(563), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(895), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    STATE(3610), 1,
      sym_format_expression,
    STATE(4086), 1,
      sym__hll_var_command_argument_list_default_format,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1969), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [13060] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2036), 1,
      anon_sym_AMP,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(2041), 1,
      aux_sym_symbol_token1,
    ACTIONS(2043), 1,
      aux_sym_symbol_token2,
    ACTIONS(2045), 1,
      anon_sym_BSLASH,
    ACTIONS(2047), 1,
      aux_sym_symbol_token3,
    STATE(956), 1,
      sym_macro,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    STATE(1491), 1,
      sym_macro_text_expansion,
    STATE(1492), 1,
      sym_string,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [13145] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2049), 1,
      anon_sym_AMP,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2054), 1,
      aux_sym_symbol_token1,
    ACTIONS(2056), 1,
      aux_sym_symbol_token2,
    ACTIONS(2058), 1,
      anon_sym_BSLASH,
    ACTIONS(2060), 1,
      aux_sym_symbol_token3,
    STATE(862), 1,
      sym_macro,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1412), 1,
      sym_macro_text_expansion,
    STATE(1421), 1,
      sym_string,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [13230] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2062), 1,
      anon_sym_AMP,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(2067), 1,
      aux_sym_symbol_token1,
    ACTIONS(2069), 1,
      aux_sym_symbol_token2,
    ACTIONS(2071), 1,
      anon_sym_BSLASH,
    ACTIONS(2073), 1,
      aux_sym_symbol_token3,
    STATE(872), 1,
      sym_macro,
    STATE(1427), 1,
      sym_macro_text_expansion,
    STATE(1433), 1,
      sym_string,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [13315] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2075), 1,
      anon_sym_AMP,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(2080), 1,
      aux_sym_symbol_token1,
    ACTIONS(2082), 1,
      aux_sym_symbol_token2,
    ACTIONS(2084), 1,
      anon_sym_BSLASH,
    ACTIONS(2086), 1,
      aux_sym_symbol_token3,
    STATE(977), 1,
      sym_macro,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1503), 1,
      sym_macro_text_expansion,
    STATE(1504), 1,
      sym_string,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [13400] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2088), 1,
      anon_sym_STAR,
    ACTIONS(2090), 1,
      anon_sym_RBRACK,
    ACTIONS(2092), 1,
      sym__blank,
    STATE(432), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(367), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2301), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [13503] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2094), 1,
      anon_sym_STAR,
    ACTIONS(2096), 1,
      anon_sym_RBRACK,
    ACTIONS(2098), 1,
      sym__blank,
    STATE(433), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2311), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [13606] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1886), 1,
      sym_identifier,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2106), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    STATE(335), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [13679] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2110), 1,
      anon_sym_AMP,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(2115), 1,
      aux_sym_symbol_token1,
    ACTIONS(2117), 1,
      aux_sym_symbol_token2,
    ACTIONS(2119), 1,
      anon_sym_BSLASH,
    ACTIONS(2121), 1,
      aux_sym_symbol_token3,
    STATE(1001), 1,
      sym_macro,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1542), 1,
      sym_string,
    STATE(1547), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [13764] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2123), 1,
      anon_sym_AMP,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(2128), 1,
      aux_sym_symbol_token1,
    ACTIONS(2130), 1,
      aux_sym_symbol_token2,
    ACTIONS(2132), 1,
      anon_sym_BSLASH,
    ACTIONS(2134), 1,
      aux_sym_symbol_token3,
    STATE(1011), 1,
      sym_macro,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1559), 1,
      sym_string,
    STATE(1561), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [13849] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2136), 1,
      anon_sym_AMP,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(2141), 1,
      aux_sym_symbol_token1,
    ACTIONS(2143), 1,
      aux_sym_symbol_token2,
    ACTIONS(2145), 1,
      anon_sym_BSLASH,
    ACTIONS(2147), 1,
      aux_sym_symbol_token3,
    STATE(886), 1,
      sym_macro,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1458), 1,
      sym_string,
    STATE(1469), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [13934] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2149), 1,
      anon_sym_AMP,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(2154), 1,
      aux_sym_symbol_token1,
    ACTIONS(2156), 1,
      aux_sym_symbol_token2,
    ACTIONS(2158), 1,
      anon_sym_BSLASH,
    ACTIONS(2160), 1,
      aux_sym_symbol_token3,
    STATE(899), 1,
      sym_macro,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1485), 1,
      sym_string,
    STATE(1509), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [14019] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1886), 1,
      sym_identifier,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(1922), 1,
      anon_sym_BSLASH,
    ACTIONS(2162), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    STATE(335), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14092] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1886), 1,
      sym_identifier,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(2164), 1,
      sym_path,
    STATE(335), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1983), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1975), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1978), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1981), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
  [14163] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2166), 1,
      anon_sym_STAR,
    ACTIONS(2168), 1,
      anon_sym_RBRACK,
    ACTIONS(2170), 1,
      sym__blank,
    STATE(386), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(353), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2283), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [14266] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2172), 1,
      anon_sym_STAR,
    ACTIONS(2174), 1,
      anon_sym_RBRACK,
    ACTIONS(2176), 1,
      sym__blank,
    STATE(419), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2304), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [14369] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2178), 1,
      anon_sym_STAR,
    ACTIONS(2180), 1,
      anon_sym_RBRACK,
    ACTIONS(2182), 1,
      sym__blank,
    STATE(429), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(352), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2312), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [14472] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2106), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    ACTIONS(2184), 1,
      sym_identifier,
    ACTIONS(2187), 1,
      anon_sym_AMP,
    STATE(373), 1,
      sym_macro,
    STATE(460), 1,
      sym_macro_text_expansion,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14547] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1800), 1,
      anon_sym_AMP,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2190), 1,
      aux_sym_symbol_token1,
    ACTIONS(2192), 1,
      aux_sym_symbol_token2,
    ACTIONS(2194), 1,
      anon_sym_BSLASH,
    STATE(473), 1,
      sym_macro,
    STATE(1033), 1,
      sym_macro_text_expansion,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [14623] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1684), 1,
      sym_identifier,
    ACTIONS(1691), 1,
      anon_sym_AMP,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(390), 1,
      sym_macro,
    STATE(577), 1,
      sym_macro_text_expansion,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14695] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2208), 1,
      sym__line_specifier,
    ACTIONS(2211), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2203), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14765] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(1700), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14835] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2208), 1,
      sym__line_specifier,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2203), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14905] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [14975] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2217), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15045] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(1967), 1,
      anon_sym_RBRACK,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2219), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2340), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [15147] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(1638), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15217] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1622), 1,
      sym_identifier,
    ACTIONS(1629), 1,
      anon_sym_AMP,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(396), 1,
      sym_macro,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(541), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15289] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2227), 1,
      sym__line_specifier,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2224), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15359] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15429] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1622), 1,
      sym_identifier,
    ACTIONS(1629), 1,
      anon_sym_AMP,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(1638), 1,
      anon_sym_BSLASH,
    STATE(397), 1,
      sym_macro,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(562), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15501] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2227), 1,
      sym__line_specifier,
    ACTIONS(2230), 1,
      anon_sym_BSLASH,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2224), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15571] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2233), 1,
      sym_identifier,
    ACTIONS(2236), 1,
      anon_sym_AMP,
    ACTIONS(2239), 1,
      anon_sym_BSLASH,
    STATE(418), 1,
      sym_macro,
    STATE(527), 1,
      sym_macro_text_expansion,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15643] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2241), 1,
      sym_identifier,
    ACTIONS(2248), 1,
      anon_sym_AMP,
    ACTIONS(2251), 1,
      sym__line_specifier,
    STATE(400), 1,
      sym_macro,
    STATE(588), 1,
      sym_macro_text_expansion,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15715] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2259), 1,
      sym__line_specifier,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2256), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15785] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2251), 1,
      sym__line_specifier,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15855] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2251), 1,
      sym__line_specifier,
    ACTIONS(2262), 1,
      anon_sym_BSLASH,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15925] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2241), 1,
      sym_identifier,
    ACTIONS(2248), 1,
      anon_sym_AMP,
    ACTIONS(2251), 1,
      sym__line_specifier,
    ACTIONS(2262), 1,
      anon_sym_BSLASH,
    STATE(403), 1,
      sym_macro,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    STATE(598), 1,
      sym_macro_text_expansion,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [15997] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2259), 1,
      sym__line_specifier,
    ACTIONS(2264), 1,
      anon_sym_BSLASH,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2256), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16067] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2271), 1,
      sym__line_specifier,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16137] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2271), 1,
      sym__line_specifier,
    ACTIONS(2273), 1,
      sym_identifier,
    ACTIONS(2276), 1,
      anon_sym_AMP,
    STATE(404), 1,
      sym_macro,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    STATE(472), 1,
      sym_macro_text_expansion,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16209] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2285), 1,
      sym__line_specifier,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2279), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2282), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16279] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2271), 1,
      sym__line_specifier,
    ACTIONS(2288), 1,
      anon_sym_BSLASH,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16349] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2294), 1,
      sym__line_specifier,
    STATE(504), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2290), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2292), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16419] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2294), 1,
      sym__line_specifier,
    ACTIONS(2296), 1,
      sym_identifier,
    ACTIONS(2299), 1,
      anon_sym_AMP,
    STATE(407), 1,
      sym_macro,
    STATE(504), 1,
      aux_sym_symbol_repeat1,
    STATE(528), 1,
      sym_macro_text_expansion,
    ACTIONS(2290), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2292), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16491] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2308), 1,
      sym__line_specifier,
    STATE(504), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2302), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2305), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16561] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2315), 1,
      sym__line_specifier,
    STATE(544), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2311), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2313), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16631] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2315), 1,
      sym__line_specifier,
    ACTIONS(2317), 1,
      sym_identifier,
    ACTIONS(2320), 1,
      anon_sym_AMP,
    STATE(410), 1,
      sym_macro,
    STATE(544), 1,
      aux_sym_symbol_repeat1,
    STATE(551), 1,
      sym_macro_text_expansion,
    ACTIONS(2311), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2313), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16703] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2329), 1,
      sym__line_specifier,
    STATE(544), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2323), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2326), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16773] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2336), 1,
      sym__line_specifier,
    STATE(554), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2332), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2334), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16843] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2239), 1,
      anon_sym_BSLASH,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [16913] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2338), 1,
      anon_sym_STAR,
    ACTIONS(2340), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2359), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [17015] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2342), 1,
      anon_sym_STAR,
    ACTIONS(2344), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2362), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [17117] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1684), 1,
      sym_identifier,
    ACTIONS(1691), 1,
      anon_sym_AMP,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(1700), 1,
      anon_sym_BSLASH,
    STATE(387), 1,
      sym_macro,
    STATE(466), 1,
      sym_macro_text_expansion,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17189] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1774), 1,
      anon_sym_AMP,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2346), 1,
      aux_sym_symbol_token1,
    ACTIONS(2348), 1,
      aux_sym_symbol_token2,
    ACTIONS(2350), 1,
      anon_sym_BSLASH,
    STATE(482), 1,
      sym_macro,
    STATE(856), 1,
      sym_macro_text_expansion,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [17265] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1922), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17335] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17405] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1680), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17475] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2352), 1,
      anon_sym_STAR,
    ACTIONS(2354), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2292), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [17577] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1704), 1,
      sym_identifier,
    ACTIONS(1711), 1,
      anon_sym_AMP,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1916), 1,
      anon_sym_BSLASH,
    STATE(431), 1,
      sym_macro,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(579), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17649] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1916), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17719] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1704), 1,
      sym_identifier,
    ACTIONS(1711), 1,
      anon_sym_AMP,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1720), 1,
      anon_sym_BSLASH,
    STATE(437), 1,
      sym_macro,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(589), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17791] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2012), 1,
      anon_sym_RBRACK,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2356), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2366), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [17893] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1704), 1,
      sym_identifier,
    ACTIONS(1711), 1,
      anon_sym_AMP,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(441), 1,
      sym_macro,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(600), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [17965] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2364), 1,
      sym__line_specifier,
    ACTIONS(2367), 1,
      anon_sym_BSLASH,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2361), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [18035] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2024), 1,
      anon_sym_RBRACK,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2370), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2367), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18137] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2364), 1,
      sym__line_specifier,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2361), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [18207] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(572), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(887), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    STATE(3601), 1,
      sym_format_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1970), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18309] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(1961), 1,
      anon_sym_RBRACK,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2372), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2295), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18411] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2374), 1,
      anon_sym_STAR,
    ACTIONS(2376), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2306), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18513] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2378), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [18583] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2096), 1,
      anon_sym_RBRACK,
    ACTIONS(2380), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2309), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18685] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2382), 1,
      anon_sym_STAR,
    ACTIONS(2384), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2315), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [18787] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1644), 1,
      sym_identifier,
    ACTIONS(1651), 1,
      anon_sym_AMP,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(1660), 1,
      anon_sym_BSLASH,
    STATE(382), 1,
      sym_macro,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(597), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [18859] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1644), 1,
      sym_identifier,
    ACTIONS(1651), 1,
      anon_sym_AMP,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(384), 1,
      sym_macro,
    STATE(477), 1,
      sym_macro_text_expansion,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [18931] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2392), 1,
      sym__line_specifier,
    ACTIONS(2395), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2389), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19001] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(1660), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19071] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2392), 1,
      sym__line_specifier,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2389), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19141] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2398), 1,
      anon_sym_STAR,
    ACTIONS(2400), 1,
      anon_sym_RBRACK,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2287), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [19243] = 25,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(580), 1,
      anon_sym_AMP,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2174), 1,
      anon_sym_RBRACK,
    ACTIONS(2402), 1,
      anon_sym_STAR,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1955), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2296), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [19345] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19415] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1644), 1,
      sym_identifier,
    ACTIONS(1651), 1,
      anon_sym_AMP,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2378), 1,
      anon_sym_BSLASH,
    STATE(385), 1,
      sym_macro,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    STATE(571), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19487] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    ACTIONS(2233), 1,
      sym_identifier,
    ACTIONS(2236), 1,
      anon_sym_AMP,
    STATE(416), 1,
      sym_macro,
    STATE(481), 1,
      sym_macro_text_expansion,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [19559] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2404), 1,
      sym_identifier,
    ACTIONS(2411), 1,
      anon_sym_AMP,
    STATE(447), 1,
      sym_macro,
    STATE(689), 1,
      sym_macro_text_expansion,
    ACTIONS(2407), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [19624] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [19687] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(2419), 1,
      sym__line_specifier,
    STATE(333), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1971), 20,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [19756] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(451), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2423), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [19819] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2425), 1,
      sym_identifier,
    ACTIONS(2428), 1,
      anon_sym_AMP,
    STATE(448), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1907), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [19882] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 23,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1928), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [19939] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2198), 1,
      sym_identifier,
    ACTIONS(2206), 1,
      anon_sym_AMP,
    STATE(452), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1890), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [20002] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(448), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1894), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [20061] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(448), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1898), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [20120] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1860), 1,
      anon_sym_AMP,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2431), 1,
      aux_sym_symbol_token1,
    ACTIONS(2433), 1,
      aux_sym_symbol_token2,
    ACTIONS(2435), 1,
      anon_sym_BSLASH,
    STATE(622), 1,
      sym_macro,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(1077), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [20195] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2437), 1,
      sym_identifier,
    ACTIONS(2439), 1,
      anon_sym_AMP,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2444), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    STATE(458), 1,
      sym_macro,
    STATE(811), 1,
      sym_macro_text_expansion,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [20268] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 23,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1924), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [20325] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2444), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    ACTIONS(2448), 1,
      sym_identifier,
    ACTIONS(2450), 1,
      anon_sym_AMP,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    STATE(537), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [20396] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1817), 1,
      anon_sym_AMP,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2452), 1,
      aux_sym_symbol_token1,
    ACTIONS(2454), 1,
      aux_sym_symbol_token2,
    ACTIONS(2456), 1,
      anon_sym_BSLASH,
    STATE(617), 1,
      sym_macro,
    STATE(1066), 1,
      sym_macro_text_expansion,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [20471] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2194), 1,
      anon_sym_BSLASH,
    ACTIONS(2448), 1,
      sym_identifier,
    ACTIONS(2450), 1,
      anon_sym_AMP,
    ACTIONS(2458), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    STATE(537), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [20542] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2460), 1,
      sym_identifier,
    ACTIONS(2467), 1,
      anon_sym_AMP,
    ACTIONS(2470), 1,
      anon_sym_BSLASH,
    STATE(462), 1,
      sym_macro,
    STATE(607), 1,
      sym_macro_text_expansion,
    STATE(699), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2463), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2465), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [20611] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1922), 1,
      anon_sym_BSLASH,
    ACTIONS(2162), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [20676] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2106), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [20741] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2470), 1,
      anon_sym_BSLASH,
    ACTIONS(2472), 1,
      sym_identifier,
    ACTIONS(2474), 1,
      anon_sym_AMP,
    STATE(732), 1,
      aux_sym_symbol_repeat1,
    STATE(545), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym__blank,
  [20808] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2480), 1,
      sym__line_specifier,
    ACTIONS(2483), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2221), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [20876] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2486), 1,
      anon_sym_BSLASH,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [20944] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2294), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2292), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [21006] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(1638), 1,
      anon_sym_BSLASH,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [21068] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2488), 1,
      sym_identifier,
    ACTIONS(2491), 1,
      anon_sym_AMP,
    STATE(478), 1,
      sym_macro,
    STATE(783), 1,
      sym_macro_text_expansion,
    ACTIONS(2407), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [21132] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2472), 1,
      sym_identifier,
    ACTIONS(2474), 1,
      anon_sym_AMP,
    STATE(545), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [21194] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2194), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21262] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(1809), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21330] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1774), 1,
      anon_sym_AMP,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2350), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    STATE(482), 1,
      sym_macro,
    STATE(856), 1,
      sym_macro_text_expansion,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21400] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2294), 1,
      sym__line_specifier,
    STATE(504), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2292), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [21462] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2350), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21530] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1774), 1,
      anon_sym_AMP,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(1783), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    STATE(486), 1,
      sym_macro,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    STATE(1016), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21600] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1774), 1,
      anon_sym_AMP,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(488), 1,
      sym_macro,
    STATE(932), 1,
      sym_macro_text_expansion,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21670] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2498), 1,
      sym__line_specifier,
    ACTIONS(2501), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2358), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21738] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [21800] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2472), 1,
      sym_identifier,
    ACTIONS(2474), 1,
      anon_sym_AMP,
    STATE(545), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2423), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [21862] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2498), 1,
      sym__line_specifier,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2358), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [21930] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2259), 1,
      sym__line_specifier,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2256), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [21992] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1922), 1,
      anon_sym_BSLASH,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [22054] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2507), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22122] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1738), 1,
      anon_sym_AMP,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(1749), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    STATE(494), 1,
      sym_macro,
    STATE(832), 1,
      sym_macro_text_expansion,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22192] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1738), 1,
      anon_sym_AMP,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(496), 1,
      sym_macro,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(915), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22262] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2509), 1,
      sym__line_specifier,
    ACTIONS(2512), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2386), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22330] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(1749), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22398] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2509), 1,
      sym__line_specifier,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2386), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22466] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22534] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1738), 1,
      anon_sym_AMP,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2507), 1,
      anon_sym_BSLASH,
    STATE(497), 1,
      sym_macro,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    STATE(921), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22604] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1761), 1,
      anon_sym_AMP,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(1770), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    STATE(498), 1,
      sym_macro,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(934), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22674] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1761), 1,
      anon_sym_AMP,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(501), 1,
      sym_macro,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(965), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22744] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2515), 1,
      sym__line_specifier,
    ACTIONS(2518), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2200), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22812] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2523), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2521), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [22868] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(1770), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [22936] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2515), 1,
      sym__line_specifier,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2200), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23004] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23072] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2525), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23140] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(1796), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23208] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1787), 1,
      anon_sym_AMP,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(507), 1,
      sym_macro,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(833), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23278] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2480), 1,
      sym__line_specifier,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2221), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23346] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23414] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1787), 1,
      anon_sym_AMP,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(1796), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    STATE(508), 1,
      sym_macro,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    STATE(837), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23484] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2308), 1,
      sym__line_specifier,
    STATE(504), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2302), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2305), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [23546] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2315), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2313), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [23608] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2527), 1,
      anon_sym_AMP,
    ACTIONS(2530), 1,
      sym__line_specifier,
    STATE(511), 1,
      sym_macro,
    STATE(869), 1,
      sym_macro_text_expansion,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23678] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2532), 1,
      sym__line_specifier,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2253), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23746] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2530), 1,
      sym__line_specifier,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23814] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2530), 1,
      sym__line_specifier,
    ACTIONS(2535), 1,
      anon_sym_BSLASH,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23882] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2527), 1,
      anon_sym_AMP,
    ACTIONS(2530), 1,
      sym__line_specifier,
    ACTIONS(2535), 1,
      anon_sym_BSLASH,
    STATE(514), 1,
      sym_macro,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    STATE(916), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [23952] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2532), 1,
      sym__line_specifier,
    ACTIONS(2537), 1,
      anon_sym_BSLASH,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2253), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24020] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2540), 1,
      sym__line_specifier,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24088] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2540), 1,
      sym__line_specifier,
    ACTIONS(2542), 1,
      anon_sym_AMP,
    STATE(515), 1,
      sym_macro,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    STATE(920), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24158] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2545), 1,
      sym__line_specifier,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2279), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24226] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2540), 1,
      sym__line_specifier,
    ACTIONS(2548), 1,
      anon_sym_BSLASH,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24294] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2550), 1,
      sym__line_specifier,
    STATE(926), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2290), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24362] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2550), 1,
      sym__line_specifier,
    ACTIONS(2552), 1,
      anon_sym_AMP,
    STATE(518), 1,
      sym_macro,
    STATE(926), 1,
      aux_sym_symbol_repeat1,
    STATE(931), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2290), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24432] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2555), 1,
      sym__line_specifier,
    STATE(926), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2302), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24500] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2558), 1,
      sym__line_specifier,
    STATE(937), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2311), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24568] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2558), 1,
      sym__line_specifier,
    ACTIONS(2560), 1,
      anon_sym_AMP,
    STATE(521), 1,
      sym_macro,
    STATE(937), 1,
      aux_sym_symbol_repeat1,
    STATE(944), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2311), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24638] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2563), 1,
      sym__line_specifier,
    STATE(937), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2323), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24706] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2566), 1,
      sym__line_specifier,
    STATE(953), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2332), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [24774] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2251), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [24836] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [24900] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2570), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2568), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [24956] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2572), 1,
      sym_identifier,
    ACTIONS(2574), 1,
      anon_sym_LPAREN,
    ACTIONS(2576), 1,
      sym__hll_number_literal_pre_hook,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(1679), 1,
      sym_hll_parenthesized_expression,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    STATE(2688), 2,
      sym__hll_expression,
      sym_hll_assignment_expression,
    STATE(3893), 2,
      sym__hll_option_value,
      sym__hll_parenthesized_option_value,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1728), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_symbol,
    STATE(2512), 8,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [25054] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2582), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2585), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(2580), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2578), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [25118] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(1680), 1,
      anon_sym_BSLASH,
    STATE(552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [25180] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2315), 1,
      sym__line_specifier,
    STATE(544), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2313), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [25242] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2590), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2588), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25304] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2590), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2588), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25360] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2600), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2598), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25416] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2590), 19,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2588), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25474] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2604), 1,
      anon_sym_CARET,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2602), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2590), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2588), 22,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25540] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2606), 1,
      sym_identifier,
    ACTIONS(2609), 1,
      anon_sym_AMP,
    STATE(534), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1907), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [25602] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2448), 1,
      sym_identifier,
    ACTIONS(2450), 1,
      anon_sym_AMP,
    STATE(605), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1888), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [25664] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2602), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2590), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2588), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [25728] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2448), 1,
      sym_identifier,
    STATE(540), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1896), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [25788] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [25850] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2486), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2612), 1,
      anon_sym_AMP,
    STATE(470), 1,
      sym_macro,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    STATE(1029), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [25920] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2615), 1,
      sym_identifier,
    ACTIONS(2618), 1,
      anon_sym_AMP,
    STATE(540), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1905), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [25982] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2251), 1,
      sym__line_specifier,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26044] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2472), 1,
      sym_identifier,
    ACTIONS(2474), 1,
      anon_sym_AMP,
    STATE(546), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1890), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym__blank,
  [26106] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2329), 1,
      sym__line_specifier,
    STATE(544), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2323), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2326), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26168] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2336), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2334), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26230] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(534), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1894), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [26288] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(534), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1898), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [26346] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1916), 1,
      anon_sym_BSLASH,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26408] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2227), 1,
      sym__line_specifier,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2224), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26470] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2604), 1,
      anon_sym_CARET,
    ACTIONS(2625), 1,
      anon_sym_PIPE,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2602), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2623), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2621), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26544] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1892), 1,
      anon_sym_AMP,
    ACTIONS(2637), 1,
      aux_sym_file_handle_token1,
    STATE(570), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2635), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2633), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26606] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2336), 1,
      sym__line_specifier,
    STATE(554), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2334), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26668] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26730] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2364), 1,
      sym__line_specifier,
    ACTIONS(2367), 1,
      anon_sym_BSLASH,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2361), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26792] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2643), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2641), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2639), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [26854] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2647), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2645), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [26910] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2651), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2649), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [26966] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2653), 1,
      sym_identifier,
    ACTIONS(2655), 1,
      anon_sym_LPAREN,
    ACTIONS(2657), 1,
      sym__hll_number_literal_pre_hook,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(1679), 1,
      sym_hll_parenthesized_expression,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    STATE(2641), 2,
      sym__hll_expression,
      sym_hll_assignment_expression,
    STATE(4255), 2,
      sym__hll_option_value,
      sym__hll_parenthesized_option_value,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1785), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_symbol,
    STATE(2647), 8,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [27064] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2659), 1,
      sym_identifier,
    ACTIONS(2661), 1,
      anon_sym_AMP,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2666), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    STATE(566), 1,
      sym_macro,
    STATE(1010), 1,
      sym_macro_text_expansion,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [27136] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2666), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    ACTIONS(2670), 1,
      sym_identifier,
    ACTIONS(2672), 1,
      anon_sym_AMP,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    STATE(654), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [27206] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2674), 1,
      sym_identifier,
    ACTIONS(2677), 1,
      anon_sym_LPAREN,
    ACTIONS(2692), 1,
      anon_sym_PERCENT,
    ACTIONS(2695), 1,
      anon_sym_sizeof,
    ACTIONS(2704), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(2707), 1,
      aux_sym_symbol_token1,
    ACTIONS(2710), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2713), 1,
      anon_sym_BSLASH,
    ACTIONS(2716), 1,
      aux_sym_symbol_token5,
    ACTIONS(2719), 1,
      sym__hll_number_literal_pre_hook,
    STATE(560), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(1006), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    STATE(4044), 1,
      sym_format_expression,
    ACTIONS(2680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2683), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(2686), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2689), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(2698), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(2701), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2235), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [27302] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2604), 1,
      anon_sym_CARET,
    ACTIONS(2625), 1,
      anon_sym_PIPE,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2602), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2724), 16,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2722), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27376] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2251), 1,
      sym__line_specifier,
    ACTIONS(2262), 1,
      anon_sym_BSLASH,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27438] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(560), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(859), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    STATE(3706), 1,
      sym_format_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1965), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [27534] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1714), 1,
      sym__line_specifier,
    ACTIONS(1720), 1,
      anon_sym_BSLASH,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27596] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2239), 1,
      anon_sym_BSLASH,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27658] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2456), 1,
      anon_sym_BSLASH,
    ACTIONS(2670), 1,
      sym_identifier,
    ACTIONS(2672), 1,
      anon_sym_AMP,
    ACTIONS(2726), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    STATE(654), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [27728] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2259), 1,
      sym__line_specifier,
    ACTIONS(2264), 1,
      anon_sym_BSLASH,
    STATE(590), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2256), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27790] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2596), 1,
      anon_sym_SLASH,
    ACTIONS(2604), 1,
      anon_sym_CARET,
    ACTIONS(2625), 1,
      anon_sym_PIPE,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2594), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2602), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2592), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2735), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2733), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2730), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(2728), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [27868] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2364), 1,
      sym__line_specifier,
    STATE(576), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2361), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27930] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2742), 1,
      anon_sym_AMP,
    ACTIONS(2745), 1,
      aux_sym_file_handle_token1,
    STATE(570), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2740), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2738), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [27992] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(2217), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28054] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(560), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat2,
    STATE(972), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    STATE(3690), 1,
      sym_format_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1956), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [28150] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2750), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2748), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [28206] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2576), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2752), 1,
      sym_identifier,
    ACTIONS(2754), 1,
      anon_sym_LPAREN,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(1679), 1,
      sym_hll_parenthesized_expression,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(2665), 2,
      sym__hll_expression,
      sym_hll_assignment_expression,
    STATE(3893), 2,
      sym__hll_option_value,
      sym__hll_parenthesized_option_value,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1752), 5,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_symbol,
    STATE(2512), 8,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [28304] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2758), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2756), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [28360] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28422] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28484] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1674), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28546] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2378), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28608] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2108), 1,
      anon_sym_BSLASH,
    STATE(578), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28670] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2227), 1,
      sym__line_specifier,
    ACTIONS(2230), 1,
      anon_sym_BSLASH,
    STATE(522), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2224), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28732] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2762), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2760), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [28788] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2766), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2764), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [28844] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2392), 1,
      sym__line_specifier,
    ACTIONS(2395), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2389), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [28906] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2770), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2768), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [28962] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1975), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1978), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1981), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
  [29022] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2582), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2585), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
    ACTIONS(1981), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
  [29082] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2271), 1,
      sym__line_specifier,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29144] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(1660), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29206] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2271), 1,
      sym__line_specifier,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29268] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2772), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29328] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2208), 1,
      sym__line_specifier,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2203), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29390] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1632), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29452] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2392), 1,
      sym__line_specifier,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2389), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29514] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2214), 1,
      anon_sym_BSLASH,
    ACTIONS(2285), 1,
      sym__line_specifier,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2279), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2282), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29576] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    ACTIONS(2775), 1,
      sym__line_specifier,
    STATE(604), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2463), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2465), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29638] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1694), 1,
      sym__line_specifier,
    ACTIONS(1700), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29700] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2271), 1,
      sym__line_specifier,
    ACTIONS(2288), 1,
      anon_sym_BSLASH,
    STATE(465), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29762] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2779), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2777), 26,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_COLON,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_COLON_COLON,
      sym_identifier,
      sym__blank,
  [29818] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1654), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(538), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [29880] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2612), 1,
      anon_sym_AMP,
    STATE(469), 1,
      sym_macro,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    STATE(1027), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [29950] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [30018] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2208), 1,
      sym__line_specifier,
    ACTIONS(2211), 1,
      anon_sym_BSLASH,
    STATE(593), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2203), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [30080] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2104), 1,
      sym__line_specifier,
    ACTIONS(2196), 1,
      anon_sym_BSLASH,
    STATE(591), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [30142] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2448), 1,
      sym_identifier,
    STATE(540), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1900), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [30202] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2781), 1,
      anon_sym_RBRACK,
    ACTIONS(2783), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3845), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [30295] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2470), 1,
      anon_sym_BSLASH,
    STATE(732), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [30354] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2787), 1,
      anon_sym_AMP,
    STATE(614), 1,
      sym_macro,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    STATE(1061), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30423] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30490] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2787), 1,
      anon_sym_AMP,
    ACTIONS(2794), 1,
      anon_sym_BSLASH,
    STATE(615), 1,
      sym_macro,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    STATE(1062), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30559] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2794), 1,
      anon_sym_BSLASH,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30626] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2796), 1,
      anon_sym_RBRACK,
    ACTIONS(2798), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3858), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [30719] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2800), 1,
      anon_sym_RBRACK,
    ACTIONS(2802), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3730), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [30812] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2456), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30879] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(1828), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [30946] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1860), 1,
      anon_sym_AMP,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2435), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    STATE(622), 1,
      sym_macro,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(1077), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31015] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2435), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31082] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1860), 1,
      anon_sym_AMP,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(1869), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    STATE(626), 1,
      sym_macro,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(1080), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31151] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1860), 1,
      anon_sym_AMP,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(628), 1,
      sym_macro,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(1083), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31220] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2806), 1,
      sym__line_specifier,
    ACTIONS(2809), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2358), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31287] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2806), 1,
      sym__line_specifier,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2358), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31354] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2815), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31421] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1847), 1,
      anon_sym_AMP,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(1856), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    STATE(636), 1,
      sym_macro,
    STATE(1089), 1,
      sym_macro_text_expansion,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31490] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1847), 1,
      anon_sym_AMP,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(639), 1,
      sym_macro,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(1092), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31559] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2817), 1,
      sym__line_specifier,
    ACTIONS(2820), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2386), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31626] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(1856), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31693] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2817), 1,
      sym__line_specifier,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2386), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31760] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31827] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1847), 1,
      anon_sym_AMP,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2815), 1,
      anon_sym_BSLASH,
    STATE(640), 1,
      sym_macro,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    STATE(1093), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [31896] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2823), 1,
      anon_sym_RBRACK,
    ACTIONS(2825), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3950), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [31989] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2827), 1,
      anon_sym_RBRACK,
    ACTIONS(2829), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3727), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [32082] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1873), 1,
      anon_sym_AMP,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(1882), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    STATE(642), 1,
      sym_macro,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(1095), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32151] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1873), 1,
      anon_sym_AMP,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(646), 1,
      sym_macro,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(1097), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32220] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2831), 1,
      sym__line_specifier,
    ACTIONS(2834), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2200), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32287] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2837), 1,
      anon_sym_RBRACK,
    ACTIONS(2839), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3864), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [32380] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(1882), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32447] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2831), 1,
      sym__line_specifier,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2200), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32514] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2670), 1,
      sym_identifier,
    ACTIONS(2672), 1,
      anon_sym_AMP,
    STATE(655), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [32575] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32642] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2841), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32709] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2843), 1,
      anon_sym_RBRACK,
    ACTIONS(2845), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3742), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [32802] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(1843), 1,
      anon_sym_BSLASH,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32869] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1834), 1,
      anon_sym_AMP,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(656), 1,
      sym_macro,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(1102), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [32938] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1993), 1,
      anon_sym_AMP,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2847), 1,
      aux_sym_symbol_token1,
    ACTIONS(2849), 1,
      aux_sym_symbol_token2,
    ACTIONS(2851), 1,
      anon_sym_BSLASH,
    STATE(844), 1,
      sym_macro,
    STATE(1557), 1,
      sym_macro_text_expansion,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [33011] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2853), 1,
      sym__line_specifier,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2221), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33078] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33145] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1834), 1,
      anon_sym_AMP,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(1843), 1,
      anon_sym_BSLASH,
    ACTIONS(2785), 1,
      sym_identifier,
    STATE(657), 1,
      sym_macro,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(1104), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33214] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2049), 1,
      anon_sym_AMP,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2856), 1,
      aux_sym_symbol_token1,
    ACTIONS(2858), 1,
      aux_sym_symbol_token2,
    ACTIONS(2860), 1,
      anon_sym_BSLASH,
    STATE(857), 1,
      sym_macro,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1411), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [33287] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2853), 1,
      sym__line_specifier,
    ACTIONS(2862), 1,
      anon_sym_BSLASH,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2221), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33354] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2869), 1,
      sym_path,
    STATE(695), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2867), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2865), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [33413] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2871), 1,
      anon_sym_RBRACK,
    ACTIONS(2873), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3882), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [33506] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2875), 1,
      anon_sym_AMP,
    ACTIONS(2878), 1,
      sym__line_specifier,
    STATE(665), 1,
      sym_macro,
    STATE(1109), 1,
      sym_macro_text_expansion,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33575] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2880), 1,
      sym__line_specifier,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2253), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33642] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2670), 1,
      sym_identifier,
    STATE(662), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [33701] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2670), 1,
      sym_identifier,
    STATE(662), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [33760] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2878), 1,
      sym__line_specifier,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33827] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2878), 1,
      sym__line_specifier,
    ACTIONS(2883), 1,
      anon_sym_BSLASH,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [33894] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(2885), 1,
      anon_sym_AMP,
    STATE(660), 1,
      sym_macro,
    STATE(1172), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [33957] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34018] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(668), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2421), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34079] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    ACTIONS(2478), 1,
      anon_sym_AMP,
    STATE(670), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1888), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34140] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2888), 1,
      sym_identifier,
    ACTIONS(2891), 1,
      anon_sym_AMP,
    STATE(662), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [34201] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2875), 1,
      anon_sym_AMP,
    ACTIONS(2878), 1,
      sym__line_specifier,
    ACTIONS(2883), 1,
      anon_sym_BSLASH,
    STATE(673), 1,
      sym_macro,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    STATE(1115), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34270] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2880), 1,
      sym__line_specifier,
    ACTIONS(2894), 1,
      anon_sym_BSLASH,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2253), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34337] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2897), 1,
      sym__line_specifier,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34404] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2897), 1,
      sym__line_specifier,
    ACTIONS(2899), 1,
      anon_sym_AMP,
    STATE(675), 1,
      sym_macro,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    STATE(1118), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34473] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1924), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [34528] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    STATE(672), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1896), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34587] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1928), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [34642] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2476), 1,
      sym_identifier,
    STATE(672), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1900), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34701] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2902), 1,
      sym__line_specifier,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2279), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34768] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2905), 1,
      sym_identifier,
    ACTIONS(2908), 1,
      anon_sym_AMP,
    STATE(672), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1905), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [34829] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2897), 1,
      sym__line_specifier,
    ACTIONS(2911), 1,
      anon_sym_BSLASH,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [34896] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1989), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(1987), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [34951] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2913), 1,
      sym__line_specifier,
    STATE(1121), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2290), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35018] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2913), 1,
      sym__line_specifier,
    ACTIONS(2915), 1,
      anon_sym_AMP,
    STATE(678), 1,
      sym_macro,
    STATE(1121), 1,
      aux_sym_symbol_repeat1,
    STATE(1122), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2290), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35087] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2918), 1,
      sym__line_specifier,
    STATE(1121), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2302), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35154] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2921), 1,
      sym__line_specifier,
    STATE(1124), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2311), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35221] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2921), 1,
      sym__line_specifier,
    ACTIONS(2923), 1,
      anon_sym_AMP,
    STATE(683), 1,
      sym_macro,
    STATE(1124), 1,
      aux_sym_symbol_repeat1,
    STATE(1125), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2311), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35290] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2928), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2926), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [35355] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2930), 1,
      sym__line_specifier,
    STATE(1124), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2323), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35422] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2935), 18,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2933), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [35485] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2937), 1,
      sym__line_specifier,
    STATE(1126), 1,
      aux_sym_symbol_repeat1,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2332), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [35552] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2941), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2939), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [35607] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2943), 1,
      anon_sym_RPAREN,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2029), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [35700] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2945), 1,
      anon_sym_RBRACK,
    ACTIONS(2947), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3905), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [35793] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2949), 1,
      anon_sym_RPAREN,
    ACTIONS(2951), 1,
      sym__blank,
    STATE(688), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1988), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [35886] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(2953), 1,
      anon_sym_RPAREN,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2024), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [35979] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2421), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2423), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [36034] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2955), 1,
      anon_sym_RBRACK,
    ACTIONS(2957), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3944), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36127] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2959), 1,
      anon_sym_RBRACK,
    ACTIONS(2961), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3825), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36220] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2963), 1,
      anon_sym_RBRACK,
    ACTIONS(2965), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3829), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36313] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2967), 1,
      anon_sym_RBRACK,
    ACTIONS(2969), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3890), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36406] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2971), 1,
      sym_identifier,
    ACTIONS(2973), 1,
      anon_sym_AMP,
    ACTIONS(2976), 1,
      anon_sym_BSLASH,
    STATE(719), 1,
      sym_macro,
    STATE(1046), 1,
      aux_sym_symbol_repeat1,
    STATE(1144), 1,
      sym_macro_text_expansion,
    ACTIONS(2465), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2463), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [36473] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2982), 1,
      sym_path,
    STATE(695), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2980), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2978), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36532] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2989), 1,
      anon_sym_AMP,
    STATE(696), 1,
      aux_sym__path_expression_repeat2,
    STATE(4288), 1,
      sym_macro,
    ACTIONS(2987), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2985), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36593] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2994), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2992), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [36648] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(2036), 1,
      anon_sym_AMP,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(2996), 1,
      aux_sym_symbol_token1,
    ACTIONS(2998), 1,
      aux_sym_symbol_token2,
    ACTIONS(3000), 1,
      anon_sym_BSLASH,
    STATE(948), 1,
      sym_macro,
    STATE(1489), 1,
      sym_macro_text_expansion,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [36721] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2470), 1,
      anon_sym_BSLASH,
    STATE(733), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [36780] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3002), 1,
      anon_sym_RBRACK,
    ACTIONS(3004), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3726), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36873] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3006), 1,
      anon_sym_RPAREN,
    ACTIONS(3008), 1,
      sym__blank,
    STATE(685), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2022), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [36966] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(258), 1,
      anon_sym_EQ,
    ACTIONS(264), 1,
      anon_sym_CARET_CARET,
    ACTIONS(266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3014), 1,
      sym__blank,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3012), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3010), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [37057] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3016), 1,
      anon_sym_RBRACK,
    ACTIONS(3018), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3832), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [37150] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3020), 1,
      anon_sym_RPAREN,
    ACTIONS(3022), 1,
      sym__blank,
    STATE(707), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2007), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [37243] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3026), 13,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 23,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37314] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(3026), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37373] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(3028), 1,
      anon_sym_RPAREN,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2008), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [37466] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37549] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(264), 1,
      anon_sym_CARET_CARET,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 7,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37634] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3026), 15,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37701] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3030), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 18,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37782] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(3030), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37861] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3026), 13,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 21,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37934] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3026), 17,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3024), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [37999] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3033), 1,
      anon_sym_RPAREN,
    ACTIONS(3035), 1,
      sym__blank,
    STATE(717), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2020), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38092] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3037), 1,
      anon_sym_RBRACK,
    ACTIONS(3039), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3861), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38185] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(3041), 1,
      anon_sym_RPAREN,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2021), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38278] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3043), 1,
      anon_sym_RBRACK,
    ACTIONS(3045), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3835), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38371] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2976), 1,
      anon_sym_BSLASH,
    ACTIONS(3047), 1,
      sym_identifier,
    ACTIONS(3049), 1,
      anon_sym_AMP,
    STATE(1146), 1,
      aux_sym_symbol_repeat1,
    STATE(755), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [38436] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3051), 1,
      anon_sym_RBRACK,
    ACTIONS(3053), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3904), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38529] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(2075), 1,
      anon_sym_AMP,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3055), 1,
      aux_sym_symbol_token1,
    ACTIONS(3057), 1,
      aux_sym_symbol_token2,
    ACTIONS(3059), 1,
      anon_sym_BSLASH,
    STATE(974), 1,
      sym_macro,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1500), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [38602] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3061), 1,
      anon_sym_RBRACK,
    ACTIONS(3063), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3844), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38695] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3065), 1,
      anon_sym_RBRACK,
    ACTIONS(3067), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3849), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38788] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3069), 1,
      anon_sym_RBRACK,
    ACTIONS(3071), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3937), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [38881] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 8,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3073), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [38964] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 9,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      aux_sym_while_block_token2,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3073), 19,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [39041] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(258), 1,
      anon_sym_EQ,
    ACTIONS(264), 1,
      anon_sym_CARET_CARET,
    ACTIONS(266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3014), 1,
      sym__blank,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3079), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3077), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [39132] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(258), 1,
      anon_sym_EQ,
    ACTIONS(264), 1,
      anon_sym_CARET_CARET,
    ACTIONS(266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3014), 1,
      sym__blank,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3083), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3081), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [39223] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(258), 1,
      anon_sym_EQ,
    ACTIONS(264), 1,
      anon_sym_CARET_CARET,
    ACTIONS(266), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(270), 1,
      anon_sym_SLASH,
    ACTIONS(272), 1,
      anon_sym_PIPE,
    ACTIONS(274), 1,
      anon_sym_CARET,
    ACTIONS(282), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 1,
      sym__and_operator_pre_hook,
    ACTIONS(3014), 1,
      sym__blank,
    STATE(555), 1,
      sym_argument_list,
    STATE(3771), 1,
      aux_sym_block_repeat1,
    ACTIONS(260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(262), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(268), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(278), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(280), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(276), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3087), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3085), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [39314] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3089), 1,
      anon_sym_RBRACK,
    ACTIONS(3091), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3823), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [39407] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3093), 1,
      anon_sym_RBRACK,
    ACTIONS(3095), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3827), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [39500] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2470), 1,
      anon_sym_BSLASH,
    STATE(733), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [39559] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3097), 1,
      anon_sym_BSLASH,
    STATE(733), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [39618] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3100), 1,
      anon_sym_RBRACK,
    ACTIONS(3102), 1,
      sym__blank,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    STATE(3846), 1,
      aux_sym_block_repeat1,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [39711] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2407), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [39766] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3104), 1,
      sym__blank,
    STATE(829), 1,
      aux_sym_block_repeat1,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1395), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [39856] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [39916] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(771), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [39976] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3106), 1,
      sym__blank,
    STATE(826), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2210), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40066] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3108), 1,
      sym__blank,
    STATE(825), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2596), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40156] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2432), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40246] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2485), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40336] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1687), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40426] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(748), 1,
      sym_macro,
    ACTIONS(3112), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3110), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40482] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3114), 1,
      sym__blank,
    STATE(750), 1,
      aux_sym_block_repeat1,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1460), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40572] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(3116), 1,
      sym__blank,
    STATE(741), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2494), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40662] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1985), 1,
      sym_path,
    ACTIONS(3112), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3110), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40718] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2980), 22,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2978), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [40772] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3118), 1,
      sym__blank,
    STATE(779), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2019), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40862] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1465), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [40952] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3120), 1,
      sym__blank,
    STATE(752), 1,
      aux_sym_block_repeat1,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1405), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [41042] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1473), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [41132] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1924), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [41186] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2444), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [41248] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3047), 1,
      sym_identifier,
    STATE(761), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1896), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [41306] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(3000), 1,
      anon_sym_BSLASH,
    ACTIONS(3122), 1,
      sym_identifier,
    ACTIONS(3124), 1,
      anon_sym_AMP,
    ACTIONS(3126), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    STATE(959), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [41374] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1928), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [41428] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3047), 1,
      sym_identifier,
    STATE(761), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1900), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [41486] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1633), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [41576] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2493), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [41666] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3128), 1,
      sym_identifier,
    ACTIONS(3131), 1,
      anon_sym_AMP,
    STATE(761), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1905), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [41726] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3134), 1,
      sym__blank,
    STATE(759), 1,
      aux_sym_block_repeat1,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1688), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [41816] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    ACTIONS(3138), 1,
      anon_sym_AMP,
    ACTIONS(3140), 1,
      anon_sym_BSLASH,
    STATE(1378), 1,
      aux_sym_symbol_repeat1,
    STATE(929), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [41880] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3142), 1,
      sym_identifier,
    ACTIONS(3144), 1,
      anon_sym_AMP,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3149), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    STATE(799), 1,
      sym_macro,
    STATE(1403), 1,
      sym_macro_text_expansion,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [41950] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1989), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1987), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [42004] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3153), 1,
      sym__blank,
    STATE(767), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2270), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42094] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2300), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42184] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3155), 1,
      sym__blank,
    STATE(769), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2319), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42274] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2364), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42364] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1989), 31,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [42418] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    STATE(809), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [42476] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1926), 31,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [42530] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3149), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    ACTIONS(3157), 1,
      sym_identifier,
    ACTIONS(3159), 1,
      anon_sym_AMP,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    STATE(990), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [42598] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1930), 31,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [42652] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    ACTIONS(2792), 1,
      anon_sym_AMP,
    STATE(776), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [42712] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2790), 1,
      sym_identifier,
    STATE(809), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [42770] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2044), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42860] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2461), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [42950] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2027), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43040] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2971), 1,
      sym_identifier,
    ACTIONS(3161), 1,
      anon_sym_AMP,
    STATE(800), 1,
      sym_macro,
    STATE(1350), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [43102] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3164), 1,
      sym__blank,
    STATE(782), 1,
      aux_sym_block_repeat1,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1391), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43192] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1394), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43282] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2421), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2423), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [43336] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2785), 1,
      sym_identifier,
    ACTIONS(3166), 1,
      anon_sym_AMP,
    STATE(738), 1,
      sym_macro,
    STATE(1392), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [43398] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    ACTIONS(3169), 1,
      sym__blank,
    STATE(786), 1,
      aux_sym_block_repeat1,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2445), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43488] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2447), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43578] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    ACTIONS(3171), 1,
      sym__blank,
    STATE(788), 1,
      aux_sym_block_repeat1,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2448), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43668] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2450), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43758] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3173), 1,
      sym__blank,
    STATE(790), 1,
      aux_sym_block_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2330), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43848] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2332), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [43938] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3175), 1,
      sym__blank,
    STATE(792), 1,
      aux_sym_block_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2333), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44028] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2335), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44118] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3177), 1,
      sym__blank,
    STATE(794), 1,
      aux_sym_block_repeat1,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1661), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44208] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1697), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44298] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3179), 1,
      sym__blank,
    STATE(796), 1,
      aux_sym_block_repeat1,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1664), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44388] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1666), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44478] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3181), 1,
      sym__blank,
    STATE(810), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2028), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44568] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3047), 1,
      sym_identifier,
    ACTIONS(3049), 1,
      anon_sym_AMP,
    STATE(755), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [44628] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2851), 1,
      anon_sym_BSLASH,
    ACTIONS(3157), 1,
      sym_identifier,
    ACTIONS(3159), 1,
      anon_sym_AMP,
    ACTIONS(3183), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    STATE(990), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [44696] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3047), 1,
      sym_identifier,
    ACTIONS(3049), 1,
      anon_sym_AMP,
    STATE(755), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2421), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [44756] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3185), 1,
      sym_identifier,
    ACTIONS(3187), 1,
      anon_sym_AMP,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3192), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    STATE(756), 1,
      sym_macro,
    STATE(1369), 1,
      sym_macro_text_expansion,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [44826] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3122), 1,
      sym_identifier,
    ACTIONS(3124), 1,
      anon_sym_AMP,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3192), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    STATE(959), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [44894] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2573), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [44984] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2032), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45074] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3047), 1,
      sym_identifier,
    ACTIONS(3049), 1,
      anon_sym_AMP,
    STATE(758), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1888), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [45134] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3196), 1,
      sym__blank,
    STATE(812), 1,
      aux_sym_block_repeat1,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2275), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45224] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2514), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45314] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3198), 1,
      sym__blank,
    STATE(777), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2033), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45404] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3200), 1,
      sym_identifier,
    ACTIONS(3203), 1,
      anon_sym_AMP,
    STATE(809), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [45464] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2041), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45554] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2194), 1,
      anon_sym_BSLASH,
    ACTIONS(2458), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [45616] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2280), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45706] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(3206), 1,
      sym__blank,
    STATE(760), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2479), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45796] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3208), 1,
      sym__blank,
    STATE(824), 1,
      aux_sym_block_repeat1,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2281), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [45886] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2407), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2409), 25,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      anon_sym_BSLASH,
      sym_identifier,
      sym__blank,
  [45940] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3210), 1,
      sym__blank,
    STATE(803), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2600), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46030] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2498), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46120] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2499), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46210] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2509), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46300] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2511), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46390] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3212), 1,
      sym__blank,
    STATE(743), 1,
      aux_sym_block_repeat1,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1650), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46480] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3214), 1,
      sym_identifier,
    ACTIONS(3221), 1,
      anon_sym_struct,
    ACTIONS(3224), 1,
      anon_sym_union,
    ACTIONS(3227), 1,
      anon_sym_enum,
    ACTIONS(3233), 1,
      sym_hll_primitive_type,
    ACTIONS(3236), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(3308), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(3230), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2801), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
    ACTIONS(3219), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
    ACTIONS(3217), 21,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [46554] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3239), 1,
      sym__blank,
    STATE(804), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2005), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46644] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2284), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46734] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2599), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46824] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2118), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [46914] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2519), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [47004] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3140), 1,
      anon_sym_BSLASH,
    ACTIONS(3241), 1,
      sym_identifier,
    ACTIONS(3243), 1,
      anon_sym_AMP,
    STATE(763), 1,
      sym_macro,
    STATE(1342), 1,
      aux_sym_symbol_repeat1,
    STATE(1375), 1,
      sym_macro_text_expansion,
    ACTIONS(2465), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2463), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [47070] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1397), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [47160] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3250), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1474), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [47225] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2530), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47284] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(1770), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47343] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2530), 1,
      sym__line_specifier,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47402] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47461] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2851), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [47526] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2004), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [47591] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2530), 1,
      sym__line_specifier,
    ACTIONS(2535), 1,
      anon_sym_BSLASH,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47650] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 1,
      anon_sym_AMP,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2860), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    STATE(857), 1,
      sym_macro,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1411), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [47717] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2532), 1,
      sym__line_specifier,
    ACTIONS(2537), 1,
      anon_sym_BSLASH,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2253), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [47776] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3262), 1,
      anon_sym_AMP,
    STATE(889), 1,
      sym_macro,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    STATE(1466), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [47843] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [47908] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3262), 1,
      anon_sym_AMP,
    ACTIONS(3265), 1,
      anon_sym_BSLASH,
    STATE(890), 1,
      sym_macro,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    STATE(1470), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [47975] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3265), 1,
      anon_sym_BSLASH,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [48040] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2860), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48105] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1625), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1627), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48158] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 1,
      anon_sym_AMP,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2058), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    STATE(863), 1,
      sym_macro,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1421), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48225] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3267), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2572), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [48312] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2987), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2985), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48365] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2049), 1,
      anon_sym_AMP,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(865), 1,
      sym_macro,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1424), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48432] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3271), 1,
      sym__line_specifier,
    ACTIONS(3274), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48497] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1667), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1669), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48550] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1707), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1709), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48603] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3271), 1,
      sym__line_specifier,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48668] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2290), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2292), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48721] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3282), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3280), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [48774] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2507), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [48833] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3284), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [48898] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3286), 1,
      sym_identifier,
    ACTIONS(3289), 1,
      anon_sym_LPAREN,
    ACTIONS(3304), 1,
      anon_sym_sizeof,
    ACTIONS(3313), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(3316), 1,
      aux_sym_symbol_token1,
    ACTIONS(3319), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3322), 1,
      anon_sym_BSLASH,
    ACTIONS(3325), 1,
      aux_sym_symbol_token5,
    ACTIONS(3328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(3292), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3295), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(3298), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3301), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(3307), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(3310), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2483), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [48985] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1975), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [49072] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2062), 1,
      anon_sym_AMP,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(2071), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    STATE(874), 1,
      sym_macro,
    STATE(1433), 1,
      sym_macro_text_expansion,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49139] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2062), 1,
      anon_sym_AMP,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(876), 1,
      sym_macro,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1438), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49206] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3331), 1,
      sym__line_specifier,
    ACTIONS(3334), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49271] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(2071), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49336] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3331), 1,
      sym__line_specifier,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49401] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49466] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2062), 1,
      anon_sym_AMP,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3284), 1,
      anon_sym_BSLASH,
    STATE(877), 1,
      sym_macro,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    STATE(1444), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49533] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(3337), 1,
      sym__line_specifier,
    STATE(892), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2463), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [49592] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2509), 1,
      sym__line_specifier,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2386), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [49651] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2540), 1,
      sym__line_specifier,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [49710] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2136), 1,
      anon_sym_AMP,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(2145), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    STATE(879), 1,
      sym_macro,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1458), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49777] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2136), 1,
      anon_sym_AMP,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(884), 1,
      sym_macro,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1468), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49844] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3339), 1,
      sym__line_specifier,
    ACTIONS(3342), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [49909] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2540), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [49968] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(2145), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50033] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3339), 1,
      sym__line_specifier,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50098] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50163] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3345), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50228] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2515), 1,
      sym__line_specifier,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2200), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [50287] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(2158), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50352] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2149), 1,
      anon_sym_AMP,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(896), 1,
      sym_macro,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1482), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50419] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3349), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3347), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [50472] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3353), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3351), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [50525] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3355), 1,
      sym__line_specifier,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50590] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50655] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2149), 1,
      anon_sym_AMP,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(2158), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    STATE(897), 1,
      sym_macro,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1485), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50722] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3355), 1,
      sym__line_specifier,
    ACTIONS(3358), 1,
      anon_sym_BSLASH,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [50787] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1984), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [50874] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1649), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [50927] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(3000), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [50992] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(2045), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [51057] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3361), 1,
      anon_sym_AMP,
    ACTIONS(3364), 1,
      sym__line_specifier,
    STATE(901), 1,
      sym_macro,
    STATE(1517), 1,
      sym_macro_text_expansion,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51124] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [51183] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2446), 1,
      anon_sym_BSLASH,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [51242] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3366), 1,
      sym__line_specifier,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51307] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1957), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [51394] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3364), 1,
      sym__line_specifier,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51459] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3364), 1,
      sym__line_specifier,
    ACTIONS(3369), 1,
      anon_sym_BSLASH,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51524] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3361), 1,
      anon_sym_AMP,
    ACTIONS(3364), 1,
      sym__line_specifier,
    ACTIONS(3369), 1,
      anon_sym_BSLASH,
    STATE(905), 1,
      sym_macro,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    STATE(1525), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51591] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3366), 1,
      sym__line_specifier,
    ACTIONS(3371), 1,
      anon_sym_BSLASH,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51656] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3374), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2546), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [51743] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3376), 1,
      sym__line_specifier,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51808] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3376), 1,
      sym__line_specifier,
    ACTIONS(3378), 1,
      anon_sym_AMP,
    STATE(906), 1,
      sym_macro,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    STATE(1528), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51875] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3381), 1,
      sym__line_specifier,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2279), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [51940] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2311), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2313), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [51993] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3376), 1,
      sym__line_specifier,
    ACTIONS(3384), 1,
      anon_sym_BSLASH,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52058] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3386), 1,
      sym__line_specifier,
    STATE(1531), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52123] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3386), 1,
      sym__line_specifier,
    ACTIONS(3388), 1,
      anon_sym_AMP,
    STATE(909), 1,
      sym_macro,
    STATE(1531), 1,
      aux_sym_symbol_repeat1,
    STATE(1532), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52190] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3391), 1,
      sym__line_specifier,
    STATE(1531), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2302), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52255] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3394), 1,
      sym__line_specifier,
    STATE(1534), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52320] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3394), 1,
      sym__line_specifier,
    ACTIONS(3396), 1,
      anon_sym_AMP,
    STATE(912), 1,
      sym_macro,
    STATE(1534), 1,
      aux_sym_symbol_repeat1,
    STATE(1536), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52387] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3399), 1,
      sym__line_specifier,
    STATE(1534), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2323), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52452] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3402), 1,
      sym__line_specifier,
    STATE(1537), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [52517] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    ACTIONS(3138), 1,
      anon_sym_AMP,
    STATE(933), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [52576] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2545), 1,
      sym__line_specifier,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2279), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52635] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52694] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2540), 1,
      sym__line_specifier,
    ACTIONS(2548), 1,
      anon_sym_BSLASH,
    STATE(918), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52753] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3404), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2550), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [52840] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2550), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2290), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52899] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2509), 1,
      sym__line_specifier,
    ACTIONS(2512), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2386), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [52958] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2550), 1,
      sym__line_specifier,
    STATE(926), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2290), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53017] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1764), 1,
      sym__line_specifier,
    ACTIONS(2525), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53076] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3408), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3406), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [53129] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3410), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2407), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [53186] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2555), 1,
      sym__line_specifier,
    STATE(926), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2302), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53245] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3413), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2557), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [53332] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2558), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2311), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53391] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53450] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1989), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [53503] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    STATE(939), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [53560] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3415), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2562), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [53647] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2558), 1,
      sym__line_specifier,
    STATE(937), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2311), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53706] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53765] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    STATE(939), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [53822] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(1796), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [53881] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3417), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2566), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [53968] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2563), 1,
      sym__line_specifier,
    STATE(937), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2323), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54027] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2566), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2332), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54086] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2498), 1,
      sym__line_specifier,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2358), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54145] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3419), 1,
      sym_identifier,
    ACTIONS(3422), 1,
      anon_sym_AMP,
    STATE(939), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [54204] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3425), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2617), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [54291] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3427), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2574), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [54378] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3429), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2576), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [54465] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3431), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2578), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [54552] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(2566), 1,
      sym__line_specifier,
    STATE(953), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2332), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54611] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2442), 1,
      sym__line_specifier,
    ACTIONS(2486), 1,
      anon_sym_BSLASH,
    STATE(964), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [54670] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2666), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [54731] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3435), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3433), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [54784] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3059), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [54849] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2075), 1,
      anon_sym_AMP,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(2084), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(978), 1,
      sym_macro,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1504), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [54916] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    STATE(4309), 1,
      sym_hll_range_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2246), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [55003] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    STATE(3966), 1,
      sym_hll_comma_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2349), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [55090] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2075), 1,
      anon_sym_AMP,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(980), 1,
      sym_macro,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1507), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [55157] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    ACTIONS(3437), 1,
      sym__line_specifier,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2641), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [55216] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [55275] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2480), 1,
      sym__line_specifier,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2221), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [55334] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3439), 1,
      sym__line_specifier,
    ACTIONS(3442), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [55399] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2267), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2269), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [55452] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3447), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3445), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [55505] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3122), 1,
      sym_identifier,
    STATE(1032), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [55562] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3447), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3445), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [55615] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3451), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3449), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [55668] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3439), 1,
      sym__line_specifier,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [55733] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3451), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3449), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [55786] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [55845] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1790), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [55904] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 29,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [55957] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3241), 1,
      sym_identifier,
    ACTIONS(3456), 1,
      anon_sym_AMP,
    STATE(985), 1,
      sym_macro,
    STATE(1543), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [56018] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    ACTIONS(3138), 1,
      anon_sym_AMP,
    STATE(929), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [56077] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3459), 1,
      anon_sym_COLON,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2613), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [56164] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    STATE(4292), 1,
      sym_hll_range_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2128), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [56251] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2480), 1,
      sym__line_specifier,
    ACTIONS(2483), 1,
      anon_sym_BSLASH,
    STATE(831), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2221), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [56310] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1983), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [56397] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    STATE(4289), 1,
      sym_hll_range_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2140), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [56484] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3461), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56549] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1934), 1,
      anon_sym_AMP,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(1945), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(991), 1,
      sym_macro,
    STATE(1513), 1,
      sym_macro_text_expansion,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56616] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1934), 1,
      anon_sym_AMP,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(993), 1,
      sym_macro,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1535), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56683] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3463), 1,
      sym__line_specifier,
    ACTIONS(3466), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56748] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(1945), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56813] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3463), 1,
      sym__line_specifier,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56878] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [56943] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1934), 1,
      anon_sym_AMP,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3461), 1,
      anon_sym_BSLASH,
    STATE(994), 1,
      sym_macro,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    STATE(1538), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57010] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 29,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [57063] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    STATE(4261), 1,
      sym_hll_range_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2069), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [57150] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 29,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [57203] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3136), 1,
      sym_identifier,
    ACTIONS(3138), 1,
      anon_sym_AMP,
    STATE(929), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [57262] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3157), 1,
      sym_identifier,
    ACTIONS(3159), 1,
      anon_sym_AMP,
    STATE(995), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
  [57321] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2110), 1,
      anon_sym_AMP,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(2119), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(996), 1,
      sym_macro,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1542), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57388] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2110), 1,
      anon_sym_AMP,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(999), 1,
      sym_macro,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1546), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57455] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3469), 1,
      sym__line_specifier,
    ACTIONS(3472), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57520] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3157), 1,
      sym_identifier,
    STATE(1014), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
  [57577] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(2119), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57642] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3469), 1,
      sym__line_specifier,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57707] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57772] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3475), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57837] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3157), 1,
      sym_identifier,
    STATE(1014), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
  [57894] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(2132), 1,
      anon_sym_BSLASH,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [57959] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2123), 1,
      anon_sym_AMP,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(1005), 1,
      sym_macro,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1556), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58026] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3477), 1,
      sym__line_specifier,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58091] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58156] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2123), 1,
      anon_sym_AMP,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(2132), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(1008), 1,
      sym_macro,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1559), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58223] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3477), 1,
      sym__line_specifier,
    ACTIONS(3480), 1,
      anon_sym_BSLASH,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58288] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(1689), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [58341] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3483), 1,
      anon_sym_AMP,
    ACTIONS(3486), 1,
      sym__line_specifier,
    STATE(1013), 1,
      sym_macro,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1539), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58408] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3488), 1,
      sym__line_specifier,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58473] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3486), 1,
      sym__line_specifier,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58538] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(858), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat1,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2174), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [58625] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2515), 1,
      sym__line_specifier,
    ACTIONS(2518), 1,
      anon_sym_BSLASH,
    STATE(927), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2200), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [58684] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3486), 1,
      sym__line_specifier,
    ACTIONS(3491), 1,
      anon_sym_BSLASH,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58749] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3483), 1,
      anon_sym_AMP,
    ACTIONS(3486), 1,
      sym__line_specifier,
    ACTIONS(3491), 1,
      anon_sym_BSLASH,
    STATE(1018), 1,
      sym_macro,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1414), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58816] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2456), 1,
      anon_sym_BSLASH,
    ACTIONS(2726), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [58877] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3488), 1,
      sym__line_specifier,
    ACTIONS(3493), 1,
      anon_sym_BSLASH,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [58942] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3122), 1,
      sym_identifier,
    ACTIONS(3124), 1,
      anon_sym_AMP,
    STATE(1030), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [59001] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3496), 1,
      sym__line_specifier,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59066] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3498), 1,
      sym_identifier,
    ACTIONS(3501), 1,
      anon_sym_AMP,
    STATE(1014), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
  [59125] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3496), 1,
      sym__line_specifier,
    ACTIONS(3504), 1,
      anon_sym_AMP,
    STATE(1019), 1,
      sym_macro,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    STATE(1425), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59192] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1743), 1,
      sym__line_specifier,
    ACTIONS(1749), 1,
      anon_sym_BSLASH,
    STATE(834), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [59251] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3507), 1,
      sym__line_specifier,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2279), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59316] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3496), 1,
      sym__line_specifier,
    ACTIONS(3510), 1,
      anon_sym_BSLASH,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59381] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3512), 1,
      sym__line_specifier,
    STATE(1431), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59446] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3512), 1,
      sym__line_specifier,
    ACTIONS(3514), 1,
      anon_sym_AMP,
    STATE(1023), 1,
      sym_macro,
    STATE(1431), 1,
      aux_sym_symbol_repeat1,
    STATE(1435), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59513] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2332), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2334), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [59566] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3517), 1,
      sym__line_specifier,
    STATE(1431), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2302), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59631] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3520), 1,
      sym__line_specifier,
    STATE(1454), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59696] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3520), 1,
      sym__line_specifier,
    ACTIONS(3522), 1,
      anon_sym_AMP,
    STATE(830), 1,
      sym_macro,
    STATE(1454), 1,
      aux_sym_symbol_repeat1,
    STATE(1461), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59763] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3525), 1,
      sym__line_specifier,
    STATE(1454), 1,
      aux_sym_symbol_repeat1,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2323), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [59828] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(1783), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [59887] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(2194), 1,
      anon_sym_BSLASH,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [59946] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2504), 1,
      anon_sym_BSLASH,
    ACTIONS(2532), 1,
      sym__line_specifier,
    STATE(873), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2253), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60005] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1803), 1,
      sym__line_specifier,
    ACTIONS(1809), 1,
      anon_sym_BSLASH,
    STATE(1037), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60064] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3122), 1,
      sym_identifier,
    STATE(1032), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [60121] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3528), 1,
      anon_sym_AMP,
    STATE(835), 1,
      sym_macro,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    STATE(1554), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [60188] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3531), 1,
      sym_identifier,
    ACTIONS(3534), 1,
      anon_sym_AMP,
    STATE(1032), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [60247] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2350), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60306] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2244), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2246), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [60359] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [60424] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2641), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2639), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [60477] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1777), 1,
      sym__line_specifier,
    ACTIONS(2496), 1,
      anon_sym_BSLASH,
    STATE(923), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60536] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2498), 1,
      sym__line_specifier,
    ACTIONS(2501), 1,
      anon_sym_BSLASH,
    STATE(954), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2358), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [60595] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3528), 1,
      anon_sym_AMP,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    STATE(836), 1,
      sym_macro,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    STATE(1555), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [60662] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3541), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3539), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [60715] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2100), 21,
      sym_label_identifier,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      aux_sym_while_block_token2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(2102), 24,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [60768] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [60833] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1926), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [60886] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1930), 30,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [60939] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2075), 1,
      anon_sym_AMP,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3059), 1,
      anon_sym_BSLASH,
    ACTIONS(3260), 1,
      sym_identifier,
    STATE(974), 1,
      sym_macro,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    STATE(1500), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [61006] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2976), 1,
      anon_sym_BSLASH,
    STATE(1176), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [61062] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [61120] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2668), 1,
      anon_sym_BSLASH,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [61178] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2664), 1,
      sym__line_specifier,
    ACTIONS(2794), 1,
      anon_sym_BSLASH,
    STATE(1060), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [61236] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1628), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61320] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1629), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61404] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1630), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61488] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1631), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61572] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1634), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61656] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1635), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61740] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1637), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61824] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1685), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61908] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1647), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [61992] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1648), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [62076] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62134] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(2456), 1,
      anon_sym_BSLASH,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62192] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1822), 1,
      sym__line_specifier,
    ACTIONS(1828), 1,
      anon_sym_BSLASH,
    STATE(1068), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62250] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1689), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [62334] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1686), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [62418] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2488), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [62502] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2435), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62560] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    ACTIONS(3545), 1,
      anon_sym_AMP,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    STATE(1612), 1,
      aux_sym_symbol_repeat1,
    STATE(1398), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [62622] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62680] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2806), 1,
      sym__line_specifier,
    ACTIONS(2809), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2358), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62738] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1863), 1,
      sym__line_specifier,
    ACTIONS(1869), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62796] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2583), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [62880] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2806), 1,
      sym__line_specifier,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    STATE(1076), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2358), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [62938] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1694), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63022] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1695), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63106] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1632), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63190] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63248] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2815), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63306] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2817), 1,
      sym__line_specifier,
    ACTIONS(2820), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2386), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63364] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2492), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63448] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(1856), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63506] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2817), 1,
      sym__line_specifier,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2386), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63564] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2425), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63648] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1850), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1090), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [63706] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2427), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63790] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1696), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63874] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1645), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [63958] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    ACTIONS(3549), 1,
      anon_sym_LPAREN,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2428), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [64042] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2831), 1,
      sym__line_specifier,
    ACTIONS(2834), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2200), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64100] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(1882), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64158] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64216] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2831), 1,
      sym__line_specifier,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2200), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64274] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64332] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1876), 1,
      sym__line_specifier,
    ACTIONS(2841), 1,
      anon_sym_BSLASH,
    STATE(1094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64390] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64448] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(1843), 1,
      anon_sym_BSLASH,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64506] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2853), 1,
      sym__line_specifier,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2221), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64564] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1837), 1,
      sym__line_specifier,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64622] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2853), 1,
      sym__line_specifier,
    ACTIONS(2862), 1,
      anon_sym_BSLASH,
    STATE(1101), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2221), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64680] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1995), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [64764] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2880), 1,
      sym__line_specifier,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2253), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64822] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2878), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64880] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2878), 1,
      sym__line_specifier,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [64938] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2010), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65022] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2878), 1,
      sym__line_specifier,
    ACTIONS(2883), 1,
      anon_sym_BSLASH,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65080] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2880), 1,
      sym__line_specifier,
    ACTIONS(2894), 1,
      anon_sym_BSLASH,
    STATE(1110), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2253), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65138] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2011), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65222] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2012), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65306] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2013), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65390] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2897), 1,
      sym__line_specifier,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65448] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2897), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65506] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2014), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65590] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2015), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65674] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2902), 1,
      sym__line_specifier,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2279), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65732] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2054), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [65816] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2897), 1,
      sym__line_specifier,
    ACTIONS(2911), 1,
      anon_sym_BSLASH,
    STATE(1116), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65874] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2913), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2290), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [65932] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2017), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66016] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2913), 1,
      sym__line_specifier,
    STATE(1121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2290), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66074] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2018), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66158] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2918), 1,
      sym__line_specifier,
    STATE(1121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2302), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66216] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2921), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2311), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66274] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2921), 1,
      sym__line_specifier,
    STATE(1124), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2311), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66332] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2812), 1,
      anon_sym_BSLASH,
    ACTIONS(2930), 1,
      sym__line_specifier,
    STATE(1124), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2323), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66390] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2937), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2332), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66448] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(2937), 1,
      sym__line_specifier,
    STATE(1126), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2332), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66506] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(3551), 1,
      sym__line_specifier,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2641), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [66564] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1159), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [66622] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2418), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66706] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2255), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66790] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2257), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66874] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2261), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [66958] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2262), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67042] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2264), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67126] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2271), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67210] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2368), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67294] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2272), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67378] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2274), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67462] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2385), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67546] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2278), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67630] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2391), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67714] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2392), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67798] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2282), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67882] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2305), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [67966] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2976), 1,
      anon_sym_BSLASH,
    STATE(1146), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [68022] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2051), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68106] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2976), 1,
      anon_sym_BSLASH,
    STATE(1176), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [68162] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2026), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68246] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2426), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68330] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2430), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68414] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1989), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68498] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1990), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68582] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2040), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68666] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2431), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68750] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1991), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [68834] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2941), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [68886] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    STATE(1160), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [68942] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2994), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [68994] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3553), 1,
      anon_sym_BSLASH,
    STATE(1158), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2407), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [69050] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    STATE(1160), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [69106] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3556), 1,
      sym_identifier,
    ACTIONS(3559), 1,
      anon_sym_AMP,
    STATE(1160), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [69164] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3562), 1,
      sym_identifier,
    ACTIONS(3564), 1,
      anon_sym_AMP,
    ACTIONS(3567), 1,
      anon_sym_BSLASH,
    STATE(1162), 1,
      sym_macro,
    STATE(1602), 1,
      sym_macro_text_expansion,
    STATE(1603), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2463), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [69228] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3567), 1,
      anon_sym_BSLASH,
    ACTIONS(3569), 1,
      sym_identifier,
    ACTIONS(3571), 1,
      anon_sym_AMP,
    STATE(1611), 1,
      aux_sym_symbol_repeat1,
    STATE(1361), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [69290] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [69342] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2469), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69426] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2470), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69510] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2471), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69594] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [69646] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2472), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69730] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2473), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69814] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2474), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69898] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2459), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [69982] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2421), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym__blank,
  [70034] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2475), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [70118] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2476), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [70202] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2477), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [70286] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3573), 1,
      anon_sym_BSLASH,
    STATE(1176), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2407), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [70342] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1046), 1,
      sym_identifier,
    ACTIONS(1048), 1,
      anon_sym_LPAREN,
    ACTIONS(1056), 1,
      anon_sym_sizeof,
    STATE(2850), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1050), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1052), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1054), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1757), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2478), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [70426] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1989), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym__blank,
  [70478] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3258), 1,
      sym_identifier,
    ACTIONS(3576), 1,
      anon_sym_AMP,
    STATE(1181), 1,
      sym_macro,
    STATE(1572), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70538] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70596] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1185), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70654] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [70706] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [70758] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    ACTIONS(3256), 1,
      anon_sym_AMP,
    STATE(1186), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70816] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    STATE(1188), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70872] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3254), 1,
      sym_identifier,
    STATE(1188), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [70928] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1996), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71012] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3579), 1,
      sym_identifier,
    ACTIONS(3582), 1,
      anon_sym_AMP,
    STATE(1188), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [71070] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1997), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71154] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1998), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71238] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1999), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71322] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2000), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71406] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2001), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71490] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1926), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym__blank,
  [71542] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(1930), 29,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym__blank,
  [71594] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2002), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71678] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2016), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71762] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2003), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71846] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2004), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [71930] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2048), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72014] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(620), 1,
      anon_sym_LPAREN,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2049), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72098] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1428), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72182] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(618), 1,
      sym_identifier,
    ACTIONS(630), 1,
      anon_sym_sizeof,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3585), 1,
      anon_sym_LPAREN,
    STATE(2855), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(622), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(624), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(626), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1623), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2050), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72266] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3260), 1,
      sym_identifier,
    ACTIONS(3587), 1,
      anon_sym_AMP,
    STATE(1248), 1,
      sym_macro,
    STATE(1614), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [72326] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [72384] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2804), 1,
      anon_sym_BSLASH,
    ACTIONS(3590), 1,
      sym__line_specifier,
    STATE(1047), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2463), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [72442] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1448), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72526] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1449), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72610] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1450), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72694] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1451), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72778] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1452), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72862] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1453), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [72946] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1569), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73030] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1455), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73114] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1457), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73198] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1432), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73282] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1463), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73366] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2023), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73450] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1495), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73534] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1496), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73618] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1471), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73702] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1529), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73786] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2053), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73870] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1993), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [73954] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1360), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74038] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    ACTIONS(3592), 1,
      anon_sym_LPAREN,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1994), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74122] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2025), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74206] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2375), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74290] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2377), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74374] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2387), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74458] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2388), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74542] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2389), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74626] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2390), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74710] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2393), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74794] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2259), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74878] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2395), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [74962] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2269), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75046] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2263), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75130] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2299), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75214] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2265), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75298] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2266), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75382] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2363), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75466] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2267), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75550] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1676), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75634] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1677), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75718] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1684), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75802] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(410), 1,
      sym_identifier,
    ACTIONS(422), 1,
      anon_sym_sizeof,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(438), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3594), 1,
      anon_sym_LPAREN,
    STATE(2856), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(416), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(418), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(424), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(426), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1700), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1678), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [75886] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3246), 1,
      sym_identifier,
    ACTIONS(3248), 1,
      anon_sym_AMP,
    STATE(1156), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [75944] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1382), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76028] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1383), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76112] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1384), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76196] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1385), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76280] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1386), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76364] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1387), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76448] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1388), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76532] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1367), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76616] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1389), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76700] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1390), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76784] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1404), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76868] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1393), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [76952] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1371), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77036] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1372), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77120] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1396), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77204] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2037), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77288] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1373), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77372] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1523), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77456] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1483), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77540] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3596), 1,
      anon_sym_LPAREN,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1567), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77624] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2039), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77708] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2437), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77792] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2438), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77876] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2423), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [77960] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2439), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78044] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2440), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78128] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2441), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78212] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2442), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78296] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2394), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78380] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2443), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78464] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2444), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78548] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2293), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78632] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2446), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78716] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2357), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78800] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2358), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78884] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2449), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [78968] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2043), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79052] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2382), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79136] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2402), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79220] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2404), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79304] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    ACTIONS(3598), 1,
      anon_sym_LPAREN,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2411), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79388] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2321), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79472] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2322), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79556] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2323), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79640] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2324), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79724] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2325), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79808] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2326), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79892] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2327), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [79976] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2394), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80060] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2328), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80144] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2329), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80228] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2293), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80312] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2331), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80396] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2357), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80480] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2358), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80564] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2334), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80648] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2382), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80732] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1347), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80816] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(300), 1,
      anon_sym_LPAREN,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1348), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80900] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(296), 1,
      sym_identifier,
    ACTIONS(312), 1,
      anon_sym_sizeof,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(328), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3600), 1,
      anon_sym_LPAREN,
    STATE(2846), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(304), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(306), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(308), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(314), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(316), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1518), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1349), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [80984] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1652), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81068] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1653), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81152] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1654), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81236] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1655), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81320] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1656), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81404] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1657), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81488] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1658), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81572] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1636), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81656] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1659), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81740] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1660), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81824] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1639), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81908] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1662), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [81992] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1641), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82076] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1642), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82160] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1665), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82244] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1643), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82328] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2345), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82412] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2254), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82496] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(1390), 1,
      sym_identifier,
    ACTIONS(1400), 1,
      anon_sym_sizeof,
    ACTIONS(3602), 1,
      anon_sym_LPAREN,
    STATE(2870), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(1394), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1396), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(1398), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1738), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2502), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82580] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2345), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82664] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(868), 1,
      anon_sym_LPAREN,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2254), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82748] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(866), 1,
      sym_identifier,
    ACTIONS(878), 1,
      anon_sym_sizeof,
    ACTIONS(884), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3604), 1,
      anon_sym_LPAREN,
    STATE(2841), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(870), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(872), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(874), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(880), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(882), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1775), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2320), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82832] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1663), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [82916] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(442), 1,
      anon_sym_LPAREN,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1683), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83000] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(440), 1,
      sym_identifier,
    ACTIONS(452), 1,
      anon_sym_sizeof,
    ACTIONS(458), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(460), 1,
      aux_sym_symbol_token1,
    ACTIONS(462), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(464), 1,
      anon_sym_BSLASH,
    ACTIONS(466), 1,
      aux_sym_symbol_token5,
    ACTIONS(468), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3606), 1,
      anon_sym_LPAREN,
    STATE(2875), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(444), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(446), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(448), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(876), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(454), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(456), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1698), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1680), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83084] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2276), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83168] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(912), 1,
      anon_sym_LPAREN,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2348), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83252] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(428), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(430), 1,
      aux_sym_symbol_token1,
    ACTIONS(432), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(434), 1,
      anon_sym_BSLASH,
    ACTIONS(436), 1,
      aux_sym_symbol_token5,
    ACTIONS(910), 1,
      sym_identifier,
    ACTIONS(922), 1,
      anon_sym_sizeof,
    ACTIONS(928), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(3608), 1,
      anon_sym_LPAREN,
    STATE(2853), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(914), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(916), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(920), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(924), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(926), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1722), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2350), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83336] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2612), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83420] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(572), 1,
      anon_sym_LPAREN,
    ACTIONS(582), 1,
      anon_sym_sizeof,
    ACTIONS(614), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(638), 1,
      sym_identifier,
    STATE(2864), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(574), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(576), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(578), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(584), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(586), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1581), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2047), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83504] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(318), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(320), 1,
      aux_sym_symbol_token1,
    ACTIONS(322), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(324), 1,
      anon_sym_BSLASH,
    ACTIONS(326), 1,
      aux_sym_symbol_token5,
    ACTIONS(636), 1,
      sym__hll_number_literal_pre_hook,
    ACTIONS(886), 1,
      sym_identifier,
    ACTIONS(888), 1,
      anon_sym_LPAREN,
    ACTIONS(896), 1,
      anon_sym_sizeof,
    STATE(2851), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(580), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(890), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(892), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(894), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(632), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(634), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1679), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(2545), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83588] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    ACTIONS(3610), 1,
      sym_identifier,
    ACTIONS(3612), 1,
      anon_sym_AMP,
    STATE(1067), 1,
      sym_macro,
    STATE(1593), 1,
      sym_macro_text_expansion,
    STATE(1601), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
    ACTIONS(2463), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [83652] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(366), 1,
      sym_identifier,
    ACTIONS(368), 1,
      anon_sym_LPAREN,
    ACTIONS(378), 1,
      anon_sym_sizeof,
    ACTIONS(384), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(386), 1,
      aux_sym_symbol_token1,
    ACTIONS(388), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(390), 1,
      anon_sym_BSLASH,
    ACTIONS(392), 1,
      aux_sym_symbol_token5,
    ACTIONS(394), 1,
      sym__hll_number_literal_pre_hook,
    STATE(2872), 1,
      sym__hll_assignment_left_expression,
    ACTIONS(370), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(372), 2,
      anon_sym_TILDE,
      anon_sym_BANG,
    ACTIONS(374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(628), 2,
      anon_sym_STAR,
      anon_sym_AMP,
    ACTIONS(380), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(382), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    STATE(1594), 6,
      sym_hll_call_expression,
      sym_hll_field_expression,
      sym_hll_subscript_expression,
      sym_hll_pointer_expression,
      sym_hll_parenthesized_expression,
      sym_symbol,
    STATE(1443), 10,
      sym__hll_expression,
      sym_hll_cast_expression,
      sym_hll_sizeof_expression,
      sym_hll_update_expression,
      sym_hll_unary_expression,
      sym_hll_binary_expression,
      sym_hll_assignment_expression,
      sym_hll_conditional_expression,
      sym_hll_char_literal,
      sym_hll_string_literal,
  [83736] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3140), 1,
      anon_sym_BSLASH,
    STATE(1399), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [83791] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [83842] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [83893] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [83944] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2407), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [83995] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3619), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3615), 25,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [84056] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3627), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [84119] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3633), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [84184] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_BSLASH,
    ACTIONS(2421), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [84235] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3562), 1,
      sym_identifier,
    ACTIONS(3639), 1,
      anon_sym_AMP,
    STATE(1353), 1,
      sym_macro,
    STATE(1675), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84294] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3569), 1,
      sym_identifier,
    ACTIONS(3571), 1,
      anon_sym_AMP,
    STATE(1361), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84351] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3569), 1,
      sym_identifier,
    ACTIONS(3571), 1,
      anon_sym_AMP,
    STATE(1361), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84408] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    ACTIONS(3545), 1,
      anon_sym_AMP,
    STATE(1398), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [84465] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
  [84516] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [84567] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [84618] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3569), 1,
      sym_identifier,
    ACTIONS(3571), 1,
      anon_sym_AMP,
    STATE(1362), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84675] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3192), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [84734] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3644), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3642), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [84797] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3569), 1,
      sym_identifier,
    STATE(1364), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84852] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3569), 1,
      sym_identifier,
    STATE(1364), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [84907] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3610), 1,
      sym_identifier,
    ACTIONS(3646), 1,
      anon_sym_AMP,
    STATE(1354), 1,
      sym_macro,
    STATE(1681), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [84966] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3649), 1,
      sym_identifier,
    ACTIONS(3652), 1,
      anon_sym_AMP,
    STATE(1364), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [85023] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
  [85074] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
  [85125] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3655), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [85188] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    ACTIONS(3545), 1,
      anon_sym_AMP,
    STATE(1398), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [85245] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(3000), 1,
      anon_sym_BSLASH,
    ACTIONS(3126), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [85304] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3236), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 16,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(3217), 25,
      sym__hll_number_literal_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [85359] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3659), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [85422] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3663), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [85485] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3667), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [85548] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2941), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [85599] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3140), 1,
      anon_sym_BSLASH,
    STATE(1378), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [85654] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    ACTIONS(3545), 1,
      anon_sym_AMP,
    STATE(1400), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [85711] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2994), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [85762] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3140), 1,
      anon_sym_BSLASH,
    STATE(1399), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [85817] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 28,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [85868] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      anon_sym_EQ,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3678), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3671), 17,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [85925] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [85976] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86043] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_EQ,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86126] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86191] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86270] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3657), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86347] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(3655), 21,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86420] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86489] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_EQ,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86570] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
    ACTIONS(3655), 19,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86645] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3703), 1,
      anon_sym_EQ,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3701), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86732] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [86783] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    ACTIONS(3711), 1,
      anon_sym_EQ,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3709), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86870] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    ACTIONS(3715), 1,
      anon_sym_EQ,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3713), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [86957] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    ACTIONS(3719), 1,
      anon_sym_EQ,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3717), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [87044] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    ACTIONS(3723), 1,
      anon_sym_EQ,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3721), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [87131] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      anon_sym_PIPE,
    ACTIONS(3689), 1,
      anon_sym_CARET,
    ACTIONS(3697), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3699), 1,
      anon_sym_AMP,
    ACTIONS(3705), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3707), 1,
      anon_sym_QMARK,
    ACTIONS(3727), 1,
      anon_sym_EQ,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3637), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3685), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3691), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3693), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3695), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3683), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3725), 16,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [87218] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    STATE(1401), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [87273] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3729), 1,
      anon_sym_BSLASH,
    STATE(1399), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [87328] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3543), 1,
      sym_identifier,
    STATE(1401), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [87383] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3732), 1,
      sym_identifier,
    ACTIONS(3735), 1,
      anon_sym_AMP,
    STATE(1401), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [87440] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3149), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [87499] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2851), 1,
      anon_sym_BSLASH,
    ACTIONS(3183), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [87558] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3631), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3738), 23,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [87621] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3719), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3717), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [87705] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3271), 1,
      sym__line_specifier,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [87761] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [87811] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3774), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [87861] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3496), 1,
      sym__line_specifier,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [87917] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [87973] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3284), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88029] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3331), 1,
      sym__line_specifier,
    ACTIONS(3334), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88085] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3507), 1,
      sym__line_specifier,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2279), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [88141] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3496), 1,
      sym__line_specifier,
    ACTIONS(3510), 1,
      anon_sym_BSLASH,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [88197] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [88247] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3778), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [88297] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [88347] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3782), 1,
      anon_sym_RPAREN,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3789), 1,
      anon_sym_STAR,
    ACTIONS(3796), 1,
      sym__blank,
    ACTIONS(3784), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(3794), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 11,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 12,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
  [88413] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3800), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [88463] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3804), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [88517] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(2071), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88573] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3512), 1,
      sym__line_specifier,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [88629] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3331), 1,
      sym__line_specifier,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88685] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2065), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1434), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88741] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3512), 1,
      sym__line_specifier,
    STATE(1431), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [88797] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [88853] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3339), 1,
      sym__line_specifier,
    ACTIONS(3342), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [88909] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3644), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3642), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [88969] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      sym_identifier,
  [89019] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3517), 1,
      sym__line_specifier,
    STATE(1431), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2302), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89075] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3520), 1,
      sym__line_specifier,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89131] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3740), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3738), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [89191] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(2145), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89247] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89303] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3520), 1,
      sym__line_specifier,
    STATE(1454), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89359] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3339), 1,
      sym__line_specifier,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89415] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3194), 1,
      anon_sym_BSLASH,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89471] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89527] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89583] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3525), 1,
      sym__line_specifier,
    STATE(1454), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2323), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [89639] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3807), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [89689] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3811), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [89739] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [89803] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2139), 1,
      sym__line_specifier,
    ACTIONS(3345), 1,
      anon_sym_BSLASH,
    STATE(1445), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89859] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [89915] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      sym_identifier,
  [89965] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 27,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
      sym_identifier,
  [90015] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90095] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90157] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90233] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90307] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 18,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90377] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90443] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3250), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [90499] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90577] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3817), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3815), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [90627] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 16,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90699] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(2158), 1,
      anon_sym_BSLASH,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [90755] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3819), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [90809] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3703), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3701), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [90893] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3250), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1474), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [90949] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3355), 1,
      sym__line_specifier,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91005] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3711), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3709), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [91089] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3190), 1,
      sym__line_specifier,
    ACTIONS(3265), 1,
      anon_sym_BSLASH,
    STATE(1439), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [91145] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3715), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3713), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [91229] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(3000), 1,
      anon_sym_BSLASH,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [91285] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3824), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3822), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [91335] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2152), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91391] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3355), 1,
      sym__line_specifier,
    ACTIONS(3358), 1,
      anon_sym_BSLASH,
    STATE(1480), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91447] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2039), 1,
      sym__line_specifier,
    ACTIONS(2045), 1,
      anon_sym_BSLASH,
    STATE(1490), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [91503] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3723), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3721), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [91587] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3828), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3826), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [91637] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3752), 1,
      anon_sym_PIPE,
    ACTIONS(3754), 1,
      anon_sym_CARET,
    ACTIONS(3764), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3766), 1,
      anon_sym_AMP,
    ACTIONS(3770), 1,
      anon_sym_QMARK,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3744), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3756), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3758), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3760), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3727), 3,
      anon_sym_EQ,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3750), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3725), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [91721] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3830), 1,
      sym__line_specifier,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2641), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [91777] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3678), 1,
      sym__blank,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3671), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [91835] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3366), 1,
      sym__line_specifier,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [91891] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2100), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [91941] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3834), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3832), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [91991] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3838), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3836), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92041] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3364), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [92097] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3435), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92147] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3364), 1,
      sym__line_specifier,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [92203] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3629), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3627), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [92263] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1667), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92313] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3364), 1,
      sym__line_specifier,
    ACTIONS(3369), 1,
      anon_sym_BSLASH,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [92369] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3840), 1,
      sym__line_specifier,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3671), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [92425] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1707), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92475] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1647), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92525] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3059), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [92581] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [92637] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3439), 1,
      sym__line_specifier,
    ACTIONS(3442), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [92693] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2078), 1,
      sym__line_specifier,
    ACTIONS(2084), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [92749] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3439), 1,
      sym__line_specifier,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    STATE(1499), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [92805] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1687), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [92855] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3661), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3659), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [92915] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3665), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3663), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [92975] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2058), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [93031] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(1625), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93081] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93137] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3461), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93193] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2244), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93243] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3844), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3842), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93293] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3463), 1,
      sym__line_specifier,
    ACTIONS(3466), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93349] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(1945), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93405] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3463), 1,
      sym__line_specifier,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2386), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93461] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2267), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93511] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1939), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1514), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93567] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2290), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93617] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3366), 1,
      sym__line_specifier,
    ACTIONS(3371), 1,
      anon_sym_BSLASH,
    STATE(1520), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [93673] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2311), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93723] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3469), 1,
      sym__line_specifier,
    ACTIONS(3472), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93779] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2332), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93829] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(2119), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93885] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [93941] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(2641), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [93991] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3541), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [94041] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3376), 1,
      sym__line_specifier,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94097] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      anon_sym_EQ,
    ACTIONS(3678), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3671), 17,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [94151] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3848), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3846), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [94201] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3376), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94257] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3789), 1,
      anon_sym_STAR,
    ACTIONS(3796), 1,
      sym__blank,
    ACTIONS(3794), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(3784), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 11,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 12,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
  [94321] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3469), 1,
      sym__line_specifier,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2200), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [94377] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3615), 22,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [94435] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3381), 1,
      sym__line_specifier,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2279), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94491] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3376), 1,
      sym__line_specifier,
    ACTIONS(3384), 1,
      anon_sym_BSLASH,
    STATE(1527), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94547] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3852), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3850), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [94597] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3386), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94653] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3386), 1,
      sym__line_specifier,
    STATE(1531), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94709] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3667), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [94769] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3391), 1,
      sym__line_specifier,
    STATE(1531), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2302), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94825] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3394), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94881] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3394), 1,
      sym__line_specifier,
    STATE(1534), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94937] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3277), 1,
      anon_sym_BSLASH,
    ACTIONS(3399), 1,
      sym__line_specifier,
    STATE(1534), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2323), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [94993] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3402), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95049] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95105] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3402), 1,
      sym__line_specifier,
    STATE(1537), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95161] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3854), 1,
      sym__line_specifier,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2641), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95217] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2113), 1,
      sym__line_specifier,
    ACTIONS(3475), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95273] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3496), 1,
      sym__line_specifier,
    STATE(1422), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95329] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [95379] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95435] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(2132), 1,
      anon_sym_BSLASH,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95491] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 16,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [95541] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3477), 1,
      sym__line_specifier,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95597] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    ACTIONS(3856), 1,
      sym__line_specifier,
    STATE(1548), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2463), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95653] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2126), 1,
      sym__line_specifier,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95709] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3477), 1,
      sym__line_specifier,
    ACTIONS(3480), 1,
      anon_sym_BSLASH,
    STATE(1553), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2221), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95765] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95821] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3151), 1,
      anon_sym_BSLASH,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95877] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3147), 1,
      sym__line_specifier,
    ACTIONS(3537), 1,
      anon_sym_BSLASH,
    STATE(1552), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [95933] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3453), 1,
      anon_sym_BSLASH,
    ACTIONS(3488), 1,
      sym__line_specifier,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [95989] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96045] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3486), 1,
      sym__line_specifier,
    STATE(1459), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [96101] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2851), 1,
      anon_sym_BSLASH,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96157] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1998), 1,
      sym__line_specifier,
    ACTIONS(2004), 1,
      anon_sym_BSLASH,
    STATE(1565), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96213] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3486), 1,
      sym__line_specifier,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [96269] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(2860), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96325] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3860), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3858), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [96375] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3486), 1,
      sym__line_specifier,
    ACTIONS(3491), 1,
      anon_sym_BSLASH,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [96431] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3864), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3862), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [96481] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3488), 1,
      sym__line_specifier,
    ACTIONS(3493), 1,
      anon_sym_BSLASH,
    STATE(1409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2253), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [96537] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3868), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3866), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [96587] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3872), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3870), 28,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
  [96637] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3252), 1,
      anon_sym_BSLASH,
    ACTIONS(3874), 1,
      sym__line_specifier,
    STATE(1426), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2463), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [96693] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2052), 1,
      sym__line_specifier,
    ACTIONS(3269), 1,
      anon_sym_BSLASH,
    STATE(1420), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96749] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3840), 1,
      sym__line_specifier,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3671), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [96807] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3762), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3635), 13,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3633), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [96869] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3271), 1,
      sym__line_specifier,
    ACTIONS(3274), 1,
      anon_sym_BSLASH,
    STATE(1410), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2358), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [96925] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3746), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 20,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [96985] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [97034] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2641), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97083] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [97132] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2100), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97181] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [97230] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [97279] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3778), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97328] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3824), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3822), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97377] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2941), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [97426] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3876), 1,
      anon_sym_BSLASH,
    STATE(1579), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [97479] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2244), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97528] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3678), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3671), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [97583] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3868), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3866), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97632] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2994), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym__line_specifier,
  [97681] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3860), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3858), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97730] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3828), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3826), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97779] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1625), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97828] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3541), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97877] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [97932] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2267), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [97981] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3864), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3862), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98030] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3834), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3832), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98079] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3838), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3836), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98128] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    STATE(1612), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [98181] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3671), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98234] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3807), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98283] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [98332] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3435), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98381] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1647), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98430] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym_identifier,
  [98479] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3872), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3870), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98528] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    STATE(1619), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [98581] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3567), 1,
      anon_sym_BSLASH,
    STATE(1611), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98634] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3567), 1,
      anon_sym_BSLASH,
    STATE(1579), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [98687] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2332), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98736] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym_identifier,
  [98785] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3811), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98834] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2941), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [98883] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1687), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98932] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1707), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [98981] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3817), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3815), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99030] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3567), 1,
      anon_sym_BSLASH,
    STATE(1579), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [99083] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3547), 1,
      anon_sym_BSLASH,
    STATE(1619), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [99136] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2994), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [99185] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [99234] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
      sym_identifier,
  [99283] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3774), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99332] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2311), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99381] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3844), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3842), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99430] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3879), 1,
      anon_sym_BSLASH,
    STATE(1619), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [99483] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3800), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99532] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3848), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3846), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99581] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(1667), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99630] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 13,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3671), 16,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99685] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(2290), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99734] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3852), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3850), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [99783] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 26,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [99832] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3882), 1,
      sym__line_specifier,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [99888] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [99950] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100028] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100088] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3657), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100162] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3723), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3721), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100244] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3727), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3725), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100326] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100398] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100466] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [100524] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [100588] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3882), 1,
      sym__line_specifier,
    ACTIONS(3924), 1,
      sym__blank,
    ACTIONS(3782), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [100646] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3740), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3738), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [100704] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(3932), 1,
      aux_sym_symbol_token1,
    ACTIONS(3934), 1,
      aux_sym_symbol_token2,
    ACTIONS(3936), 1,
      anon_sym_BSLASH,
    ACTIONS(3938), 1,
      aux_sym_symbol_token3,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    STATE(1835), 1,
      sym_macro,
    STATE(2106), 1,
      sym_string,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    STATE(2220), 1,
      sym_macro_text_expansion,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [100778] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3661), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3659), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [100836] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3665), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3663), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [100894] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3667), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [100952] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3942), 1,
      sym__line_specifier,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101006] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3644), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3642), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [101064] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3942), 1,
      sym__line_specifier,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101120] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [101196] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [101266] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(3950), 1,
      aux_sym_symbol_token1,
    ACTIONS(3952), 1,
      aux_sym_symbol_token2,
    ACTIONS(3954), 1,
      anon_sym_BSLASH,
    ACTIONS(3956), 1,
      aux_sym_symbol_token3,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    STATE(1820), 1,
      sym_macro,
    STATE(2077), 1,
      sym_macro_text_expansion,
    STATE(2200), 1,
      sym_string,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [101340] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3703), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3701), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [101422] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(3962), 1,
      aux_sym_symbol_token1,
    ACTIONS(3964), 1,
      aux_sym_symbol_token2,
    ACTIONS(3966), 1,
      anon_sym_BSLASH,
    ACTIONS(3968), 1,
      aux_sym_symbol_token3,
    STATE(1825), 1,
      sym_macro,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(2112), 1,
      sym_macro_text_expansion,
    STATE(2142), 1,
      sym_string,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [101496] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101558] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101636] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101696] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3657), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101770] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101842] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 17,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101910] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [101974] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102050] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102120] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3703), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3701), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102202] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3711), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3709), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102284] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3615), 21,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102340] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3719), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3717), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102422] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3723), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3721), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102504] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3727), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3725), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102586] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(3996), 1,
      aux_sym_symbol_token1,
    ACTIONS(3998), 1,
      aux_sym_symbol_token2,
    ACTIONS(4000), 1,
      anon_sym_BSLASH,
    ACTIONS(4002), 1,
      aux_sym_symbol_token3,
    STATE(1846), 1,
      sym_macro,
    STATE(2099), 1,
      sym_macro_text_expansion,
    STATE(2110), 1,
      sym_string,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [102660] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4006), 1,
      aux_sym_symbol_token1,
    ACTIONS(4008), 1,
      aux_sym_symbol_token2,
    ACTIONS(4010), 1,
      anon_sym_BSLASH,
    ACTIONS(4012), 1,
      aux_sym_symbol_token3,
    STATE(1838), 1,
      sym_macro,
    STATE(2073), 1,
      sym_string,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(2199), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [102734] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [102782] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4016), 1,
      aux_sym_symbol_token1,
    ACTIONS(4018), 1,
      aux_sym_symbol_token2,
    ACTIONS(4020), 1,
      anon_sym_BSLASH,
    ACTIONS(4022), 1,
      aux_sym_symbol_token3,
    STATE(1875), 1,
      sym_macro,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(2144), 1,
      sym_string,
    STATE(2198), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [102856] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3942), 1,
      sym__line_specifier,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [102910] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3882), 1,
      sym__line_specifier,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [102964] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4026), 1,
      aux_sym_symbol_token1,
    ACTIONS(4028), 1,
      aux_sym_symbol_token2,
    ACTIONS(4030), 1,
      anon_sym_BSLASH,
    ACTIONS(4032), 1,
      aux_sym_symbol_token3,
    STATE(1883), 1,
      sym_macro,
    STATE(2108), 1,
      sym_string,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(2237), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [103038] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [103086] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [103134] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3615), 21,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103190] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3629), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3627), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103248] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3635), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3633), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103308] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 11,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym__blank,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 16,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
  [103360] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3633), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [103420] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 15,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103468] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4036), 1,
      aux_sym_symbol_token1,
    ACTIONS(4038), 1,
      aux_sym_symbol_token2,
    ACTIONS(4040), 1,
      anon_sym_BSLASH,
    ACTIONS(4042), 1,
      aux_sym_symbol_token3,
    STATE(1887), 1,
      sym_macro,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(2063), 1,
      sym_string,
    STATE(2148), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [103542] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3629), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3627), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [103600] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3644), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3642), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [103658] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103716] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3711), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3709), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103798] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3715), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3713), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103880] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(3898), 1,
      anon_sym_PIPE,
    ACTIONS(3900), 1,
      anon_sym_CARET,
    ACTIONS(3908), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3910), 1,
      anon_sym_AMP,
    ACTIONS(3912), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3914), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3719), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3890), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3896), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3902), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3904), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3906), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3888), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3717), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [103962] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3740), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3738), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104020] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3882), 1,
      sym__line_specifier,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [104074] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3882), 1,
      sym__line_specifier,
    ACTIONS(3782), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [104130] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4046), 1,
      aux_sym_symbol_token1,
    ACTIONS(4048), 1,
      aux_sym_symbol_token2,
    ACTIONS(4050), 1,
      anon_sym_BSLASH,
    ACTIONS(4052), 1,
      aux_sym_symbol_token3,
    STATE(1901), 1,
      sym_macro,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(2195), 1,
      sym_string,
    STATE(2196), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [104204] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4056), 1,
      aux_sym_symbol_token1,
    ACTIONS(4058), 1,
      aux_sym_symbol_token2,
    ACTIONS(4060), 1,
      anon_sym_BSLASH,
    ACTIONS(4062), 1,
      aux_sym_symbol_token3,
    STATE(1837), 1,
      sym_macro,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    STATE(2189), 1,
      sym_string,
    STATE(2252), 1,
      sym_macro_text_expansion,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [104278] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3661), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3659), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104336] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3665), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3663), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104394] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3886), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3667), 19,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104452] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(3976), 1,
      anon_sym_PIPE,
    ACTIONS(3978), 1,
      anon_sym_CARET,
    ACTIONS(3986), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3988), 1,
      anon_sym_AMP,
    ACTIONS(3990), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3992), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3715), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3918), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3972), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(3980), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3982), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3984), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3970), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3713), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [104534] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [104585] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104632] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3678), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [104683] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [104730] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3872), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3870), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [104777] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3559), 1,
      sym_option_expression,
    STATE(3875), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4064), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4066), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [104834] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104881] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [104928] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [104975] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2641), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105022] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3541), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105069] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3824), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3822), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105116] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105163] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105210] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2290), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105257] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105304] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2311), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105351] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2332), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105398] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2641), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105445] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3435), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105492] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3541), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105539] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3834), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3832), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105586] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3800), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105633] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3864), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3862), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105680] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [105733] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3860), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3858), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105780] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3838), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3836), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105827] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3864), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3862), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105874] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3817), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3815), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [105921] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3868), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3866), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [105968] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3924), 1,
      sym__blank,
    ACTIONS(3782), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [106023] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3774), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106070] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3435), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106117] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106164] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2244), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106211] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3778), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106258] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3800), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106305] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3828), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3826), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106352] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1667), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106399] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3844), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3842), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106446] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106497] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3580), 1,
      sym_option_expression,
    STATE(3920), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [106554] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    ACTIONS(4072), 1,
      anon_sym_COMMA,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3580), 1,
      sym_option_expression,
    STATE(3920), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 19,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [106613] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3559), 1,
      sym_option_expression,
    STATE(3875), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [106670] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3807), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106717] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3811), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106764] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3848), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3846), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106811] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3778), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106858] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3868), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3866), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106905] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3852), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3850), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [106952] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1625), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [106999] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3807), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [107046] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107093] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3828), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3826), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107140] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3782), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [107193] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3844), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3842), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107240] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3811), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [107287] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1707), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [107334] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3848), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3846), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107381] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3787), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [107432] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3834), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3832), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107479] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3838), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3836), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107526] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3678), 1,
      sym__blank,
    ACTIONS(3782), 1,
      anon_sym_RPAREN,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 14,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [107581] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107628] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3852), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3850), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107675] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3824), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3822), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [107722] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2267), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107769] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3457), 1,
      sym_option_expression,
    STATE(3923), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4064), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4066), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [107826] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1687), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107873] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3860), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3858), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [107920] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3872), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3870), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [107967] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    ACTIONS(472), 1,
      sym__blank,
    ACTIONS(4072), 1,
      anon_sym_COMMA,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    STATE(3559), 1,
      sym_option_expression,
    STATE(3875), 1,
      aux_sym__command_arguments_repeat2,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 19,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108026] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4075), 1,
      sym__blank,
    STATE(1770), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 15,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(3217), 22,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
      sym_comment,
      sym__blank_line,
  [108077] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(1647), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [108124] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(2100), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      sym_comment,
      sym__blank_line,
  [108171] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3817), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3815), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [108218] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 14,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3774), 25,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [108265] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3673), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 15,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [108318] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4080), 1,
      sym__blank,
    STATE(1765), 1,
      aux_sym_block_repeat1,
    ACTIONS(4078), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108370] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3681), 1,
      sym__line_specifier,
    ACTIONS(3782), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [108424] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4084), 1,
      sym__blank,
    STATE(1703), 1,
      aux_sym_block_repeat1,
    ACTIONS(4082), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108476] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4090), 1,
      sym__blank,
    STATE(1741), 1,
      aux_sym_block_repeat1,
    ACTIONS(4082), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4086), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4088), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108528] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4094), 1,
      sym__blank,
    STATE(1739), 1,
      aux_sym_block_repeat1,
    ACTIONS(4092), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4086), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4088), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108580] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    STATE(1784), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1888), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [108631] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4100), 1,
      sym_identifier,
    ACTIONS(4103), 1,
      anon_sym_AMP,
    STATE(1782), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1905), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [108682] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    STATE(1790), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [108733] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    STATE(1782), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1900), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [108784] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3782), 1,
      sym__blank,
    ACTIONS(3787), 1,
      anon_sym_EQ,
    ACTIONS(3792), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3676), 12,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP,
    ACTIONS(3671), 13,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [108835] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    STATE(1782), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1896), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [108886] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4110), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(3217), 21,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [108935] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    STATE(1790), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [108986] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    STATE(1788), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [109037] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4113), 1,
      sym_identifier,
    ACTIONS(4116), 1,
      anon_sym_AMP,
    STATE(1790), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [109088] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4119), 1,
      aux_sym_symbol_token1,
    ACTIONS(4121), 1,
      aux_sym_symbol_token2,
    ACTIONS(4123), 1,
      anon_sym_BSLASH,
    STATE(1855), 1,
      sym_macro,
    STATE(2071), 1,
      sym_macro_text_expansion,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [109150] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4125), 1,
      sym__blank,
    STATE(1796), 1,
      aux_sym_block_repeat1,
    ACTIONS(4086), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4088), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109198] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    ACTIONS(4127), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4129), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109246] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    ACTIONS(4064), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4066), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109294] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4131), 1,
      aux_sym_symbol_token1,
    ACTIONS(4133), 1,
      aux_sym_symbol_token2,
    ACTIONS(4135), 1,
      anon_sym_BSLASH,
    STATE(1868), 1,
      sym_macro,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(2157), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [109356] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(472), 1,
      sym__blank,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109404] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4137), 1,
      sym__blank,
    STATE(1794), 1,
      aux_sym_block_repeat1,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109452] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4139), 1,
      aux_sym_symbol_token1,
    ACTIONS(4141), 1,
      aux_sym_symbol_token2,
    ACTIONS(4143), 1,
      anon_sym_BSLASH,
    STATE(1829), 1,
      sym_macro,
    STATE(2060), 1,
      sym_macro_text_expansion,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [109514] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4145), 1,
      aux_sym_symbol_token1,
    ACTIONS(4147), 1,
      aux_sym_symbol_token2,
    ACTIONS(4149), 1,
      anon_sym_BSLASH,
    STATE(1893), 1,
      sym_macro,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(2084), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [109576] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(472), 1,
      sym__blank,
    ACTIONS(4072), 1,
      anon_sym_COMMA,
    STATE(1787), 1,
      aux_sym_block_repeat1,
    ACTIONS(4068), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4070), 19,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109626] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4151), 1,
      sym__blank,
    STATE(1793), 1,
      aux_sym_block_repeat1,
    ACTIONS(4064), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4066), 20,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [109674] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 23,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [109717] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4153), 1,
      sym_path,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1783), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [109776] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 23,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [109819] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1930), 25,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [109862] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4157), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [109919] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4123), 1,
      anon_sym_BSLASH,
    ACTIONS(4161), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [109976] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1989), 25,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [110019] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4143), 1,
      anon_sym_BSLASH,
    ACTIONS(4163), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    STATE(1783), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [110076] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
    ACTIONS(1926), 25,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [110119] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [110178] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1983), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1975), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1978), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [110233] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4167), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    STATE(1783), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [110290] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4167), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    ACTIONS(4171), 1,
      sym_identifier,
    STATE(1809), 1,
      sym_macro,
    STATE(2045), 1,
      sym_macro_text_expansion,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [110349] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 12,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 23,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [110392] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4157), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    ACTIONS(4173), 1,
      sym_identifier,
    STATE(1807), 1,
      sym_macro,
    STATE(2006), 1,
      sym_macro_text_expansion,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110451] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [110510] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1783), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1983), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1975), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1978), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [110565] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4010), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1839), 1,
      sym_macro,
    STATE(2073), 1,
      sym_macro_text_expansion,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [110621] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4179), 1,
      sym__line_specifier,
    ACTIONS(4182), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2200), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [110675] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4187), 1,
      sym__line_specifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    STATE(2087), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2302), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110729] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4193), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2104), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2311), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110783] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4193), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1827), 1,
      sym_macro,
    STATE(2104), 1,
      aux_sym_symbol_repeat1,
    STATE(2138), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2311), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110839] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4199), 1,
      sym__line_specifier,
    STATE(2104), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2323), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110893] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4202), 1,
      sym__line_specifier,
    ACTIONS(4205), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2386), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [110947] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4000), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111001] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4208), 1,
      sym__line_specifier,
    STATE(2141), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2332), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111055] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4202), 1,
      sym__line_specifier,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2386), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111109] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4135), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111163] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111217] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(1842), 1,
      sym_macro,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(2215), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111273] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4212), 1,
      anon_sym_BSLASH,
    STATE(1854), 1,
      sym_macro,
    STATE(2088), 1,
      sym_macro_text_expansion,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111329] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(3966), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1826), 1,
      sym_macro,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(2142), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111385] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1830), 1,
      sym_macro,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(2192), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111441] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4214), 1,
      sym__line_specifier,
    ACTIONS(4217), 1,
      anon_sym_BSLASH,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2358), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111495] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(1860), 1,
      sym_macro,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(2197), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111551] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4220), 1,
      sym__line_specifier,
    ACTIONS(4223), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2358), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111605] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4226), 1,
      sym__line_specifier,
    ACTIONS(4229), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2386), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111659] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(3954), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111713] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4040), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111767] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4179), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2200), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111821] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111875] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4235), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [111929] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4020), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1865), 1,
      sym_macro,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(2144), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [111985] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1921), 1,
      sym_macro,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(2194), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112041] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4237), 1,
      sym__line_specifier,
    ACTIONS(4240), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2200), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112095] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(3954), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1840), 1,
      sym_macro,
    STATE(2200), 1,
      sym_macro_text_expansion,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112151] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4149), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1893), 1,
      sym_macro,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(2084), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112207] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4220), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2358), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112261] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4020), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112315] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4237), 1,
      sym__line_specifier,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2203), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2200), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112369] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(3936), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112423] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112477] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4243), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112531] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4149), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112585] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1909), 1,
      sym_macro,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    STATE(2234), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112641] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4226), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2389), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2386), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112695] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4214), 1,
      sym__line_specifier,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2361), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2358), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [112749] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112803] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112857] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4245), 1,
      anon_sym_BSLASH,
    STATE(1914), 1,
      sym_macro,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    STATE(2236), 1,
      sym_macro_text_expansion,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112913] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4245), 1,
      anon_sym_BSLASH,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [112967] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4050), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113021] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4135), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1868), 1,
      sym_macro,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    STATE(2157), 1,
      sym_macro_text_expansion,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113077] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4030), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113131] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1879), 1,
      sym_macro,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(2240), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113187] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(1897), 1,
      sym_macro,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(2193), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113243] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4247), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113297] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4249), 1,
      sym__line_specifier,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2221), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113351] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4252), 1,
      sym__line_specifier,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2221), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113405] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4262), 1,
      sym__blank,
    STATE(3511), 1,
      aux_sym_block_repeat1,
    ACTIONS(4259), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(1871), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(4255), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4257), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [113455] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(1881), 1,
      sym_macro,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(2143), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113511] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4247), 1,
      anon_sym_BSLASH,
    STATE(1843), 1,
      sym_macro,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    STATE(2232), 1,
      sym_macro_text_expansion,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [113567] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4030), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1880), 1,
      sym_macro,
    STATE(2108), 1,
      sym_macro_text_expansion,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113623] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4249), 1,
      sym__line_specifier,
    ACTIONS(4265), 1,
      anon_sym_BSLASH,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2221), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113677] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4268), 1,
      sym__line_specifier,
    STATE(1886), 1,
      sym_macro,
    STATE(2146), 1,
      sym_macro_text_expansion,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113733] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4270), 1,
      sym__line_specifier,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2253), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113787] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4106), 1,
      sym_identifier,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4275), 1,
      sym__blank,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(4273), 2,
      sym_comment,
      sym__blank_line,
    STATE(1783), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [113849] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4268), 1,
      sym__line_specifier,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113903] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4268), 1,
      sym__line_specifier,
    ACTIONS(4277), 1,
      anon_sym_BSLASH,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [113957] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114011] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4268), 1,
      sym__line_specifier,
    ACTIONS(4277), 1,
      anon_sym_BSLASH,
    STATE(1915), 1,
      sym_macro,
    STATE(2062), 1,
      sym_macro_text_expansion,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114067] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4270), 1,
      sym__line_specifier,
    ACTIONS(4279), 1,
      anon_sym_BSLASH,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2253), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114121] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1891), 1,
      sym_macro,
    STATE(2151), 1,
      sym_macro_text_expansion,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114177] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4050), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1898), 1,
      sym_macro,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(2195), 1,
      sym_macro_text_expansion,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114233] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4282), 1,
      sym__line_specifier,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114287] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4252), 1,
      sym__line_specifier,
    ACTIONS(4284), 1,
      anon_sym_BSLASH,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2224), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2221), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114341] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114395] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4287), 1,
      anon_sym_BSLASH,
    STATE(1852), 1,
      sym_macro,
    STATE(2155), 1,
      sym_macro_text_expansion,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114451] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1983), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [114509] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4123), 1,
      anon_sym_BSLASH,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114563] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4287), 1,
      anon_sym_BSLASH,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114617] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4212), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114671] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4289), 1,
      sym__line_specifier,
    STATE(1902), 1,
      sym_macro,
    STATE(2205), 1,
      sym_macro_text_expansion,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114727] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4282), 1,
      sym__line_specifier,
    STATE(1917), 1,
      sym_macro,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    STATE(2076), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [114783] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4291), 1,
      sym__line_specifier,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2253), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114837] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4289), 1,
      sym__line_specifier,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114891] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4289), 1,
      sym__line_specifier,
    ACTIONS(4294), 1,
      anon_sym_BSLASH,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [114945] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4289), 1,
      sym__line_specifier,
    ACTIONS(4294), 1,
      anon_sym_BSLASH,
    STATE(1905), 1,
      sym_macro,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    STATE(2211), 1,
      sym_macro_text_expansion,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115001] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4296), 1,
      sym__line_specifier,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2279), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [115055] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4291), 1,
      sym__line_specifier,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2256), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2253), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115109] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4302), 1,
      sym__line_specifier,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115163] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4302), 1,
      sym__line_specifier,
    STATE(1906), 1,
      sym_macro,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    STATE(2216), 1,
      sym_macro_text_expansion,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115219] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4304), 1,
      sym__line_specifier,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2282), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2279), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115273] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4302), 1,
      sym__line_specifier,
    ACTIONS(4307), 1,
      anon_sym_BSLASH,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115327] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4309), 1,
      sym__line_specifier,
    STATE(2221), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2290), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115381] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4309), 1,
      sym__line_specifier,
    STATE(1910), 1,
      sym_macro,
    STATE(2221), 1,
      aux_sym_symbol_repeat1,
    STATE(2223), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2290), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115437] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4311), 1,
      sym__line_specifier,
    STATE(2221), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2305), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2302), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115491] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4143), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115545] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4314), 1,
      sym__line_specifier,
    STATE(2228), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2313), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2311), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115599] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4314), 1,
      sym__line_specifier,
    STATE(1913), 1,
      sym_macro,
    STATE(2228), 1,
      aux_sym_symbol_repeat1,
    STATE(2230), 1,
      sym_macro_text_expansion,
    ACTIONS(2313), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2311), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115655] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4316), 1,
      sym__line_specifier,
    STATE(2228), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2326), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2323), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115709] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4319), 1,
      sym__line_specifier,
    STATE(2231), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2334), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2332), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115763] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4060), 1,
      anon_sym_BSLASH,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [115817] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4282), 1,
      sym__line_specifier,
    ACTIONS(4321), 1,
      anon_sym_BSLASH,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [115871] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4000), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1850), 1,
      sym_macro,
    STATE(2110), 1,
      sym_macro_text_expansion,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [115927] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4323), 1,
      sym__line_specifier,
    STATE(2087), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2292), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2290), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [115981] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    ACTIONS(4323), 1,
      sym__line_specifier,
    STATE(1822), 1,
      sym_macro,
    STATE(2087), 1,
      aux_sym_symbol_repeat1,
    STATE(2094), 1,
      sym_macro_text_expansion,
    ACTIONS(2292), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2290), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [116037] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1853), 1,
      sym_macro,
    STATE(2081), 1,
      sym_macro_text_expansion,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [116093] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4040), 1,
      anon_sym_BSLASH,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1863), 1,
      sym_macro,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    STATE(2063), 1,
      sym_macro_text_expansion,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [116149] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4185), 1,
      sym_identifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [116203] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3774), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [116244] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(1936), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [116291] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1930), 24,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_identifier,
      sym__blank,
  [116332] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(1932), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1896), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [116379] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(1932), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1900), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [116426] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3800), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [116467] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(3694), 1,
      sym_hll_option_expression,
    STATE(3865), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
    ACTIONS(4325), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4327), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [116518] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(1936), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [116565] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(1926), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1888), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [116612] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(3659), 1,
      sym_hll_option_expression,
    STATE(3885), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
    ACTIONS(4325), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4327), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [116663] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4331), 1,
      sym_identifier,
    ACTIONS(4334), 1,
      anon_sym_AMP,
    STATE(1932), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1905), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [116710] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    ACTIONS(4341), 1,
      anon_sym_BSLASH,
    STATE(2372), 1,
      aux_sym_symbol_repeat1,
    STATE(1979), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [116761] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [116808] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [116855] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4343), 1,
      sym_identifier,
    ACTIONS(4346), 1,
      anon_sym_AMP,
    STATE(1936), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [116902] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3778), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [116943] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4175), 1,
      sym_identifier,
    STATE(1935), 1,
      sym_macro,
    STATE(2378), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [116992] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(1923), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [117039] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1930), 22,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [117080] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4349), 1,
      sym_identifier,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4353), 1,
      anon_sym_BSLASH,
    STATE(1950), 1,
      sym_macro,
    STATE(2405), 1,
      sym_macro_text_expansion,
    STATE(2407), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2463), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [117133] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3807), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [117174] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(3614), 1,
      sym_hll_option_expression,
    STATE(3735), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
    ACTIONS(4355), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4357), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [117225] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4185), 1,
      sym_identifier,
    STATE(1925), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2421), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [117272] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(1926), 22,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [117313] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4359), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 15,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
    ACTIONS(3217), 16,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [117358] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4273), 1,
      anon_sym_RPAREN,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [117417] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(4197), 1,
      sym_identifier,
    STATE(1944), 1,
      sym_macro,
    STATE(2365), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [117466] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(3659), 1,
      sym_hll_option_expression,
    STATE(3885), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
    ACTIONS(4355), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4357), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [117517] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4353), 1,
      anon_sym_BSLASH,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(2396), 1,
      aux_sym_symbol_repeat1,
    STATE(1971), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [117568] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3811), 24,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [117609] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    ACTIONS(4341), 1,
      anon_sym_BSLASH,
    ACTIONS(4364), 1,
      sym_identifier,
    STATE(1933), 1,
      sym_macro,
    STATE(2399), 1,
      sym_macro_text_expansion,
    STATE(2413), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2463), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [117662] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(4177), 1,
      sym_identifier,
    STATE(1929), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [117709] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1926), 24,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_identifier,
      sym__blank,
  [117750] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4366), 1,
      sym_identifier,
    ACTIONS(4369), 1,
      anon_sym_AMP,
    STATE(1955), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1905), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [117796] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4406), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1982), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4404), 2,
      sym_comment,
      sym__blank_line,
  [117878] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4410), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1931), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4408), 2,
      sym_comment,
      sym__blank_line,
  [117960] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1900), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [118006] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(1955), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1898), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1900), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [118052] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    ACTIONS(4364), 1,
      sym_identifier,
    STATE(1966), 1,
      sym_macro,
    STATE(2464), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [118100] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1979), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [118146] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4349), 1,
      sym_identifier,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    STATE(1967), 1,
      sym_macro,
    STATE(2487), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [118194] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4412), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4416), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [118234] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4420), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(4060), 1,
      sym_hll_option_expression,
    ACTIONS(4325), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4327), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [118282] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4422), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1949), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4408), 2,
      sym_comment,
      sym__blank_line,
  [118364] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1979), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2421), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [118410] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(1971), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2423), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [118456] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4424), 1,
      sym__line_specifier,
    STATE(1789), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1971), 17,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [118508] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4428), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1943), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4426), 2,
      sym_comment,
      sym__blank_line,
  [118590] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4432), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1976), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4430), 2,
      sym_comment,
      sym__blank_line,
  [118672] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(1955), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1896), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [118718] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4434), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4437), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [118758] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4440), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4442), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [118798] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4444), 14,
      anon_sym_PLUS,
      anon_sym_DASH,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_access_class,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
      sym_float,
      aux_sym_bitmask_token1,
      aux_sym_bitmask_token2,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_time,
      sym_frequency,
      sym_identifier,
    ACTIONS(4447), 18,
      sym__decimal_number_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__composed_name,
      sym_percentage,
      anon_sym_POUND,
  [118838] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4452), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1928), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4450), 2,
      sym_comment,
      sym__blank_line,
  [118920] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4420), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(4037), 1,
      sym_hll_option_expression,
    ACTIONS(4355), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4357), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [118968] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1958), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1888), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119014] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4420), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(4075), 1,
      sym_hll_option_expression,
    ACTIONS(4325), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4327), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [119062] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4337), 1,
      sym_identifier,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1894), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1896), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119108] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4454), 1,
      sym__line_specifier,
    STATE(1781), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 19,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119160] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(1959), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1890), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1888), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [119206] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    ACTIONS(4420), 1,
      anon_sym_SLASH,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    STATE(4075), 1,
      sym_hll_option_expression,
    ACTIONS(4355), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4357), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [119254] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4458), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1964), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4456), 2,
      sym_comment,
      sym__blank_line,
  [119336] = 24,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    ACTIONS(4400), 1,
      aux_sym__hll_expression_separator_token1,
    ACTIONS(4402), 1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4460), 1,
      sym__blank,
    STATE(1610), 1,
      sym_hll_argument_list,
    STATE(1978), 1,
      aux_sym_block_repeat1,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4404), 2,
      sym_comment,
      sym__blank_line,
  [119418] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4462), 1,
      sym_identifier,
    ACTIONS(4465), 1,
      anon_sym_AMP,
    STATE(1985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1907), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1905), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119464] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(4362), 1,
      sym_identifier,
    STATE(1971), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [119510] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(4096), 1,
      sym_identifier,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4273), 1,
      sym__blank,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    STATE(1786), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [119568] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2953), 1,
      anon_sym_RPAREN,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4496), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3526), 1,
      aux_sym_block_repeat1,
    STATE(3757), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [119647] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3659), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [119696] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3663), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [119745] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3667), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [119794] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4498), 1,
      anon_sym_AMP,
    ACTIONS(4500), 1,
      aux_sym_file_handle_token1,
    STATE(2057), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2633), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2635), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [119839] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3627), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [119890] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3633), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [119943] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [119998] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 13,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120053] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120122] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120175] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120242] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120307] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120368] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 13,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120425] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 8,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120492] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [120555] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3701), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [120628] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4123), 1,
      anon_sym_BSLASH,
    ACTIONS(4161), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [120675] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3028), 1,
      anon_sym_RPAREN,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4502), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3461), 1,
      aux_sym_block_repeat1,
    STATE(3924), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [120754] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4504), 1,
      anon_sym_RPAREN,
    ACTIONS(4506), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3462), 1,
      aux_sym_block_repeat1,
    STATE(3945), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [120833] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4167), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [120880] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [120951] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121002] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121069] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121134] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 9,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121195] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 6,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121252] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [121303] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121372] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121435] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3703), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3701), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [121510] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3041), 1,
      anon_sym_RPAREN,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4508), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3476), 1,
      aux_sym_block_repeat1,
    STATE(3872), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [121589] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4510), 1,
      anon_sym_RPAREN,
    ACTIONS(4512), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3478), 1,
      aux_sym_block_repeat1,
    STATE(3876), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [121668] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2943), 1,
      anon_sym_RPAREN,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4514), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3512), 1,
      aux_sym_block_repeat1,
    STATE(3753), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [121747] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3738), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [121798] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4516), 1,
      anon_sym_RPAREN,
    ACTIONS(4518), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3533), 1,
      aux_sym_block_repeat1,
    STATE(3793), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [121877] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3709), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [121950] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3711), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3709), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [122025] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3715), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3713), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [122100] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3719), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3717), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [122175] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4520), 1,
      anon_sym_RPAREN,
    ACTIONS(4522), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3509), 1,
      aux_sym_block_repeat1,
    STATE(3891), 1,
      aux_sym_hll_argument_list_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [122254] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [122293] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1926), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [122332] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3713), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [122405] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3717), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [122478] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1930), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [122517] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4275), 1,
      sym__blank,
    ACTIONS(4424), 1,
      sym__line_specifier,
    STATE(1789), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(4273), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 14,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [122572] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [122611] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3659), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [122662] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4157), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [122709] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3663), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [122760] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3723), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3721), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [122835] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    ACTIONS(4376), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4380), 1,
      anon_sym_SLASH,
    ACTIONS(4382), 1,
      anon_sym_PIPE,
    ACTIONS(4384), 1,
      anon_sym_CARET,
    ACTIONS(4394), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4396), 1,
      anon_sym_AMP,
    ACTIONS(4398), 1,
      anon_sym_QMARK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3727), 2,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4372), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4378), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4386), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4388), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4390), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3725), 3,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [122910] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1989), 23,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [122949] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3721), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [123022] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3725), 5,
      anon_sym_RPAREN,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym__blank,
  [123095] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4143), 1,
      anon_sym_BSLASH,
    ACTIONS(4163), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123142] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 21,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [123181] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3667), 18,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [123232] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3615), 17,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [123279] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3627), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [123328] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3633), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [123379] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3738), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [123428] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4524), 1,
      anon_sym_AMP,
    ACTIONS(4527), 1,
      aux_sym_file_handle_token1,
    STATE(2052), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2738), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2740), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123473] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3619), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3615), 20,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_RBRACK,
      sym__blank,
  [123522] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3742), 1,
      anon_sym_LPAREN,
    ACTIONS(3772), 1,
      anon_sym_LBRACK,
    STATE(1610), 1,
      sym_hll_argument_list,
    ACTIONS(3768), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 9,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      aux_sym__hll_expression_separator_token2,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      sym_comment,
      sym__blank_line,
  [123571] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4530), 1,
      anon_sym_AMP,
    ACTIONS(4532), 1,
      aux_sym_file_handle_token1,
    STATE(2052), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2633), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2635), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123616] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4534), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4536), 23,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [123655] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4538), 1,
      anon_sym_AMP,
    ACTIONS(4541), 1,
      aux_sym_file_handle_token1,
    STATE(2057), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
    ACTIONS(2738), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2740), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [123700] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4255), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4257), 23,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [123739] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4544), 1,
      anon_sym_RPAREN,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4548), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3746), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [123815] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4135), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123859] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123903] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4282), 1,
      sym__line_specifier,
    ACTIONS(4321), 1,
      anon_sym_BSLASH,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [123947] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4050), 1,
      anon_sym_BSLASH,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [123991] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4550), 1,
      anon_sym_RPAREN,
    ACTIONS(4552), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3834), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [124067] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2760), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2762), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [124105] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2764), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2766), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [124143] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4554), 1,
      anon_sym_RPAREN,
    ACTIONS(4556), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3866), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [124219] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4169), 1,
      anon_sym_BSLASH,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [124263] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4558), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4560), 1,
      anon_sym_RBRACK,
    ACTIONS(4562), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3774), 1,
      aux_sym_block_repeat1,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [124341] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3800), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [124379] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4149), 1,
      anon_sym_BSLASH,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124423] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4323), 1,
      sym__line_specifier,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2290), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124467] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(3954), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [124511] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4568), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4573), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3125), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3523), 1,
      aux_sym_block_repeat1,
    ACTIONS(4570), 2,
      sym_comment,
      sym__blank_line,
    STATE(2380), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [124563] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4568), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4573), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3125), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3523), 1,
      aux_sym_block_repeat1,
    ACTIONS(4570), 2,
      sym_comment,
      sym__blank_line,
    STATE(2207), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [124615] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4323), 1,
      sym__line_specifier,
    STATE(2087), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2290), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124659] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4179), 1,
      sym__line_specifier,
    ACTIONS(4182), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2200), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [124703] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4237), 1,
      sym__line_specifier,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2200), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124747] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124791] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4220), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2358), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [124835] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [124879] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2578), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2582), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2585), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(2580), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [124925] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [124969] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4212), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125013] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2588), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [125055] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4187), 1,
      sym__line_specifier,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    STATE(2087), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2302), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125099] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4193), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2311), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125143] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4243), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125187] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [125233] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2756), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2758), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [125271] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4580), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4586), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3138), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3583), 1,
      aux_sym_block_repeat1,
    ACTIONS(4583), 2,
      sym_comment,
      sym__blank_line,
    STATE(2380), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [125323] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4580), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4586), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3138), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3583), 1,
      aux_sym_block_repeat1,
    ACTIONS(4583), 2,
      sym_comment,
      sym__blank_line,
    STATE(2132), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [125375] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2568), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2570), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [125413] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4193), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2104), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2311), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125457] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2649), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2651), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [125495] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4589), 1,
      anon_sym_AMP,
    STATE(2127), 1,
      aux_sym__path_expression_repeat2,
    STATE(2429), 1,
      sym_macro,
    ACTIONS(2865), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2867), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125539] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2760), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2762), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [125577] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2588), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [125615] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4237), 1,
      sym__line_specifier,
    ACTIONS(4240), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2200), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125659] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2645), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2647), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [125697] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4591), 1,
      anon_sym_RPAREN,
    ACTIONS(4593), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3897), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [125773] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 18,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [125813] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4199), 1,
      sym__line_specifier,
    STATE(2104), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2323), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125857] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4208), 1,
      sym__line_specifier,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2332), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125901] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2764), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2766), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [125939] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(3966), 1,
      anon_sym_BSLASH,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [125983] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4597), 1,
      anon_sym_CARET,
    ACTIONS(4595), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2588), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [126029] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4268), 1,
      sym__line_specifier,
    ACTIONS(4277), 1,
      anon_sym_BSLASH,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [126073] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2521), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2523), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [126111] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4020), 1,
      anon_sym_BSLASH,
    STATE(2135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [126155] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4273), 1,
      anon_sym_RPAREN,
    ACTIONS(4454), 1,
      sym__line_specifier,
    STATE(1781), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 16,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [126207] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4202), 1,
      sym__line_specifier,
    ACTIONS(4205), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2386), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [126251] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4599), 1,
      anon_sym_RPAREN,
    ACTIONS(4601), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3772), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [126327] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2768), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2770), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [126365] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2651), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [126403] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4595), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2588), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 15,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [126447] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4603), 1,
      sym__line_specifier,
    STATE(2145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2463), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [126491] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4607), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3611), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4605), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [126565] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 20,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [126603] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4597), 1,
      anon_sym_CARET,
    ACTIONS(4609), 1,
      anon_sym_PIPE,
    ACTIONS(4595), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2722), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2724), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [126657] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4252), 1,
      sym__line_specifier,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2221), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [126701] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4619), 1,
      anon_sym_PIPE,
    ACTIONS(4621), 1,
      anon_sym_CARET,
    ACTIONS(4611), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2722), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2724), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [126757] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 20,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [126795] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4623), 1,
      anon_sym_AMP,
    STATE(2124), 1,
      aux_sym__path_expression_repeat2,
    STATE(4126), 1,
      sym_macro,
    ACTIONS(2985), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2987), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [126839] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2578), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2582), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2585), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(2580), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [126885] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4630), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4636), 1,
      sym__blank,
    STATE(2662), 1,
      sym_else_block,
    STATE(3137), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3581), 1,
      aux_sym_block_repeat1,
    ACTIONS(4633), 2,
      sym_comment,
      sym__blank_line,
    STATE(2091), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4626), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4628), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [126937] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4623), 1,
      anon_sym_AMP,
    STATE(2127), 1,
      aux_sym__path_expression_repeat2,
    STATE(4320), 1,
      sym_macro,
    ACTIONS(2985), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2987), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [126981] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4558), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4562), 1,
      sym__blank,
    ACTIONS(4639), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3774), 1,
      aux_sym_block_repeat1,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [127059] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4641), 1,
      anon_sym_RPAREN,
    ACTIONS(4643), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3901), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [127135] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1926), 22,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [127173] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4014), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127217] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4649), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4655), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(3139), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3586), 1,
      aux_sym_block_repeat1,
    ACTIONS(4652), 2,
      sym_comment,
      sym__blank_line,
    STATE(2380), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4645), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4647), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [127269] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2521), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2523), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [127307] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3774), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [127345] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127389] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    ACTIONS(4325), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4327), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [127431] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1930), 22,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [127469] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4208), 1,
      sym__line_specifier,
    STATE(2141), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2332), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127513] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2756), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2758), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [127551] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4558), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4562), 1,
      sym__blank,
    ACTIONS(4658), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3774), 1,
      aux_sym_block_repeat1,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [127629] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4660), 1,
      sym__line_specifier,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2641), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127673] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4000), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127717] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4044), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [127761] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4030), 1,
      anon_sym_BSLASH,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127805] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127849] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4282), 1,
      sym__line_specifier,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127893] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4159), 1,
      anon_sym_BSLASH,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [127937] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4252), 1,
      sym__line_specifier,
    ACTIONS(4284), 1,
      anon_sym_BSLASH,
    STATE(2191), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2221), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [127981] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3960), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [128025] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 20,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [128063] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4123), 1,
      anon_sym_BSLASH,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [128107] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4568), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4665), 1,
      sym__blank,
    STATE(2662), 1,
      sym_else_block,
    STATE(3131), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3485), 1,
      aux_sym_block_repeat1,
    ACTIONS(4662), 2,
      sym_comment,
      sym__blank_line,
    STATE(2074), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4626), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4628), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [128159] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4668), 1,
      anon_sym_RPAREN,
    ACTIONS(4670), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3922), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [128235] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [128279] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(3936), 1,
      anon_sym_BSLASH,
    STATE(2149), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [128323] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2598), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2600), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [128361] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4247), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [128405] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4155), 1,
      sym__line_specifier,
    ACTIONS(4287), 1,
      anon_sym_BSLASH,
    STATE(2167), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [128449] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(1989), 22,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [128487] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [128533] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4619), 1,
      anon_sym_PIPE,
    ACTIONS(4621), 1,
      anon_sym_CARET,
    ACTIONS(4611), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(2733), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2735), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2730), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [128591] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2578), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2582), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2585), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(2580), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [128637] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2034), 1,
      sym__blank,
    STATE(1370), 1,
      aux_sym_block_repeat1,
    ACTIONS(4355), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4357), 22,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [128679] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2645), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2647), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [128717] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [128761] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1983), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(2582), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2585), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [128803] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3930), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [128847] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2768), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2770), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [128885] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4672), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4677), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3109), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3540), 1,
      aux_sym_block_repeat1,
    ACTIONS(4674), 2,
      sym_comment,
      sym__blank_line,
    STATE(2421), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [128937] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4672), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4677), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3109), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3540), 1,
      aux_sym_block_repeat1,
    ACTIONS(4674), 2,
      sym_comment,
      sym__blank_line,
    STATE(2176), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [128989] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4202), 1,
      sym__line_specifier,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2386), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [129033] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2590), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [129077] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4597), 1,
      anon_sym_CARET,
    ACTIONS(4609), 1,
      anon_sym_PIPE,
    ACTIONS(4595), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2621), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2623), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [129131] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    ACTIONS(4706), 1,
      sym__blank,
    STATE(1773), 1,
      sym_hll_argument_list,
    STATE(2136), 1,
      aux_sym_block_repeat1,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4400), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [129205] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2588), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2590), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [129243] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4672), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4711), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(3110), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3544), 1,
      aux_sym_block_repeat1,
    ACTIONS(4708), 2,
      sym_comment,
      sym__blank_line,
    STATE(2421), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4645), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4647), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [129295] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2590), 16,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [129335] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4714), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4720), 1,
      sym__blank,
    STATE(2662), 1,
      sym_else_block,
    STATE(3146), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3590), 1,
      aux_sym_block_repeat1,
    ACTIONS(4717), 2,
      sym_comment,
      sym__blank_line,
    STATE(2179), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4626), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4628), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [129387] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4723), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4729), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3147), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3592), 1,
      aux_sym_block_repeat1,
    ACTIONS(4726), 2,
      sym_comment,
      sym__blank_line,
    STATE(2421), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [129439] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4723), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4729), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(3147), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3592), 1,
      aux_sym_block_repeat1,
    ACTIONS(4726), 2,
      sym_comment,
      sym__blank_line,
    STATE(2181), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4564), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4566), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [129491] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4732), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4738), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(3127), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3595), 1,
      aux_sym_block_repeat1,
    ACTIONS(4735), 2,
      sym_comment,
      sym__blank_line,
    STATE(2421), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4645), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4647), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [129543] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4621), 1,
      anon_sym_CARET,
    ACTIONS(4611), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 7,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2590), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [129591] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2748), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2750), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [129629] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3807), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [129667] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4611), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 8,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2590), 14,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [129713] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3811), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [129751] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4741), 1,
      sym__line_specifier,
    STATE(2242), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2465), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2463), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [129795] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4249), 1,
      sym__line_specifier,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2221), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [129839] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4004), 1,
      sym__line_specifier,
    ACTIONS(4010), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [129883] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4291), 1,
      sym__line_specifier,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2253), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [129927] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4289), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [129971] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3994), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2131), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [130015] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4289), 1,
      sym__line_specifier,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130059] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4024), 1,
      sym__line_specifier,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [130103] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4289), 1,
      sym__line_specifier,
    ACTIONS(4294), 1,
      anon_sym_BSLASH,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130147] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4291), 1,
      sym__line_specifier,
    ACTIONS(4299), 1,
      anon_sym_BSLASH,
    STATE(2206), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2253), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130191] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3948), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130235] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4249), 1,
      sym__line_specifier,
    ACTIONS(4265), 1,
      anon_sym_BSLASH,
    STATE(2229), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2224), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2221), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [130279] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4226), 1,
      sym__line_specifier,
    ACTIONS(4229), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2386), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130323] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4040), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130367] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130411] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      anon_sym_DOT,
    ACTIONS(3778), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym__blank,
  [130449] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4597), 1,
      anon_sym_CARET,
    ACTIONS(4609), 1,
      anon_sym_PIPE,
    ACTIONS(4595), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2733), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2735), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4576), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(4578), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2730), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [130505] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4226), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2201), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2389), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2386), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130549] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4302), 1,
      sym__line_specifier,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130593] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4302), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130637] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4568), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4746), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(3105), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3528), 1,
      aux_sym_block_repeat1,
    ACTIONS(4743), 2,
      sym_comment,
      sym__blank_line,
    STATE(2380), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4645), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4647), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [130689] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4179), 1,
      sym__line_specifier,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2203), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2200), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130733] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4304), 1,
      sym__line_specifier,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2279), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130777] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4751), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3662), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4749), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [130851] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4302), 1,
      sym__line_specifier,
    ACTIONS(4307), 1,
      anon_sym_BSLASH,
    STATE(2214), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [130895] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1983), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1975), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1978), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [130937] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4753), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2407), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [130979] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4309), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2290), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131023] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131067] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4309), 1,
      sym__line_specifier,
    STATE(2221), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2292), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2290), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131111] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    ACTIONS(4756), 1,
      anon_sym_RPAREN,
    ACTIONS(4758), 1,
      sym__blank,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3951), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [131187] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2598), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2600), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [131225] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4311), 1,
      sym__line_specifier,
    STATE(2221), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2305), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2302), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131269] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4214), 1,
      sym__line_specifier,
    ACTIONS(4217), 1,
      anon_sym_BSLASH,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2358), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [131313] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4314), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2311), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131357] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4214), 1,
      sym__line_specifier,
    STATE(2079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2358), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [131401] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4314), 1,
      sym__line_specifier,
    STATE(2228), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2313), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2311), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131445] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4672), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4763), 1,
      sym__blank,
    STATE(2662), 1,
      sym_else_block,
    STATE(3106), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3535), 1,
      aux_sym_block_repeat1,
    ACTIONS(4760), 2,
      sym_comment,
      sym__blank_line,
    STATE(2169), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4626), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4628), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [131497] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4282), 1,
      sym__line_specifier,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [131541] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4270), 1,
      sym__line_specifier,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2253), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [131585] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4232), 1,
      anon_sym_BSLASH,
    ACTIONS(4316), 1,
      sym__line_specifier,
    STATE(2228), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2326), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2323), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131629] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4319), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2332), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131673] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4268), 1,
      sym__line_specifier,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [131717] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4319), 1,
      sym__line_specifier,
    STATE(2231), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2334), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2332), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131761] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    ACTIONS(4766), 1,
      sym__line_specifier,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2641), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131805] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4034), 1,
      sym__line_specifier,
    ACTIONS(4235), 1,
      anon_sym_BSLASH,
    STATE(2061), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131849] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4768), 1,
      anon_sym_AMP,
    STATE(2124), 1,
      aux_sym__path_expression_repeat2,
    STATE(2517), 1,
      sym_macro,
    ACTIONS(2865), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2867), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131893] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4143), 1,
      anon_sym_BSLASH,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [131937] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    ACTIONS(4770), 1,
      sym__blank,
    STATE(1773), 1,
      sym_hll_argument_list,
    STATE(2163), 1,
      aux_sym_block_repeat1,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4400), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [132011] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4054), 1,
      sym__line_specifier,
    ACTIONS(4060), 1,
      anon_sym_BSLASH,
    STATE(2154), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132055] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4270), 1,
      sym__line_specifier,
    ACTIONS(4279), 1,
      anon_sym_BSLASH,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2256), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2253), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [132099] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1983), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2582), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2585), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [132141] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4245), 1,
      anon_sym_BSLASH,
    STATE(2165), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132185] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4195), 1,
      anon_sym_BSLASH,
    ACTIONS(4268), 1,
      sym__line_specifier,
    STATE(2225), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [132229] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2748), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2750), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [132267] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4165), 1,
      sym__line_specifier,
    ACTIONS(4210), 1,
      anon_sym_BSLASH,
    STATE(2213), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132311] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2777), 11,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
      sym__blank,
    ACTIONS(2779), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
  [132349] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 12,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [132395] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4772), 1,
      anon_sym_BSLASH,
    STATE(2245), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2407), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [132437] = 23,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3621), 1,
      anon_sym_DOT,
    ACTIONS(3623), 1,
      anon_sym_DASH_GT,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4558), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4562), 1,
      sym__blank,
    ACTIONS(4775), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3774), 1,
      aux_sym_block_repeat1,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [132515] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4617), 1,
      anon_sym_SLASH,
    ACTIONS(4619), 1,
      anon_sym_PIPE,
    ACTIONS(4621), 1,
      anon_sym_CARET,
    ACTIONS(4611), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4615), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4613), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2621), 4,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2623), 13,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132571] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4190), 1,
      anon_sym_BSLASH,
    ACTIONS(4296), 1,
      sym__line_specifier,
    STATE(2072), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2282), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2279), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [132615] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2568), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2570), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [132653] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1983), 4,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym_comment,
      sym__blank_line,
    ACTIONS(1975), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1978), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [132695] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2777), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2779), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON_COLON_COLON,
      sym__blank,
  [132733] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4220), 1,
      sym__line_specifier,
    ACTIONS(4223), 1,
      anon_sym_BSLASH,
    STATE(2083), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2361), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2358), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132777] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [132842] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3627), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [132889] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [132958] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4829), 1,
      sym_comment,
    ACTIONS(4831), 1,
      sym__blank,
    STATE(2586), 1,
      aux_sym_block_repeat1,
    STATE(2621), 1,
      sym_block,
    STATE(3418), 1,
      aux_sym_labeled_expression_repeat1,
    ACTIONS(4825), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__blank_line,
    ACTIONS(4827), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [133007] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133056] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4833), 1,
      anon_sym_RPAREN,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(4863), 1,
      sym__blank,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3524), 1,
      aux_sym_argument_list_repeat1,
    STATE(3602), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [133129] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133176] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(4275), 1,
      sym__blank,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(4273), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 5,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [133225] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133290] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133353] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3738), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133400] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133459] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3659), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133506] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3663), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133553] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3667), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133600] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4454), 1,
      sym__line_specifier,
    ACTIONS(4867), 1,
      anon_sym_AMP,
    STATE(333), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 16,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [133649] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [133708] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3701), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [133777] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 5,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133832] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133899] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1926), 22,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      aux_sym_file_handle_token1,
      sym__blank,
  [133936] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [133997] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3703), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3701), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134070] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3615), 16,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [134115] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1930), 22,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      aux_sym_file_handle_token1,
      sym__blank,
  [134152] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3711), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3709), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134225] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4897), 1,
      sym_path,
    STATE(2417), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2865), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2867), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [134266] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3715), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3713), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134339] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3719), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3717), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134412] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3723), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3721), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134485] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2796), 1,
      anon_sym_RBRACK,
    ACTIONS(2798), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3858), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [134558] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3727), 1,
      sym__blank,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3725), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [134631] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1926), 20,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      aux_sym_file_handle_token1,
      sym_comment,
      sym__blank_line,
  [134668] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4899), 1,
      sym__and_operator_pre_hook,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [134729] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2800), 1,
      anon_sym_RBRACK,
    ACTIONS(2802), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3730), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [134802] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4589), 1,
      anon_sym_AMP,
    STATE(2516), 1,
      sym_macro,
    ACTIONS(2865), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2867), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [134843] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(3073), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [134908] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2994), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [134945] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3073), 4,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      sym__blank,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 6,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [135004] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2823), 1,
      anon_sym_RBRACK,
    ACTIONS(2825), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3950), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135077] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3738), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [135124] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3079), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [135195] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2827), 1,
      anon_sym_RBRACK,
    ACTIONS(2829), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3727), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135268] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2837), 1,
      anon_sym_RBRACK,
    ACTIONS(2839), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3864), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135341] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2843), 1,
      anon_sym_RBRACK,
    ACTIONS(2845), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3742), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135414] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2933), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2935), 17,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [135459] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3709), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135528] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3713), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135597] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3043), 1,
      anon_sym_RBRACK,
    ACTIONS(3045), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3835), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135670] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(4454), 1,
      sym__line_specifier,
    STATE(1789), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 16,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [135719] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3087), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [135788] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2871), 1,
      anon_sym_RBRACK,
    ACTIONS(2873), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3882), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135861] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3667), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [135908] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3002), 1,
      anon_sym_RBRACK,
    ACTIONS(3004), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3726), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [135981] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3012), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [136050] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3073), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [136113] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3061), 1,
      anon_sym_RBRACK,
    ACTIONS(3063), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3844), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [136186] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3073), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 7,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [136243] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2781), 1,
      anon_sym_RBRACK,
    ACTIONS(2783), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3845), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [136316] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2967), 1,
      anon_sym_RBRACK,
    ACTIONS(2969), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3890), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [136389] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3079), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [136458] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 11,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [136509] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3065), 1,
      anon_sym_RBRACK,
    ACTIONS(3067), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3849), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [136582] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3083), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [136651] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [136692] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3024), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [136755] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3717), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [136824] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3633), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [136873] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [136924] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [136991] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137040] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137103] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137164] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137221] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 5,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137274] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137339] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [137398] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3703), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3701), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137469] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3711), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3709), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137540] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3715), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3713), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137611] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3719), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3717), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137682] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3723), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3721), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137753] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3727), 1,
      sym__blank,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(4684), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4688), 1,
      anon_sym_PIPE,
    ACTIONS(4690), 1,
      anon_sym_CARET,
    ACTIONS(4700), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4702), 1,
      anon_sym_AMP,
    ACTIONS(4704), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3725), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4680), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4692), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4694), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4696), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4698), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4686), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [137824] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3024), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [137889] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 14,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [137938] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4912), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [137999] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4899), 1,
      sym__and_operator_pre_hook,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      sym__blank,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 5,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [138062] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2959), 1,
      anon_sym_RBRACK,
    ACTIONS(2961), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3825), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [138135] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3100), 1,
      anon_sym_RBRACK,
    ACTIONS(3102), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3846), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [138208] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2963), 1,
      anon_sym_RBRACK,
    ACTIONS(2965), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3829), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [138281] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [138318] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3083), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [138389] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3615), 17,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [138434] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 6,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3026), 10,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [138489] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4917), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4915), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [138560] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3627), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [138607] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    ACTIONS(4546), 1,
      anon_sym_COMMA,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4920), 2,
      anon_sym_RPAREN,
      sym__blank,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [138678] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3633), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [138727] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3087), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [138798] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4922), 1,
      sym_path,
    STATE(2415), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2865), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2867), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [138839] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [138876] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2933), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2935), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [138921] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4912), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3026), 6,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [138980] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3024), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 11,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [139033] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3659), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [139080] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3663), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [139127] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3051), 1,
      anon_sym_RBRACK,
    ACTIONS(3053), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3904), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139200] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2955), 1,
      anon_sym_RBRACK,
    ACTIONS(2957), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3944), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139273] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 16,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [139320] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3069), 1,
      anon_sym_RBRACK,
    ACTIONS(3071), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3937), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139393] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3721), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139462] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3725), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139531] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2421), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [139568] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3016), 1,
      anon_sym_RBRACK,
    ACTIONS(3018), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3832), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139641] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3089), 1,
      anon_sym_RBRACK,
    ACTIONS(3091), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3823), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [139714] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [139761] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2941), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [139798] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4924), 1,
      anon_sym_BSLASH,
    STATE(2370), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2407), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [139839] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4589), 1,
      anon_sym_AMP,
    STATE(2516), 1,
      sym_macro,
    ACTIONS(3110), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3112), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [139880] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4341), 1,
      anon_sym_BSLASH,
    STATE(2398), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [139921] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2926), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2928), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [139968] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3093), 1,
      anon_sym_RBRACK,
    ACTIONS(3095), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3827), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [140041] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140092] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3024), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3026), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [140139] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 5,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140204] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [140241] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2994), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [140278] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4931), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4937), 1,
      sym__blank,
    STATE(3167), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3697), 1,
      aux_sym_block_repeat1,
    ACTIONS(4934), 2,
      sym_comment,
      sym__blank_line,
    STATE(2380), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4927), 6,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4929), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [140327] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4768), 1,
      anon_sym_AMP,
    STATE(2486), 1,
      sym_macro,
    ACTIONS(2865), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2867), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [140368] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3667), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [140415] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2941), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [140452] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1983), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2578), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2582), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(2585), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(2580), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [140497] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3738), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [140544] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1983), 3,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [140589] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 14,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140638] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140701] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 7,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140762] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 9,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140819] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3659), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [140866] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3663), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [140913] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 11,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [140966] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 15,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [141013] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [141076] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4353), 1,
      anon_sym_BSLASH,
    STATE(2370), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141117] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3026), 12,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141166] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4940), 1,
      anon_sym_BSLASH,
    STATE(2398), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2409), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2407), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [141207] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4341), 1,
      anon_sym_BSLASH,
    STATE(2372), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [141248] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3037), 1,
      anon_sym_RBRACK,
    ACTIONS(3039), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3861), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [141321] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4768), 1,
      anon_sym_AMP,
    STATE(2486), 1,
      sym_macro,
    ACTIONS(3110), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3112), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141362] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3615), 18,
      anon_sym_RPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [141407] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(4863), 1,
      sym__blank,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4943), 1,
      anon_sym_RPAREN,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3483), 1,
      aux_sym_argument_list_repeat1,
    STATE(3602), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [141480] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3627), 16,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [141527] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4353), 1,
      anon_sym_BSLASH,
    STATE(2396), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141568] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3012), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [141639] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4353), 1,
      anon_sym_BSLASH,
    STATE(2370), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141680] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3026), 10,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141733] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2926), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2928), 16,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [141780] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3026), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [141821] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3633), 14,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_RBRACK,
  [141870] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 2,
      anon_sym_EQ,
      sym__blank,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3026), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [141937] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4341), 1,
      anon_sym_BSLASH,
    STATE(2398), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [141978] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2945), 1,
      anon_sym_RBRACK,
    ACTIONS(2947), 1,
      sym__blank,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    STATE(3905), 1,
      aux_sym_block_repeat1,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [142051] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4945), 1,
      sym_path,
    STATE(2415), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2978), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2980), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [142092] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2414), 1,
      anon_sym_LPAREN,
    ACTIONS(2417), 1,
      anon_sym_DOT,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(4273), 1,
      sym__blank,
    ACTIONS(4454), 1,
      sym__line_specifier,
    STATE(1781), 1,
      sym_macro,
    STATE(3818), 1,
      aux_sym__function_identifier_repeat1,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 15,
      sym__and_operator_pre_hook,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [142143] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4948), 1,
      sym_path,
    STATE(2417), 1,
      aux_sym__path_expression_repeat1,
    ACTIONS(2978), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2980), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [142184] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4807), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4805), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142237] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(4951), 1,
      sym_comment,
    ACTIONS(4953), 1,
      sym__blank,
    STATE(2588), 1,
      aux_sym_block_repeat1,
    STATE(2625), 1,
      sym_block,
    STATE(3414), 1,
      aux_sym_labeled_expression_repeat1,
    ACTIONS(4825), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym__blank_line,
    ACTIONS(4827), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [142286] = 21,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(4863), 1,
      sym__blank,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4955), 1,
      anon_sym_RPAREN,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3460), 1,
      aux_sym_argument_list_repeat1,
    STATE(3602), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [142359] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4957), 1,
      aux_sym_elif_block_token1,
    ACTIONS(4963), 1,
      sym__blank,
    STATE(3332), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3696), 1,
      aux_sym_block_repeat1,
    ACTIONS(4960), 2,
      sym_comment,
      sym__blank_line,
    STATE(2421), 2,
      sym_elif_block,
      aux_sym_if_block_repeat1,
    ACTIONS(4927), 6,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(4929), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [142408] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1930), 20,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      aux_sym_file_handle_token1,
      sym_comment,
      sym__blank_line,
  [142445] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [142493] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2985), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2987), 21,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__blank,
  [142529] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3619), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3615), 16,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142573] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3661), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3659), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142619] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3629), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3627), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142665] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3633), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142713] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2164), 1,
      sym_path,
    ACTIONS(3110), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3112), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [142751] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3665), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3663), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [142797] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3721), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [142867] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3725), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [142937] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4994), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [143007] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4998), 1,
      sym__blank,
    ACTIONS(4996), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3776), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3774), 18,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [143047] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3774), 20,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [143083] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3800), 20,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [143119] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143169] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143233] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143295] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143355] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143411] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143463] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143525] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [143583] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3701), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143651] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3709), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143719] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3713), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143787] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3717), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143855] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3721), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143923] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3725), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [143991] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5022), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144061] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(5026), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5024), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144129] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3778), 20,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [144165] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3807), 20,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [144201] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 8,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3811), 20,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym_comment,
      sym__blank_line,
  [144237] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5029), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144307] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5031), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144377] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5033), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144447] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3669), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3667), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [144493] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5035), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144563] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5033), 2,
      sym_comment,
      sym__blank_line,
  [144633] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(5039), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5037), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144701] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2407), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [144737] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
    ACTIONS(2421), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [144773] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5042), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144843] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1926), 21,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [144879] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1930), 21,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [144915] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5044), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [144985] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3657), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145037] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145103] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 12,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145151] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145215] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3657), 1,
      anon_sym_PIPE,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145277] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 8,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145335] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(3657), 4,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 10,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145389] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3657), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3655), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145435] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145499] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3657), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3655), 6,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [145559] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3701), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [145629] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5046), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [145699] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1926), 19,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [145735] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [145771] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    ACTIONS(5004), 1,
      anon_sym_PIPE,
    ACTIONS(5006), 1,
      anon_sym_CARET,
    ACTIONS(5014), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5016), 1,
      anon_sym_AMP,
    ACTIONS(5018), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5020), 1,
      anon_sym_QMARK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4400), 2,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5002), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5008), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(5010), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5012), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5000), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [145839] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1930), 19,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [145875] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5022), 2,
      sym_comment,
      sym__blank_line,
  [145945] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2980), 19,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [145981] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 10,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [146017] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3740), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3738), 14,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      sym_comment,
      sym__blank_line,
  [146063] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(4273), 1,
      anon_sym_RPAREN,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 11,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      sym__blank,
  [146109] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3782), 1,
      anon_sym_RPAREN,
    ACTIONS(3676), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3671), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym__blank,
  [146147] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4996), 1,
      anon_sym_RPAREN,
    ACTIONS(3776), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3774), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      sym__blank,
  [146185] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3709), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146255] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3713), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146325] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3717), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146395] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5048), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146465] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5050), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146535] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5052), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [146605] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5050), 2,
      sym_comment,
      sym__blank_line,
  [146675] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5048), 2,
      sym_comment,
      sym__blank_line,
  [146745] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2985), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2987), 19,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [146781] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3776), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3774), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [146817] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3916), 1,
      anon_sym_LPAREN,
    ACTIONS(3922), 1,
      anon_sym_LBRACK,
    STATE(1773), 1,
      sym_hll_argument_list,
    ACTIONS(3920), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4682), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4966), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3635), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3633), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [146865] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3780), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3778), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [146901] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3802), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3800), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [146937] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5054), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147007] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3809), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3807), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [147043] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3813), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
      sym__blank,
    ACTIONS(3811), 21,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      aux_sym__hll_expression_separator_token1,
      aux_sym__hll_expression_separator_token2,
  [147079] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5056), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147149] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5056), 2,
      sym_comment,
      sym__blank_line,
  [147219] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5058), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147289] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5058), 2,
      sym_comment,
      sym__blank_line,
  [147359] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3924), 1,
      sym__blank,
    ACTIONS(3782), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(3676), 7,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3671), 18,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [147399] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5060), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147469] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5060), 2,
      sym_comment,
      sym__blank_line,
  [147539] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5066), 1,
      anon_sym_EQ,
    ACTIONS(5068), 1,
      sym__blank,
    STATE(3770), 1,
      aux_sym_block_repeat1,
    ACTIONS(5062), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5064), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [147581] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2978), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2980), 21,
      sym__and_operator_pre_hook,
      sym_path,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [147617] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4153), 1,
      sym_path,
    ACTIONS(3110), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3112), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [147655] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4785), 1,
      anon_sym_SLASH,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4902), 1,
      anon_sym_EQ,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4908), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3940), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4783), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5070), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147725] = 20,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4976), 1,
      anon_sym_SLASH,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5070), 2,
      sym_comment,
      sym__blank_line,
  [147795] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(5074), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5072), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [147863] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5077), 10,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5079), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [147898] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5081), 10,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5083), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [147933] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2100), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [147968] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3012), 1,
      anon_sym_COMMA,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148035] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 9,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [148084] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3024), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3026), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148145] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3024), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3026), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148208] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 12,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [148255] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5113), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 2,
      anon_sym_EQ,
      anon_sym_PIPE,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3026), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148314] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5113), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3024), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3026), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148371] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3024), 5,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 9,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COMMA,
      sym__blank,
  [148422] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [148467] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3073), 1,
      anon_sym_EQ,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(3075), 4,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148528] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(3073), 3,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(3075), 5,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_COMMA,
      sym__blank,
  [148583] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3079), 1,
      anon_sym_COMMA,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148650] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3083), 1,
      anon_sym_COMMA,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148717] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3435), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [148752] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2244), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [148787] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3087), 1,
      anon_sym_COMMA,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148854] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5116), 1,
      anon_sym_RPAREN,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148921] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5116), 1,
      anon_sym_RBRACE,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [148988] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3449), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3451), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149023] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5122), 1,
      aux_sym_while_block_token1,
    STATE(3647), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(5125), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(5118), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(5120), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [149064] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1667), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149099] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5128), 1,
      anon_sym_RPAREN,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [149166] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5130), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [149233] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1707), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149268] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1707), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149303] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3347), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3349), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149338] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5132), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [149405] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1647), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149440] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3347), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3349), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149475] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5134), 1,
      anon_sym_RPAREN,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [149542] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5134), 1,
      anon_sym_RBRACE,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [149609] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3351), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3353), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149644] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1687), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149679] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5136), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [149746] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2100), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149781] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2267), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149816] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1667), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [149851] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1625), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [149886] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5138), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [149953] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5140), 1,
      anon_sym_RPAREN,
    ACTIONS(5077), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5079), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [149990] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2244), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150025] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2267), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150060] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5142), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150127] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2290), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150162] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2311), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150197] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2332), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150232] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2641), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150267] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3541), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150302] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5144), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150369] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5146), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150436] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5148), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150503] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2290), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150538] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5150), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150605] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3435), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150640] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5152), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150707] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2311), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150742] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2332), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150777] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(2641), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150812] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3351), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3353), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [150847] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5154), 1,
      anon_sym_RPAREN,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [150914] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3541), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [150949] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5160), 1,
      aux_sym_while_block_token1,
    STATE(3600), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(5163), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(5156), 7,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(5158), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [150990] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(5170), 1,
      sym__blank,
    STATE(2614), 1,
      aux_sym_block_repeat1,
    ACTIONS(5166), 8,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5168), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [151031] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4915), 1,
      anon_sym_COMMA,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    ACTIONS(5172), 1,
      sym__blank,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [151098] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(5170), 1,
      sym__blank,
    STATE(2614), 1,
      aux_sym_block_repeat1,
    ACTIONS(5166), 8,
      sym_label_identifier,
      ts_builtin_sym_end,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5168), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [151139] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1983), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(4273), 1,
      sym__blank,
    ACTIONS(1981), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(1973), 3,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1975), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(1978), 6,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_DOT_DOT,
    ACTIONS(1971), 10,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [151184] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5175), 1,
      anon_sym_RPAREN,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [151251] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(4837), 1,
      anon_sym_EQ,
    ACTIONS(4843), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4845), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4849), 1,
      anon_sym_PIPE,
    ACTIONS(4851), 1,
      anon_sym_CARET,
    ACTIONS(4859), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4865), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4910), 1,
      sym__blank,
    ACTIONS(5175), 1,
      anon_sym_RBRACE,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3908), 1,
      aux_sym_block_repeat1,
    ACTIONS(4839), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4841), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4855), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4857), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4847), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4853), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [151318] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2926), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2928), 14,
      sym__and_operator_pre_hook,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [151363] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(2933), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(2935), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COMMA,
      sym__blank,
  [151406] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(3024), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3026), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151445] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3445), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3447), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [151480] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5177), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [151547] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3445), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3447), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [151582] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3449), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3451), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [151617] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5179), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [151684] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5181), 1,
      anon_sym_RBRACK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [151751] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3280), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3282), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [151786] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3406), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3408), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151821] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1647), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [151856] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3445), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3447), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151891] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3445), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3447), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151926] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3449), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3451), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151961] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3449), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3451), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [151996] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1625), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [152031] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5183), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_sizeof,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5185), 21,
      sym__hll_number_literal_pre_hook,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_BANG,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [152066] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(1687), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [152101] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3280), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(3282), 20,
      sym__and_operator_pre_hook,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym__blank,
  [152136] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5187), 1,
      anon_sym_RPAREN,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [152203] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5189), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [152270] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5191), 1,
      sym__blank,
    STATE(2614), 1,
      aux_sym_block_repeat1,
    ACTIONS(3217), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(3219), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [152309] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5198), 1,
      anon_sym_RPAREN,
    ACTIONS(5194), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5196), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152346] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3406), 9,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
      sym__blank,
    ACTIONS(3408), 18,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [152381] = 19,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4881), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4883), 1,
      anon_sym_PIPE,
    ACTIONS(4885), 1,
      anon_sym_CARET,
    ACTIONS(4887), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4889), 1,
      anon_sym_AMP,
    ACTIONS(4891), 1,
      anon_sym_QMARK,
    ACTIONS(5200), 1,
      anon_sym_COLON,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4869), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4873), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4875), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4879), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4871), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [152448] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5202), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5204), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152482] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5206), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5208), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152516] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5206), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5208), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152550] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5166), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5168), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152584] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5210), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5212), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152618] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5077), 9,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5079), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152652] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5214), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5216), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152686] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5166), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5168), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152720] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5218), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5220), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152754] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5218), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5220), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152788] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5222), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5224), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152822] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(555), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [152886] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5226), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5228), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152920] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5226), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5228), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152954] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5226), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5228), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [152988] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5226), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5228), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153022] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5230), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5232), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153056] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5230), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5232), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153090] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5234), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5236), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153124] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5238), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5240), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153158] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5242), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5244), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153192] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5246), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5248), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153226] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5250), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5252), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153260] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3617), 1,
      anon_sym_LPAREN,
    ACTIONS(3625), 1,
      anon_sym_LBRACK,
    ACTIONS(4472), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4476), 1,
      anon_sym_PIPE,
    ACTIONS(4478), 1,
      anon_sym_CARET,
    ACTIONS(4488), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4490), 1,
      anon_sym_AMP,
    ACTIONS(4494), 1,
      anon_sym_QMARK,
    STATE(1456), 1,
      sym_hll_argument_list,
    ACTIONS(3623), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4468), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4470), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4480), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4482), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4484), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4486), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4474), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [153324] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5254), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5256), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153358] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5258), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5260), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153392] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5258), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5260), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153426] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5262), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5264), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153460] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5266), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5268), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153494] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3782), 1,
      sym__blank,
    ACTIONS(3676), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3671), 19,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [153530] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5266), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5268), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153564] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5270), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5272), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153598] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5274), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5276), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153632] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4996), 1,
      sym__blank,
    ACTIONS(3776), 6,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_AMP,
    ACTIONS(3774), 19,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_AMP_AMP,
      anon_sym_DOT,
      anon_sym_QMARK,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
  [153668] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2100), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [153732] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5278), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5280), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153766] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5282), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5284), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153800] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4645), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(4647), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153834] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(4787), 1,
      anon_sym_PIPE,
    ACTIONS(4789), 1,
      anon_sym_CARET,
    ACTIONS(4797), 1,
      anon_sym_DOT_DOT,
    ACTIONS(4799), 1,
      sym__and_operator_pre_hook,
    ACTIONS(4904), 1,
      anon_sym_CARET_CARET,
    ACTIONS(4906), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5109), 1,
      sym__blank,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(4779), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4781), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4793), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4795), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4783), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(4791), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [153898] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5286), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5288), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153932] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4927), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(4929), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [153966] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5290), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5292), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154000] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5194), 9,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5196), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154034] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    ACTIONS(5085), 1,
      anon_sym_EQ,
    ACTIONS(5091), 1,
      anon_sym_CARET_CARET,
    ACTIONS(5093), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(5097), 1,
      anon_sym_PIPE,
    ACTIONS(5099), 1,
      anon_sym_CARET,
    ACTIONS(5107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5109), 1,
      sym__blank,
    ACTIONS(5111), 1,
      sym__and_operator_pre_hook,
    STATE(2164), 1,
      sym_argument_list,
    STATE(3948), 1,
      aux_sym_block_repeat1,
    ACTIONS(5087), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5089), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5103), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(5105), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(5095), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(5101), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [154098] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4564), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(4566), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154132] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5294), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5296), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154166] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5298), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5300), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154200] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4972), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4978), 1,
      anon_sym_PIPE,
    ACTIONS(4980), 1,
      anon_sym_CARET,
    ACTIONS(4988), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4990), 1,
      anon_sym_AMP,
    ACTIONS(4992), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4374), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4968), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4970), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4982), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4984), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4974), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [154264] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4825), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(4827), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154298] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5302), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5304), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154332] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5306), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5308), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154366] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5310), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5312), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154400] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5314), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5316), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154434] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5318), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5320), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154468] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5318), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5320), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154502] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5322), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5324), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154536] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5326), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5328), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154570] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5330), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5332), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154604] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5334), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5336), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154638] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5334), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5336), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154672] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4275), 1,
      sym__blank,
    ACTIONS(4273), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(1973), 8,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 15,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [154710] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5334), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5336), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154744] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5338), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5340), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154778] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5342), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5344), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154812] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5346), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5348), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154846] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5334), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5336), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154880] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5342), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5344), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154914] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5350), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5352), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154948] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5350), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5352), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [154982] = 17,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5364), 1,
      sym_hll_primitive_type,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2716), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(2735), 1,
      sym__hll_declaration_specifiers,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(3819), 1,
      sym_hll_declaration,
    STATE(3938), 1,
      sym__var_definition_command_argument_list_format,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2908), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [155044] = 18,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3884), 1,
      anon_sym_LPAREN,
    ACTIONS(3894), 1,
      anon_sym_LBRACK,
    ACTIONS(4809), 1,
      anon_sym_PIPE,
    ACTIONS(4811), 1,
      anon_sym_CARET,
    ACTIONS(4821), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4823), 1,
      anon_sym_AMP,
    ACTIONS(4893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(4895), 1,
      anon_sym_QMARK,
    STATE(1726), 1,
      sym_hll_argument_list,
    ACTIONS(3892), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4801), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(4803), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(4813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(4815), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(4817), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(4819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(4805), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [155108] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5342), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5344), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155142] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5368), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5370), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155176] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5372), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5374), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155210] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5342), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5344), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155244] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5376), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5378), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155278] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5376), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5378), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155312] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5380), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5382), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155346] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5206), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5208), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155380] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5372), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5374), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155414] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5206), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5208), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155448] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5384), 9,
      sym_label_identifier,
      ts_builtin_sym_end,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5386), 17,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155482] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5392), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5396), 1,
      anon_sym_LBRACK,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    STATE(2701), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    ACTIONS(5390), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3244), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(3373), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [155541] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5392), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5396), 1,
      anon_sym_LBRACK,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5412), 1,
      sym__blank,
    STATE(2700), 1,
      aux_sym_block_repeat1,
    STATE(2701), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5410), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3224), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(3413), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [155600] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4273), 1,
      anon_sym_RPAREN,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 17,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
      sym__blank,
  [155635] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5414), 1,
      anon_sym_RPAREN,
    ACTIONS(5416), 1,
      sym_hll_primitive_type,
    STATE(2710), 1,
      sym__hll_declaration_specifiers,
    STATE(2715), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(3785), 1,
      sym_hll_parameter_declaration,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2818), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [155691] = 22,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7), 1,
      sym_identifier,
    ACTIONS(35), 1,
      aux_sym__host_command_with_default_format_token1,
    ACTIONS(5420), 1,
      aux_sym_parameter_declaration_token3,
    ACTIONS(5422), 1,
      aux_sym_subroutine_call_expression_token1,
    ACTIONS(5424), 1,
      aux_sym__hll_non_default_format_var_command_token1,
    STATE(3639), 1,
      sym__hll_var_command_with_default_format,
    STATE(3668), 1,
      sym__command_identifier,
    STATE(3683), 1,
      sym__var_command_with_non_hll_format,
    STATE(3914), 1,
      sym_macro_definition_command,
    STATE(3986), 1,
      sym__hll_default_format_var_command,
    STATE(4002), 1,
      sym__host_command,
    STATE(4009), 1,
      sym__other_command,
    STATE(4010), 1,
      sym__var_command,
    STATE(4013), 1,
      sym__non_hll_var_command,
    STATE(4016), 1,
      sym__hll_non_default_format_var_command,
    STATE(4063), 1,
      sym__hll_var_definition_command,
    STATE(4073), 1,
      sym__hll_var_definition_command_expression,
    STATE(4080), 1,
      sym__hll_var_command,
    STATE(4094), 1,
      sym__host_command_with_default_format,
    ACTIONS(5418), 2,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
    ACTIONS(33), 3,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
  [155761] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5416), 1,
      sym_hll_primitive_type,
    ACTIONS(5426), 1,
      anon_sym_RPAREN,
    STATE(2710), 1,
      sym__hll_declaration_specifiers,
    STATE(2715), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(3913), 1,
      sym_hll_parameter_declaration,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2818), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [155817] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5428), 1,
      sym__blank,
    STATE(2706), 1,
      aux_sym_block_repeat1,
    ACTIONS(3217), 7,
      sym_label_identifier,
      aux_sym_block_token1,
      anon_sym_RPAREN,
      aux_sym_while_block_token2,
      anon_sym_EQ,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(3219), 15,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
  [155853] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2707), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(5435), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(5433), 5,
      sym_label_identifier,
      aux_sym_block_token1,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
    ACTIONS(5431), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [155889] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4273), 1,
      sym__blank,
    ACTIONS(1973), 7,
      anon_sym_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(1971), 16,
      sym__and_operator_pre_hook,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_CARET_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_DOT_DOT,
  [155923] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5392), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5396), 1,
      anon_sym_LBRACK,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    STATE(2701), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3361), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(3530), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [155978] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5392), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5396), 1,
      anon_sym_LBRACK,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    STATE(2701), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5438), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3343), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(3419), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156031] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5392), 1,
      anon_sym_LPAREN,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5396), 1,
      anon_sym_LBRACK,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5440), 1,
      sym__blank,
    STATE(2701), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2709), 1,
      aux_sym_block_repeat1,
    STATE(3368), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
    STATE(3521), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156086] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5416), 1,
      sym_hll_primitive_type,
    STATE(2710), 1,
      sym__hll_declaration_specifiers,
    STATE(2715), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    STATE(4065), 1,
      sym_hll_parameter_declaration,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2818), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [156139] = 13,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(590), 1,
      anon_sym_struct,
    ACTIONS(592), 1,
      anon_sym_union,
    ACTIONS(594), 1,
      anon_sym_enum,
    ACTIONS(5442), 1,
      sym_identifier,
    ACTIONS(5444), 1,
      sym_hll_primitive_type,
    ACTIONS(5446), 1,
      sym__blank,
    STATE(2730), 1,
      aux_sym_block_repeat1,
    STATE(3308), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2823), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat1,
    ACTIONS(596), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2801), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [156189] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5450), 6,
      sym_label_identifier,
      aux_sym_while_block_token2,
      anon_sym_AMP_AMP,
      aux_sym_macro_definition_token1,
      sym_comment,
      sym__blank_line,
    ACTIONS(5448), 16,
      aux_sym_subroutine_block_token1,
      aux_sym_if_block_token1,
      aux_sym_while_block_token1,
      aux_sym__repeat_block_pre_condition_format_token1,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token1,
      aux_sym_parameter_declaration_token2,
      aux_sym_parameter_declaration_token3,
      aux_sym_subroutine_call_expression_token1,
      aux_sym_macro_definition_command_token1,
      aux_sym_macro_definition_command_token2,
      aux_sym_macro_definition_command_token3,
      aux_sym__host_command_with_default_format_token1,
      aux_sym__hll_non_default_format_var_command_token1,
      sym_identifier,
      sym__blank,
  [156219] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5452), 1,
      sym_hll_primitive_type,
    STATE(2838), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2826), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [156266] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    ACTIONS(5356), 1,
      anon_sym_struct,
    ACTIONS(5358), 1,
      anon_sym_union,
    ACTIONS(5360), 1,
      anon_sym_enum,
    ACTIONS(5454), 1,
      sym_hll_primitive_type,
    STATE(2838), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    STATE(3154), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(588), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5362), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2948), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [156313] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5458), 1,
      anon_sym_LPAREN,
    ACTIONS(5461), 1,
      anon_sym_LBRACK,
    ACTIONS(5464), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2746), 1,
      aux_sym_block_repeat1,
    ACTIONS(5456), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3410), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156365] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5469), 1,
      anon_sym_LPAREN,
    ACTIONS(5472), 1,
      anon_sym_LBRACK,
    ACTIONS(5475), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2742), 1,
      aux_sym_block_repeat1,
    ACTIONS(5467), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3365), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156417] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5480), 1,
      anon_sym_LPAREN,
    ACTIONS(5483), 1,
      anon_sym_LBRACK,
    ACTIONS(5486), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2753), 1,
      aux_sym_block_repeat1,
    ACTIONS(5478), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3411), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156469] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5491), 1,
      anon_sym_LPAREN,
    ACTIONS(5494), 1,
      anon_sym_LBRACK,
    ACTIONS(5497), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2758), 1,
      aux_sym_block_repeat1,
    ACTIONS(5489), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3362), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156521] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5502), 1,
      anon_sym_LPAREN,
    ACTIONS(5505), 1,
      anon_sym_LBRACK,
    ACTIONS(5508), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2761), 1,
      aux_sym_block_repeat1,
    ACTIONS(5500), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3364), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156573] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5513), 1,
      anon_sym_LPAREN,
    ACTIONS(5516), 1,
      anon_sym_LBRACK,
    ACTIONS(5519), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2757), 1,
      aux_sym_block_repeat1,
    ACTIONS(5511), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3358), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156625] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5524), 1,
      anon_sym_LPAREN,
    ACTIONS(5527), 1,
      anon_sym_LBRACK,
    ACTIONS(5530), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2770), 1,
      aux_sym_block_repeat1,
    ACTIONS(5522), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3401), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156677] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5535), 1,
      anon_sym_LPAREN,
    ACTIONS(5538), 1,
      anon_sym_LBRACK,
    ACTIONS(5541), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2765), 1,
      aux_sym_block_repeat1,
    ACTIONS(5533), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3363), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156729] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5546), 1,
      anon_sym_LPAREN,
    ACTIONS(5549), 1,
      anon_sym_LBRACK,
    ACTIONS(5552), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2767), 1,
      aux_sym_block_repeat1,
    ACTIONS(5544), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3387), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156781] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5557), 1,
      anon_sym_LPAREN,
    ACTIONS(5560), 1,
      anon_sym_LBRACK,
    ACTIONS(5563), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2766), 1,
      aux_sym_block_repeat1,
    ACTIONS(5555), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3386), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156833] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5568), 1,
      anon_sym_LPAREN,
    ACTIONS(5571), 1,
      anon_sym_LBRACK,
    ACTIONS(5574), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2768), 1,
      aux_sym_block_repeat1,
    ACTIONS(5566), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    STATE(3388), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156885] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3316), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156933] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3284), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [156981] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(590), 1,
      anon_sym_struct,
    ACTIONS(592), 1,
      anon_sym_union,
    ACTIONS(594), 1,
      anon_sym_enum,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(5442), 1,
      sym_identifier,
    ACTIONS(5593), 1,
      sym_hll_primitive_type,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3308), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(596), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2800), 6,
      sym__hll_type_specifier,
      sym_hll_struct_specifier,
      sym_hll_union_specifier,
      sym_hll_enum_specifier,
      sym_hll_sized_type_specifier,
      sym__hll_type_identifier,
  [157023] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3569), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157071] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5599), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2777), 1,
      aux_sym_block_repeat1,
    STATE(3318), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157119] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5601), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2738), 1,
      aux_sym_block_repeat1,
    STATE(3413), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157167] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3323), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157215] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5603), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2748), 1,
      aux_sym_block_repeat1,
    STATE(3288), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157263] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5613), 1,
      aux_sym_symbol_token1,
    ACTIONS(5615), 1,
      aux_sym_symbol_token2,
    ACTIONS(5617), 1,
      anon_sym_BSLASH,
    ACTIONS(5619), 1,
      aux_sym_symbol_token3,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    STATE(2897), 1,
      sym_macro,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    STATE(3083), 1,
      sym_macro_text_expansion,
    STATE(3103), 1,
      sym_string,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [157315] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5623), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2742), 1,
      aux_sym_block_repeat1,
    STATE(3365), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157363] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3373), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157411] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5625), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2746), 1,
      aux_sym_block_repeat1,
    STATE(3410), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157459] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5627), 1,
      sym__blank,
    STATE(2731), 1,
      aux_sym_block_repeat1,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3449), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157507] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3314), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157555] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3411), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157603] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3317), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157651] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5629), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2753), 1,
      aux_sym_block_repeat1,
    STATE(3411), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157699] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5631), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2755), 1,
      aux_sym_block_repeat1,
    STATE(3317), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157747] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3358), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157795] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5633), 1,
      sym__blank,
    STATE(2734), 1,
      aux_sym_block_repeat1,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3342), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157843] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3344), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157891] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5635), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2757), 1,
      aux_sym_block_repeat1,
    STATE(3358), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157939] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5637), 1,
      sym__blank,
    STATE(2729), 1,
      aux_sym_block_repeat1,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3245), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [157987] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5641), 1,
      aux_sym_symbol_token1,
    ACTIONS(5643), 1,
      aux_sym_symbol_token2,
    ACTIONS(5645), 1,
      anon_sym_BSLASH,
    ACTIONS(5647), 1,
      aux_sym_symbol_token3,
    STATE(2910), 1,
      sym_macro,
    STATE(3068), 1,
      sym_macro_text_expansion,
    STATE(3078), 1,
      sym_string,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [158039] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5649), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2758), 1,
      aux_sym_block_repeat1,
    STATE(3362), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158087] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3363), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158135] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5651), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2761), 1,
      aux_sym_block_repeat1,
    STATE(3364), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158183] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3256), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158231] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5653), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2765), 1,
      aux_sym_block_repeat1,
    STATE(3363), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158279] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3385), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158327] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3386), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158375] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5655), 1,
      sym__blank,
    STATE(2743), 1,
      aux_sym_block_repeat1,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3282), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158423] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5657), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2762), 1,
      aux_sym_block_repeat1,
    STATE(3521), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158471] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3387), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158519] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3530), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158567] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5659), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2767), 1,
      aux_sym_block_repeat1,
    STATE(3387), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158615] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5661), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2768), 1,
      aux_sym_block_repeat1,
    STATE(3388), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158663] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3389), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158711] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3348), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158759] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3448), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158807] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3401), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158855] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5663), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2770), 1,
      aux_sym_block_repeat1,
    STATE(3401), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158903] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3407), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [158951] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(5667), 1,
      aux_sym_symbol_token1,
    ACTIONS(5669), 1,
      aux_sym_symbol_token2,
    ACTIONS(5671), 1,
      anon_sym_BSLASH,
    ACTIONS(5673), 1,
      aux_sym_symbol_token3,
    STATE(2936), 1,
      sym_macro,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3088), 1,
      sym_string,
    STATE(3089), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [159003] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3232), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159051] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(5677), 1,
      aux_sym_symbol_token1,
    ACTIONS(5679), 1,
      aux_sym_symbol_token2,
    ACTIONS(5681), 1,
      anon_sym_BSLASH,
    ACTIONS(5683), 1,
      aux_sym_symbol_token3,
    STATE(2919), 1,
      sym_macro,
    STATE(3099), 1,
      sym_macro_text_expansion,
    STATE(3116), 1,
      sym_string,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [159103] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5685), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2781), 1,
      aux_sym_block_repeat1,
    STATE(3232), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159151] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5687), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2782), 1,
      aux_sym_block_repeat1,
    STATE(3235), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159199] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5689), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2772), 1,
      aux_sym_block_repeat1,
    STATE(3281), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159247] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3292), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159295] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3245), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159343] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5691), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2778), 1,
      aux_sym_block_repeat1,
    STATE(3292), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159391] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5693), 1,
      sym__blank,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2784), 1,
      aux_sym_block_repeat1,
    STATE(3246), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159439] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3277), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159487] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3278), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159535] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5695), 1,
      sym__blank,
    STATE(2741), 1,
      aux_sym_block_repeat1,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3278), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159583] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3280), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159631] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5577), 1,
      sym_identifier,
    ACTIONS(5579), 1,
      anon_sym_LPAREN,
    ACTIONS(5581), 1,
      anon_sym_LBRACK,
    ACTIONS(5583), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5585), 1,
      aux_sym_symbol_token1,
    ACTIONS(5587), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5589), 1,
      anon_sym_BSLASH,
    ACTIONS(5591), 1,
      aux_sym_symbol_token5,
    ACTIONS(5697), 1,
      sym__blank,
    STATE(2728), 1,
      aux_sym_block_repeat1,
    STATE(2747), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3280), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159679] = 16,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(5701), 1,
      aux_sym_symbol_token1,
    ACTIONS(5703), 1,
      aux_sym_symbol_token2,
    ACTIONS(5705), 1,
      anon_sym_BSLASH,
    ACTIONS(5707), 1,
      aux_sym_symbol_token3,
    STATE(2930), 1,
      sym_macro,
    STATE(3075), 1,
      sym_macro_text_expansion,
    STATE(3107), 1,
      sym_string,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [159731] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5394), 1,
      anon_sym_STAR,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5595), 1,
      anon_sym_LPAREN,
    ACTIONS(5597), 1,
      anon_sym_LBRACK,
    ACTIONS(5709), 1,
      sym__blank,
    STATE(2733), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2766), 1,
      aux_sym_block_repeat1,
    STATE(3386), 6,
      sym__hll_declarator,
      sym_hll_pointer_declarator,
      sym_hll_function_declarator,
      sym_hll_array_declarator,
      sym_hll_parenthesized_declarator,
      sym_symbol,
  [159779] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5717), 1,
      sym__decimal_number_pre_hook,
    ACTIONS(5719), 1,
      sym_hll_number_literal,
    ACTIONS(5715), 2,
      aux_sym_integer_token1,
      aux_sym_integer_token2,
    STATE(4058), 3,
      sym_hll_char_literal,
      sym_hll_string_literal,
      sym_integer,
    ACTIONS(5711), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(5713), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [159812] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5729), 1,
      aux_sym_symbol_token1,
    ACTIONS(5731), 1,
      aux_sym_symbol_token2,
    ACTIONS(5733), 1,
      anon_sym_BSLASH,
    ACTIONS(5735), 1,
      aux_sym_symbol_token3,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    STATE(2997), 1,
      sym_macro,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    STATE(3189), 1,
      sym_macro_text_expansion,
    STATE(3248), 1,
      sym_string,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [159861] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(5741), 1,
      aux_sym_symbol_token1,
    ACTIONS(5743), 1,
      aux_sym_symbol_token2,
    ACTIONS(5745), 1,
      anon_sym_BSLASH,
    ACTIONS(5747), 1,
      aux_sym_symbol_token3,
    STATE(2972), 1,
      sym_macro,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3252), 1,
      sym_string,
    STATE(3253), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [159910] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5755), 1,
      sym__blank,
    STATE(2813), 1,
      sym_hll_type_qualifier,
    STATE(3424), 1,
      aux_sym_block_repeat1,
    STATE(3654), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(5753), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5749), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5751), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [159945] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5760), 1,
      aux_sym_symbol_token1,
    ACTIONS(5762), 1,
      aux_sym_symbol_token2,
    ACTIONS(5764), 1,
      anon_sym_BSLASH,
    ACTIONS(5766), 1,
      aux_sym_symbol_token3,
    STATE(3003), 1,
      sym_macro,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3306), 1,
      sym_macro_text_expansion,
    STATE(3310), 1,
      sym_string,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [159994] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(5770), 1,
      aux_sym_symbol_token1,
    ACTIONS(5772), 1,
      aux_sym_symbol_token2,
    ACTIONS(5774), 1,
      anon_sym_BSLASH,
    ACTIONS(5776), 1,
      aux_sym_symbol_token3,
    STATE(2955), 1,
      sym_macro,
    STATE(3152), 1,
      sym_macro_text_expansion,
    STATE(3155), 1,
      sym_string,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [160043] = 15,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(5780), 1,
      aux_sym_symbol_token1,
    ACTIONS(5782), 1,
      aux_sym_symbol_token2,
    ACTIONS(5784), 1,
      anon_sym_BSLASH,
    ACTIONS(5786), 1,
      aux_sym_symbol_token3,
    STATE(2966), 1,
      sym_macro,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3184), 1,
      sym_string,
    STATE(3191), 1,
      sym_macro_text_expansion,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [160092] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5788), 1,
      anon_sym_RPAREN,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5798), 1,
      sym__blank,
    STATE(2824), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3021), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3402), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160132] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5801), 1,
      anon_sym_RPAREN,
    ACTIONS(5803), 1,
      sym__blank,
    STATE(2829), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3021), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3396), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160172] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5806), 1,
      anon_sym_RPAREN,
    ACTIONS(5808), 1,
      sym__blank,
    STATE(2827), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2796), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3425), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160212] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5811), 1,
      anon_sym_RPAREN,
    ACTIONS(5814), 1,
      sym__blank,
    STATE(2833), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2799), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3400), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160252] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5818), 1,
      anon_sym_RPAREN,
    ACTIONS(5821), 1,
      sym__blank,
    STATE(2822), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3021), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3356), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160292] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5825), 1,
      anon_sym_RPAREN,
    ACTIONS(5827), 1,
      sym__blank,
    STATE(2825), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2802), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3415), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160332] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5830), 1,
      anon_sym_RPAREN,
    ACTIONS(5832), 1,
      sym__blank,
    STATE(2835), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2795), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3352), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160372] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5835), 1,
      anon_sym_RPAREN,
    ACTIONS(5837), 1,
      sym__blank,
    STATE(2831), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3021), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    STATE(3382), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [160412] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4536), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      sym__blank,
    ACTIONS(4534), 11,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [160436] = 14,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5388), 1,
      sym_identifier,
    ACTIONS(5398), 1,
      anon_sym_BSLASH_BSLASH_BSLASH,
    ACTIONS(5400), 1,
      aux_sym_symbol_token1,
    ACTIONS(5402), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5404), 1,
      anon_sym_BSLASH,
    ACTIONS(5406), 1,
      aux_sym_symbol_token5,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(5840), 1,
      anon_sym_POUND,
    ACTIONS(5842), 1,
      sym__blank,
    ACTIONS(5844), 1,
      sym_path,
    STATE(2984), 1,
      aux_sym_block_repeat1,
    STATE(4008), 1,
      sym__hll_var_command_argument_list_non_default_format,
    STATE(4006), 3,
      sym_string,
      sym_symbol,
      sym_file_handle,
  [160481] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2588), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [160504] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2756), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2758), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [160527] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2588), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [160554] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 8,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [160579] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(2588), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2590), 4,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_COLON_COLON_COLON,
  [160610] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2588), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2590), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [160639] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5860), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(5858), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5854), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5856), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160668] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5867), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(5858), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5863), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5865), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160697] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5874), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(5858), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5870), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5872), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160726] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2777), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2779), 11,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_DOT_DOT,
      anon_sym_COLON_COLON_COLON,
  [160749] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5881), 1,
      sym__blank,
    STATE(2817), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5877), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5879), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160777] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5883), 1,
      aux_sym_symbol_token1,
    ACTIONS(5885), 1,
      aux_sym_symbol_token2,
    ACTIONS(5887), 1,
      anon_sym_BSLASH,
    STATE(2903), 1,
      sym_macro,
    STATE(3067), 1,
      sym_macro_text_expansion,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [160817] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5893), 1,
      sym__blank,
    STATE(2817), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5889), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5891), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160845] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5881), 1,
      sym__blank,
    STATE(2815), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5896), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5898), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [160873] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5900), 1,
      anon_sym_RPAREN,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [160909] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5904), 1,
      aux_sym_symbol_token1,
    ACTIONS(5906), 1,
      aux_sym_symbol_token2,
    ACTIONS(5908), 1,
      anon_sym_BSLASH,
    STATE(2894), 1,
      sym_macro,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    STATE(3134), 1,
      sym_macro_text_expansion,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [160949] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5910), 1,
      anon_sym_RBRACE,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [160985] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3353), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161021] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5919), 1,
      sym__blank,
    ACTIONS(5916), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2823), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat1,
    ACTIONS(5914), 9,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [161047] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3376), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161083] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3382), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161119] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5881), 1,
      sym__blank,
    STATE(2834), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5921), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5923), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [161147] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3396), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161183] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5925), 1,
      anon_sym_RPAREN,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161219] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3428), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161255] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5900), 1,
      anon_sym_RBRACE,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161291] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3429), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161327] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5925), 1,
      anon_sym_RBRACE,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161363] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3356), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161399] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5881), 1,
      sym__blank,
    STATE(2817), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5927), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5929), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [161427] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3402), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [161463] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5931), 1,
      anon_sym_RPAREN,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161499] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5931), 1,
      anon_sym_RBRACE,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161535] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2838), 1,
      aux_sym__hll_declaration_specifiers_repeat1,
    ACTIONS(5935), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(4087), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
    ACTIONS(5933), 9,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [161561] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4534), 5,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(4536), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [161583] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5852), 1,
      anon_sym_CARET,
    ACTIONS(5902), 1,
      anon_sym_PIPE,
    ACTIONS(5910), 1,
      anon_sym_RPAREN,
    ACTIONS(5850), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5846), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5848), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161619] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5940), 1,
      sym__blank,
    STATE(2874), 1,
      aux_sym_block_repeat1,
    ACTIONS(5938), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161642] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5908), 1,
      anon_sym_BSLASH,
    ACTIONS(5942), 1,
      sym_identifier,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(5946), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    STATE(2882), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [161677] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(5948), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161700] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5950), 1,
      aux_sym_symbol_token1,
    ACTIONS(5952), 1,
      aux_sym_symbol_token2,
    ACTIONS(5954), 1,
      anon_sym_BSLASH,
    STATE(3000), 1,
      sym_macro,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3305), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [161737] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(5956), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161760] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5960), 1,
      sym__blank,
    STATE(2848), 1,
      aux_sym_block_repeat1,
    ACTIONS(5958), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161783] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5962), 1,
      aux_sym_symbol_token1,
    ACTIONS(5964), 1,
      aux_sym_symbol_token2,
    ACTIONS(5966), 1,
      anon_sym_BSLASH,
    STATE(2992), 1,
      sym_macro,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    STATE(3309), 1,
      sym_macro_text_expansion,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [161820] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(5968), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161843] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5942), 1,
      sym_identifier,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5972), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    STATE(2882), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [161878] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5978), 1,
      sym__blank,
    STATE(2860), 1,
      aux_sym_block_repeat1,
    ACTIONS(5976), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161901] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5982), 1,
      sym__blank,
    STATE(2854), 1,
      aux_sym_block_repeat1,
    ACTIONS(5980), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161924] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5990), 1,
      anon_sym_CARET,
    ACTIONS(2588), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 2,
      anon_sym_PIPE,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [161953] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5994), 1,
      sym__blank,
    STATE(2862), 1,
      aux_sym_block_repeat1,
    ACTIONS(5992), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161976] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(5996), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [161999] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6000), 1,
      sym__blank,
    STATE(2871), 1,
      aux_sym_block_repeat1,
    ACTIONS(5998), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162022] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6004), 1,
      sym__blank,
    STATE(2861), 1,
      aux_sym_block_repeat1,
    ACTIONS(6002), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162045] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(5933), 11,
      anon_sym_const,
      anon_sym_volatile,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_enum,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_hll_primitive_type,
      sym_identifier,
  [162068] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(5990), 1,
      anon_sym_CARET,
    ACTIONS(6006), 1,
      anon_sym_PIPE,
    ACTIONS(6008), 1,
      anon_sym_COLON,
    ACTIONS(6010), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [162101] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6016), 1,
      sym__blank,
    STATE(3271), 1,
      aux_sym_block_repeat1,
    ACTIONS(6012), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6014), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [162126] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6019), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162149] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6021), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162172] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6023), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162195] = 11,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5972), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    ACTIONS(6025), 1,
      sym_identifier,
    STATE(2842), 1,
      sym_macro,
    STATE(3044), 1,
      sym_macro_text_expansion,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [162232] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6029), 1,
      sym__blank,
    STATE(2877), 1,
      aux_sym_block_repeat1,
    ACTIONS(6027), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162255] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6035), 1,
      sym__blank,
    STATE(3271), 1,
      aux_sym_block_repeat1,
    ACTIONS(6031), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6033), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [162280] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2588), 2,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2590), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [162307] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6038), 1,
      sym__blank,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(3217), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [162332] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5990), 1,
      anon_sym_CARET,
    ACTIONS(6006), 1,
      anon_sym_PIPE,
    ACTIONS(6041), 1,
      anon_sym_COLON,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [162365] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2627), 1,
      anon_sym_COLON,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5990), 1,
      anon_sym_CARET,
    ACTIONS(6006), 1,
      anon_sym_PIPE,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [162398] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6045), 1,
      sym__blank,
    STATE(2873), 1,
      aux_sym_block_repeat1,
    ACTIONS(6043), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162421] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6047), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162444] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6051), 1,
      sym__blank,
    STATE(2845), 1,
      aux_sym_block_repeat1,
    ACTIONS(6049), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162467] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6053), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162490] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6055), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162513] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6059), 1,
      sym__blank,
    STATE(2843), 1,
      aux_sym_block_repeat1,
    ACTIONS(6057), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162536] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2590), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2588), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
  [162561] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6061), 11,
      anon_sym_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [162584] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(2588), 4,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_COLON,
      anon_sym_COLON_COLON,
    ACTIONS(2590), 6,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_COLON_COLON_COLON,
  [162607] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2629), 1,
      anon_sym_COLON_COLON_COLON,
    ACTIONS(2631), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5990), 1,
      anon_sym_CARET,
    ACTIONS(6006), 1,
      anon_sym_PIPE,
    ACTIONS(6063), 1,
      anon_sym_COLON,
    ACTIONS(5984), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(5986), 3,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_DOT_DOT,
    ACTIONS(5988), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [162640] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5887), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2903), 1,
      sym_macro,
    STATE(3067), 1,
      sym_macro_text_expansion,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [162674] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1890), 1,
      anon_sym_BSLASH,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2887), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [162700] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5942), 1,
      sym_identifier,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(1894), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2884), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 6,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [162726] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5942), 1,
      sym_identifier,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(1898), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2884), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 6,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [162752] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6071), 1,
      sym_identifier,
    ACTIONS(6074), 1,
      anon_sym_AMP,
    ACTIONS(1907), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2884), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 6,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [162778] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5966), 1,
      anon_sym_BSLASH,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6077), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    STATE(2886), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [162810] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1894), 1,
      anon_sym_BSLASH,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2889), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [162836] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1898), 1,
      anon_sym_BSLASH,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2889), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [162862] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5908), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [162894] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1907), 1,
      anon_sym_BSLASH,
    ACTIONS(6081), 1,
      sym_identifier,
    ACTIONS(6084), 1,
      anon_sym_AMP,
    STATE(2889), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym__blank,
  [162920] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5617), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [162952] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2888), 1,
      sym_macro,
    STATE(3069), 1,
      sym_macro_text_expansion,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [162986] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163018] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5410), 1,
      anon_sym_RPAREN,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(6087), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2927), 1,
      aux_sym_block_repeat1,
    STATE(3224), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [163050] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5887), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163082] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5645), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2912), 1,
      sym_macro,
    STATE(3078), 1,
      sym_macro_text_expansion,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163116] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(2914), 1,
      sym_macro,
    STATE(3091), 1,
      sym_macro_text_expansion,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163150] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2361), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6091), 1,
      sym__line_specifier,
    ACTIONS(6094), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163182] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6097), 1,
      anon_sym_BSLASH,
    STATE(2890), 1,
      sym_macro,
    STATE(3077), 1,
      sym_macro_text_expansion,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163216] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6097), 1,
      anon_sym_BSLASH,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163248] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2361), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6091), 1,
      sym__line_specifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163280] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6102), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(3794), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [163300] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6104), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6106), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [163320] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6108), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163352] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6110), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6112), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [163372] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6114), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6116), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [163392] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5889), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5891), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [163412] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(5681), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2953), 1,
      sym_macro,
    STATE(3116), 1,
      sym_macro_text_expansion,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163446] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6118), 1,
      sym__blank,
    STATE(2939), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5896), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5898), 6,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [163472] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(2922), 1,
      sym_macro,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3133), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163506] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2389), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6121), 1,
      sym__line_specifier,
    ACTIONS(6124), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163538] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6127), 1,
      sym__blank,
    STATE(2817), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5927), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5929), 6,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [163564] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(5681), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163596] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2389), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6121), 1,
      sym__line_specifier,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163628] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163660] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6108), 1,
      anon_sym_BSLASH,
    STATE(2923), 1,
      sym_macro,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    STATE(3140), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163694] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(5705), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2924), 1,
      sym_macro,
    STATE(3107), 1,
      sym_macro_text_expansion,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163728] = 12,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5912), 1,
      sym__blank,
    ACTIONS(6130), 1,
      sym_identifier,
    ACTIONS(6134), 1,
      anon_sym_PERCENT,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    STATE(3052), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(3225), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(3374), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(3860), 1,
      sym_hll_type_pattern,
    STATE(4008), 1,
      sym__hll_var_pattern_command_argument_list_format,
    STATE(4017), 1,
      sym_format_expression,
    ACTIONS(6132), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [163766] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(2928), 1,
      sym_macro,
    STATE(3074), 1,
      sym_macro_text_expansion,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163800] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2203), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6136), 1,
      sym__line_specifier,
    ACTIONS(6139), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163832] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5942), 1,
      sym_identifier,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(1890), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2883), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 6,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_comment,
      sym__blank_line,
  [163858] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2203), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6136), 1,
      sym__line_specifier,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163890] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163922] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6142), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163954] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(5671), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [163986] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(2933), 1,
      sym_macro,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3084), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164020] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2224), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6144), 1,
      sym__line_specifier,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164052] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5390), 1,
      anon_sym_RPAREN,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3244), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [164084] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164116] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(5671), 1,
      anon_sym_BSLASH,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(2934), 1,
      sym_macro,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3088), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164150] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2224), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6144), 1,
      sym__line_specifier,
    ACTIONS(6147), 1,
      anon_sym_BSLASH,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164182] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6150), 1,
      sym__line_specifier,
    STATE(2937), 1,
      sym_macro,
    STATE(3093), 1,
      sym_macro_text_expansion,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164216] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2256), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6152), 1,
      sym__line_specifier,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164248] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6150), 1,
      sym__line_specifier,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164280] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6150), 1,
      sym__line_specifier,
    ACTIONS(6155), 1,
      anon_sym_BSLASH,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164312] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6150), 1,
      sym__line_specifier,
    ACTIONS(6155), 1,
      anon_sym_BSLASH,
    STATE(2941), 1,
      sym_macro,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    STATE(3101), 1,
      sym_macro_text_expansion,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164346] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2256), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6152), 1,
      sym__line_specifier,
    ACTIONS(6157), 1,
      anon_sym_BSLASH,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164378] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6160), 1,
      sym__line_specifier,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164410] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6160), 1,
      sym__line_specifier,
    STATE(2942), 1,
      sym_macro,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    STATE(3104), 1,
      sym_macro_text_expansion,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164444] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6162), 1,
      sym__blank,
    STATE(2817), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5877), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5879), 6,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [164470] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2282), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6165), 1,
      sym__line_specifier,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2279), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164502] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6160), 1,
      sym__line_specifier,
    ACTIONS(6168), 1,
      anon_sym_BSLASH,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164534] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6170), 1,
      sym__line_specifier,
    STATE(3111), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2290), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164566] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6170), 1,
      sym__line_specifier,
    STATE(2945), 1,
      sym_macro,
    STATE(3111), 1,
      aux_sym_symbol_repeat1,
    STATE(3113), 1,
      sym_macro_text_expansion,
    ACTIONS(2290), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164600] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2305), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6172), 1,
      sym__line_specifier,
    STATE(3111), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2302), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164632] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6175), 1,
      sym__line_specifier,
    STATE(3120), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2311), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164664] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6177), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(6179), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      sym__blank,
  [164684] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6175), 1,
      sym__line_specifier,
    STATE(2950), 1,
      sym_macro,
    STATE(3120), 1,
      aux_sym_symbol_repeat1,
    STATE(3123), 1,
      sym_macro_text_expansion,
    ACTIONS(2311), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164718] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6181), 1,
      sym__blank,
    STATE(2911), 1,
      aux_sym__hll_declaration_specifiers_repeat2,
    STATE(3434), 1,
      aux_sym_block_repeat1,
    ACTIONS(5921), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(5923), 6,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
  [164744] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2326), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6184), 1,
      sym__line_specifier,
    STATE(3120), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2323), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164776] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6187), 1,
      sym__line_specifier,
    STATE(3124), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2332), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164808] = 10,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6189), 1,
      sym_identifier,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6193), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    STATE(2885), 1,
      sym_macro,
    STATE(3072), 1,
      sym_macro_text_expansion,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [164842] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6193), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    STATE(2886), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [164874] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(5705), 1,
      anon_sym_BSLASH,
    ACTIONS(6079), 1,
      sym_identifier,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164906] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [164935] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6203), 1,
      sym__line_specifier,
    ACTIONS(6206), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [164964] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(6213), 1,
      anon_sym_BSLASH,
    STATE(3223), 1,
      aux_sym_symbol_repeat1,
    STATE(3025), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [164993] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(5784), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165022] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6203), 1,
      sym__line_specifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2200), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165051] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165080] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6218), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165109] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(5745), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165138] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2969), 1,
      sym_macro,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3247), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165169] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6222), 1,
      sym__line_specifier,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165198] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165227] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(5745), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2970), 1,
      sym_macro,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3252), 1,
      sym_macro_text_expansion,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165258] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6222), 1,
      sym__line_specifier,
    ACTIONS(6225), 1,
      anon_sym_BSLASH,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2221), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165287] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6228), 1,
      sym__line_specifier,
    STATE(2954), 1,
      sym_macro,
    STATE(3266), 1,
      sym_macro_text_expansion,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165318] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6230), 1,
      sym__line_specifier,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165347] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6228), 1,
      sym__line_specifier,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165376] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6228), 1,
      sym__line_specifier,
    ACTIONS(6233), 1,
      anon_sym_BSLASH,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165405] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6228), 1,
      sym__line_specifier,
    ACTIONS(6233), 1,
      anon_sym_BSLASH,
    STATE(2976), 1,
      sym_macro,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    STATE(3274), 1,
      sym_macro_text_expansion,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165436] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6230), 1,
      sym__line_specifier,
    ACTIONS(6235), 1,
      anon_sym_BSLASH,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2253), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165465] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(1890), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3009), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [165490] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2977), 1,
      sym_macro,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    STATE(3279), 1,
      sym_macro_text_expansion,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165521] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6238), 1,
      sym__line_specifier,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2279), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165550] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6241), 1,
      anon_sym_BSLASH,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165579] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6243), 1,
      sym__line_specifier,
    STATE(3291), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2290), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165608] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6243), 1,
      sym__line_specifier,
    STATE(2980), 1,
      sym_macro,
    STATE(3291), 1,
      aux_sym_symbol_repeat1,
    STATE(3293), 1,
      sym_macro_text_expansion,
    ACTIONS(2290), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165639] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6245), 1,
      sym__line_specifier,
    STATE(3291), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2302), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165668] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6248), 1,
      sym__line_specifier,
    STATE(3300), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2311), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165697] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6248), 1,
      sym__line_specifier,
    STATE(2983), 1,
      sym_macro,
    STATE(3300), 1,
      aux_sym_symbol_repeat1,
    STATE(3301), 1,
      sym_macro_text_expansion,
    ACTIONS(2311), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165728] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2964), 1,
      sym_macro,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3190), 1,
      sym_macro_text_expansion,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165759] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6250), 1,
      sym__line_specifier,
    STATE(3303), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2332), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165788] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6252), 1,
      sym__blank,
    STATE(2984), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 3,
      anon_sym_BSLASH_BSLASH,
      anon_sym_BSLASH,
      sym_identifier,
    ACTIONS(3217), 6,
      sym_path,
      anon_sym_DQUOTE,
      anon_sym_BSLASH_BSLASH_BSLASH,
      aux_sym_symbol_token1,
      aux_sym_symbol_token5,
      anon_sym_POUND,
  [165811] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6255), 1,
      sym_identifier,
    ACTIONS(6258), 1,
      anon_sym_AMP,
    ACTIONS(1907), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [165836] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5966), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165865] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5733), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165894] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6261), 1,
      anon_sym_BSLASH,
    STATE(2987), 1,
      sym_macro,
    STATE(3151), 1,
      sym_macro_text_expansion,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165925] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6261), 1,
      anon_sym_BSLASH,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165954] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5954), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(3000), 1,
      sym_macro,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3305), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [165985] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(3361), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [166014] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5954), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166043] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6263), 1,
      sym_identifier,
    ACTIONS(6265), 1,
      aux_sym_if_block_token1,
    ACTIONS(6269), 1,
      aux_sym__hll_non_default_format_var_command_token5,
    ACTIONS(6273), 2,
      aux_sym__hll_var_definition_command_expression_token1,
      aux_sym__hll_var_definition_command_expression_token2,
    ACTIONS(6267), 3,
      aux_sym__hll_non_default_format_var_command_token2,
      aux_sym__hll_non_default_format_var_command_token3,
      aux_sym__hll_non_default_format_var_command_token4,
    ACTIONS(6271), 3,
      aux_sym__var_command_with_non_hll_format_token1,
      aux_sym__var_command_with_non_hll_format_token2,
      aux_sym__var_command_with_non_hll_format_token3,
  [166070] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5790), 1,
      anon_sym_LPAREN,
    ACTIONS(5792), 1,
      anon_sym_STAR,
    ACTIONS(5794), 1,
      anon_sym_LBRACK,
    ACTIONS(6275), 1,
      sym__blank,
    STATE(2893), 1,
      sym__hll_pointer_declarator_specifier,
    STATE(2991), 1,
      aux_sym_block_repeat1,
    STATE(3368), 5,
      sym__hll_abstract_declarator,
      sym_hll_abstract_pointer_declarator,
      sym_hll_abstract_function_declarator,
      sym_hll_abstract_array_declarator,
      sym_hll_abstract_parenthesized_declarator,
  [166099] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5764), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(3004), 1,
      sym_macro,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3310), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166130] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(3006), 1,
      sym_macro,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3325), 1,
      sym_macro_text_expansion,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166161] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6277), 1,
      sym__line_specifier,
    ACTIONS(6280), 1,
      anon_sym_BSLASH,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166190] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6277), 1,
      sym__line_specifier,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2358), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166219] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2465), 1,
      sym__blank,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(6213), 1,
      anon_sym_BSLASH,
    ACTIONS(6283), 1,
      sym_identifier,
    STATE(2956), 1,
      sym_macro,
    STATE(3182), 1,
      sym_macro_text_expansion,
    STATE(3195), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2463), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [166250] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6285), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166279] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(5774), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2957), 1,
      sym_macro,
    STATE(3155), 1,
      sym_macro_text_expansion,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166310] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2959), 1,
      sym_macro,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3168), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166341] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6287), 1,
      sym__line_specifier,
    ACTIONS(6290), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166370] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(5774), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166399] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6287), 1,
      sym__line_specifier,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2386), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166428] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166457] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6220), 1,
      sym_identifier,
    ACTIONS(6285), 1,
      anon_sym_BSLASH,
    STATE(2960), 1,
      sym_macro,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    STATE(3181), 1,
      sym_macro_text_expansion,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166488] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(1894), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [166513] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(1898), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(2985), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [166538] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6065), 1,
      sym_identifier,
    STATE(3012), 1,
      sym_macro,
    STATE(3328), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [166565] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [166590] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6079), 1,
      sym_identifier,
    ACTIONS(2423), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3008), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [166615] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(5784), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2961), 1,
      sym_macro,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    STATE(3184), 1,
      sym_macro_text_expansion,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166646] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(2986), 1,
      sym_macro,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    STATE(3340), 1,
      sym_macro_text_expansion,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166677] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166706] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6293), 1,
      sym__line_specifier,
    STATE(3300), 1,
      aux_sym_symbol_repeat1,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2323), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [166735] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1907), 1,
      anon_sym_BSLASH,
    ACTIONS(6296), 1,
      sym_identifier,
    ACTIONS(6299), 1,
      anon_sym_AMP,
    STATE(3017), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [166759] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3025), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [166783] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 8,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [166801] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 8,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [166819] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6305), 1,
      sym__blank,
    STATE(3507), 1,
      aux_sym_block_repeat1,
    ACTIONS(6302), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(3021), 2,
      sym_hll_type_qualifier,
      aux_sym_hll_type_descriptor_repeat2,
    ACTIONS(4257), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [166843] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 1,
      anon_sym_BSLASH,
    ACTIONS(1926), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [166861] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 1,
      anon_sym_BSLASH,
    ACTIONS(1930), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [166879] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6263), 1,
      sym_identifier,
    ACTIONS(6269), 1,
      aux_sym__hll_non_default_format_var_command_token5,
    ACTIONS(6273), 2,
      aux_sym__hll_var_definition_command_expression_token1,
      aux_sym__hll_var_definition_command_expression_token2,
    ACTIONS(6267), 3,
      aux_sym__hll_non_default_format_var_command_token2,
      aux_sym__hll_non_default_format_var_command_token3,
      aux_sym__hll_non_default_format_var_command_token4,
    ACTIONS(6271), 3,
      aux_sym__var_command_with_non_hll_format_token1,
      aux_sym__var_command_with_non_hll_format_token2,
      aux_sym__var_command_with_non_hll_format_token3,
  [166903] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(1894), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3030), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [166927] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1894), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3017), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [166951] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1890), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3028), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [166975] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1898), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3017), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [166999] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [167023] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6308), 1,
      sym_identifier,
    ACTIONS(6311), 1,
      anon_sym_AMP,
    ACTIONS(1907), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3030), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167047] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6314), 1,
      sym__blank,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    ACTIONS(3219), 3,
      anon_sym_const,
      anon_sym_volatile,
      sym_identifier,
    ACTIONS(3217), 5,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
  [167069] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6197), 1,
      sym_identifier,
    STATE(3026), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [167093] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6317), 1,
      sym__blank,
    STATE(3100), 1,
      sym_hll_type_qualifier,
    STATE(3395), 1,
      aux_sym_block_repeat1,
    STATE(3669), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5751), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [167119] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6220), 1,
      sym_identifier,
    STATE(3032), 1,
      sym_macro,
    STATE(3427), 1,
      sym_macro_text_expansion,
    ACTIONS(2407), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [167145] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 1,
      anon_sym_BSLASH,
    ACTIONS(1989), 9,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym__blank,
  [167163] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6320), 1,
      sym_identifier,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6324), 1,
      anon_sym_BSLASH,
    STATE(3041), 1,
      sym_macro,
    STATE(3366), 1,
      aux_sym_symbol_repeat1,
    STATE(3423), 1,
      sym_macro_text_expansion,
    ACTIONS(2463), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167191] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(1898), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3030), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167215] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(2423), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3025), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167239] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6209), 1,
      sym_identifier,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(1890), 2,
      anon_sym_BSLASH,
      sym__blank,
    STATE(3037), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167263] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 8,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      anon_sym_BSLASH_BSLASH,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [167281] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6324), 1,
      anon_sym_BSLASH,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3391), 1,
      aux_sym_symbol_repeat1,
    STATE(3056), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167307] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(6283), 1,
      sym_identifier,
    STATE(3038), 1,
      sym_macro,
    STATE(3408), 1,
      sym_macro_text_expansion,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167333] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6336), 1,
      sym__blank,
    STATE(3431), 1,
      aux_sym_format_expression_repeat1,
    STATE(3058), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(6334), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167361] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5908), 1,
      anon_sym_BSLASH,
    ACTIONS(5946), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167386] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1898), 1,
      sym__blank,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    STATE(3050), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167409] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6338), 1,
      anon_sym_AMP,
    ACTIONS(6340), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(6342), 1,
      anon_sym_DQUOTE,
    ACTIONS(6344), 1,
      sym__blank,
    STATE(3289), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    STATE(3517), 1,
      aux_sym_block_repeat1,
    STATE(4049), 1,
      sym__host_command_argument_list_default_format,
    STATE(3506), 2,
      sym_macro,
      sym_string,
  [167438] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 1,
      anon_sym_BSLASH,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3056), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2421), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167461] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6348), 1,
      sym__blank,
    STATE(3058), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(6346), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167484] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1890), 1,
      anon_sym_BSLASH,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3062), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167507] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1907), 1,
      sym__blank,
    ACTIONS(6350), 1,
      sym_identifier,
    ACTIONS(6353), 1,
      anon_sym_AMP,
    STATE(3050), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167530] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 7,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [167547] = 9,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6130), 1,
      sym_identifier,
    ACTIONS(6134), 1,
      anon_sym_PERCENT,
    STATE(3225), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(3370), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(3371), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(3852), 1,
      sym_hll_type_pattern,
    STATE(4017), 1,
      sym_format_expression,
    ACTIONS(6132), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [167576] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 7,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [167593] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1907), 1,
      anon_sym_BSLASH,
    ACTIONS(6356), 1,
      sym_identifier,
    ACTIONS(6359), 1,
      anon_sym_AMP,
    STATE(3054), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1905), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167616] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 7,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [167633] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1894), 1,
      anon_sym_BSLASH,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3054), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167656] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(6320), 1,
      sym_identifier,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    STATE(3047), 1,
      sym_macro,
    STATE(3578), 1,
      sym_macro_text_expansion,
    ACTIONS(2407), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167681] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1894), 1,
      sym__blank,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    STATE(3050), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1896), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167704] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3056), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(2407), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167727] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1890), 1,
      sym__blank,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    STATE(3045), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1888), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [167750] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5972), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167775] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1898), 1,
      anon_sym_BSLASH,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6326), 1,
      sym_identifier,
    STATE(3054), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(1900), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [167798] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3458), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(4101), 1,
      sym__var_command_argument_list_non_hll_format,
    STATE(3702), 2,
      sym_format_expression,
      sym_hll_option_expression,
  [167824] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1937), 1,
      anon_sym_DQUOTE,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6364), 1,
      aux_sym_symbol_token1,
    ACTIONS(6366), 1,
      aux_sym_symbol_token2,
    STATE(843), 1,
      sym_macro,
    STATE(1464), 2,
      sym_macro_text_expansion,
      sym_string,
  [167850] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(3635), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6334), 2,
      anon_sym_COMMA,
      sym__blank,
    STATE(2886), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
  [167874] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5860), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(6370), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5856), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [167894] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6108), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167916] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2389), 1,
      sym__blank,
    ACTIONS(6121), 1,
      sym__line_specifier,
    ACTIONS(6124), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167938] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5908), 1,
      anon_sym_BSLASH,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [167960] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5609), 1,
      anon_sym_DQUOTE,
    ACTIONS(6372), 1,
      aux_sym_symbol_token1,
    ACTIONS(6374), 1,
      aux_sym_symbol_token2,
    STATE(2899), 1,
      sym_macro,
    STATE(3112), 2,
      sym_macro_text_expansion,
      sym_string,
  [167986] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2224), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6144), 1,
      sym__line_specifier,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168008] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5966), 1,
      anon_sym_BSLASH,
    ACTIONS(6077), 1,
      anon_sym_BSLASH_BSLASH,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [168030] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6035), 1,
      sym__blank,
    STATE(3271), 1,
      aux_sym_block_repeat1,
    ACTIONS(6033), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
  [168048] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168070] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2224), 1,
      sym__blank,
    ACTIONS(6144), 1,
      sym__line_specifier,
    ACTIONS(6147), 1,
      anon_sym_BSLASH,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168092] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2361), 1,
      sym__blank,
    ACTIONS(6091), 1,
      sym__line_specifier,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168114] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(5617), 1,
      anon_sym_BSLASH,
    STATE(3079), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168136] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(5681), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168158] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168180] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2256), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6152), 1,
      sym__line_specifier,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168202] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5725), 1,
      anon_sym_DQUOTE,
    ACTIONS(6376), 1,
      aux_sym_symbol_token1,
    ACTIONS(6378), 1,
      aux_sym_symbol_token2,
    STATE(2989), 1,
      sym_macro,
    STATE(3313), 2,
      sym_macro_text_expansion,
      sym_string,
  [168228] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6150), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168250] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2361), 1,
      sym__blank,
    ACTIONS(6091), 1,
      sym__line_specifier,
    ACTIONS(6094), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168272] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6150), 1,
      sym__line_specifier,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168294] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2389), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6121), 1,
      sym__line_specifier,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168316] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(1996), 1,
      anon_sym_DQUOTE,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6382), 1,
      aux_sym_symbol_token1,
    ACTIONS(6384), 1,
      aux_sym_symbol_token2,
    STATE(1042), 1,
      sym_macro,
    STATE(1550), 2,
      sym_macro_text_expansion,
      sym_string,
  [168342] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5867), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(6370), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5865), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [168362] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(6150), 1,
      sym__line_specifier,
    ACTIONS(6155), 1,
      anon_sym_BSLASH,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168384] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2256), 1,
      sym__blank,
    ACTIONS(6152), 1,
      sym__line_specifier,
    ACTIONS(6157), 1,
      anon_sym_BSLASH,
    STATE(3094), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168406] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 1,
      anon_sym_BSLASH,
    ACTIONS(1989), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [168422] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3117), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168444] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1989), 6,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [168460] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6160), 1,
      sym__line_specifier,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168482] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6160), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168504] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1820), 1,
      anon_sym_DQUOTE,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6388), 1,
      aux_sym_symbol_token1,
    ACTIONS(6390), 1,
      aux_sym_symbol_token2,
    STATE(611), 1,
      sym_macro,
    STATE(1049), 2,
      sym_macro_text_expansion,
      sym_string,
  [168530] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168552] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1926), 6,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [168568] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2282), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6165), 1,
      sym__line_specifier,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2279), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168590] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2203), 1,
      sym__blank,
    ACTIONS(6136), 1,
      sym__line_specifier,
    ACTIONS(6139), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168612] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5874), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(6370), 2,
      anon_sym_const,
      anon_sym_volatile,
    ACTIONS(5872), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
  [168632] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(6160), 1,
      sym__line_specifier,
    ACTIONS(6168), 1,
      anon_sym_BSLASH,
    STATE(3102), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168654] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6170), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168676] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5645), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168698] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6170), 1,
      sym__line_specifier,
    STATE(3111), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168720] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6396), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3469), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [168746] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6400), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3539), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [168772] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(5671), 1,
      anon_sym_BSLASH,
    STATE(3082), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168794] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2305), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6172), 1,
      sym__line_specifier,
    STATE(3111), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2302), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168816] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6402), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3543), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [168842] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6404), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3545), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [168868] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6175), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168890] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(6097), 1,
      anon_sym_BSLASH,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168912] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6175), 1,
      sym__line_specifier,
    STATE(3120), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168934] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(1930), 6,
      anon_sym_LPAREN,
      anon_sym_AMP,
      aux_sym__hll_var_definition_command_token1,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [168950] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(5970), 1,
      sym__line_specifier,
    ACTIONS(5974), 1,
      anon_sym_BSLASH,
    STATE(3145), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168972] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(5705), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [168994] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169016] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(170), 1,
      anon_sym_DQUOTE,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(6406), 1,
      aux_sym_symbol_token1,
    ACTIONS(6408), 1,
      aux_sym_symbol_token2,
    STATE(1862), 1,
      sym_macro,
    STATE(2239), 2,
      sym_macro_text_expansion,
      sym_string,
  [169042] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2326), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6184), 1,
      sym__line_specifier,
    STATE(3120), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2323), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169064] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6187), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169086] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(5675), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169108] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 1,
      anon_sym_BSLASH,
    ACTIONS(1926), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [169124] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6187), 1,
      sym__line_specifier,
    STATE(3124), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169146] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6410), 1,
      sym__line_specifier,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2641), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169168] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6412), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3510), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169194] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(78), 1,
      anon_sym_DQUOTE,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(6414), 1,
      aux_sym_symbol_token1,
    ACTIONS(6416), 1,
      aux_sym_symbol_token2,
    STATE(1892), 1,
      sym_macro,
    STATE(2158), 2,
      sym_macro_text_expansion,
      sym_string,
  [169220] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6420), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3596), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169246] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2203), 1,
      sym__blank,
    ACTIONS(6099), 1,
      anon_sym_BSLASH,
    ACTIONS(6136), 1,
      sym__line_specifier,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169268] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2465), 1,
      sym__blank,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    ACTIONS(6422), 1,
      sym__line_specifier,
    STATE(3096), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2463), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169290] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6193), 1,
      anon_sym_BSLASH_BSLASH,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [169312] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6424), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3486), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169338] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 1,
      anon_sym_BSLASH,
    ACTIONS(1930), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym__line_specifier,
      sym_identifier,
      sym__blank,
  [169354] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169376] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(5639), 1,
      sym__line_specifier,
    ACTIONS(5887), 1,
      anon_sym_BSLASH,
    STATE(3121), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169398] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      sym__blank,
    ACTIONS(6426), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [169418] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6338), 1,
      anon_sym_AMP,
    ACTIONS(6342), 1,
      anon_sym_DQUOTE,
    ACTIONS(6344), 1,
      sym__blank,
    ACTIONS(6429), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    STATE(3517), 1,
      aux_sym_block_repeat1,
    STATE(3563), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    STATE(3886), 2,
      sym_macro,
      sym_string,
  [169444] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6433), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3582), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169470] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6435), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3584), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169496] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6437), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3587), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169522] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(5699), 1,
      sym__line_specifier,
    ACTIONS(6142), 1,
      anon_sym_BSLASH,
    STATE(3142), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169544] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6016), 1,
      sym__blank,
    STATE(3271), 1,
      aux_sym_block_repeat1,
    ACTIONS(6014), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
  [169562] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(5665), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169584] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1741), 1,
      anon_sym_DQUOTE,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6441), 1,
      aux_sym_symbol_token1,
    ACTIONS(6443), 1,
      aux_sym_symbol_token2,
    STATE(464), 1,
      sym_macro,
    STATE(945), 2,
      sym_macro_text_expansion,
      sym_string,
  [169610] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6336), 1,
      sym__blank,
    STATE(3060), 1,
      sym_macro,
    STATE(3430), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6334), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [169634] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(5611), 1,
      sym__line_specifier,
    ACTIONS(6089), 1,
      anon_sym_BSLASH,
    STATE(3135), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [169656] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6445), 1,
      sym__blank,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3591), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169682] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6447), 1,
      sym__blank,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3594), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [169708] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(130), 1,
      anon_sym_DQUOTE,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6453), 1,
      aux_sym_symbol_token1,
    ACTIONS(6455), 1,
      aux_sym_symbol_token2,
    STATE(411), 1,
      sym_macro,
    STATE(565), 2,
      sym_macro_text_expansion,
      sym_string,
  [169734] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6459), 1,
      anon_sym_DQUOTE,
    ACTIONS(6463), 1,
      sym__line_continuation,
    STATE(3193), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6461), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [169753] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4062), 1,
      aux_sym_symbol_token3,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    STATE(1849), 1,
      sym_macro,
    STATE(2080), 1,
      sym_macro_text_expansion,
  [169778] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5733), 1,
      anon_sym_BSLASH,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [169797] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6203), 1,
      sym__line_specifier,
    ACTIONS(6206), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [169816] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 1,
      sym__blank,
    ACTIONS(1926), 6,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [169831] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5354), 1,
      sym_identifier,
    STATE(2946), 1,
      sym__hll_type_identifier,
    STATE(3379), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(6467), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [169850] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(5784), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [169869] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6469), 1,
      anon_sym_DQUOTE,
    STATE(3161), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6471), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [169888] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [169907] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6106), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [169920] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6473), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [169937] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 1,
      anon_sym_BSLASH,
    ACTIONS(1926), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [169952] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6476), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [169971] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2994), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [169986] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6112), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [169999] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6116), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [170012] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6203), 1,
      sym__line_specifier,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2200), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170031] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 1,
      anon_sym_BSLASH,
    ACTIONS(1930), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [170046] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6480), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6482), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3626), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [170069] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170088] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4012), 1,
      aux_sym_symbol_token3,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    STATE(1857), 1,
      sym_macro,
    STATE(2204), 1,
      sym_macro_text_expansion,
  [170113] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(6486), 1,
      sym__blank,
    STATE(2668), 1,
      sym_block,
    STATE(3307), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3854), 1,
      aux_sym_block_repeat1,
    ACTIONS(6484), 2,
      sym_comment,
      sym__blank_line,
  [170136] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170155] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3938), 1,
      aux_sym_symbol_token3,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    STATE(1858), 1,
      sym_macro,
    STATE(2222), 1,
      sym_macro_text_expansion,
  [170180] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(3968), 1,
      aux_sym_symbol_token3,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    STATE(1828), 1,
      sym_macro,
    STATE(2171), 1,
      sym_macro_text_expansion,
  [170205] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(4002), 1,
      aux_sym_symbol_token3,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    STATE(1851), 1,
      sym_macro,
    STATE(2078), 1,
      sym_macro_text_expansion,
  [170230] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(4022), 1,
      aux_sym_symbol_token3,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    STATE(1869), 1,
      sym_macro,
    STATE(2188), 1,
      sym_macro_text_expansion,
  [170255] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(4032), 1,
      aux_sym_symbol_token3,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    STATE(1877), 1,
      sym_macro,
    STATE(2226), 1,
      sym_macro_text_expansion,
  [170280] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    ACTIONS(6490), 1,
      aux_sym_symbol_token3,
    STATE(1900), 1,
      sym_macro,
    STATE(2248), 1,
      sym_macro_text_expansion,
  [170305] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    ACTIONS(6492), 1,
      aux_sym_symbol_token3,
    STATE(1821), 1,
      sym_macro,
    STATE(2086), 1,
      sym_macro_text_expansion,
  [170330] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(3940), 1,
      aux_sym_symbol_token4,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    ACTIONS(6494), 1,
      aux_sym_symbol_token3,
    STATE(1824), 1,
      sym_macro,
    STATE(2103), 1,
      sym_macro_text_expansion,
  [170355] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2086), 1,
      aux_sym_symbol_token3,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    STATE(979), 1,
      sym_macro,
    STATE(1505), 1,
      sym_macro_text_expansion,
  [170380] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5778), 1,
      sym__line_specifier,
    ACTIONS(6218), 1,
      anon_sym_BSLASH,
    STATE(3183), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170399] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(6213), 1,
      anon_sym_BSLASH,
    STATE(3223), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [170418] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170437] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(5745), 1,
      anon_sym_BSLASH,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170456] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 1,
      sym__blank,
    ACTIONS(1989), 6,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [170471] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6498), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [170490] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170509] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6222), 1,
      sym__line_specifier,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170528] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6277), 1,
      sym__line_specifier,
    ACTIONS(6280), 1,
      anon_sym_BSLASH,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170547] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5739), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170566] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6222), 1,
      sym__line_specifier,
    ACTIONS(6225), 1,
      anon_sym_BSLASH,
    STATE(3230), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2221), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [170585] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 1,
      sym__blank,
    ACTIONS(1930), 6,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [170600] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6500), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [170619] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6502), 1,
      anon_sym_DQUOTE,
    STATE(3276), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6504), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [170638] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(6213), 1,
      anon_sym_BSLASH,
    STATE(3345), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [170657] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1811), 1,
      aux_sym_symbol_token3,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    STATE(479), 1,
      sym_macro,
    STATE(938), 1,
      sym_macro_text_expansion,
  [170682] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1785), 1,
      aux_sym_symbol_token3,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    STATE(487), 1,
      sym_macro,
    STATE(868), 1,
      sym_macro_text_expansion,
  [170707] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1751), 1,
      aux_sym_symbol_token3,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    STATE(495), 1,
      sym_macro,
    STATE(878), 1,
      sym_macro_text_expansion,
  [170732] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1772), 1,
      aux_sym_symbol_token3,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    STATE(500), 1,
      sym_macro,
    STATE(955), 1,
      sym_macro_text_expansion,
  [170757] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(1798), 1,
      aux_sym_symbol_token3,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    STATE(506), 1,
      sym_macro,
    STATE(1028), 1,
      sym_macro_text_expansion,
  [170782] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    ACTIONS(6508), 1,
      aux_sym_symbol_token3,
    STATE(513), 1,
      sym_macro,
    STATE(914), 1,
      sym_macro_text_expansion,
  [170807] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    ACTIONS(6510), 1,
      aux_sym_symbol_token3,
    STATE(517), 1,
      sym_macro,
    STATE(924), 1,
      sym_macro_text_expansion,
  [170832] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(1753), 1,
      aux_sym_symbol_token4,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    ACTIONS(6512), 1,
      aux_sym_symbol_token3,
    STATE(520), 1,
      sym_macro,
    STATE(936), 1,
      sym_macro_text_expansion,
  [170857] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1682), 1,
      aux_sym_symbol_token3,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    STATE(427), 1,
      sym_macro,
    STATE(569), 1,
      sym_macro_text_expansion,
  [170882] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1722), 1,
      aux_sym_symbol_token3,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    STATE(438), 1,
      sym_macro,
    STATE(594), 1,
      sym_macro_text_expansion,
  [170907] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6067), 1,
      sym_identifier,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2886), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
    ACTIONS(6346), 3,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__blank,
  [170926] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6516), 1,
      anon_sym_DQUOTE,
    STATE(3211), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6518), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [170945] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1662), 1,
      aux_sym_symbol_token3,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    STATE(383), 1,
      sym_macro,
    STATE(592), 1,
      sym_macro_text_expansion,
  [170970] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(1702), 1,
      aux_sym_symbol_token3,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    STATE(389), 1,
      sym_macro,
    STATE(548), 1,
      sym_macro_text_expansion,
  [170995] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1640), 1,
      aux_sym_symbol_token3,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    STATE(395), 1,
      sym_macro,
    STATE(480), 1,
      sym_macro_text_expansion,
  [171020] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6520), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [171039] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    ACTIONS(6522), 1,
      aux_sym_symbol_token3,
    STATE(402), 1,
      sym_macro,
    STATE(595), 1,
      sym_macro_text_expansion,
  [171064] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    ACTIONS(6524), 1,
      aux_sym_symbol_token3,
    STATE(406), 1,
      sym_macro,
    STATE(503), 1,
      sym_macro_text_expansion,
  [171089] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5619), 1,
      aux_sym_symbol_token3,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    STATE(2900), 1,
      sym_macro,
    STATE(3076), 1,
      sym_macro_text_expansion,
  [171114] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5647), 1,
      aux_sym_symbol_token3,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    STATE(2913), 1,
      sym_macro,
    STATE(3085), 1,
      sym_macro_text_expansion,
  [171139] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5683), 1,
      aux_sym_symbol_token3,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    STATE(2921), 1,
      sym_macro,
    STATE(3128), 1,
      sym_macro_text_expansion,
  [171164] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5707), 1,
      aux_sym_symbol_token3,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    STATE(2926), 1,
      sym_macro,
    STATE(3071), 1,
      sym_macro_text_expansion,
  [171189] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(5673), 1,
      aux_sym_symbol_token3,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    STATE(2932), 1,
      sym_macro,
    STATE(3080), 1,
      sym_macro_text_expansion,
  [171214] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    ACTIONS(6528), 1,
      aux_sym_symbol_token3,
    STATE(2940), 1,
      sym_macro,
    STATE(3098), 1,
      sym_macro_text_expansion,
  [171239] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    ACTIONS(6530), 1,
      aux_sym_symbol_token3,
    STATE(2944), 1,
      sym_macro,
    STATE(3108), 1,
      sym_macro_text_expansion,
  [171264] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(5621), 1,
      aux_sym_symbol_token4,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    ACTIONS(6532), 1,
      aux_sym_symbol_token3,
    STATE(2949), 1,
      sym_macro,
    STATE(3119), 1,
      sym_macro_text_expansion,
  [171289] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1642), 1,
      aux_sym_symbol_token4,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    ACTIONS(6534), 1,
      aux_sym_symbol_token3,
    STATE(409), 1,
      sym_macro,
    STATE(543), 1,
      sym_macro_text_expansion,
  [171314] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(6213), 1,
      anon_sym_BSLASH,
    STATE(3345), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [171333] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
    ACTIONS(6536), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [171356] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6130), 1,
      sym_identifier,
    ACTIONS(6548), 1,
      sym__blank,
    STATE(3296), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(6544), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(6546), 2,
      sym_comment,
      sym__blank_line,
  [171377] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1947), 1,
      aux_sym_symbol_token3,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    STATE(992), 1,
      sym_macro,
    STATE(1522), 1,
      sym_macro_text_expansion,
  [171402] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4257), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [171415] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6550), 1,
      anon_sym_DQUOTE,
    STATE(3233), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6552), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [171434] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6230), 1,
      sym__line_specifier,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171453] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6228), 1,
      sym__line_specifier,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171472] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5431), 1,
      sym__blank,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(6554), 2,
      sym_comment,
      sym__blank_line,
    ACTIONS(5433), 3,
      aux_sym_block_token1,
      aux_sym_elif_block_token1,
      aux_sym_while_block_token1,
  [171491] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6559), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [171512] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6563), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [171531] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    ACTIONS(6565), 1,
      aux_sym_symbol_token3,
    STATE(1912), 1,
      sym_macro,
    STATE(2227), 1,
      sym_macro_text_expansion,
  [171556] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6567), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [171577] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5735), 1,
      aux_sym_symbol_token3,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    STATE(2998), 1,
      sym_macro,
    STATE(3347), 1,
      sym_macro_text_expansion,
  [171602] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5766), 1,
      aux_sym_symbol_token3,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    STATE(3005), 1,
      sym_macro,
    STATE(3319), 1,
      sym_macro_text_expansion,
  [171627] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5776), 1,
      aux_sym_symbol_token3,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    STATE(2958), 1,
      sym_macro,
    STATE(3165), 1,
      sym_macro_text_expansion,
  [171652] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5786), 1,
      aux_sym_symbol_token3,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    STATE(2963), 1,
      sym_macro,
    STATE(3188), 1,
      sym_macro_text_expansion,
  [171677] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(5747), 1,
      aux_sym_symbol_token3,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    STATE(2968), 1,
      sym_macro,
    STATE(3229), 1,
      sym_macro_text_expansion,
  [171702] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    ACTIONS(6571), 1,
      aux_sym_symbol_token3,
    STATE(2975), 1,
      sym_macro,
    STATE(3270), 1,
      sym_macro_text_expansion,
  [171727] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    ACTIONS(6573), 1,
      aux_sym_symbol_token3,
    STATE(2979), 1,
      sym_macro,
    STATE(3283), 1,
      sym_macro_text_expansion,
  [171752] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(5737), 1,
      aux_sym_symbol_token4,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    ACTIONS(6575), 1,
      aux_sym_symbol_token3,
    STATE(3016), 1,
      sym_macro,
    STATE(3299), 1,
      sym_macro_text_expansion,
  [171777] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
    ACTIONS(6577), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [171800] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6579), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [171821] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6581), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [171842] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6228), 1,
      sym__line_specifier,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171861] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5764), 1,
      anon_sym_BSLASH,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171880] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6583), 1,
      sym_identifier,
    ACTIONS(6585), 1,
      anon_sym_SLASH,
    ACTIONS(6587), 1,
      sym__blank,
    STATE(3285), 1,
      sym_macro,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    STATE(3933), 1,
      sym_macro_text_expansion,
  [171905] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6589), 1,
      anon_sym_DQUOTE,
    STATE(3255), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6591), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [171924] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6179), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [171937] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6228), 1,
      sym__line_specifier,
    ACTIONS(6233), 1,
      anon_sym_BSLASH,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171956] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6230), 1,
      sym__line_specifier,
    ACTIONS(6235), 1,
      anon_sym_BSLASH,
    STATE(3267), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2253), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [171975] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4052), 1,
      aux_sym_symbol_token3,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    STATE(1896), 1,
      sym_macro,
    STATE(2190), 1,
      sym_macro_text_expansion,
  [172000] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6593), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172019] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6595), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172040] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2006), 1,
      aux_sym_symbol_token3,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    STATE(853), 1,
      sym_macro,
    STATE(1406), 1,
      sym_macro_text_expansion,
  [172065] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2060), 1,
      aux_sym_symbol_token3,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    STATE(864), 1,
      sym_macro,
    STATE(1423), 1,
      sym_macro_text_expansion,
  [172090] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2073), 1,
      aux_sym_symbol_token3,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    STATE(875), 1,
      sym_macro,
    STATE(1436), 1,
      sym_macro_text_expansion,
  [172115] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2147), 1,
      aux_sym_symbol_token3,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    STATE(883), 1,
      sym_macro,
    STATE(1462), 1,
      sym_macro_text_expansion,
  [172140] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(2160), 1,
      aux_sym_symbol_token3,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    STATE(894), 1,
      sym_macro,
    STATE(1476), 1,
      sym_macro_text_expansion,
  [172165] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    ACTIONS(6599), 1,
      aux_sym_symbol_token3,
    STATE(903), 1,
      sym_macro,
    STATE(1524), 1,
      sym_macro_text_expansion,
  [172190] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    ACTIONS(6601), 1,
      aux_sym_symbol_token3,
    STATE(908), 1,
      sym_macro,
    STATE(1530), 1,
      sym_macro_text_expansion,
  [172215] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(2008), 1,
      aux_sym_symbol_token4,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    ACTIONS(6603), 1,
      aux_sym_symbol_token3,
    STATE(911), 1,
      sym_macro,
    STATE(1533), 1,
      sym_macro_text_expansion,
  [172240] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6605), 1,
      anon_sym_DQUOTE,
    STATE(3268), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6607), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172259] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172278] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172297] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6609), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172316] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6611), 1,
      anon_sym_DQUOTE,
    STATE(3272), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6613), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172335] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6238), 1,
      sym__line_specifier,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2279), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172354] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6615), 5,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_identifier,
  [172371] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6617), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172390] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2121), 1,
      aux_sym_symbol_token3,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    STATE(998), 1,
      sym_macro,
    STATE(1544), 1,
      sym_macro_text_expansion,
  [172415] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6199), 1,
      sym__line_specifier,
    ACTIONS(6241), 1,
      anon_sym_BSLASH,
    STATE(3275), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172434] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6243), 1,
      sym__line_specifier,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172453] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6619), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172472] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6621), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172493] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6623), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172514] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6243), 1,
      sym__line_specifier,
    STATE(3291), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2290), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172533] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6625), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172554] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6627), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172575] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6629), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172596] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6245), 1,
      sym__line_specifier,
    STATE(3291), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2302), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172615] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6631), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172636] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6328), 1,
      sym_identifier,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6635), 1,
      sym__blank,
    ACTIONS(6633), 2,
      sym_comment,
      sym__blank_line,
    STATE(3058), 2,
      sym_macro,
      aux_sym_macro_text_expansion_repeat1,
  [172657] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2047), 1,
      aux_sym_symbol_token3,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    STATE(962), 1,
      sym_macro,
    STATE(1493), 1,
      sym_macro_text_expansion,
  [172682] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6637), 1,
      anon_sym_DQUOTE,
    STATE(3297), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6639), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172701] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6641), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172722] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6643), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(6647), 1,
      sym__blank,
    STATE(3136), 1,
      aux_sym_block_repeat1,
    STATE(3553), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    STATE(3560), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(6645), 2,
      sym_comment,
      sym__blank_line,
  [172745] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(2134), 1,
      aux_sym_symbol_token3,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    STATE(1004), 1,
      sym_macro,
    STATE(1551), 1,
      sym_macro_text_expansion,
  [172770] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6248), 1,
      sym__line_specifier,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172789] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6649), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [172810] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6248), 1,
      sym__line_specifier,
    STATE(3300), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2311), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172829] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3794), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_STAR,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_volatile,
      sym__blank,
  [172842] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172861] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6651), 1,
      sym_identifier,
    ACTIONS(6659), 1,
      sym__blank,
    STATE(3296), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(6654), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(6657), 2,
      sym_comment,
      sym__blank_line,
  [172882] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6661), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6478), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [172901] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    ACTIONS(6663), 1,
      aux_sym_symbol_token3,
    STATE(1904), 1,
      sym_macro,
    STATE(2209), 1,
      sym_macro_text_expansion,
  [172926] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6293), 1,
      sym__line_specifier,
    STATE(3300), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2323), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172945] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6250), 1,
      sym__line_specifier,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172964] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6250), 1,
      sym__line_specifier,
    STATE(3303), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2332), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [172983] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6348), 1,
      sym__blank,
    STATE(3060), 1,
      sym_macro,
    ACTIONS(6346), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [173002] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6665), 1,
      sym__line_specifier,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2641), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173021] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    ACTIONS(6667), 1,
      aux_sym_symbol_token3,
    STATE(1017), 1,
      sym_macro,
    STATE(1413), 1,
      sym_macro_text_expansion,
  [173046] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6285), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173065] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6287), 1,
      sym__line_specifier,
    ACTIONS(6290), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173084] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(6486), 1,
      sym__blank,
    STATE(2654), 1,
      sym_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3854), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [173107] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5442), 1,
      sym_identifier,
    STATE(3251), 1,
      sym__hll_type_identifier,
    STATE(3379), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(6669), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [173126] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5758), 1,
      sym__line_specifier,
    ACTIONS(5954), 1,
      anon_sym_BSLASH,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173145] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(5774), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173164] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    ACTIONS(6671), 1,
      aux_sym_symbol_token3,
    STATE(1022), 1,
      sym_macro,
    STATE(1430), 1,
      sym_macro_text_expansion,
  [173189] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    ACTIONS(6673), 1,
      sym__line_specifier,
    STATE(3322), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2463), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173208] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6261), 1,
      anon_sym_BSLASH,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173227] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6675), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173248] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(1949), 1,
      aux_sym_symbol_token4,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    ACTIONS(6677), 1,
      aux_sym_symbol_token3,
    STATE(1025), 1,
      sym_macro,
    STATE(1440), 1,
      sym_macro_text_expansion,
  [173273] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6679), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173294] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6681), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173315] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6683), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173336] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6287), 1,
      sym__line_specifier,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2386), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173355] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(4042), 1,
      aux_sym_symbol_token3,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    STATE(1870), 1,
      sym_macro,
    STATE(2121), 1,
      sym_macro_text_expansion,
  [173380] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2941), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [173395] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3159), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173414] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6685), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173435] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [173450] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5768), 1,
      sym__line_specifier,
    ACTIONS(6201), 1,
      anon_sym_BSLASH,
    STATE(3157), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173469] = 5,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6687), 1,
      anon_sym_AMP,
    ACTIONS(6690), 1,
      anon_sym_DQUOTE,
    STATE(3326), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6692), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [173488] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1830), 1,
      aux_sym_symbol_token3,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    STATE(621), 1,
      sym_macro,
    STATE(1072), 1,
      sym_macro_text_expansion,
  [173513] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 5,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym__line_specifier,
      sym_comment,
      sym__blank_line,
  [173528] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6191), 1,
      sym__line_specifier,
    ACTIONS(6195), 1,
      anon_sym_BSLASH,
    STATE(3171), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173547] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1871), 1,
      aux_sym_symbol_token3,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    STATE(627), 1,
      sym_macro,
    STATE(1081), 1,
      sym_macro_text_expansion,
  [173572] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1858), 1,
      aux_sym_symbol_token3,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    STATE(637), 1,
      sym_macro,
    STATE(1091), 1,
      sym_macro_text_expansion,
  [173597] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6697), 1,
      aux_sym_elif_block_token1,
    ACTIONS(6699), 1,
      sym__blank,
    STATE(2658), 1,
      sym_elif_block,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    STATE(3699), 1,
      aux_sym_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [173620] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1884), 1,
      aux_sym_symbol_token3,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    STATE(645), 1,
      sym_macro,
    STATE(1096), 1,
      sym_macro_text_expansion,
  [173645] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(1845), 1,
      aux_sym_symbol_token3,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    STATE(653), 1,
      sym_macro,
    STATE(1100), 1,
      sym_macro_text_expansion,
  [173670] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    ACTIONS(6701), 1,
      aux_sym_symbol_token3,
    STATE(671), 1,
      sym_macro,
    STATE(1113), 1,
      sym_macro_text_expansion,
  [173695] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3956), 1,
      aux_sym_symbol_token3,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    STATE(1841), 1,
      sym_macro,
    STATE(2208), 1,
      sym_macro_text_expansion,
  [173720] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    ACTIONS(6703), 1,
      aux_sym_symbol_token3,
    STATE(677), 1,
      sym_macro,
    STATE(1120), 1,
      sym_macro_text_expansion,
  [173745] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      aux_sym_symbol_token4,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    ACTIONS(6705), 1,
      aux_sym_symbol_token3,
    STATE(681), 1,
      sym_macro,
    STATE(1123), 1,
      sym_macro_text_expansion,
  [173770] = 5,
    ACTIONS(6457), 1,
      anon_sym_AMP,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(6707), 1,
      anon_sym_DQUOTE,
    STATE(3186), 2,
      sym_macro,
      aux_sym_string_repeat1,
    ACTIONS(6709), 3,
      sym__ampersand_char,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [173789] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5727), 1,
      sym__line_specifier,
    ACTIONS(5966), 1,
      anon_sym_BSLASH,
    STATE(3187), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173808] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1987), 1,
      anon_sym_BSLASH,
    ACTIONS(1989), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_COMMA,
      sym_identifier,
      sym__blank,
  [173823] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6711), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173844] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
    ACTIONS(6713), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [173867] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    ACTIONS(6561), 1,
      sym__blank,
    STATE(3467), 1,
      sym_hll_parameter_list,
    STATE(3698), 1,
      aux_sym_block_repeat1,
    ACTIONS(6715), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173888] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      sym__blank,
    ACTIONS(6717), 1,
      anon_sym_BSLASH,
    STATE(3345), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [173907] = 8,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(3958), 1,
      aux_sym_symbol_token4,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    ACTIONS(6720), 1,
      aux_sym_symbol_token3,
    STATE(1908), 1,
      sym_macro,
    STATE(2219), 1,
      sym_macro_text_expansion,
  [173932] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6215), 1,
      anon_sym_BSLASH,
    ACTIONS(6277), 1,
      sym__line_specifier,
    STATE(3295), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2358), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [173951] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6675), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [173971] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6724), 1,
      aux_sym_symbol_token1,
    ACTIONS(6726), 1,
      aux_sym_symbol_token2,
    STATE(841), 1,
      sym_macro,
    STATE(1437), 1,
      sym_macro_text_expansion,
  [173993] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(6465), 1,
      aux_sym_symbol_token1,
    ACTIONS(6728), 1,
      aux_sym_symbol_token4,
    STATE(1939), 1,
      sym_macro,
    STATE(2343), 1,
      sym_macro_text_expansion,
  [174015] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    ACTIONS(6730), 1,
      sym_identifier,
    ACTIONS(6732), 1,
      aux_sym_symbol_token1,
    ACTIONS(6734), 1,
      aux_sym_symbol_token4,
    STATE(1986), 1,
      sym_macro,
    STATE(2482), 1,
      sym_macro_text_expansion,
  [174037] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6736), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174059] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6738), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174081] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6741), 1,
      sym__blank,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    ACTIONS(3217), 4,
      anon_sym_SLASH,
      anon_sym_AMP,
      aux_sym_parameter_declaration_token4,
      sym_identifier,
  [174097] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(6583), 1,
      sym_identifier,
    ACTIONS(6587), 1,
      sym__blank,
    STATE(3285), 1,
      sym_macro,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    STATE(3933), 1,
      sym_macro_text_expansion,
  [174119] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6744), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174141] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6749), 1,
      sym__blank,
    ACTIONS(6747), 5,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
      sym_comment,
      sym__blank_line,
  [174155] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6559), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174175] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4867), 1,
      anon_sym_AMP,
    ACTIONS(6751), 1,
      sym_identifier,
    ACTIONS(6753), 1,
      aux_sym_symbol_token1,
    ACTIONS(6755), 1,
      aux_sym_symbol_token2,
    STATE(368), 1,
      sym_macro,
    STATE(461), 1,
      sym_macro_text_expansion,
  [174197] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6757), 1,
      aux_sym_symbol_token1,
    ACTIONS(6759), 1,
      aux_sym_symbol_token2,
    STATE(417), 1,
      sym_macro,
    STATE(580), 1,
      sym_macro_text_expansion,
  [174219] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6761), 1,
      anon_sym_RPAREN,
    ACTIONS(6763), 1,
      sym__blank,
    STATE(3377), 1,
      aux_sym_block_repeat1,
    STATE(3502), 1,
      sym_hll_parameter_list,
  [174241] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6567), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174261] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6579), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174281] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6581), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174301] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6683), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174321] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6324), 1,
      anon_sym_BSLASH,
    STATE(3409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [174337] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5912), 1,
      sym__blank,
    STATE(3031), 1,
      aux_sym_block_repeat1,
    ACTIONS(6765), 4,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_QMARK,
      sym_identifier,
  [174353] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6767), 1,
      anon_sym_RPAREN,
    ACTIONS(6769), 1,
      sym__blank,
    STATE(3390), 1,
      aux_sym_block_repeat1,
    STATE(3502), 1,
      sym_hll_parameter_list,
  [174375] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6771), 1,
      sym_identifier,
    ACTIONS(6773), 1,
      aux_sym_symbol_token1,
    ACTIONS(6775), 1,
      aux_sym_symbol_token2,
    STATE(2952), 1,
      sym_macro,
    STATE(3130), 1,
      sym_macro_text_expansion,
  [174397] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6777), 1,
      anon_sym_PERCENT,
    STATE(3370), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat1,
    STATE(4017), 1,
      sym_format_expression,
    ACTIONS(6765), 3,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
  [174415] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6130), 1,
      sym_identifier,
    STATE(3225), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(3375), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(3820), 1,
      sym_hll_type_pattern,
    ACTIONS(6132), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [174435] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6780), 1,
      aux_sym_symbol_token1,
    ACTIONS(6782), 1,
      aux_sym_symbol_token2,
    STATE(3015), 1,
      sym_macro,
    STATE(3329), 1,
      sym_macro_text_expansion,
  [174457] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6685), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174477] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6130), 1,
      sym_identifier,
    STATE(3225), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(3375), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(3852), 1,
      sym_hll_type_pattern,
    ACTIONS(6132), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [174497] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6784), 1,
      sym_identifier,
    STATE(3375), 1,
      aux_sym__hll_var_pattern_command_argument_list_format_repeat2,
    STATE(3468), 1,
      aux_sym_hll_type_pattern_repeat1,
    STATE(4263), 1,
      sym_hll_type_pattern,
    ACTIONS(6787), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [174517] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6790), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174539] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6792), 1,
      anon_sym_RPAREN,
    ACTIONS(6794), 1,
      anon_sym_LBRACK,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3487), 1,
      sym_hll_parameter_list,
  [174561] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6336), 1,
      sym__blank,
    STATE(3399), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6334), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [174579] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6615), 1,
      sym_identifier,
    STATE(3379), 1,
      aux_sym_hll_sized_type_specifier_repeat1,
    ACTIONS(6796), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [174595] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6799), 1,
      sym_identifier,
    ACTIONS(6801), 1,
      anon_sym_AMP,
    ACTIONS(6803), 1,
      aux_sym_symbol_token1,
    ACTIONS(6805), 1,
      aux_sym_symbol_token4,
    STATE(968), 1,
      sym_macro,
    STATE(1540), 1,
      sym_macro_text_expansion,
  [174617] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1932), 1,
      sym_identifier,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    ACTIONS(6496), 1,
      aux_sym_symbol_token1,
    ACTIONS(6807), 1,
      aux_sym_symbol_token4,
    STATE(1205), 1,
      sym_macro,
    STATE(1596), 1,
      sym_macro_text_expansion,
  [174639] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6809), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174661] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    ACTIONS(6811), 1,
      sym_identifier,
    ACTIONS(6813), 1,
      aux_sym_symbol_token1,
    ACTIONS(6815), 1,
      aux_sym_symbol_token2,
    STATE(1813), 1,
      sym_macro,
    STATE(2009), 1,
      sym_macro_text_expansion,
  [174683] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(2407), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [174697] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6621), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174717] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6623), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174737] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6625), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174757] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6629), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174777] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6631), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [174797] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6761), 1,
      anon_sym_RPAREN,
    ACTIONS(6794), 1,
      anon_sym_LBRACK,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3487), 1,
      sym_hll_parameter_list,
  [174819] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6324), 1,
      anon_sym_BSLASH,
    STATE(3409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [174835] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    ACTIONS(6817), 1,
      sym_identifier,
    ACTIONS(6819), 1,
      aux_sym_symbol_token1,
    ACTIONS(6821), 1,
      aux_sym_symbol_token2,
    STATE(2849), 1,
      sym_macro,
    STATE(3061), 1,
      sym_macro_text_expansion,
  [174857] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6823), 1,
      anon_sym_DOT,
    ACTIONS(6828), 1,
      sym__blank,
    STATE(3393), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6826), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [174875] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6830), 1,
      aux_sym_symbol_token1,
    ACTIONS(6832), 1,
      aux_sym_symbol_token2,
    STATE(2892), 1,
      sym_macro,
    STATE(3115), 1,
      sym_macro_text_expansion,
  [174897] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3066), 1,
      sym_hll_type_qualifier,
    STATE(3653), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
  [174917] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6834), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [174939] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6836), 1,
      sym_identifier,
    ACTIONS(6838), 1,
      anon_sym_AMP,
    ACTIONS(6840), 1,
      aux_sym_symbol_token1,
    ACTIONS(6842), 1,
      aux_sym_symbol_token2,
    STATE(456), 1,
      sym_macro,
    STATE(754), 1,
      sym_macro_text_expansion,
  [174961] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6844), 1,
      aux_sym_symbol_token1,
    ACTIONS(6846), 1,
      aux_sym_symbol_token2,
    STATE(602), 1,
      sym_macro,
    STATE(893), 1,
      sym_macro_text_expansion,
  [174983] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6850), 1,
      sym__blank,
    STATE(3393), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [175001] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6852), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175023] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6681), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175043] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6855), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175065] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3944), 1,
      sym_identifier,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    ACTIONS(6857), 1,
      aux_sym_symbol_token1,
    ACTIONS(6859), 1,
      aux_sym_symbol_token2,
    STATE(1859), 1,
      sym_macro,
    STATE(2068), 1,
      sym_macro_text_expansion,
  [175087] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6449), 1,
      sym_identifier,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    ACTIONS(6514), 1,
      aux_sym_symbol_token1,
    ACTIONS(6861), 1,
      aux_sym_symbol_token4,
    STATE(445), 1,
      sym_macro,
    STATE(735), 1,
      sym_macro_text_expansion,
  [175109] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6863), 1,
      sym_identifier,
    ACTIONS(6865), 1,
      anon_sym_AMP,
    ACTIONS(6867), 1,
      aux_sym_symbol_token1,
    ACTIONS(6869), 1,
      aux_sym_symbol_token2,
    STATE(773), 1,
      sym_macro,
    STATE(1402), 1,
      sym_macro_text_expansion,
  [175131] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6871), 1,
      aux_sym_symbol_token1,
    ACTIONS(6873), 1,
      aux_sym_symbol_token2,
    STATE(1035), 1,
      sym_macro,
    STATE(1549), 1,
      sym_macro_text_expansion,
  [175153] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6595), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175173] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2421), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [175187] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6875), 1,
      anon_sym_BSLASH,
    STATE(3409), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2407), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [175203] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6627), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175223] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6649), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175243] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6695), 1,
      aux_sym_symbol_token1,
    ACTIONS(6878), 1,
      aux_sym_symbol_token4,
    STATE(737), 1,
      sym_macro,
    STATE(1381), 1,
      sym_macro_text_expansion,
  [175265] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6711), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175285] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(6486), 1,
      sym__blank,
    ACTIONS(6880), 1,
      sym_comment,
    STATE(2648), 1,
      sym_block,
    STATE(3640), 1,
      aux_sym_labeled_expression_repeat1,
    STATE(3854), 1,
      aux_sym_block_repeat1,
  [175307] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6882), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175329] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 1,
      anon_sym_BSLASH,
    ACTIONS(2941), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [175343] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(6488), 1,
      aux_sym_symbol_token1,
    ACTIONS(6884), 1,
      aux_sym_symbol_token4,
    STATE(1934), 1,
      sym_macro,
    STATE(2353), 1,
      sym_macro_text_expansion,
  [175365] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(9), 1,
      aux_sym_block_token1,
    ACTIONS(6486), 1,
      sym__blank,
    ACTIONS(6880), 1,
      sym_comment,
    STATE(2646), 1,
      sym_block,
    STATE(3640), 1,
      aux_sym_labeled_expression_repeat1,
    STATE(3854), 1,
      aux_sym_block_repeat1,
  [175387] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6713), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175407] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6886), 1,
      sym_identifier,
    ACTIONS(6888), 1,
      anon_sym_AMP,
    ACTIONS(6890), 1,
      aux_sym_symbol_token1,
    ACTIONS(6892), 1,
      aux_sym_symbol_token2,
    STATE(559), 1,
      sym_macro,
    STATE(946), 1,
      sym_macro_text_expansion,
  [175429] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6894), 1,
      sym_identifier,
    ACTIONS(6896), 1,
      anon_sym_AMP,
    ACTIONS(6898), 1,
      aux_sym_symbol_token1,
    ACTIONS(6900), 1,
      aux_sym_symbol_token4,
    STATE(468), 1,
      sym_macro,
    STATE(815), 1,
      sym_macro_text_expansion,
  [175451] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1815), 1,
      sym_identifier,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    ACTIONS(6902), 1,
      aux_sym_symbol_token1,
    ACTIONS(6904), 1,
      aux_sym_symbol_token2,
    STATE(609), 1,
      sym_macro,
    STATE(1048), 1,
      sym_macro_text_expansion,
  [175473] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6324), 1,
      anon_sym_BSLASH,
    STATE(3391), 1,
      aux_sym_symbol_repeat1,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [175489] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2811), 1,
      sym_hll_type_qualifier,
    STATE(3674), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(6906), 2,
      anon_sym_const,
      anon_sym_volatile,
  [175509] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6908), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175531] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    ACTIONS(6910), 1,
      sym_identifier,
    ACTIONS(6912), 1,
      aux_sym_symbol_token1,
    ACTIONS(6914), 1,
      aux_sym_symbol_token4,
    STATE(1961), 1,
      sym_macro,
    STATE(2463), 1,
      sym_macro_text_expansion,
  [175553] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 1,
      anon_sym_BSLASH,
    ACTIONS(2421), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [175567] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6916), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175589] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6540), 1,
      anon_sym_LBRACK,
    ACTIONS(6542), 1,
      sym__blank,
    ACTIONS(6918), 1,
      anon_sym_RPAREN,
    STATE(3502), 1,
      sym_hll_parameter_list,
    STATE(3503), 1,
      aux_sym_block_repeat1,
  [175611] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6850), 1,
      sym__blank,
    STATE(3393), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [175629] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6332), 1,
      anon_sym_DOT,
    ACTIONS(6850), 1,
      sym__blank,
    STATE(3393), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 3,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [175647] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1736), 1,
      sym_identifier,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    ACTIONS(6506), 1,
      aux_sym_symbol_token1,
    ACTIONS(6920), 1,
      aux_sym_symbol_token4,
    STATE(659), 1,
      sym_macro,
    STATE(1167), 1,
      sym_macro_text_expansion,
  [175669] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6922), 1,
      sym_identifier,
    ACTIONS(6924), 1,
      anon_sym_AMP,
    ACTIONS(6926), 1,
      aux_sym_symbol_token1,
    ACTIONS(6928), 1,
      aux_sym_symbol_token4,
    STATE(1368), 1,
      sym_macro,
    STATE(1669), 1,
      sym_macro_text_expansion,
  [175691] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(6906), 2,
      anon_sym_const,
      anon_sym_volatile,
    STATE(2906), 2,
      sym_hll_type_qualifier,
      sym__hll_declaration_modifiers,
  [175709] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6930), 1,
      sym_identifier,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      aux_sym_symbol_token1,
    ACTIONS(6936), 1,
      aux_sym_symbol_token4,
    STATE(798), 1,
      sym_macro,
    STATE(1346), 1,
      sym_macro_text_expansion,
  [175731] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5605), 1,
      sym_identifier,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    ACTIONS(6526), 1,
      aux_sym_symbol_token1,
    ACTIONS(6938), 1,
      aux_sym_symbol_token4,
    STATE(3011), 1,
      sym_macro,
    STATE(3324), 1,
      sym_macro_text_expansion,
  [175753] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    ACTIONS(6940), 1,
      sym_identifier,
    ACTIONS(6942), 1,
      aux_sym_symbol_token1,
    ACTIONS(6944), 1,
      aux_sym_symbol_token4,
    STATE(3018), 1,
      sym_macro,
    STATE(3439), 1,
      sym_macro_text_expansion,
  [175775] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5721), 1,
      sym_identifier,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    ACTIONS(6569), 1,
      aux_sym_symbol_token1,
    ACTIONS(6946), 1,
      aux_sym_symbol_token4,
    STATE(3029), 1,
      sym_macro,
    STATE(3384), 1,
      sym_macro_text_expansion,
  [175797] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 2,
      anon_sym_BSLASH,
      sym__blank,
    ACTIONS(2407), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [175811] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    ACTIONS(6948), 1,
      sym_identifier,
    ACTIONS(6950), 1,
      aux_sym_symbol_token1,
    ACTIONS(6952), 1,
      aux_sym_symbol_token4,
    STATE(3059), 1,
      sym_macro,
    STATE(3571), 1,
      sym_macro_text_expansion,
  [175833] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1991), 1,
      sym_identifier,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    ACTIONS(6597), 1,
      aux_sym_symbol_token1,
    ACTIONS(6954), 1,
      aux_sym_symbol_token4,
    STATE(1180), 1,
      sym_macro,
    STATE(1575), 1,
      sym_macro_text_expansion,
  [175855] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6956), 1,
      sym_identifier,
    ACTIONS(6958), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      aux_sym_symbol_token1,
    ACTIONS(6962), 1,
      aux_sym_symbol_token4,
    STATE(1352), 1,
      sym_macro,
    STATE(1674), 1,
      sym_macro_text_expansion,
  [175877] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    ACTIONS(6964), 1,
      sym_identifier,
    ACTIONS(6966), 1,
      aux_sym_symbol_token1,
    ACTIONS(6968), 1,
      aux_sym_symbol_token2,
    STATE(1806), 1,
      sym_macro,
    STATE(2038), 1,
      sym_macro_text_expansion,
  [175899] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3926), 1,
      sym_identifier,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    ACTIONS(6970), 1,
      aux_sym_symbol_token1,
    ACTIONS(6972), 1,
      aux_sym_symbol_token2,
    STATE(1888), 1,
      sym_macro,
    STATE(2147), 1,
      sym_macro_text_expansion,
  [175921] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 1,
      anon_sym_BSLASH,
    ACTIONS(2994), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__line_specifier,
      sym__blank,
  [175935] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(2881), 1,
      sym_macro,
    STATE(3634), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6334), 2,
      anon_sym_COMMA,
      sym__blank,
  [175955] = 7,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6974), 1,
      sym_identifier,
    ACTIONS(6976), 1,
      anon_sym_AMP,
    ACTIONS(6978), 1,
      aux_sym_symbol_token1,
    ACTIONS(6980), 1,
      aux_sym_symbol_token2,
    STATE(802), 1,
      sym_macro,
    STATE(1359), 1,
      sym_macro_text_expansion,
  [175977] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6722), 1,
      sym__blank,
    STATE(3604), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
    ACTIONS(6679), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [175997] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6982), 1,
      anon_sym_RPAREN,
    ACTIONS(6984), 1,
      sym__blank,
    STATE(3568), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
  [176016] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4078), 2,
      sym_comment,
      sym__blank_line,
  [176033] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(6988), 2,
      sym_comment,
      sym__blank_line,
  [176050] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3490), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(6988), 2,
      sym_comment,
      sym__blank_line,
  [176067] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6994), 1,
      sym__blank,
    ACTIONS(6992), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176080] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2639), 1,
      sym__blank,
    ACTIONS(2641), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176093] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3539), 1,
      sym__blank,
    ACTIONS(3541), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176106] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6996), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176117] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3451), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(6998), 2,
      sym_comment,
      sym__blank_line,
  [176134] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(398), 1,
      anon_sym_PERCENT,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(3480), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(3701), 2,
      sym_format_expression,
      sym_hll_option_expression,
  [176151] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4082), 2,
      sym_comment,
      sym__blank_line,
  [176168] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(7000), 1,
      anon_sym_RPAREN,
    ACTIONS(7002), 1,
      sym__blank,
    STATE(3549), 1,
      aux_sym_argument_list_repeat1,
    STATE(3921), 1,
      aux_sym_block_repeat1,
  [176187] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4504), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3945), 1,
      aux_sym_hll_argument_list_repeat1,
  [176206] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7004), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3955), 1,
      aux_sym_hll_argument_list_repeat1,
  [176225] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7006), 1,
      anon_sym_COMMA,
    ACTIONS(7008), 1,
      sym__blank,
    STATE(1769), 1,
      aux_sym_block_repeat1,
    ACTIONS(4082), 2,
      sym_comment,
      sym__blank_line,
  [176242] = 3,
    ACTIONS(1924), 1,
      anon_sym_DQUOTE,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(1926), 4,
      sym__ampersand_char,
      anon_sym_AMP,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [176255] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7012), 1,
      sym__blank,
    ACTIONS(7010), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176268] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3450), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4082), 2,
      sym_comment,
      sym__blank_line,
  [176285] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7016), 1,
      sym__blank,
    ACTIONS(7014), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176298] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6546), 1,
      sym__blank,
    ACTIONS(7018), 1,
      sym_identifier,
    STATE(3494), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(7020), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [176315] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2669), 1,
      sym_else_block,
  [176334] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7022), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176345] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7026), 1,
      sym__blank,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
    ACTIONS(7024), 2,
      sym_comment,
      sym__blank_line,
  [176362] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7029), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176373] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7031), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176384] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7033), 1,
      anon_sym_DOT,
    ACTIONS(7038), 1,
      sym__blank,
    STATE(3474), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7036), 2,
      sym_comment,
      sym__blank_line,
  [176401] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7040), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176412] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4510), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3876), 1,
      aux_sym_hll_argument_list_repeat1,
  [176431] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7042), 1,
      anon_sym_DOT,
    ACTIONS(7046), 1,
      sym__blank,
    STATE(3500), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7044), 2,
      sym_comment,
      sym__blank_line,
  [176448] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7048), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3878), 1,
      aux_sym_hll_argument_list_repeat1,
  [176467] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7050), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176478] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7052), 1,
      anon_sym_SLASH,
    ACTIONS(7055), 1,
      anon_sym_PERCENT,
    STATE(3480), 1,
      aux_sym__var_command_argument_list_non_hll_format_repeat1,
    STATE(3978), 2,
      sym_format_expression,
      sym_hll_option_expression,
  [176495] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7058), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176506] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7060), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176517] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(7002), 1,
      sym__blank,
    ACTIONS(7062), 1,
      anon_sym_RPAREN,
    STATE(3549), 1,
      aux_sym_argument_list_repeat1,
    STATE(3921), 1,
      aux_sym_block_repeat1,
  [176536] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1649), 1,
      sym__blank,
    ACTIONS(1647), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176549] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [176568] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2639), 1,
      sym_else_block,
  [176587] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7064), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176598] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7066), 1,
      sym_comment,
    ACTIONS(7068), 1,
      sym__blank_line,
    ACTIONS(7070), 1,
      sym__blank,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [176617] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3433), 1,
      sym__blank,
    ACTIONS(3435), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176630] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(7072), 2,
      sym_comment,
      sym__blank_line,
  [176647] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2246), 1,
      sym__blank,
    ACTIONS(2244), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176660] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6338), 1,
      anon_sym_AMP,
    ACTIONS(6587), 1,
      sym__blank,
    ACTIONS(7074), 1,
      aux_sym_parameter_declaration_token4,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    STATE(3741), 1,
      sym_macro,
  [176679] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7076), 1,
      sym_comment,
    ACTIONS(7078), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [176698] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6657), 1,
      sym__blank,
    ACTIONS(7080), 1,
      sym_identifier,
    STATE(3494), 1,
      aux_sym_hll_type_pattern_repeat1,
    ACTIONS(7083), 2,
      anon_sym_STAR,
      anon_sym_QMARK,
  [176715] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2881), 1,
      sym_macro,
    ACTIONS(6346), 3,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__blank,
  [176730] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7088), 1,
      sym__blank,
    ACTIONS(7086), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176743] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7090), 1,
      anon_sym_RPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3714), 1,
      sym_hll_parameter_list,
  [176762] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7094), 1,
      sym__blank,
    ACTIONS(7092), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176775] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7096), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176786] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7098), 1,
      anon_sym_DOT,
    ACTIONS(7102), 1,
      sym__blank,
    STATE(3474), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7100), 2,
      sym_comment,
      sym__blank_line,
  [176803] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7098), 1,
      anon_sym_DOT,
    ACTIONS(7106), 1,
      sym__blank,
    STATE(3474), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7104), 2,
      sym_comment,
      sym__blank_line,
  [176820] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7108), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [176831] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(6794), 1,
      anon_sym_LBRACK,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3487), 1,
      sym_hll_parameter_list,
  [176850] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2635), 1,
      sym__blank,
    ACTIONS(7110), 1,
      anon_sym_AMP,
    ACTIONS(7112), 1,
      aux_sym_file_handle_token1,
    STATE(3536), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [176867] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7114), 1,
      sym_comment,
    ACTIONS(7116), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [176886] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6647), 1,
      sym__blank,
    STATE(3136), 1,
      aux_sym_block_repeat1,
    STATE(3553), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(6645), 2,
      sym_comment,
      sym__blank_line,
  [176903] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3227), 1,
      sym_hll_type_qualifier,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
  [176920] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2269), 1,
      sym__blank,
    ACTIONS(2267), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [176933] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7118), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3896), 1,
      aux_sym_hll_argument_list_repeat1,
  [176952] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [176971] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2058), 1,
      sym_hll_type_qualifier,
    ACTIONS(7120), 2,
      anon_sym_const,
      anon_sym_volatile,
  [176988] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4520), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3891), 1,
      aux_sym_hll_argument_list_repeat1,
  [177007] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7122), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177018] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7124), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177029] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7126), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177040] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7128), 1,
      anon_sym_COMMA,
    ACTIONS(7130), 1,
      sym__blank,
    STATE(1740), 1,
      aux_sym_block_repeat1,
    ACTIONS(4092), 2,
      sym_comment,
      sym__blank_line,
  [177057] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3219), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(7132), 1,
      sym__blank,
    STATE(3517), 1,
      aux_sym_block_repeat1,
    ACTIONS(3217), 2,
      anon_sym_AMP,
      anon_sym_DQUOTE,
  [177074] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3459), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4092), 2,
      sym_comment,
      sym__blank_line,
  [177091] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7135), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177102] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7137), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177113] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7139), 1,
      anon_sym_RPAREN,
    ACTIONS(7141), 1,
      sym__blank,
    STATE(3529), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
  [177132] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7143), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177143] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [177162] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4861), 1,
      anon_sym_COMMA,
    ACTIONS(7002), 1,
      sym__blank,
    ACTIONS(7145), 1,
      anon_sym_RPAREN,
    STATE(3549), 1,
      aux_sym_argument_list_repeat1,
    STATE(3921), 1,
      aux_sym_block_repeat1,
  [177181] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7092), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177192] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4516), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3793), 1,
      aux_sym_hll_argument_list_repeat1,
  [177211] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7147), 1,
      sym_comment,
    ACTIONS(7149), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [177230] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6392), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [177249] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7151), 1,
      anon_sym_RPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3714), 1,
      sym_hll_parameter_list,
  [177268] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7151), 1,
      anon_sym_RPAREN,
    ACTIONS(7153), 1,
      sym__blank,
    STATE(3534), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
  [177287] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7155), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177298] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7157), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177309] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7159), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3828), 1,
      aux_sym_hll_argument_list_repeat1,
  [177328] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7161), 1,
      anon_sym_RPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3714), 1,
      sym_hll_parameter_list,
  [177347] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [177366] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2740), 1,
      sym__blank,
    ACTIONS(7163), 1,
      anon_sym_AMP,
    ACTIONS(7166), 1,
      aux_sym_file_handle_token1,
    STATE(3536), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [177383] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2292), 1,
      sym__blank,
    ACTIONS(2290), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177396] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7010), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177407] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2639), 1,
      sym_else_block,
  [177426] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [177445] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7169), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177456] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7171), 1,
      sym_comment,
    ACTIONS(7173), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [177475] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [177494] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [177513] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6398), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2669), 1,
      sym_else_block,
  [177532] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(6998), 2,
      sym_comment,
      sym__blank_line,
  [177549] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7175), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177560] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1689), 1,
      sym__blank,
    ACTIONS(1687), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177573] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5072), 1,
      anon_sym_RPAREN,
    ACTIONS(7177), 1,
      anon_sym_COMMA,
    ACTIONS(7180), 1,
      sym__blank,
    STATE(3549), 1,
      aux_sym_argument_list_repeat1,
    STATE(3921), 1,
      aux_sym_block_repeat1,
  [177592] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7183), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177603] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7185), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177614] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1709), 1,
      sym__blank,
    ACTIONS(1707), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177627] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6647), 1,
      sym__blank,
    STATE(3136), 1,
      aux_sym_block_repeat1,
    STATE(3573), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(7187), 2,
      sym_comment,
      sym__blank_line,
  [177644] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2313), 1,
      sym__blank,
    ACTIONS(2311), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177657] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7189), 1,
      sym_comment,
    ACTIONS(7191), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [177676] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6348), 1,
      sym__blank,
    ACTIONS(6346), 4,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym_comment,
      sym__blank_line,
  [177689] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6338), 1,
      anon_sym_AMP,
    ACTIONS(6587), 1,
      sym__blank,
    ACTIONS(7193), 1,
      aux_sym_parameter_declaration_token4,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    STATE(3741), 1,
      sym_macro,
  [177708] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6986), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(7195), 2,
      sym_comment,
      sym__blank_line,
  [177725] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3546), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(7195), 2,
      sym_comment,
      sym__blank_line,
  [177742] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7197), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(7202), 1,
      sym__blank,
    STATE(3560), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(7200), 2,
      sym_comment,
      sym__blank_line,
  [177759] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7204), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177770] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7206), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177781] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6643), 1,
      aux_sym__host_command_argument_list_default_format_token1,
    ACTIONS(7210), 1,
      sym__blank,
    STATE(3560), 1,
      aux_sym__host_command_argument_list_default_format_repeat1,
    ACTIONS(7208), 2,
      sym_comment,
      sym__blank_line,
  [177798] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7046), 1,
      sym__blank,
    ACTIONS(7212), 1,
      anon_sym_DOT,
    STATE(3500), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7044), 2,
      sym_comment,
      sym__blank_line,
  [177815] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7098), 1,
      anon_sym_DOT,
    ACTIONS(7216), 1,
      sym__blank,
    STATE(3501), 1,
      aux_sym__command_identifier_repeat1,
    ACTIONS(7214), 2,
      sym_comment,
      sym__blank_line,
  [177832] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7218), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177843] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7222), 1,
      sym__blank,
    ACTIONS(7220), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177856] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7224), 1,
      anon_sym_RPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3714), 1,
      sym_hll_parameter_list,
  [177875] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    ACTIONS(7224), 1,
      anon_sym_RPAREN,
    ACTIONS(7226), 1,
      sym__blank,
    STATE(3497), 1,
      aux_sym_block_repeat1,
    STATE(3670), 1,
      sym_hll_parameter_list,
  [177894] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7228), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [177905] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2409), 1,
      anon_sym_BSLASH,
    ACTIONS(2407), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [177918] = 3,
    ACTIONS(1928), 1,
      anon_sym_DQUOTE,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(1930), 4,
      sym__ampersand_char,
      anon_sym_AMP,
      aux_sym_string_token1,
      aux_sym_string_token2,
  [177931] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7230), 1,
      sym__blank,
    STATE(3136), 1,
      aux_sym_block_repeat1,
    STATE(3573), 1,
      aux_sym__host_command_argument_list_default_format_repeat2,
    ACTIONS(7208), 2,
      sym_comment,
      sym__blank_line,
  [177948] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7233), 1,
      sym__blank,
    ACTIONS(7096), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177961] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2102), 1,
      sym__blank,
    ACTIONS(2100), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177974] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7237), 1,
      sym__blank,
    ACTIONS(7235), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [177987] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2334), 1,
      sym__blank,
    ACTIONS(2332), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [178000] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2423), 1,
      anon_sym_BSLASH,
    ACTIONS(2421), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178013] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1669), 1,
      sym__blank,
    ACTIONS(1667), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [178026] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6990), 1,
      sym__blank,
    STATE(3249), 1,
      aux_sym_block_repeat1,
    STATE(3558), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(4078), 2,
      sym_comment,
      sym__blank_line,
  [178043] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [178062] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2639), 1,
      sym_else_block,
  [178081] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [178100] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [178119] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7239), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      sym__blank,
  [178130] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [178149] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6431), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2669), 1,
      sym_else_block,
  [178168] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7241), 1,
      sym__blank,
    STATE(3355), 1,
      aux_sym_block_repeat1,
    STATE(3588), 1,
      aux_sym__command_arguments_repeat3,
    ACTIONS(6633), 2,
      sym_comment,
      sym__blank_line,
  [178185] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7244), 1,
      sym_comment,
    ACTIONS(7246), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [178204] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2655), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [178223] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2639), 1,
      sym_else_block,
  [178242] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2639), 1,
      sym_else_block,
    STATE(2658), 1,
      sym_elif_block,
  [178261] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7070), 1,
      sym__blank,
    ACTIONS(7248), 1,
      sym_comment,
    ACTIONS(7250), 1,
      sym__blank_line,
    STATE(3471), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [178280] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [178299] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
    STATE(2699), 1,
      sym_else_block,
  [178318] = 6,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6418), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
    STATE(2669), 1,
      sym_else_block,
  [178337] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1627), 1,
      sym__blank,
    ACTIONS(1625), 4,
      anon_sym_LPAREN,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [178350] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7252), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3164), 1,
      sym__hll_type_identifier,
  [178366] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(7254), 1,
      sym_identifier,
    STATE(3206), 1,
      sym_macro,
    STATE(3830), 1,
      sym_macro_text_expansion,
  [178382] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7256), 1,
      aux_sym_while_block_token1,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [178396] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4432), 1,
      sym__blank,
    STATE(1976), 1,
      aux_sym_block_repeat1,
    ACTIONS(4430), 2,
      sym_comment,
      sym__blank_line,
  [178410] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7258), 1,
      anon_sym_EQ,
    ACTIONS(7260), 1,
      anon_sym_COMMA,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [178426] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7262), 1,
      anon_sym_DQUOTE,
    STATE(3607), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7264), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178440] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6538), 1,
      anon_sym_LPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3714), 1,
      sym_hll_parameter_list,
  [178456] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2100), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178466] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6338), 1,
      anon_sym_AMP,
    ACTIONS(6587), 1,
      sym__blank,
    STATE(3354), 1,
      aux_sym_block_repeat1,
    STATE(3741), 1,
      sym_macro,
  [178482] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7266), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178496] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7272), 1,
      sym__blank,
    STATE(3954), 1,
      aux_sym_block_repeat1,
    ACTIONS(7270), 2,
      sym_comment,
      sym__blank_line,
  [178510] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1647), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178520] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4428), 1,
      sym__blank,
    STATE(1943), 1,
      aux_sym_block_repeat1,
    ACTIONS(4426), 2,
      sym_comment,
      sym__blank_line,
  [178534] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(7274), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [178548] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2332), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178558] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6747), 4,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
      sym__blank,
  [178568] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7276), 1,
      sym__blank,
    STATE(3881), 1,
      aux_sym_block_repeat1,
    ACTIONS(4450), 2,
      sym_comment,
      sym__blank_line,
  [178582] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7278), 1,
      anon_sym_DQUOTE,
    STATE(3618), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7280), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178596] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(7282), 2,
      anon_sym_SLASH,
      anon_sym_PERCENT,
  [178610] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7286), 1,
      sym__blank,
    STATE(99), 1,
      aux_sym_block_repeat1,
    ACTIONS(7284), 2,
      sym_comment,
      sym__blank_line,
  [178624] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7288), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178638] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5456), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178648] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5511), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178658] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5489), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178668] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5500), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178678] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7292), 1,
      sym__blank,
    STATE(3926), 1,
      aux_sym_block_repeat1,
    ACTIONS(7290), 2,
      sym_comment,
      sym__blank_line,
  [178692] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2641), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178702] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6992), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178712] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6480), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
  [178728] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5533), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178738] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2267), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178748] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3541), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178758] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7296), 1,
      sym__blank,
    STATE(97), 1,
      aux_sym_block_repeat1,
    ACTIONS(7294), 2,
      sym_comment,
      sym__blank_line,
  [178772] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7298), 1,
      anon_sym_DQUOTE,
    STATE(3688), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7300), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178786] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3435), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178796] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7110), 1,
      anon_sym_AMP,
    ACTIONS(7302), 1,
      aux_sym_file_handle_token1,
    STATE(3504), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [178810] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(3638), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 2,
      anon_sym_COMMA,
      sym__blank,
  [178824] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(3638), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 2,
      anon_sym_COMMA,
      sym__blank,
  [178838] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(3638), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6848), 2,
      anon_sym_COMMA,
      sym__blank,
  [178852] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1625), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [178862] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7304), 1,
      anon_sym_DOT,
    STATE(3638), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6826), 2,
      anon_sym_COMMA,
      sym__blank,
  [178876] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7309), 1,
      sym__blank,
    STATE(361), 1,
      aux_sym_block_repeat1,
    ACTIONS(7307), 2,
      sym_comment,
      sym__blank_line,
  [178890] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7311), 1,
      aux_sym_block_token1,
    ACTIONS(7313), 1,
      sym_comment,
    ACTIONS(7316), 1,
      sym__blank,
    STATE(3640), 1,
      aux_sym_labeled_expression_repeat1,
  [178906] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5555), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178916] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4867), 1,
      anon_sym_AMP,
    ACTIONS(7318), 1,
      aux_sym_file_handle_token1,
    STATE(550), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [178930] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7320), 1,
      anon_sym_DQUOTE,
    STATE(3644), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7322), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178944] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7324), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178958] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5467), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [178968] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7326), 1,
      anon_sym_DQUOTE,
    STATE(3676), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7328), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [178982] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7330), 1,
      aux_sym_while_block_token1,
    STATE(3231), 1,
      aux_sym_subroutine_block_repeat1,
    ACTIONS(6394), 2,
      sym_comment,
      sym__blank_line,
  [178996] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7332), 1,
      anon_sym_DQUOTE,
    STATE(3692), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7334), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179010] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5544), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [179020] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    ACTIONS(7336), 1,
      sym_identifier,
    STATE(3065), 1,
      sym_macro,
    STATE(3652), 1,
      sym_macro_text_expansion,
  [179036] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7220), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179046] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6368), 1,
      anon_sym_DOT,
    STATE(3636), 1,
      aux_sym_format_expression_repeat1,
    ACTIONS(6334), 2,
      anon_sym_COMMA,
      sym__blank,
  [179060] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(3087), 1,
      sym_hll_type_qualifier,
    STATE(3675), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179074] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2811), 1,
      sym_hll_type_qualifier,
    STATE(3675), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(6906), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179088] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7252), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3158), 1,
      sym__hll_type_identifier,
  [179104] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7252), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(3163), 1,
      sym__hll_type_identifier,
  [179120] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7338), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2904), 1,
      sym__hll_type_identifier,
  [179136] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7338), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2905), 1,
      sym__hll_type_identifier,
  [179152] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7276), 1,
      sym__blank,
    STATE(3881), 1,
      aux_sym_block_repeat1,
    ACTIONS(7340), 2,
      sym_comment,
      sym__blank_line,
  [179166] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7342), 1,
      sym__blank,
    STATE(3672), 1,
      aux_sym_block_repeat1,
    ACTIONS(6370), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179180] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5566), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [179190] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(4605), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [179204] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7346), 1,
      sym__blank,
    STATE(31), 1,
      aux_sym_block_repeat1,
    ACTIONS(7344), 2,
      sym_comment,
      sym__blank_line,
  [179218] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7348), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179232] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7352), 1,
      sym__blank,
    STATE(35), 1,
      aux_sym_block_repeat1,
    ACTIONS(7350), 2,
      sym_comment,
      sym__blank_line,
  [179246] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7357), 1,
      sym__blank,
    STATE(30), 1,
      aux_sym_block_repeat1,
    ACTIONS(7355), 2,
      sym_comment,
      sym__blank_line,
  [179260] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7361), 1,
      sym__blank,
    STATE(574), 1,
      aux_sym_block_repeat1,
    ACTIONS(7359), 2,
      sym_comment,
      sym__blank_line,
  [179274] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7365), 1,
      sym__blank,
    STATE(21), 1,
      aux_sym_block_repeat1,
    ACTIONS(7363), 2,
      sym_comment,
      sym__blank_line,
  [179288] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(3066), 1,
      sym_hll_type_qualifier,
    STATE(3675), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(5796), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179302] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7014), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179312] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7276), 1,
      sym__blank,
    STATE(3881), 1,
      aux_sym_block_repeat1,
    ACTIONS(7367), 2,
      sym_comment,
      sym__blank_line,
  [179326] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    ACTIONS(7369), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179340] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1687), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179350] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(2812), 1,
      sym_hll_type_qualifier,
    STATE(3675), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(6906), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179364] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    STATE(3660), 1,
      sym_hll_type_qualifier,
    STATE(3675), 1,
      aux_sym__hll_pointer_declarator_specifier_repeat1,
    ACTIONS(7371), 2,
      anon_sym_const,
      anon_sym_volatile,
  [179378] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7374), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179392] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7376), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7378), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179406] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7381), 1,
      anon_sym_DQUOTE,
    STATE(3682), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7383), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179420] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(7385), 1,
      sym_identifier,
    STATE(3048), 1,
      sym_macro,
    STATE(3556), 1,
      sym_macro_text_expansion,
  [179436] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2244), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179446] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    ACTIONS(7387), 1,
      sym_identifier,
    STATE(3043), 1,
      sym_macro,
    STATE(3378), 1,
      sym_macro_text_expansion,
  [179462] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7389), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179476] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7393), 1,
      sym__blank,
    STATE(3063), 1,
      aux_sym_block_repeat1,
    ACTIONS(7391), 2,
      sym_comment,
      sym__blank_line,
  [179490] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5478), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [179500] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1707), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179510] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1667), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179520] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7397), 1,
      sym__blank,
    ACTIONS(7395), 3,
      anon_sym_DOT,
      sym_comment,
      sym__blank_line,
  [179532] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7399), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179546] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7403), 1,
      sym__blank,
    STATE(130), 1,
      aux_sym_block_repeat1,
    ACTIONS(7401), 2,
      sym_comment,
      sym__blank_line,
  [179560] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4406), 1,
      sym__blank,
    STATE(1982), 1,
      aux_sym_block_repeat1,
    ACTIONS(4404), 2,
      sym_comment,
      sym__blank_line,
  [179574] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7272), 1,
      sym__blank,
    STATE(3954), 1,
      aux_sym_block_repeat1,
    ACTIONS(7405), 2,
      sym_comment,
      sym__blank_line,
  [179588] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7407), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179602] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4530), 1,
      anon_sym_AMP,
    ACTIONS(7409), 1,
      aux_sym_file_handle_token1,
    STATE(2055), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [179616] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7276), 1,
      sym__blank,
    STATE(3881), 1,
      aux_sym_block_repeat1,
    ACTIONS(7411), 2,
      sym_comment,
      sym__blank_line,
  [179630] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2290), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179640] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6697), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
  [179656] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6480), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2658), 1,
      sym_elif_block,
  [179672] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5408), 1,
      sym__blank,
    ACTIONS(6557), 1,
      anon_sym_LPAREN,
    STATE(2867), 1,
      aux_sym_block_repeat1,
    STATE(3576), 1,
      sym_hll_parameter_list,
  [179688] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6697), 1,
      aux_sym_elif_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2638), 1,
      sym_elif_block,
  [179704] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5522), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      sym__blank,
  [179714] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7415), 1,
      sym__blank,
    STATE(3616), 1,
      aux_sym_block_repeat1,
    ACTIONS(7413), 2,
      sym_comment,
      sym__blank_line,
  [179728] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7415), 1,
      sym__blank,
    STATE(3616), 1,
      aux_sym_block_repeat1,
    ACTIONS(7417), 2,
      sym_comment,
      sym__blank_line,
  [179742] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7421), 1,
      sym__blank,
    STATE(131), 1,
      aux_sym_block_repeat1,
    ACTIONS(7419), 2,
      sym_comment,
      sym__blank_line,
  [179756] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7423), 1,
      anon_sym_DQUOTE,
    STATE(3664), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7425), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179770] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7292), 1,
      sym__blank,
    STATE(3926), 1,
      aux_sym_block_repeat1,
    ACTIONS(7427), 2,
      sym_comment,
      sym__blank_line,
  [179784] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4422), 1,
      sym__blank,
    STATE(1949), 1,
      aux_sym_block_repeat1,
    ACTIONS(4408), 2,
      sym_comment,
      sym__blank_line,
  [179798] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2311), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179808] = 5,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7338), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
    STATE(2902), 1,
      sym__hll_type_identifier,
  [179824] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7429), 1,
      anon_sym_DQUOTE,
    STATE(3710), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7431), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179838] = 4,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(7433), 1,
      anon_sym_DQUOTE,
    STATE(3677), 1,
      aux_sym_hll_string_literal_repeat1,
    ACTIONS(7268), 2,
      aux_sym_hll_string_literal_token1,
      sym_hll_escape_sequence,
  [179852] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7086), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179862] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4498), 1,
      anon_sym_AMP,
    ACTIONS(7435), 1,
      aux_sym_file_handle_token1,
    STATE(1992), 2,
      sym_macro,
      aux_sym_file_handle_repeat1,
  [179876] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7437), 1,
      sym__blank,
    STATE(525), 1,
      aux_sym_block_repeat1,
    ACTIONS(7359), 2,
      sym_comment,
      sym__blank_line,
  [179890] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7235), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      sym__blank,
  [179900] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7440), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [179913] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7442), 1,
      anon_sym_RPAREN,
    ACTIONS(7444), 1,
      sym__blank,
    STATE(3719), 1,
      aux_sym_block_repeat1,
  [179926] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7446), 1,
      anon_sym_RPAREN,
    ACTIONS(7448), 1,
      sym__blank,
    STATE(3720), 1,
      aux_sym_block_repeat1,
  [179939] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4544), 1,
      anon_sym_RPAREN,
    ACTIONS(4548), 1,
      sym__blank,
    STATE(3746), 1,
      aux_sym_block_repeat1,
  [179952] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7450), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [179965] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7452), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [179978] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7454), 1,
      anon_sym_RPAREN,
    ACTIONS(7456), 1,
      sym__blank,
    STATE(3722), 1,
      aux_sym_block_repeat1,
  [179991] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7458), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180004] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7460), 1,
      anon_sym_RPAREN,
    ACTIONS(7462), 1,
      sym__blank,
    STATE(3752), 1,
      aux_sym_block_repeat1,
  [180017] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7464), 1,
      anon_sym_RPAREN,
    ACTIONS(7466), 1,
      sym__blank,
    STATE(3754), 1,
      aux_sym_block_repeat1,
  [180030] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3505), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [180043] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7470), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180056] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7472), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180069] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    STATE(3466), 1,
      sym_option_expression,
    STATE(3843), 1,
      aux_sym__command_arguments_repeat2,
  [180082] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7474), 1,
      sym_identifier,
    ACTIONS(7476), 1,
      anon_sym_LPAREN,
    ACTIONS(7478), 1,
      anon_sym_LBRACE,
  [180095] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7480), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180108] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7482), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180121] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7484), 1,
      anon_sym_RPAREN,
    ACTIONS(7486), 1,
      sym__blank,
    STATE(3736), 1,
      aux_sym_block_repeat1,
  [180134] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7488), 1,
      anon_sym_RPAREN,
    ACTIONS(7490), 1,
      sym__blank,
    STATE(3737), 1,
      aux_sym_block_repeat1,
  [180147] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1928), 1,
      sym__blank,
    ACTIONS(1930), 2,
      sym_comment,
      sym__blank_line,
  [180158] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(3659), 1,
      sym_hll_option_expression,
    STATE(3883), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
  [180171] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7492), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180184] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7494), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180197] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7496), 1,
      anon_sym_RPAREN,
    ACTIONS(7498), 1,
      sym__blank,
    STATE(3740), 1,
      aux_sym_block_repeat1,
  [180210] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7500), 1,
      anon_sym_RPAREN,
    ACTIONS(7502), 1,
      sym__blank,
    STATE(3743), 1,
      aux_sym_block_repeat1,
  [180223] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7504), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180236] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7508), 1,
      sym__blank,
    ACTIONS(7506), 2,
      sym_comment,
      sym__blank_line,
  [180247] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7510), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180260] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7512), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180273] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7514), 1,
      anon_sym_RPAREN,
    ACTIONS(7516), 1,
      sym__blank,
    STATE(3747), 1,
      aux_sym_block_repeat1,
  [180286] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7518), 1,
      anon_sym_RPAREN,
    ACTIONS(7520), 1,
      sym__blank,
    STATE(3748), 1,
      aux_sym_block_repeat1,
  [180299] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7522), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180312] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7524), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180325] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7526), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180338] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7528), 1,
      anon_sym_RPAREN,
    ACTIONS(7530), 1,
      sym__blank,
    STATE(3715), 1,
      aux_sym_block_repeat1,
  [180351] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4668), 1,
      anon_sym_RPAREN,
    ACTIONS(4670), 1,
      sym__blank,
    STATE(3922), 1,
      aux_sym_block_repeat1,
  [180364] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7532), 1,
      sym_identifier,
    ACTIONS(7534), 1,
      anon_sym_LPAREN,
    ACTIONS(7536), 1,
      anon_sym_LBRACE,
  [180377] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7538), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180390] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4520), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [180403] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7540), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180416] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7542), 1,
      anon_sym_RPAREN,
    ACTIONS(7544), 1,
      sym__blank,
    STATE(3791), 1,
      aux_sym_block_repeat1,
  [180429] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 3,
      anon_sym_AMP,
      aux_sym_file_handle_token1,
      sym__blank,
  [180438] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4516), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [180451] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7546), 1,
      anon_sym_RPAREN,
    ACTIONS(7548), 1,
      sym__blank,
    STATE(3760), 1,
      aux_sym_block_repeat1,
  [180464] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 3,
      anon_sym_AMP,
      aux_sym_file_handle_token1,
      sym__blank,
  [180473] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7550), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180486] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7552), 1,
      anon_sym_RPAREN,
    ACTIONS(7554), 1,
      sym__blank,
    STATE(3764), 1,
      aux_sym_block_repeat1,
  [180499] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7556), 1,
      anon_sym_RPAREN,
    ACTIONS(7558), 1,
      sym__blank,
    STATE(3765), 1,
      aux_sym_block_repeat1,
  [180512] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7560), 1,
      anon_sym_RPAREN,
    ACTIONS(7562), 1,
      anon_sym_COMMA,
    STATE(3763), 1,
      aux_sym_hll_parameter_list_repeat1,
  [180525] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7565), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180538] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7567), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180551] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7569), 1,
      anon_sym_RPAREN,
    ACTIONS(7571), 1,
      sym__blank,
    STATE(3767), 1,
      aux_sym_block_repeat1,
  [180564] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7573), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180577] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7575), 1,
      sym_identifier,
    ACTIONS(7577), 1,
      anon_sym_LPAREN,
    ACTIONS(7579), 1,
      anon_sym_LBRACE,
  [180590] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7581), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180603] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7583), 1,
      anon_sym_EQ,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180616] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1813), 1,
      anon_sym_EQ,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180629] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4641), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180642] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7585), 1,
      anon_sym_RPAREN,
    ACTIONS(7587), 1,
      sym__blank,
    STATE(3776), 1,
      aux_sym_block_repeat1,
  [180655] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7589), 1,
      anon_sym_DOT_DOT,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180668] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4550), 1,
      anon_sym_RPAREN,
    ACTIONS(4552), 1,
      sym__blank,
    STATE(3834), 1,
      aux_sym_block_repeat1,
  [180681] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7591), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180694] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7593), 1,
      anon_sym_RPAREN,
    ACTIONS(7595), 1,
      sym__blank,
    STATE(3779), 1,
      aux_sym_block_repeat1,
  [180707] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7597), 1,
      anon_sym_RPAREN,
    ACTIONS(7599), 1,
      sym__blank,
    STATE(3780), 1,
      aux_sym_block_repeat1,
  [180720] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7601), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180733] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7603), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180746] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7605), 1,
      anon_sym_RPAREN,
    ACTIONS(7607), 1,
      sym__blank,
    STATE(3782), 1,
      aux_sym_block_repeat1,
  [180759] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7609), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180772] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7611), 1,
      sym_identifier,
    ACTIONS(7613), 1,
      anon_sym_LPAREN,
    ACTIONS(7615), 1,
      anon_sym_LBRACE,
  [180785] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7617), 1,
      sym_identifier,
    ACTIONS(7619), 1,
      anon_sym_LPAREN,
    ACTIONS(7621), 1,
      anon_sym_LBRACE,
  [180798] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7623), 1,
      anon_sym_RPAREN,
    ACTIONS(7625), 1,
      anon_sym_COMMA,
    STATE(3826), 1,
      aux_sym_hll_parameter_list_repeat1,
  [180811] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7627), 1,
      sym_identifier,
    ACTIONS(7629), 1,
      anon_sym_LPAREN,
    ACTIONS(7631), 1,
      anon_sym_LBRACE,
  [180824] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7633), 1,
      sym_identifier,
    ACTIONS(7635), 1,
      anon_sym_LPAREN,
    ACTIONS(7637), 1,
      anon_sym_LBRACE,
  [180837] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7639), 1,
      sym_identifier,
    ACTIONS(7641), 1,
      anon_sym_LPAREN,
    ACTIONS(7643), 1,
      anon_sym_LBRACE,
  [180850] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7645), 1,
      anon_sym_RPAREN,
    ACTIONS(7647), 1,
      sym__blank,
    STATE(3836), 1,
      aux_sym_block_repeat1,
  [180863] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7649), 1,
      sym_identifier,
    ACTIONS(7651), 1,
      anon_sym_LPAREN,
    ACTIONS(7653), 1,
      anon_sym_LBRACE,
  [180876] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7655), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [180889] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7657), 1,
      sym_identifier,
    ACTIONS(7659), 1,
      anon_sym_LPAREN,
    ACTIONS(7661), 1,
      anon_sym_LBRACE,
  [180902] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7159), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [180915] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7663), 1,
      sym_identifier,
    ACTIONS(7665), 1,
      anon_sym_LPAREN,
    ACTIONS(7667), 1,
      anon_sym_LBRACE,
  [180928] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7669), 1,
      sym_identifier,
    ACTIONS(7671), 1,
      anon_sym_LPAREN,
    ACTIONS(7673), 1,
      anon_sym_LBRACE,
  [180941] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7675), 1,
      sym_identifier,
    ACTIONS(7677), 1,
      anon_sym_LPAREN,
    ACTIONS(7679), 1,
      anon_sym_LBRACE,
  [180954] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7681), 1,
      sym_identifier,
    ACTIONS(7683), 1,
      anon_sym_LPAREN,
    ACTIONS(7685), 1,
      anon_sym_LBRACE,
  [180967] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN,
    ACTIONS(7691), 1,
      anon_sym_LBRACE,
  [180980] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7693), 1,
      sym_identifier,
    ACTIONS(7695), 1,
      anon_sym_LPAREN,
    ACTIONS(7697), 1,
      anon_sym_LBRACE,
  [180993] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7699), 1,
      sym_identifier,
    ACTIONS(7701), 1,
      anon_sym_LPAREN,
    ACTIONS(7703), 1,
      anon_sym_LBRACE,
  [181006] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7705), 1,
      sym_identifier,
    ACTIONS(7707), 1,
      anon_sym_LPAREN,
    ACTIONS(7709), 1,
      anon_sym_LBRACE,
  [181019] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7711), 1,
      sym_identifier,
    ACTIONS(7713), 1,
      anon_sym_LPAREN,
    ACTIONS(7715), 1,
      anon_sym_LBRACE,
  [181032] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7717), 1,
      sym_identifier,
    ACTIONS(7719), 1,
      anon_sym_LPAREN,
    ACTIONS(7721), 1,
      anon_sym_LBRACE,
  [181045] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN,
    ACTIONS(7727), 1,
      anon_sym_LBRACE,
  [181058] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7729), 1,
      sym_identifier,
    ACTIONS(7731), 1,
      anon_sym_LPAREN,
    ACTIONS(7733), 1,
      anon_sym_LBRACE,
  [181071] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7735), 1,
      sym_identifier,
    ACTIONS(7737), 1,
      anon_sym_LPAREN,
    ACTIONS(7739), 1,
      anon_sym_LBRACE,
  [181084] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7741), 1,
      sym_identifier,
    ACTIONS(7743), 1,
      anon_sym_LPAREN,
    ACTIONS(7745), 1,
      anon_sym_LBRACE,
  [181097] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7747), 1,
      sym_identifier,
    ACTIONS(7749), 1,
      anon_sym_LPAREN,
    ACTIONS(7751), 1,
      anon_sym_LBRACE,
  [181110] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7753), 1,
      sym_identifier,
    ACTIONS(7755), 1,
      anon_sym_LPAREN,
    ACTIONS(7757), 1,
      anon_sym_LBRACE,
  [181123] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7759), 1,
      sym_identifier,
    ACTIONS(7761), 1,
      anon_sym_LPAREN,
    ACTIONS(7763), 1,
      anon_sym_LBRACE,
  [181136] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7765), 1,
      sym_identifier,
    ACTIONS(7767), 1,
      anon_sym_LPAREN,
    ACTIONS(7769), 1,
      anon_sym_LBRACE,
  [181149] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7771), 1,
      sym_identifier,
    ACTIONS(7773), 1,
      anon_sym_LPAREN,
    ACTIONS(7775), 1,
      anon_sym_LBRACE,
  [181162] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7777), 1,
      sym_identifier,
    ACTIONS(7779), 1,
      anon_sym_LPAREN,
    ACTIONS(7781), 1,
      anon_sym_LBRACE,
  [181175] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7783), 1,
      sym_identifier,
    ACTIONS(7785), 1,
      anon_sym_LPAREN,
    ACTIONS(7787), 1,
      anon_sym_LBRACE,
  [181188] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7789), 1,
      sym_identifier,
    ACTIONS(7791), 1,
      anon_sym_LPAREN,
    ACTIONS(7793), 1,
      anon_sym_LBRACE,
  [181201] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7795), 1,
      sym_identifier,
    ACTIONS(7797), 1,
      anon_sym_LPAREN,
    ACTIONS(7799), 1,
      anon_sym_LBRACE,
  [181214] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7801), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181227] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7803), 1,
      anon_sym_LPAREN,
    ACTIONS(7805), 1,
      anon_sym_DOT,
    STATE(3892), 1,
      aux_sym__function_identifier_repeat1,
  [181240] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7807), 3,
      aux_sym__hll_var_definition_command_token1,
      sym_comment,
      sym__blank_line,
  [181249] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7811), 1,
      sym__blank,
    ACTIONS(7809), 2,
      sym_comment,
      sym__blank_line,
  [181260] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4591), 1,
      anon_sym_RPAREN,
    ACTIONS(4593), 1,
      sym__blank,
    STATE(3897), 1,
      aux_sym_block_repeat1,
  [181273] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7813), 1,
      anon_sym_RPAREN,
    ACTIONS(7815), 1,
      sym__blank,
    STATE(3917), 1,
      aux_sym_block_repeat1,
  [181286] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7817), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181299] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3555), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [181312] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7819), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181325] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7625), 1,
      anon_sym_COMMA,
    ACTIONS(7821), 1,
      anon_sym_RPAREN,
    STATE(3763), 1,
      aux_sym_hll_parameter_list_repeat1,
  [181338] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7823), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181351] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7825), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [181364] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7827), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181377] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6346), 3,
      anon_sym_DOT,
      anon_sym_COMMA,
      sym__blank,
  [181386] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7831), 1,
      sym__blank,
    ACTIONS(7829), 2,
      sym_comment,
      sym__blank_line,
  [181397] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7833), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181410] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7835), 1,
      sym_identifier,
    ACTIONS(7837), 1,
      anon_sym_LPAREN,
    ACTIONS(7839), 1,
      anon_sym_LBRACE,
  [181423] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4554), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181436] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7841), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181449] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7843), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181462] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7625), 1,
      anon_sym_COMMA,
    ACTIONS(7845), 1,
      anon_sym_RPAREN,
    STATE(3763), 1,
      aux_sym_hll_parameter_list_repeat1,
  [181475] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7847), 1,
      sym__blank,
    STATE(3557), 1,
      aux_sym_block_repeat1,
    STATE(3589), 1,
      aux_sym_macro_definition_repeat1,
  [181488] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4554), 1,
      anon_sym_RPAREN,
    ACTIONS(4556), 1,
      sym__blank,
    STATE(3866), 1,
      aux_sym_block_repeat1,
  [181501] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7849), 1,
      anon_sym_RPAREN,
    ACTIONS(7851), 1,
      sym__blank,
    STATE(3957), 1,
      aux_sym_block_repeat1,
  [181514] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7853), 1,
      anon_sym_RPAREN,
    ACTIONS(7855), 1,
      sym__blank,
    STATE(3868), 1,
      aux_sym_block_repeat1,
  [181527] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7857), 1,
      anon_sym_RPAREN,
    ACTIONS(7859), 1,
      sym__blank,
    STATE(3869), 1,
      aux_sym_block_repeat1,
  [181540] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7861), 1,
      anon_sym_SLASH,
    STATE(3843), 1,
      aux_sym__command_arguments_repeat2,
    STATE(4012), 1,
      sym_option_expression,
  [181553] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7864), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181566] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7866), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181579] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7868), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181592] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7870), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181605] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7872), 1,
      anon_sym_RPAREN,
    ACTIONS(7874), 1,
      sym__blank,
    STATE(3853), 1,
      aux_sym_block_repeat1,
  [181618] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7876), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181631] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7878), 1,
      anon_sym_RPAREN,
    ACTIONS(7880), 1,
      sym__blank,
    STATE(3855), 1,
      aux_sym_block_repeat1,
  [181644] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7882), 3,
      anon_sym_STAR,
      anon_sym_QMARK,
      sym_identifier,
  [181653] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7811), 1,
      sym__blank,
    ACTIONS(7884), 2,
      sym_comment,
      sym__blank_line,
  [181664] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7886), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181677] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1755), 1,
      aux_sym_block_token1,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181690] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7888), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181703] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7890), 1,
      anon_sym_RPAREN,
    ACTIONS(7892), 1,
      sym__blank,
    STATE(3857), 1,
      aux_sym_block_repeat1,
  [181716] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7894), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181729] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7896), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181742] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7898), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181755] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7811), 1,
      sym__blank,
    ACTIONS(7900), 2,
      sym_comment,
      sym__blank_line,
  [181766] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7902), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181779] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3527), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [181792] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7904), 1,
      anon_sym_RPAREN,
    ACTIONS(7906), 1,
      sym__blank,
    STATE(3928), 1,
      aux_sym_block_repeat1,
  [181805] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7908), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181818] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(3671), 1,
      sym_hll_option_expression,
    STATE(3883), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
  [181831] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7910), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181844] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7914), 1,
      sym__blank,
    ACTIONS(7912), 2,
      sym_comment,
      sym__blank_line,
  [181855] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7916), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181868] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7918), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181881] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7920), 1,
      anon_sym_RPAREN,
    ACTIONS(7922), 1,
      sym__blank,
    STATE(3874), 1,
      aux_sym_block_repeat1,
  [181894] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4641), 1,
      anon_sym_RPAREN,
    ACTIONS(4643), 1,
      sym__blank,
    STATE(3901), 1,
      aux_sym_block_repeat1,
  [181907] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4510), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [181920] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7924), 1,
      anon_sym_RPAREN,
    ACTIONS(7926), 1,
      sym__blank,
    STATE(3910), 1,
      aux_sym_block_repeat1,
  [181933] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7928), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [181946] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    STATE(3457), 1,
      sym_option_expression,
    STATE(3843), 1,
      aux_sym__command_arguments_repeat2,
  [181959] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7048), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [181972] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7930), 1,
      anon_sym_RPAREN,
    ACTIONS(7932), 1,
      sym__blank,
    STATE(3915), 1,
      aux_sym_block_repeat1,
  [181985] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7934), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [181998] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7936), 1,
      sym_identifier,
    ACTIONS(7938), 1,
      anon_sym_LPAREN,
    ACTIONS(7940), 1,
      anon_sym_LBRACE,
  [182011] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(6585), 1,
      anon_sym_SLASH,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182024] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7942), 1,
      anon_sym_SLASH,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182037] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7944), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182050] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7946), 1,
      anon_sym_SLASH,
    STATE(3883), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
    STATE(3984), 1,
      sym_hll_option_expression,
  [182063] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7949), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182076] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4329), 1,
      anon_sym_SLASH,
    STATE(3694), 1,
      sym_hll_option_expression,
    STATE(3883), 1,
      aux_sym__hll_var_command_argument_list_default_format_repeat3,
  [182089] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7210), 1,
      sym__blank,
    ACTIONS(7208), 2,
      sym_comment,
      sym__blank_line,
  [182100] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4599), 1,
      anon_sym_RPAREN,
    ACTIONS(4601), 1,
      sym__blank,
    STATE(3772), 1,
      aux_sym_block_repeat1,
  [182113] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7951), 1,
      anon_sym_RPAREN,
    ACTIONS(7953), 1,
      sym__blank,
    STATE(3931), 1,
      aux_sym_block_repeat1,
  [182126] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7955), 1,
      anon_sym_RPAREN,
    ACTIONS(7957), 1,
      sym__blank,
    STATE(3859), 1,
      aux_sym_block_repeat1,
  [182139] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7959), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182152] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7118), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182165] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7961), 1,
      anon_sym_LPAREN,
    ACTIONS(7963), 1,
      anon_sym_DOT,
    STATE(3892), 1,
      aux_sym__function_identifier_repeat1,
  [182178] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7968), 1,
      sym__blank,
    ACTIONS(7966), 2,
      sym_comment,
      sym__blank_line,
  [182189] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7970), 1,
      anon_sym_RPAREN,
    ACTIONS(7972), 1,
      sym__blank,
    STATE(3898), 1,
      aux_sym_block_repeat1,
  [182202] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7976), 1,
      sym__blank,
    ACTIONS(7974), 2,
      sym_comment,
      sym__blank_line,
  [182213] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7978), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182226] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7980), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182239] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7982), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182252] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7984), 1,
      anon_sym_RPAREN,
    ACTIONS(7986), 1,
      sym__blank,
    STATE(3902), 1,
      aux_sym_block_repeat1,
  [182265] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7988), 1,
      anon_sym_RPAREN,
    ACTIONS(7990), 1,
      sym__blank,
    STATE(3903), 1,
      aux_sym_block_repeat1,
  [182278] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7992), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182291] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7994), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182304] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7996), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182317] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7998), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182330] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8000), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182343] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8002), 1,
      anon_sym_RPAREN,
    ACTIONS(8004), 1,
      sym__blank,
    STATE(3907), 1,
      aux_sym_block_repeat1,
  [182356] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8006), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182369] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7258), 1,
      anon_sym_EQ,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182382] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8008), 1,
      sym_identifier,
    ACTIONS(8010), 1,
      anon_sym_LPAREN,
    ACTIONS(8012), 1,
      anon_sym_LBRACE,
  [182395] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8014), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182408] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4756), 1,
      anon_sym_RPAREN,
    ACTIONS(4758), 1,
      sym__blank,
    STATE(3951), 1,
      aux_sym_block_repeat1,
  [182421] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8016), 1,
      anon_sym_RPAREN,
    ACTIONS(8018), 1,
      sym__blank,
    STATE(3952), 1,
      aux_sym_block_repeat1,
  [182434] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7625), 1,
      anon_sym_COMMA,
    ACTIONS(8020), 1,
      anon_sym_RPAREN,
    STATE(3837), 1,
      aux_sym_hll_parameter_list_repeat1,
  [182447] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3593), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [182460] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8022), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182473] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2992), 1,
      sym__blank,
    ACTIONS(2994), 2,
      sym_comment,
      sym__blank_line,
  [182484] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8024), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182497] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8026), 1,
      anon_sym_RPAREN,
    ACTIONS(8028), 1,
      sym__blank,
    STATE(3941), 1,
      aux_sym_block_repeat1,
  [182510] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4749), 1,
      anon_sym_RPAREN,
    ACTIONS(8030), 1,
      anon_sym_COMMA,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182523] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    STATE(3559), 1,
      sym_option_expression,
    STATE(3843), 1,
      aux_sym__command_arguments_repeat2,
  [182536] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(7260), 1,
      anon_sym_COMMA,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182549] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4591), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182562] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(470), 1,
      anon_sym_SLASH,
    STATE(3452), 1,
      sym_option_expression,
    STATE(3843), 1,
      aux_sym__command_arguments_repeat2,
  [182575] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(4504), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182588] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8033), 1,
      sym_identifier,
    ACTIONS(8035), 1,
      anon_sym_LPAREN,
    ACTIONS(8037), 1,
      anon_sym_LBRACE,
  [182601] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8039), 1,
      aux_sym_if_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182614] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3488), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [182627] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8041), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182640] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8043), 1,
      anon_sym_RPAREN,
    ACTIONS(8045), 1,
      sym__blank,
    STATE(3769), 1,
      aux_sym_block_repeat1,
  [182653] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8047), 1,
      sym__blank,
    STATE(3492), 1,
      aux_sym_block_repeat1,
    STATE(3493), 1,
      aux_sym_macro_definition_repeat1,
  [182666] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8049), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182679] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8051), 1,
      sym_identifier,
    ACTIONS(8053), 1,
      anon_sym_LPAREN,
    ACTIONS(8055), 1,
      anon_sym_LBRACE,
  [182692] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6635), 1,
      sym__blank,
    ACTIONS(6633), 2,
      sym_comment,
      sym__blank_line,
  [182703] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8057), 1,
      sym_identifier,
    ACTIONS(8059), 1,
      anon_sym_LPAREN,
    ACTIONS(8061), 1,
      anon_sym_LBRACE,
  [182716] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8063), 1,
      anon_sym_COMMA,
    ACTIONS(8065), 1,
      sym__blank,
    STATE(1800), 1,
      aux_sym_block_repeat1,
  [182729] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5066), 1,
      anon_sym_EQ,
    ACTIONS(8067), 1,
      sym__blank,
    STATE(3770), 1,
      aux_sym_block_repeat1,
  [182742] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8069), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182755] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8071), 1,
      aux_sym__hll_var_definition_command_token1,
    ACTIONS(8073), 2,
      sym_comment,
      sym__blank_line,
  [182766] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7468), 1,
      sym__blank,
    STATE(3542), 1,
      aux_sym_macro_definition_repeat1,
    STATE(3606), 1,
      aux_sym_block_repeat1,
  [182779] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8075), 1,
      anon_sym_EQ,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182792] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8077), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182805] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8079), 1,
      sym_identifier,
    ACTIONS(8081), 1,
      anon_sym_LPAREN,
    ACTIONS(8083), 1,
      anon_sym_LBRACE,
  [182818] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2939), 1,
      sym__blank,
    ACTIONS(2941), 2,
      sym_comment,
      sym__blank_line,
  [182829] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8085), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182842] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(7004), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182855] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8087), 1,
      sym_identifier,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182868] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1924), 1,
      sym__blank,
    ACTIONS(1926), 2,
      sym_comment,
      sym__blank_line,
  [182879] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8089), 1,
      anon_sym_EQ,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182892] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8093), 1,
      sym__blank,
    ACTIONS(8091), 2,
      sym_comment,
      sym__blank_line,
  [182903] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8095), 1,
      anon_sym_RBRACK,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182916] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4544), 1,
      anon_sym_RPAREN,
    ACTIONS(5366), 1,
      sym__blank,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182929] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8097), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182942] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8099), 1,
      anon_sym_RPAREN,
    ACTIONS(8101), 1,
      sym__blank,
    STATE(3847), 1,
      aux_sym_block_repeat1,
  [182955] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8103), 1,
      aux_sym_if_block_token1,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [182968] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4492), 1,
      anon_sym_COMMA,
    ACTIONS(8105), 1,
      anon_sym_RPAREN,
    STATE(3919), 1,
      aux_sym_hll_argument_list_repeat1,
  [182981] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8107), 1,
      anon_sym_RPAREN,
    ACTIONS(8109), 1,
      sym__blank,
    STATE(3731), 1,
      aux_sym_block_repeat1,
  [182994] = 4,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5366), 1,
      sym__blank,
    ACTIONS(8111), 1,
      anon_sym_RPAREN,
    STATE(1946), 1,
      aux_sym_block_repeat1,
  [183007] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8113), 1,
      sym__blank,
    STATE(128), 1,
      aux_sym_block_repeat1,
  [183017] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8115), 1,
      sym__blank,
    STATE(807), 1,
      aux_sym_block_repeat1,
  [183027] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6330), 1,
      anon_sym_AMP,
    STATE(3060), 1,
      sym_macro,
  [183037] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2600), 2,
      sym_comment,
      sym__blank_line,
  [183045] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5944), 1,
      anon_sym_AMP,
    STATE(2920), 1,
      sym_macro,
  [183055] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8117), 1,
      sym_identifier,
    ACTIONS(8119), 1,
      anon_sym_LPAREN,
  [183065] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5607), 1,
      anon_sym_AMP,
    STATE(2973), 1,
      sym_macro,
  [183075] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6211), 1,
      anon_sym_AMP,
    STATE(3039), 1,
      sym_macro,
  [183085] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4920), 2,
      anon_sym_RPAREN,
      sym__blank,
  [183093] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6069), 1,
      anon_sym_AMP,
    STATE(2881), 1,
      sym_macro,
  [183103] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8121), 1,
      sym_identifier,
    STATE(1479), 1,
      sym__hll_field_identifier,
  [183113] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(5723), 1,
      anon_sym_AMP,
    STATE(3027), 1,
      sym_macro,
  [183123] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8123), 2,
      sym_comment,
      sym__blank_line,
  [183131] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6322), 1,
      anon_sym_AMP,
    STATE(3049), 1,
      sym_macro,
  [183141] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8125), 1,
      sym_identifier,
    STATE(1592), 1,
      sym__hll_field_identifier,
  [183151] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6865), 1,
      anon_sym_AMP,
    STATE(986), 1,
      sym_macro,
  [183161] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8127), 1,
      sym_identifier,
    ACTIONS(8129), 1,
      anon_sym_LPAREN,
  [183171] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6380), 1,
      anon_sym_AMP,
    STATE(1184), 1,
      sym_macro,
  [183181] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4768), 1,
      anon_sym_AMP,
    STATE(2486), 1,
      sym_macro,
  [183191] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6958), 1,
      anon_sym_AMP,
    STATE(1358), 1,
      sym_macro,
  [183201] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8131), 1,
      sym__blank,
    STATE(3616), 1,
      aux_sym_block_repeat1,
  [183211] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8133), 1,
      sym__blank,
    STATE(105), 1,
      aux_sym_block_repeat1,
  [183221] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8135), 1,
      sym__blank,
    STATE(3954), 1,
      aux_sym_block_repeat1,
  [183231] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8137), 2,
      sym_comment,
      sym__blank_line,
  [183239] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8139), 1,
      sym__blank,
    STATE(3657), 1,
      aux_sym_block_repeat1,
  [183249] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6976), 1,
      anon_sym_AMP,
    STATE(1012), 1,
      sym_macro,
  [183259] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8141), 1,
      sym__blank,
    STATE(3881), 1,
      aux_sym_block_repeat1,
  [183269] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8143), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [183277] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8145), 2,
      sym_comment,
      sym__blank_line,
  [183285] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8147), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8149), 1,
      sym_hll_escape_sequence,
  [183295] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8151), 1,
      anon_sym_LPAREN,
    STATE(2095), 1,
      sym_hll_var_call_expression_argument_list,
  [183305] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(698), 1,
      anon_sym_AMP,
    STATE(748), 1,
      sym_macro,
  [183315] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8153), 1,
      sym__blank,
    STATE(119), 1,
      aux_sym_block_repeat1,
  [183325] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8155), 2,
      sym_comment,
      sym__blank_line,
  [183333] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8157), 2,
      sym_comment,
      sym__blank_line,
  [183341] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6451), 1,
      anon_sym_AMP,
    STATE(450), 1,
      sym_macro,
  [183351] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(248), 1,
      anon_sym_LPAREN,
    STATE(555), 1,
      sym_argument_list,
  [183361] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8159), 1,
      sym__blank,
    STATE(2804), 1,
      aux_sym_block_repeat1,
  [183371] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8161), 1,
      anon_sym_LPAREN,
    STATE(556), 1,
      sym_hll_var_call_expression_argument_list,
  [183381] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8163), 1,
      sym__blank,
    STATE(117), 1,
      aux_sym_block_repeat1,
  [183391] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6924), 1,
      anon_sym_AMP,
    STATE(1376), 1,
      sym_macro,
  [183401] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 2,
      anon_sym_EQ,
      sym__blank,
  [183409] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8165), 1,
      sym_identifier,
    STATE(1759), 1,
      sym__hll_field_identifier,
  [183419] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8167), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8169), 1,
      anon_sym_AMP,
  [183429] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8171), 1,
      sym_comment,
    ACTIONS(8173), 1,
      sym__blank_line,
  [183439] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8175), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8177), 1,
      sym_hll_escape_sequence,
  [183449] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8179), 1,
      sym__blank,
    STATE(3271), 1,
      aux_sym_block_repeat1,
  [183459] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8181), 1,
      sym__blank,
    STATE(778), 1,
      aux_sym_block_repeat1,
  [183469] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8183), 1,
      sym__blank,
    STATE(428), 1,
      aux_sym_block_repeat1,
  [183479] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3807), 2,
      sym_comment,
      sym__blank_line,
  [183487] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8185), 2,
      sym_comment,
      sym__blank_line,
  [183495] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8187), 1,
      sym_comment,
    ACTIONS(8189), 1,
      sym__blank_line,
  [183505] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8191), 1,
      sym_comment,
    ACTIONS(8193), 1,
      sym__blank_line,
  [183515] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8195), 1,
      sym__blank,
    STATE(114), 1,
      aux_sym_block_repeat1,
  [183525] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8197), 1,
      sym__blank,
    STATE(3880), 1,
      aux_sym_block_repeat1,
  [183535] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8199), 2,
      sym_comment,
      sym__blank_line,
  [183543] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8201), 1,
      sym__blank,
    STATE(129), 1,
      aux_sym_block_repeat1,
  [183553] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8203), 1,
      sym__blank,
    STATE(2917), 1,
      aux_sym_block_repeat1,
  [183563] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8145), 2,
      sym_comment,
      sym__blank_line,
  [183571] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8205), 1,
      sym__blank,
    STATE(3367), 1,
      aux_sym_block_repeat1,
  [183581] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4589), 1,
      anon_sym_AMP,
    STATE(2516), 1,
      sym_macro,
  [183591] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8207), 1,
      sym__blank,
    STATE(34), 1,
      aux_sym_block_repeat1,
  [183601] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6896), 1,
      anon_sym_AMP,
    STATE(542), 1,
      sym_macro,
  [183611] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8210), 1,
      sym_identifier,
    STATE(1724), 1,
      sym__hll_field_identifier,
  [183621] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8212), 2,
      sym_comment,
      sym__blank_line,
  [183629] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8214), 1,
      sym__blank,
    STATE(3655), 1,
      aux_sym_block_repeat1,
  [183639] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8216), 1,
      sym__blank,
    STATE(3656), 1,
      aux_sym_block_repeat1,
  [183649] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8218), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [183657] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8220), 1,
      sym__blank,
    STATE(557), 1,
      aux_sym_block_repeat1,
  [183667] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8223), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8225), 1,
      sym_hll_escape_sequence,
  [183677] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8227), 1,
      sym__blank,
    STATE(3598), 1,
      aux_sym_block_repeat1,
  [183687] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8229), 2,
      sym_comment,
      sym__blank_line,
  [183695] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8231), 1,
      sym_comment,
    ACTIONS(8233), 1,
      sym__blank_line,
  [183705] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3778), 2,
      sym_comment,
      sym__blank_line,
  [183713] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2523), 2,
      sym_comment,
      sym__blank_line,
  [183721] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8235), 1,
      sym__blank,
    STATE(3817), 1,
      aux_sym_block_repeat1,
  [183731] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3811), 2,
      sym_comment,
      sym__blank_line,
  [183739] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8237), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8239), 1,
      sym_hll_escape_sequence,
  [183749] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6888), 1,
      anon_sym_AMP,
    STATE(638), 1,
      sym_macro,
  [183759] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4456), 2,
      sym_comment,
      sym__blank_line,
  [183767] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8241), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8243), 1,
      sym_hll_escape_sequence,
  [183777] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8245), 2,
      sym_comment,
      sym__blank_line,
  [183785] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6362), 1,
      anon_sym_AMP,
    STATE(1127), 1,
      sym_macro,
  [183795] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8247), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8249), 1,
      sym_hll_escape_sequence,
  [183805] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8251), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8253), 1,
      anon_sym_AMP,
  [183815] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8255), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8257), 1,
      sym_hll_escape_sequence,
  [183825] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8259), 1,
      sym__blank,
    STATE(2163), 1,
      aux_sym_block_repeat1,
  [183835] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8261), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8263), 1,
      sym_hll_escape_sequence,
  [183845] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3946), 1,
      anon_sym_AMP,
    STATE(1953), 1,
      sym_macro,
  [183855] = 3,
    ACTIONS(6463), 1,
      sym__line_continuation,
    ACTIONS(8265), 1,
      aux_sym_hll_char_literal_token1,
    ACTIONS(8267), 1,
      sym_hll_escape_sequence,
  [183865] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8269), 1,
      sym__blank,
    STATE(3658), 1,
      aux_sym_block_repeat1,
  [183875] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8271), 2,
      sym_comment,
      sym__blank_line,
  [183883] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4351), 1,
      anon_sym_AMP,
    STATE(1981), 1,
      sym_macro,
  [183893] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8273), 1,
      sym__blank,
    STATE(3946), 1,
      aux_sym_block_repeat1,
  [183903] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8275), 2,
      sym_comment,
      sym__blank_line,
  [183911] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6386), 1,
      anon_sym_AMP,
    STATE(775), 1,
      sym_macro,
  [183921] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4867), 1,
      anon_sym_AMP,
    STATE(333), 1,
      sym_macro,
  [183931] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8277), 1,
      sym__blank,
    STATE(124), 1,
      aux_sym_block_repeat1,
  [183941] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8279), 1,
      sym__blank,
    STATE(125), 1,
      aux_sym_block_repeat1,
  [183951] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8281), 1,
      sym__blank,
    STATE(817), 1,
      aux_sym_block_repeat1,
  [183961] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8283), 2,
      sym_comment,
      sym__blank_line,
  [183969] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8285), 1,
      sym__blank,
    STATE(818), 1,
      aux_sym_block_repeat1,
  [183979] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8287), 2,
      sym_comment,
      sym__blank_line,
  [183987] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8289), 2,
      sym_comment,
      sym__blank_line,
  [183995] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8291), 1,
      sym_comment,
    ACTIONS(8293), 1,
      sym__blank_line,
  [184005] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8295), 2,
      sym_comment,
      sym__blank_line,
  [184013] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8297), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8299), 1,
      anon_sym_AMP,
  [184023] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7560), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [184031] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8301), 2,
      sym_comment,
      sym__blank_line,
  [184039] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8303), 1,
      sym__blank,
    STATE(126), 1,
      aux_sym_block_repeat1,
  [184049] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8305), 1,
      sym__blank,
    STATE(127), 1,
      aux_sym_block_repeat1,
  [184059] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8307), 1,
      sym__blank,
    STATE(819), 1,
      aux_sym_block_repeat1,
  [184069] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8309), 1,
      sym__blank,
    STATE(3708), 1,
      aux_sym_block_repeat1,
  [184079] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8311), 1,
      sym__blank,
    STATE(820), 1,
      aux_sym_block_repeat1,
  [184089] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8313), 2,
      anon_sym_LPAREN,
      anon_sym_DOT,
  [184097] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8315), 1,
      sym__blank,
    STATE(2687), 1,
      aux_sym_block_repeat1,
  [184107] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6801), 1,
      anon_sym_AMP,
    STATE(913), 1,
      sym_macro,
  [184117] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8317), 2,
      sym_comment,
      sym__blank_line,
  [184125] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8319), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8321), 1,
      anon_sym_AMP,
  [184135] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 2,
      anon_sym_EQ,
      sym__blank,
  [184143] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8323), 1,
      sym__blank,
    STATE(3926), 1,
      aux_sym_block_repeat1,
  [184153] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4098), 1,
      anon_sym_AMP,
    STATE(1781), 1,
      sym_macro,
  [184163] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8199), 2,
      sym_comment,
      sym__blank_line,
  [184171] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(3928), 1,
      anon_sym_AMP,
    STATE(1930), 1,
      sym_macro,
  [184181] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8325), 1,
      sym__blank,
    STATE(3884), 1,
      aux_sym_block_repeat1,
  [184191] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8327), 1,
      sym__blank,
    STATE(742), 1,
      aux_sym_block_repeat1,
  [184201] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8329), 2,
      aux_sym_character_token1,
      aux_sym_character_token2,
  [184209] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4339), 1,
      anon_sym_AMP,
    STATE(1977), 1,
      sym_macro,
  [184219] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8331), 2,
      sym_comment,
      sym__blank_line,
  [184227] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8333), 1,
      sym__blank,
    STATE(2857), 1,
      aux_sym_block_repeat1,
  [184237] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8335), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__blank_line,
  [184247] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6838), 1,
      anon_sym_AMP,
    STATE(535), 1,
      sym_macro,
  [184257] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4777), 1,
      anon_sym_LPAREN,
    STATE(2164), 1,
      sym_argument_list,
  [184267] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6439), 1,
      anon_sym_AMP,
    STATE(661), 1,
      sym_macro,
  [184277] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4108), 1,
      anon_sym_AMP,
    STATE(1789), 1,
      sym_macro,
  [184287] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    STATE(805), 1,
      sym_macro,
  [184297] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8339), 1,
      sym__blank,
    STATE(3046), 1,
      aux_sym_block_repeat1,
  [184307] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4835), 1,
      anon_sym_LPAREN,
    STATE(2100), 1,
      sym_argument_list,
  [184317] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8341), 1,
      sym__blank,
    STATE(132), 1,
      aux_sym_block_repeat1,
  [184327] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8343), 1,
      sym__blank,
    STATE(827), 1,
      aux_sym_block_repeat1,
  [184337] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8345), 1,
      anon_sym_LPAREN,
    STATE(2115), 1,
      sym_hll_var_call_expression_argument_list,
  [184347] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8347), 1,
      sym__blank,
    STATE(96), 1,
      aux_sym_block_repeat1,
  [184357] = 3,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8349), 1,
      sym__blank,
    STATE(94), 1,
      aux_sym_block_repeat1,
  [184367] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8351), 2,
      sym_comment,
      sym__blank_line,
  [184375] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8353), 1,
      sym_identifier,
  [184382] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8355), 1,
      anon_sym_RPAREN,
  [184389] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8355), 1,
      anon_sym_RBRACE,
  [184396] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8357), 1,
      anon_sym_RBRACE,
  [184403] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8359), 1,
      anon_sym_RBRACE,
  [184410] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8361), 1,
      anon_sym_RBRACE,
  [184417] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8363), 1,
      sym__decimal_number,
  [184424] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8365), 1,
      sym_identifier,
  [184431] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8367), 1,
      anon_sym_SQUOTE,
  [184438] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8369), 1,
      anon_sym_SQUOTE,
  [184445] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8371), 1,
      anon_sym_RPAREN,
  [184452] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8373), 1,
      sym_identifier,
  [184459] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8371), 1,
      anon_sym_RBRACE,
  [184466] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8375), 1,
      anon_sym_RBRACE,
  [184473] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8377), 1,
      sym_identifier,
  [184480] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8379), 1,
      sym_identifier,
  [184487] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8381), 1,
      sym_hll_number_literal,
  [184494] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8383), 1,
      anon_sym_RPAREN,
  [184501] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8383), 1,
      anon_sym_RBRACE,
  [184508] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7912), 1,
      sym__blank,
  [184515] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8385), 1,
      sym__blank,
  [184522] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8387), 1,
      anon_sym_RPAREN,
  [184529] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8387), 1,
      anon_sym_RBRACE,
  [184536] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8389), 1,
      sym__blank,
  [184543] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4153), 1,
      sym_path,
  [184550] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8391), 1,
      anon_sym_SQUOTE,
  [184557] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8393), 1,
      anon_sym_RPAREN,
  [184564] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8393), 1,
      anon_sym_RBRACE,
  [184571] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8395), 1,
      sym_hll_number_literal,
  [184578] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8397), 1,
      anon_sym_DOT,
  [184585] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8399), 1,
      sym_identifier,
  [184592] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8401), 1,
      sym__line_specifier,
  [184599] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8403), 1,
      sym_identifier,
  [184606] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8405), 1,
      sym_identifier,
  [184613] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8407), 1,
      anon_sym_RBRACE,
  [184620] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8409), 1,
      anon_sym_RPAREN,
  [184627] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8411), 1,
      anon_sym_RPAREN,
  [184634] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8411), 1,
      anon_sym_RBRACE,
  [184641] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8413), 1,
      anon_sym_RBRACE,
  [184648] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8415), 1,
      anon_sym_RPAREN,
  [184655] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8417), 1,
      anon_sym_RPAREN,
  [184662] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8417), 1,
      anon_sym_RBRACE,
  [184669] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8419), 1,
      sym_identifier,
  [184676] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8421), 1,
      sym_identifier,
  [184683] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8415), 1,
      anon_sym_RBRACE,
  [184690] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8423), 1,
      anon_sym_RPAREN,
  [184697] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8425), 1,
      sym_identifier,
  [184704] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8427), 1,
      sym_identifier,
  [184711] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8429), 1,
      sym_hll_number_literal,
  [184718] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8431), 1,
      sym_identifier,
  [184725] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8433), 1,
      sym_identifier,
  [184732] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8435), 1,
      anon_sym_SQUOTE,
  [184739] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8437), 1,
      anon_sym_RPAREN,
  [184746] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8439), 1,
      anon_sym_RPAREN,
  [184753] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8439), 1,
      anon_sym_RBRACE,
  [184760] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8441), 1,
      sym_hll_number_literal,
  [184767] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8443), 1,
      sym_identifier,
  [184774] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8445), 1,
      sym_identifier,
  [184781] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8447), 1,
      anon_sym_RPAREN,
  [184788] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8449), 1,
      anon_sym_SQUOTE,
  [184795] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8451), 1,
      sym__blank,
  [184802] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8453), 1,
      sym_identifier,
  [184809] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8455), 1,
      sym_identifier,
  [184816] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8457), 1,
      sym_identifier,
  [184823] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8459), 1,
      anon_sym_RPAREN,
  [184830] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8461), 1,
      sym_hll_number_literal,
  [184837] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8463), 1,
      sym_identifier,
  [184844] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8465), 1,
      sym_identifier,
  [184851] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8467), 1,
      anon_sym_SQUOTE,
  [184858] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8469), 1,
      anon_sym_RPAREN,
  [184865] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8471), 1,
      sym_hll_number_literal,
  [184872] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8473), 1,
      sym_identifier,
  [184879] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8475), 1,
      sym_identifier,
  [184886] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8469), 1,
      anon_sym_RBRACE,
  [184893] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8459), 1,
      anon_sym_RBRACE,
  [184900] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8477), 1,
      sym_identifier,
  [184907] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8479), 1,
      sym_identifier,
  [184914] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8481), 1,
      sym__blank,
  [184921] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8483), 1,
      sym__decimal_number,
  [184928] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8485), 1,
      sym_identifier,
  [184935] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8487), 1,
      sym_identifier,
  [184942] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8489), 1,
      sym_identifier,
  [184949] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8491), 1,
      sym_identifier,
  [184956] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8493), 1,
      sym_identifier,
  [184963] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8495), 1,
      sym_hll_number_literal,
  [184970] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8497), 1,
      sym_identifier,
  [184977] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8499), 1,
      sym_identifier,
  [184984] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8501), 1,
      sym_identifier,
  [184991] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8503), 1,
      sym_identifier,
  [184998] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8505), 1,
      sym_identifier,
  [185005] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8507), 1,
      sym_identifier,
  [185012] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8509), 1,
      sym_identifier,
  [185019] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8511), 1,
      sym_identifier,
  [185026] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8513), 1,
      sym_identifier,
  [185033] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8515), 1,
      sym_identifier,
  [185040] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8517), 1,
      sym_identifier,
  [185047] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8519), 1,
      sym_identifier,
  [185054] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8521), 1,
      sym_identifier,
  [185061] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8523), 1,
      sym_identifier,
  [185068] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8525), 1,
      sym_identifier,
  [185075] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8527), 1,
      sym_identifier,
  [185082] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8529), 1,
      sym_identifier,
  [185089] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8531), 1,
      sym_identifier,
  [185096] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8533), 1,
      sym_identifier,
  [185103] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8535), 1,
      sym_identifier,
  [185110] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8537), 1,
      sym_identifier,
  [185117] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8539), 1,
      sym_identifier,
  [185124] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8541), 1,
      sym_identifier,
  [185131] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8543), 1,
      sym_identifier,
  [185138] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8545), 1,
      sym_identifier,
  [185145] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8547), 1,
      sym_identifier,
  [185152] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8549), 1,
      sym_identifier,
  [185159] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8551), 1,
      sym_identifier,
  [185166] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8553), 1,
      sym_identifier,
  [185173] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8555), 1,
      sym_identifier,
  [185180] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8557), 1,
      sym_identifier,
  [185187] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8559), 1,
      sym_identifier,
  [185194] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8561), 1,
      sym_identifier,
  [185201] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8563), 1,
      sym_identifier,
  [185208] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8565), 1,
      sym_identifier,
  [185215] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8567), 1,
      sym_identifier,
  [185222] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8569), 1,
      sym_identifier,
  [185229] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8571), 1,
      sym_identifier,
  [185236] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1926), 1,
      sym_path,
  [185243] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8359), 1,
      anon_sym_RPAREN,
  [185250] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8573), 1,
      sym_identifier,
  [185257] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8575), 1,
      sym_identifier,
  [185264] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8577), 1,
      sym_identifier,
  [185271] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8579), 1,
      sym_identifier,
  [185278] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8581), 1,
      sym_identifier,
  [185285] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8583), 1,
      sym_identifier,
  [185292] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8585), 1,
      sym_identifier,
  [185299] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8587), 1,
      sym_identifier,
  [185306] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8589), 1,
      sym_identifier,
  [185313] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8591), 1,
      sym_identifier,
  [185320] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8593), 1,
      sym_identifier,
  [185327] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8595), 1,
      sym_identifier,
  [185334] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8597), 1,
      sym_identifier,
  [185341] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8599), 1,
      sym_identifier,
  [185348] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8601), 1,
      anon_sym_RPAREN,
  [185355] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8601), 1,
      anon_sym_RBRACE,
  [185362] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8603), 1,
      anon_sym_RPAREN,
  [185369] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8605), 1,
      sym_identifier,
  [185376] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8603), 1,
      anon_sym_RBRACE,
  [185383] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8607), 1,
      sym_identifier,
  [185390] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8609), 1,
      ts_builtin_sym_end,
  [185397] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8611), 1,
      anon_sym_RPAREN,
  [185404] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8613), 1,
      sym_identifier,
  [185411] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8423), 1,
      anon_sym_RBRACE,
  [185418] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8615), 1,
      anon_sym_RPAREN,
  [185425] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8611), 1,
      anon_sym_RBRACE,
  [185432] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8091), 1,
      sym__blank,
  [185439] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7974), 1,
      sym__blank,
  [185446] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(7966), 1,
      sym__blank,
  [185453] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8617), 1,
      anon_sym_SQUOTE,
  [185460] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8615), 1,
      anon_sym_RBRACE,
  [185467] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8619), 1,
      anon_sym_SQUOTE,
  [185474] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8621), 1,
      anon_sym_RPAREN,
  [185481] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8623), 1,
      anon_sym_RPAREN,
  [185488] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4560), 1,
      anon_sym_RBRACK,
  [185495] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8625), 1,
      anon_sym_SQUOTE,
  [185502] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8627), 1,
      sym__blank,
  [185509] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8629), 1,
      anon_sym_RPAREN,
  [185516] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8629), 1,
      anon_sym_RBRACE,
  [185523] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8631), 1,
      sym__decimal_number,
  [185530] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8633), 1,
      sym_identifier,
  [185537] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8635), 1,
      anon_sym_RPAREN,
  [185544] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8635), 1,
      anon_sym_RBRACE,
  [185551] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8637), 1,
      anon_sym_RPAREN,
  [185558] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8639), 1,
      sym_hll_number_literal,
  [185565] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8623), 1,
      anon_sym_RBRACE,
  [185572] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8641), 1,
      sym_hll_number_literal,
  [185579] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8643), 1,
      anon_sym_COLON,
  [185586] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8645), 1,
      sym_hll_number_literal,
  [185593] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8621), 1,
      anon_sym_RBRACE,
  [185600] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8647), 1,
      anon_sym_RPAREN,
  [185607] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8647), 1,
      anon_sym_RBRACE,
  [185614] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8649), 1,
      anon_sym_RPAREN,
  [185621] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8651), 1,
      anon_sym_SQUOTE,
  [185628] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8649), 1,
      anon_sym_RBRACE,
  [185635] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1930), 1,
      sym_path,
  [185642] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8653), 1,
      anon_sym_RPAREN,
  [185649] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8655), 1,
      anon_sym_RPAREN,
  [185656] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8653), 1,
      anon_sym_RBRACE,
  [185663] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8655), 1,
      anon_sym_RBRACE,
  [185670] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8657), 1,
      sym_identifier,
  [185677] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(1985), 1,
      sym_path,
  [185684] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4658), 1,
      anon_sym_RBRACK,
  [185691] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8659), 1,
      anon_sym_RPAREN,
  [185698] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8659), 1,
      anon_sym_RBRACE,
  [185705] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4639), 1,
      anon_sym_RBRACK,
  [185712] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8661), 1,
      anon_sym_LPAREN,
  [185719] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8663), 1,
      anon_sym_SQUOTE,
  [185726] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8665), 1,
      anon_sym_RPAREN,
  [185733] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8667), 1,
      anon_sym_RPAREN,
  [185740] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8667), 1,
      anon_sym_RBRACE,
  [185747] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8669), 1,
      anon_sym_DOT,
  [185754] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8671), 1,
      sym_identifier,
  [185761] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8673), 1,
      sym_identifier,
  [185768] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8665), 1,
      anon_sym_RBRACE,
  [185775] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8675), 1,
      sym__line_specifier,
  [185782] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8677), 1,
      sym__decimal_number,
  [185789] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8679), 1,
      anon_sym_RPAREN,
  [185796] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8681), 1,
      anon_sym_RPAREN,
  [185803] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8407), 1,
      anon_sym_RPAREN,
  [185810] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8681), 1,
      anon_sym_RBRACE,
  [185817] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8679), 1,
      anon_sym_RBRACE,
  [185824] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(4775), 1,
      anon_sym_RBRACK,
  [185831] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8683), 1,
      anon_sym_RPAREN,
  [185838] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8685), 1,
      anon_sym_RPAREN,
  [185845] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8685), 1,
      anon_sym_RBRACE,
  [185852] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8687), 1,
      sym_identifier,
  [185859] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8683), 1,
      anon_sym_RBRACE,
  [185866] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8689), 1,
      anon_sym_RPAREN,
  [185873] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8691), 1,
      anon_sym_RPAREN,
  [185880] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8691), 1,
      anon_sym_RBRACE,
  [185887] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8689), 1,
      anon_sym_RBRACE,
  [185894] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8413), 1,
      anon_sym_RPAREN,
  [185901] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(2164), 1,
      sym_path,
  [185908] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8693), 1,
      anon_sym_RPAREN,
  [185915] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8693), 1,
      anon_sym_RBRACE,
  [185922] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8375), 1,
      anon_sym_RPAREN,
  [185929] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8695), 1,
      sym_hll_number_literal,
  [185936] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8697), 1,
      anon_sym_SQUOTE,
  [185943] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8361), 1,
      anon_sym_RPAREN,
  [185950] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8357), 1,
      anon_sym_RPAREN,
  [185957] = 2,
    ACTIONS(3), 1,
      sym__line_continuation,
    ACTIONS(8699), 1,
      sym_identifier,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(257)] = 0,
  [SMALL_STATE(258)] = 147,
  [SMALL_STATE(259)] = 294,
  [SMALL_STATE(260)] = 441,
  [SMALL_STATE(261)] = 588,
  [SMALL_STATE(262)] = 735,
  [SMALL_STATE(263)] = 882,
  [SMALL_STATE(264)] = 1029,
  [SMALL_STATE(265)] = 1175,
  [SMALL_STATE(266)] = 1321,
  [SMALL_STATE(267)] = 1467,
  [SMALL_STATE(268)] = 1613,
  [SMALL_STATE(269)] = 1759,
  [SMALL_STATE(270)] = 1905,
  [SMALL_STATE(271)] = 2051,
  [SMALL_STATE(272)] = 2197,
  [SMALL_STATE(273)] = 2343,
  [SMALL_STATE(274)] = 2489,
  [SMALL_STATE(275)] = 2635,
  [SMALL_STATE(276)] = 2781,
  [SMALL_STATE(277)] = 2927,
  [SMALL_STATE(278)] = 3073,
  [SMALL_STATE(279)] = 3219,
  [SMALL_STATE(280)] = 3365,
  [SMALL_STATE(281)] = 3511,
  [SMALL_STATE(282)] = 3657,
  [SMALL_STATE(283)] = 3803,
  [SMALL_STATE(284)] = 3949,
  [SMALL_STATE(285)] = 4095,
  [SMALL_STATE(286)] = 4241,
  [SMALL_STATE(287)] = 4387,
  [SMALL_STATE(288)] = 4533,
  [SMALL_STATE(289)] = 4679,
  [SMALL_STATE(290)] = 4825,
  [SMALL_STATE(291)] = 4971,
  [SMALL_STATE(292)] = 5117,
  [SMALL_STATE(293)] = 5263,
  [SMALL_STATE(294)] = 5409,
  [SMALL_STATE(295)] = 5555,
  [SMALL_STATE(296)] = 5701,
  [SMALL_STATE(297)] = 5847,
  [SMALL_STATE(298)] = 5993,
  [SMALL_STATE(299)] = 6139,
  [SMALL_STATE(300)] = 6285,
  [SMALL_STATE(301)] = 6431,
  [SMALL_STATE(302)] = 6577,
  [SMALL_STATE(303)] = 6723,
  [SMALL_STATE(304)] = 6869,
  [SMALL_STATE(305)] = 7015,
  [SMALL_STATE(306)] = 7161,
  [SMALL_STATE(307)] = 7307,
  [SMALL_STATE(308)] = 7453,
  [SMALL_STATE(309)] = 7543,
  [SMALL_STATE(310)] = 7633,
  [SMALL_STATE(311)] = 7723,
  [SMALL_STATE(312)] = 7813,
  [SMALL_STATE(313)] = 7903,
  [SMALL_STATE(314)] = 8044,
  [SMALL_STATE(315)] = 8185,
  [SMALL_STATE(316)] = 8326,
  [SMALL_STATE(317)] = 8467,
  [SMALL_STATE(318)] = 8555,
  [SMALL_STATE(319)] = 8695,
  [SMALL_STATE(320)] = 8835,
  [SMALL_STATE(321)] = 8923,
  [SMALL_STATE(322)] = 9011,
  [SMALL_STATE(323)] = 9099,
  [SMALL_STATE(324)] = 9239,
  [SMALL_STATE(325)] = 9327,
  [SMALL_STATE(326)] = 9464,
  [SMALL_STATE(327)] = 9551,
  [SMALL_STATE(328)] = 9638,
  [SMALL_STATE(329)] = 9725,
  [SMALL_STATE(330)] = 9862,
  [SMALL_STATE(331)] = 9949,
  [SMALL_STATE(332)] = 10036,
  [SMALL_STATE(333)] = 10173,
  [SMALL_STATE(334)] = 10240,
  [SMALL_STATE(335)] = 10377,
  [SMALL_STATE(336)] = 10440,
  [SMALL_STATE(337)] = 10577,
  [SMALL_STATE(338)] = 10714,
  [SMALL_STATE(339)] = 10777,
  [SMALL_STATE(340)] = 10844,
  [SMALL_STATE(341)] = 10981,
  [SMALL_STATE(342)] = 11118,
  [SMALL_STATE(343)] = 11196,
  [SMALL_STATE(344)] = 11274,
  [SMALL_STATE(345)] = 11408,
  [SMALL_STATE(346)] = 11542,
  [SMALL_STATE(347)] = 11602,
  [SMALL_STATE(348)] = 11736,
  [SMALL_STATE(349)] = 11796,
  [SMALL_STATE(350)] = 11930,
  [SMALL_STATE(351)] = 12015,
  [SMALL_STATE(352)] = 12118,
  [SMALL_STATE(353)] = 12221,
  [SMALL_STATE(354)] = 12324,
  [SMALL_STATE(355)] = 12399,
  [SMALL_STATE(356)] = 12458,
  [SMALL_STATE(357)] = 12543,
  [SMALL_STATE(358)] = 12646,
  [SMALL_STATE(359)] = 12749,
  [SMALL_STATE(360)] = 12852,
  [SMALL_STATE(361)] = 12955,
  [SMALL_STATE(362)] = 13060,
  [SMALL_STATE(363)] = 13145,
  [SMALL_STATE(364)] = 13230,
  [SMALL_STATE(365)] = 13315,
  [SMALL_STATE(366)] = 13400,
  [SMALL_STATE(367)] = 13503,
  [SMALL_STATE(368)] = 13606,
  [SMALL_STATE(369)] = 13679,
  [SMALL_STATE(370)] = 13764,
  [SMALL_STATE(371)] = 13849,
  [SMALL_STATE(372)] = 13934,
  [SMALL_STATE(373)] = 14019,
  [SMALL_STATE(374)] = 14092,
  [SMALL_STATE(375)] = 14163,
  [SMALL_STATE(376)] = 14266,
  [SMALL_STATE(377)] = 14369,
  [SMALL_STATE(378)] = 14472,
  [SMALL_STATE(379)] = 14547,
  [SMALL_STATE(380)] = 14623,
  [SMALL_STATE(381)] = 14695,
  [SMALL_STATE(382)] = 14765,
  [SMALL_STATE(383)] = 14835,
  [SMALL_STATE(384)] = 14905,
  [SMALL_STATE(385)] = 14975,
  [SMALL_STATE(386)] = 15045,
  [SMALL_STATE(387)] = 15147,
  [SMALL_STATE(388)] = 15217,
  [SMALL_STATE(389)] = 15289,
  [SMALL_STATE(390)] = 15359,
  [SMALL_STATE(391)] = 15429,
  [SMALL_STATE(392)] = 15501,
  [SMALL_STATE(393)] = 15571,
  [SMALL_STATE(394)] = 15643,
  [SMALL_STATE(395)] = 15715,
  [SMALL_STATE(396)] = 15785,
  [SMALL_STATE(397)] = 15855,
  [SMALL_STATE(398)] = 15925,
  [SMALL_STATE(399)] = 15997,
  [SMALL_STATE(400)] = 16067,
  [SMALL_STATE(401)] = 16137,
  [SMALL_STATE(402)] = 16209,
  [SMALL_STATE(403)] = 16279,
  [SMALL_STATE(404)] = 16349,
  [SMALL_STATE(405)] = 16419,
  [SMALL_STATE(406)] = 16491,
  [SMALL_STATE(407)] = 16561,
  [SMALL_STATE(408)] = 16631,
  [SMALL_STATE(409)] = 16703,
  [SMALL_STATE(410)] = 16773,
  [SMALL_STATE(411)] = 16843,
  [SMALL_STATE(412)] = 16913,
  [SMALL_STATE(413)] = 17015,
  [SMALL_STATE(414)] = 17117,
  [SMALL_STATE(415)] = 17189,
  [SMALL_STATE(416)] = 17265,
  [SMALL_STATE(417)] = 17335,
  [SMALL_STATE(418)] = 17405,
  [SMALL_STATE(419)] = 17475,
  [SMALL_STATE(420)] = 17577,
  [SMALL_STATE(421)] = 17649,
  [SMALL_STATE(422)] = 17719,
  [SMALL_STATE(423)] = 17791,
  [SMALL_STATE(424)] = 17893,
  [SMALL_STATE(425)] = 17965,
  [SMALL_STATE(426)] = 18035,
  [SMALL_STATE(427)] = 18137,
  [SMALL_STATE(428)] = 18207,
  [SMALL_STATE(429)] = 18309,
  [SMALL_STATE(430)] = 18411,
  [SMALL_STATE(431)] = 18513,
  [SMALL_STATE(432)] = 18583,
  [SMALL_STATE(433)] = 18685,
  [SMALL_STATE(434)] = 18787,
  [SMALL_STATE(435)] = 18859,
  [SMALL_STATE(436)] = 18931,
  [SMALL_STATE(437)] = 19001,
  [SMALL_STATE(438)] = 19071,
  [SMALL_STATE(439)] = 19141,
  [SMALL_STATE(440)] = 19243,
  [SMALL_STATE(441)] = 19345,
  [SMALL_STATE(442)] = 19415,
  [SMALL_STATE(443)] = 19487,
  [SMALL_STATE(444)] = 19559,
  [SMALL_STATE(445)] = 19624,
  [SMALL_STATE(446)] = 19687,
  [SMALL_STATE(447)] = 19756,
  [SMALL_STATE(448)] = 19819,
  [SMALL_STATE(449)] = 19882,
  [SMALL_STATE(450)] = 19939,
  [SMALL_STATE(451)] = 20002,
  [SMALL_STATE(452)] = 20061,
  [SMALL_STATE(453)] = 20120,
  [SMALL_STATE(454)] = 20195,
  [SMALL_STATE(455)] = 20268,
  [SMALL_STATE(456)] = 20325,
  [SMALL_STATE(457)] = 20396,
  [SMALL_STATE(458)] = 20471,
  [SMALL_STATE(459)] = 20542,
  [SMALL_STATE(460)] = 20611,
  [SMALL_STATE(461)] = 20676,
  [SMALL_STATE(462)] = 20741,
  [SMALL_STATE(463)] = 20808,
  [SMALL_STATE(464)] = 20876,
  [SMALL_STATE(465)] = 20944,
  [SMALL_STATE(466)] = 21006,
  [SMALL_STATE(467)] = 21068,
  [SMALL_STATE(468)] = 21132,
  [SMALL_STATE(469)] = 21194,
  [SMALL_STATE(470)] = 21262,
  [SMALL_STATE(471)] = 21330,
  [SMALL_STATE(472)] = 21400,
  [SMALL_STATE(473)] = 21462,
  [SMALL_STATE(474)] = 21530,
  [SMALL_STATE(475)] = 21600,
  [SMALL_STATE(476)] = 21670,
  [SMALL_STATE(477)] = 21738,
  [SMALL_STATE(478)] = 21800,
  [SMALL_STATE(479)] = 21862,
  [SMALL_STATE(480)] = 21930,
  [SMALL_STATE(481)] = 21992,
  [SMALL_STATE(482)] = 22054,
  [SMALL_STATE(483)] = 22122,
  [SMALL_STATE(484)] = 22192,
  [SMALL_STATE(485)] = 22262,
  [SMALL_STATE(486)] = 22330,
  [SMALL_STATE(487)] = 22398,
  [SMALL_STATE(488)] = 22466,
  [SMALL_STATE(489)] = 22534,
  [SMALL_STATE(490)] = 22604,
  [SMALL_STATE(491)] = 22674,
  [SMALL_STATE(492)] = 22744,
  [SMALL_STATE(493)] = 22812,
  [SMALL_STATE(494)] = 22868,
  [SMALL_STATE(495)] = 22936,
  [SMALL_STATE(496)] = 23004,
  [SMALL_STATE(497)] = 23072,
  [SMALL_STATE(498)] = 23140,
  [SMALL_STATE(499)] = 23208,
  [SMALL_STATE(500)] = 23278,
  [SMALL_STATE(501)] = 23346,
  [SMALL_STATE(502)] = 23414,
  [SMALL_STATE(503)] = 23484,
  [SMALL_STATE(504)] = 23546,
  [SMALL_STATE(505)] = 23608,
  [SMALL_STATE(506)] = 23678,
  [SMALL_STATE(507)] = 23746,
  [SMALL_STATE(508)] = 23814,
  [SMALL_STATE(509)] = 23882,
  [SMALL_STATE(510)] = 23952,
  [SMALL_STATE(511)] = 24020,
  [SMALL_STATE(512)] = 24088,
  [SMALL_STATE(513)] = 24158,
  [SMALL_STATE(514)] = 24226,
  [SMALL_STATE(515)] = 24294,
  [SMALL_STATE(516)] = 24362,
  [SMALL_STATE(517)] = 24432,
  [SMALL_STATE(518)] = 24500,
  [SMALL_STATE(519)] = 24568,
  [SMALL_STATE(520)] = 24638,
  [SMALL_STATE(521)] = 24706,
  [SMALL_STATE(522)] = 24774,
  [SMALL_STATE(523)] = 24836,
  [SMALL_STATE(524)] = 24900,
  [SMALL_STATE(525)] = 24956,
  [SMALL_STATE(526)] = 25054,
  [SMALL_STATE(527)] = 25118,
  [SMALL_STATE(528)] = 25180,
  [SMALL_STATE(529)] = 25242,
  [SMALL_STATE(530)] = 25304,
  [SMALL_STATE(531)] = 25360,
  [SMALL_STATE(532)] = 25416,
  [SMALL_STATE(533)] = 25474,
  [SMALL_STATE(534)] = 25540,
  [SMALL_STATE(535)] = 25602,
  [SMALL_STATE(536)] = 25664,
  [SMALL_STATE(537)] = 25728,
  [SMALL_STATE(538)] = 25788,
  [SMALL_STATE(539)] = 25850,
  [SMALL_STATE(540)] = 25920,
  [SMALL_STATE(541)] = 25982,
  [SMALL_STATE(542)] = 26044,
  [SMALL_STATE(543)] = 26106,
  [SMALL_STATE(544)] = 26168,
  [SMALL_STATE(545)] = 26230,
  [SMALL_STATE(546)] = 26288,
  [SMALL_STATE(547)] = 26346,
  [SMALL_STATE(548)] = 26408,
  [SMALL_STATE(549)] = 26470,
  [SMALL_STATE(550)] = 26544,
  [SMALL_STATE(551)] = 26606,
  [SMALL_STATE(552)] = 26668,
  [SMALL_STATE(553)] = 26730,
  [SMALL_STATE(554)] = 26792,
  [SMALL_STATE(555)] = 26854,
  [SMALL_STATE(556)] = 26910,
  [SMALL_STATE(557)] = 26966,
  [SMALL_STATE(558)] = 27064,
  [SMALL_STATE(559)] = 27136,
  [SMALL_STATE(560)] = 27206,
  [SMALL_STATE(561)] = 27302,
  [SMALL_STATE(562)] = 27376,
  [SMALL_STATE(563)] = 27438,
  [SMALL_STATE(564)] = 27534,
  [SMALL_STATE(565)] = 27596,
  [SMALL_STATE(566)] = 27658,
  [SMALL_STATE(567)] = 27728,
  [SMALL_STATE(568)] = 27790,
  [SMALL_STATE(569)] = 27868,
  [SMALL_STATE(570)] = 27930,
  [SMALL_STATE(571)] = 27992,
  [SMALL_STATE(572)] = 28054,
  [SMALL_STATE(573)] = 28150,
  [SMALL_STATE(574)] = 28206,
  [SMALL_STATE(575)] = 28304,
  [SMALL_STATE(576)] = 28360,
  [SMALL_STATE(577)] = 28422,
  [SMALL_STATE(578)] = 28484,
  [SMALL_STATE(579)] = 28546,
  [SMALL_STATE(580)] = 28608,
  [SMALL_STATE(581)] = 28670,
  [SMALL_STATE(582)] = 28732,
  [SMALL_STATE(583)] = 28788,
  [SMALL_STATE(584)] = 28844,
  [SMALL_STATE(585)] = 28906,
  [SMALL_STATE(586)] = 28962,
  [SMALL_STATE(587)] = 29022,
  [SMALL_STATE(588)] = 29082,
  [SMALL_STATE(589)] = 29144,
  [SMALL_STATE(590)] = 29206,
  [SMALL_STATE(591)] = 29268,
  [SMALL_STATE(592)] = 29328,
  [SMALL_STATE(593)] = 29390,
  [SMALL_STATE(594)] = 29452,
  [SMALL_STATE(595)] = 29514,
  [SMALL_STATE(596)] = 29576,
  [SMALL_STATE(597)] = 29638,
  [SMALL_STATE(598)] = 29700,
  [SMALL_STATE(599)] = 29762,
  [SMALL_STATE(600)] = 29818,
  [SMALL_STATE(601)] = 29880,
  [SMALL_STATE(602)] = 29950,
  [SMALL_STATE(603)] = 30018,
  [SMALL_STATE(604)] = 30080,
  [SMALL_STATE(605)] = 30142,
  [SMALL_STATE(606)] = 30202,
  [SMALL_STATE(607)] = 30295,
  [SMALL_STATE(608)] = 30354,
  [SMALL_STATE(609)] = 30423,
  [SMALL_STATE(610)] = 30490,
  [SMALL_STATE(611)] = 30559,
  [SMALL_STATE(612)] = 30626,
  [SMALL_STATE(613)] = 30719,
  [SMALL_STATE(614)] = 30812,
  [SMALL_STATE(615)] = 30879,
  [SMALL_STATE(616)] = 30946,
  [SMALL_STATE(617)] = 31015,
  [SMALL_STATE(618)] = 31082,
  [SMALL_STATE(619)] = 31151,
  [SMALL_STATE(620)] = 31220,
  [SMALL_STATE(621)] = 31287,
  [SMALL_STATE(622)] = 31354,
  [SMALL_STATE(623)] = 31421,
  [SMALL_STATE(624)] = 31490,
  [SMALL_STATE(625)] = 31559,
  [SMALL_STATE(626)] = 31626,
  [SMALL_STATE(627)] = 31693,
  [SMALL_STATE(628)] = 31760,
  [SMALL_STATE(629)] = 31827,
  [SMALL_STATE(630)] = 31896,
  [SMALL_STATE(631)] = 31989,
  [SMALL_STATE(632)] = 32082,
  [SMALL_STATE(633)] = 32151,
  [SMALL_STATE(634)] = 32220,
  [SMALL_STATE(635)] = 32287,
  [SMALL_STATE(636)] = 32380,
  [SMALL_STATE(637)] = 32447,
  [SMALL_STATE(638)] = 32514,
  [SMALL_STATE(639)] = 32575,
  [SMALL_STATE(640)] = 32642,
  [SMALL_STATE(641)] = 32709,
  [SMALL_STATE(642)] = 32802,
  [SMALL_STATE(643)] = 32869,
  [SMALL_STATE(644)] = 32938,
  [SMALL_STATE(645)] = 33011,
  [SMALL_STATE(646)] = 33078,
  [SMALL_STATE(647)] = 33145,
  [SMALL_STATE(648)] = 33214,
  [SMALL_STATE(649)] = 33287,
  [SMALL_STATE(650)] = 33354,
  [SMALL_STATE(651)] = 33413,
  [SMALL_STATE(652)] = 33506,
  [SMALL_STATE(653)] = 33575,
  [SMALL_STATE(654)] = 33642,
  [SMALL_STATE(655)] = 33701,
  [SMALL_STATE(656)] = 33760,
  [SMALL_STATE(657)] = 33827,
  [SMALL_STATE(658)] = 33894,
  [SMALL_STATE(659)] = 33957,
  [SMALL_STATE(660)] = 34018,
  [SMALL_STATE(661)] = 34079,
  [SMALL_STATE(662)] = 34140,
  [SMALL_STATE(663)] = 34201,
  [SMALL_STATE(664)] = 34270,
  [SMALL_STATE(665)] = 34337,
  [SMALL_STATE(666)] = 34404,
  [SMALL_STATE(667)] = 34473,
  [SMALL_STATE(668)] = 34528,
  [SMALL_STATE(669)] = 34587,
  [SMALL_STATE(670)] = 34642,
  [SMALL_STATE(671)] = 34701,
  [SMALL_STATE(672)] = 34768,
  [SMALL_STATE(673)] = 34829,
  [SMALL_STATE(674)] = 34896,
  [SMALL_STATE(675)] = 34951,
  [SMALL_STATE(676)] = 35018,
  [SMALL_STATE(677)] = 35087,
  [SMALL_STATE(678)] = 35154,
  [SMALL_STATE(679)] = 35221,
  [SMALL_STATE(680)] = 35290,
  [SMALL_STATE(681)] = 35355,
  [SMALL_STATE(682)] = 35422,
  [SMALL_STATE(683)] = 35485,
  [SMALL_STATE(684)] = 35552,
  [SMALL_STATE(685)] = 35607,
  [SMALL_STATE(686)] = 35700,
  [SMALL_STATE(687)] = 35793,
  [SMALL_STATE(688)] = 35886,
  [SMALL_STATE(689)] = 35979,
  [SMALL_STATE(690)] = 36034,
  [SMALL_STATE(691)] = 36127,
  [SMALL_STATE(692)] = 36220,
  [SMALL_STATE(693)] = 36313,
  [SMALL_STATE(694)] = 36406,
  [SMALL_STATE(695)] = 36473,
  [SMALL_STATE(696)] = 36532,
  [SMALL_STATE(697)] = 36593,
  [SMALL_STATE(698)] = 36648,
  [SMALL_STATE(699)] = 36721,
  [SMALL_STATE(700)] = 36780,
  [SMALL_STATE(701)] = 36873,
  [SMALL_STATE(702)] = 36966,
  [SMALL_STATE(703)] = 37057,
  [SMALL_STATE(704)] = 37150,
  [SMALL_STATE(705)] = 37243,
  [SMALL_STATE(706)] = 37314,
  [SMALL_STATE(707)] = 37373,
  [SMALL_STATE(708)] = 37466,
  [SMALL_STATE(709)] = 37549,
  [SMALL_STATE(710)] = 37634,
  [SMALL_STATE(711)] = 37701,
  [SMALL_STATE(712)] = 37782,
  [SMALL_STATE(713)] = 37861,
  [SMALL_STATE(714)] = 37934,
  [SMALL_STATE(715)] = 37999,
  [SMALL_STATE(716)] = 38092,
  [SMALL_STATE(717)] = 38185,
  [SMALL_STATE(718)] = 38278,
  [SMALL_STATE(719)] = 38371,
  [SMALL_STATE(720)] = 38436,
  [SMALL_STATE(721)] = 38529,
  [SMALL_STATE(722)] = 38602,
  [SMALL_STATE(723)] = 38695,
  [SMALL_STATE(724)] = 38788,
  [SMALL_STATE(725)] = 38881,
  [SMALL_STATE(726)] = 38964,
  [SMALL_STATE(727)] = 39041,
  [SMALL_STATE(728)] = 39132,
  [SMALL_STATE(729)] = 39223,
  [SMALL_STATE(730)] = 39314,
  [SMALL_STATE(731)] = 39407,
  [SMALL_STATE(732)] = 39500,
  [SMALL_STATE(733)] = 39559,
  [SMALL_STATE(734)] = 39618,
  [SMALL_STATE(735)] = 39711,
  [SMALL_STATE(736)] = 39766,
  [SMALL_STATE(737)] = 39856,
  [SMALL_STATE(738)] = 39916,
  [SMALL_STATE(739)] = 39976,
  [SMALL_STATE(740)] = 40066,
  [SMALL_STATE(741)] = 40156,
  [SMALL_STATE(742)] = 40246,
  [SMALL_STATE(743)] = 40336,
  [SMALL_STATE(744)] = 40426,
  [SMALL_STATE(745)] = 40482,
  [SMALL_STATE(746)] = 40572,
  [SMALL_STATE(747)] = 40662,
  [SMALL_STATE(748)] = 40718,
  [SMALL_STATE(749)] = 40772,
  [SMALL_STATE(750)] = 40862,
  [SMALL_STATE(751)] = 40952,
  [SMALL_STATE(752)] = 41042,
  [SMALL_STATE(753)] = 41132,
  [SMALL_STATE(754)] = 41186,
  [SMALL_STATE(755)] = 41248,
  [SMALL_STATE(756)] = 41306,
  [SMALL_STATE(757)] = 41374,
  [SMALL_STATE(758)] = 41428,
  [SMALL_STATE(759)] = 41486,
  [SMALL_STATE(760)] = 41576,
  [SMALL_STATE(761)] = 41666,
  [SMALL_STATE(762)] = 41726,
  [SMALL_STATE(763)] = 41816,
  [SMALL_STATE(764)] = 41880,
  [SMALL_STATE(765)] = 41950,
  [SMALL_STATE(766)] = 42004,
  [SMALL_STATE(767)] = 42094,
  [SMALL_STATE(768)] = 42184,
  [SMALL_STATE(769)] = 42274,
  [SMALL_STATE(770)] = 42364,
  [SMALL_STATE(771)] = 42418,
  [SMALL_STATE(772)] = 42476,
  [SMALL_STATE(773)] = 42530,
  [SMALL_STATE(774)] = 42598,
  [SMALL_STATE(775)] = 42652,
  [SMALL_STATE(776)] = 42712,
  [SMALL_STATE(777)] = 42770,
  [SMALL_STATE(778)] = 42860,
  [SMALL_STATE(779)] = 42950,
  [SMALL_STATE(780)] = 43040,
  [SMALL_STATE(781)] = 43102,
  [SMALL_STATE(782)] = 43192,
  [SMALL_STATE(783)] = 43282,
  [SMALL_STATE(784)] = 43336,
  [SMALL_STATE(785)] = 43398,
  [SMALL_STATE(786)] = 43488,
  [SMALL_STATE(787)] = 43578,
  [SMALL_STATE(788)] = 43668,
  [SMALL_STATE(789)] = 43758,
  [SMALL_STATE(790)] = 43848,
  [SMALL_STATE(791)] = 43938,
  [SMALL_STATE(792)] = 44028,
  [SMALL_STATE(793)] = 44118,
  [SMALL_STATE(794)] = 44208,
  [SMALL_STATE(795)] = 44298,
  [SMALL_STATE(796)] = 44388,
  [SMALL_STATE(797)] = 44478,
  [SMALL_STATE(798)] = 44568,
  [SMALL_STATE(799)] = 44628,
  [SMALL_STATE(800)] = 44696,
  [SMALL_STATE(801)] = 44756,
  [SMALL_STATE(802)] = 44826,
  [SMALL_STATE(803)] = 44894,
  [SMALL_STATE(804)] = 44984,
  [SMALL_STATE(805)] = 45074,
  [SMALL_STATE(806)] = 45134,
  [SMALL_STATE(807)] = 45224,
  [SMALL_STATE(808)] = 45314,
  [SMALL_STATE(809)] = 45404,
  [SMALL_STATE(810)] = 45464,
  [SMALL_STATE(811)] = 45554,
  [SMALL_STATE(812)] = 45616,
  [SMALL_STATE(813)] = 45706,
  [SMALL_STATE(814)] = 45796,
  [SMALL_STATE(815)] = 45886,
  [SMALL_STATE(816)] = 45940,
  [SMALL_STATE(817)] = 46030,
  [SMALL_STATE(818)] = 46120,
  [SMALL_STATE(819)] = 46210,
  [SMALL_STATE(820)] = 46300,
  [SMALL_STATE(821)] = 46390,
  [SMALL_STATE(822)] = 46480,
  [SMALL_STATE(823)] = 46554,
  [SMALL_STATE(824)] = 46644,
  [SMALL_STATE(825)] = 46734,
  [SMALL_STATE(826)] = 46824,
  [SMALL_STATE(827)] = 46914,
  [SMALL_STATE(828)] = 47004,
  [SMALL_STATE(829)] = 47070,
  [SMALL_STATE(830)] = 47160,
  [SMALL_STATE(831)] = 47225,
  [SMALL_STATE(832)] = 47284,
  [SMALL_STATE(833)] = 47343,
  [SMALL_STATE(834)] = 47402,
  [SMALL_STATE(835)] = 47461,
  [SMALL_STATE(836)] = 47526,
  [SMALL_STATE(837)] = 47591,
  [SMALL_STATE(838)] = 47650,
  [SMALL_STATE(839)] = 47717,
  [SMALL_STATE(840)] = 47776,
  [SMALL_STATE(841)] = 47843,
  [SMALL_STATE(842)] = 47908,
  [SMALL_STATE(843)] = 47975,
  [SMALL_STATE(844)] = 48040,
  [SMALL_STATE(845)] = 48105,
  [SMALL_STATE(846)] = 48158,
  [SMALL_STATE(847)] = 48225,
  [SMALL_STATE(848)] = 48312,
  [SMALL_STATE(849)] = 48365,
  [SMALL_STATE(850)] = 48432,
  [SMALL_STATE(851)] = 48497,
  [SMALL_STATE(852)] = 48550,
  [SMALL_STATE(853)] = 48603,
  [SMALL_STATE(854)] = 48668,
  [SMALL_STATE(855)] = 48721,
  [SMALL_STATE(856)] = 48774,
  [SMALL_STATE(857)] = 48833,
  [SMALL_STATE(858)] = 48898,
  [SMALL_STATE(859)] = 48985,
  [SMALL_STATE(860)] = 49072,
  [SMALL_STATE(861)] = 49139,
  [SMALL_STATE(862)] = 49206,
  [SMALL_STATE(863)] = 49271,
  [SMALL_STATE(864)] = 49336,
  [SMALL_STATE(865)] = 49401,
  [SMALL_STATE(866)] = 49466,
  [SMALL_STATE(867)] = 49533,
  [SMALL_STATE(868)] = 49592,
  [SMALL_STATE(869)] = 49651,
  [SMALL_STATE(870)] = 49710,
  [SMALL_STATE(871)] = 49777,
  [SMALL_STATE(872)] = 49844,
  [SMALL_STATE(873)] = 49909,
  [SMALL_STATE(874)] = 49968,
  [SMALL_STATE(875)] = 50033,
  [SMALL_STATE(876)] = 50098,
  [SMALL_STATE(877)] = 50163,
  [SMALL_STATE(878)] = 50228,
  [SMALL_STATE(879)] = 50287,
  [SMALL_STATE(880)] = 50352,
  [SMALL_STATE(881)] = 50419,
  [SMALL_STATE(882)] = 50472,
  [SMALL_STATE(883)] = 50525,
  [SMALL_STATE(884)] = 50590,
  [SMALL_STATE(885)] = 50655,
  [SMALL_STATE(886)] = 50722,
  [SMALL_STATE(887)] = 50787,
  [SMALL_STATE(888)] = 50874,
  [SMALL_STATE(889)] = 50927,
  [SMALL_STATE(890)] = 50992,
  [SMALL_STATE(891)] = 51057,
  [SMALL_STATE(892)] = 51124,
  [SMALL_STATE(893)] = 51183,
  [SMALL_STATE(894)] = 51242,
  [SMALL_STATE(895)] = 51307,
  [SMALL_STATE(896)] = 51394,
  [SMALL_STATE(897)] = 51459,
  [SMALL_STATE(898)] = 51524,
  [SMALL_STATE(899)] = 51591,
  [SMALL_STATE(900)] = 51656,
  [SMALL_STATE(901)] = 51743,
  [SMALL_STATE(902)] = 51808,
  [SMALL_STATE(903)] = 51875,
  [SMALL_STATE(904)] = 51940,
  [SMALL_STATE(905)] = 51993,
  [SMALL_STATE(906)] = 52058,
  [SMALL_STATE(907)] = 52123,
  [SMALL_STATE(908)] = 52190,
  [SMALL_STATE(909)] = 52255,
  [SMALL_STATE(910)] = 52320,
  [SMALL_STATE(911)] = 52387,
  [SMALL_STATE(912)] = 52452,
  [SMALL_STATE(913)] = 52517,
  [SMALL_STATE(914)] = 52576,
  [SMALL_STATE(915)] = 52635,
  [SMALL_STATE(916)] = 52694,
  [SMALL_STATE(917)] = 52753,
  [SMALL_STATE(918)] = 52840,
  [SMALL_STATE(919)] = 52899,
  [SMALL_STATE(920)] = 52958,
  [SMALL_STATE(921)] = 53017,
  [SMALL_STATE(922)] = 53076,
  [SMALL_STATE(923)] = 53129,
  [SMALL_STATE(924)] = 53186,
  [SMALL_STATE(925)] = 53245,
  [SMALL_STATE(926)] = 53332,
  [SMALL_STATE(927)] = 53391,
  [SMALL_STATE(928)] = 53450,
  [SMALL_STATE(929)] = 53503,
  [SMALL_STATE(930)] = 53560,
  [SMALL_STATE(931)] = 53647,
  [SMALL_STATE(932)] = 53706,
  [SMALL_STATE(933)] = 53765,
  [SMALL_STATE(934)] = 53822,
  [SMALL_STATE(935)] = 53881,
  [SMALL_STATE(936)] = 53968,
  [SMALL_STATE(937)] = 54027,
  [SMALL_STATE(938)] = 54086,
  [SMALL_STATE(939)] = 54145,
  [SMALL_STATE(940)] = 54204,
  [SMALL_STATE(941)] = 54291,
  [SMALL_STATE(942)] = 54378,
  [SMALL_STATE(943)] = 54465,
  [SMALL_STATE(944)] = 54552,
  [SMALL_STATE(945)] = 54611,
  [SMALL_STATE(946)] = 54670,
  [SMALL_STATE(947)] = 54731,
  [SMALL_STATE(948)] = 54784,
  [SMALL_STATE(949)] = 54849,
  [SMALL_STATE(950)] = 54916,
  [SMALL_STATE(951)] = 55003,
  [SMALL_STATE(952)] = 55090,
  [SMALL_STATE(953)] = 55157,
  [SMALL_STATE(954)] = 55216,
  [SMALL_STATE(955)] = 55275,
  [SMALL_STATE(956)] = 55334,
  [SMALL_STATE(957)] = 55399,
  [SMALL_STATE(958)] = 55452,
  [SMALL_STATE(959)] = 55505,
  [SMALL_STATE(960)] = 55562,
  [SMALL_STATE(961)] = 55615,
  [SMALL_STATE(962)] = 55668,
  [SMALL_STATE(963)] = 55733,
  [SMALL_STATE(964)] = 55786,
  [SMALL_STATE(965)] = 55845,
  [SMALL_STATE(966)] = 55904,
  [SMALL_STATE(967)] = 55957,
  [SMALL_STATE(968)] = 56018,
  [SMALL_STATE(969)] = 56077,
  [SMALL_STATE(970)] = 56164,
  [SMALL_STATE(971)] = 56251,
  [SMALL_STATE(972)] = 56310,
  [SMALL_STATE(973)] = 56397,
  [SMALL_STATE(974)] = 56484,
  [SMALL_STATE(975)] = 56549,
  [SMALL_STATE(976)] = 56616,
  [SMALL_STATE(977)] = 56683,
  [SMALL_STATE(978)] = 56748,
  [SMALL_STATE(979)] = 56813,
  [SMALL_STATE(980)] = 56878,
  [SMALL_STATE(981)] = 56943,
  [SMALL_STATE(982)] = 57010,
  [SMALL_STATE(983)] = 57063,
  [SMALL_STATE(984)] = 57150,
  [SMALL_STATE(985)] = 57203,
  [SMALL_STATE(986)] = 57262,
  [SMALL_STATE(987)] = 57321,
  [SMALL_STATE(988)] = 57388,
  [SMALL_STATE(989)] = 57455,
  [SMALL_STATE(990)] = 57520,
  [SMALL_STATE(991)] = 57577,
  [SMALL_STATE(992)] = 57642,
  [SMALL_STATE(993)] = 57707,
  [SMALL_STATE(994)] = 57772,
  [SMALL_STATE(995)] = 57837,
  [SMALL_STATE(996)] = 57894,
  [SMALL_STATE(997)] = 57959,
  [SMALL_STATE(998)] = 58026,
  [SMALL_STATE(999)] = 58091,
  [SMALL_STATE(1000)] = 58156,
  [SMALL_STATE(1001)] = 58223,
  [SMALL_STATE(1002)] = 58288,
  [SMALL_STATE(1003)] = 58341,
  [SMALL_STATE(1004)] = 58408,
  [SMALL_STATE(1005)] = 58473,
  [SMALL_STATE(1006)] = 58538,
  [SMALL_STATE(1007)] = 58625,
  [SMALL_STATE(1008)] = 58684,
  [SMALL_STATE(1009)] = 58749,
  [SMALL_STATE(1010)] = 58816,
  [SMALL_STATE(1011)] = 58877,
  [SMALL_STATE(1012)] = 58942,
  [SMALL_STATE(1013)] = 59001,
  [SMALL_STATE(1014)] = 59066,
  [SMALL_STATE(1015)] = 59125,
  [SMALL_STATE(1016)] = 59192,
  [SMALL_STATE(1017)] = 59251,
  [SMALL_STATE(1018)] = 59316,
  [SMALL_STATE(1019)] = 59381,
  [SMALL_STATE(1020)] = 59446,
  [SMALL_STATE(1021)] = 59513,
  [SMALL_STATE(1022)] = 59566,
  [SMALL_STATE(1023)] = 59631,
  [SMALL_STATE(1024)] = 59696,
  [SMALL_STATE(1025)] = 59763,
  [SMALL_STATE(1026)] = 59828,
  [SMALL_STATE(1027)] = 59887,
  [SMALL_STATE(1028)] = 59946,
  [SMALL_STATE(1029)] = 60005,
  [SMALL_STATE(1030)] = 60064,
  [SMALL_STATE(1031)] = 60121,
  [SMALL_STATE(1032)] = 60188,
  [SMALL_STATE(1033)] = 60247,
  [SMALL_STATE(1034)] = 60306,
  [SMALL_STATE(1035)] = 60359,
  [SMALL_STATE(1036)] = 60424,
  [SMALL_STATE(1037)] = 60477,
  [SMALL_STATE(1038)] = 60536,
  [SMALL_STATE(1039)] = 60595,
  [SMALL_STATE(1040)] = 60662,
  [SMALL_STATE(1041)] = 60715,
  [SMALL_STATE(1042)] = 60768,
  [SMALL_STATE(1043)] = 60833,
  [SMALL_STATE(1044)] = 60886,
  [SMALL_STATE(1045)] = 60939,
  [SMALL_STATE(1046)] = 61006,
  [SMALL_STATE(1047)] = 61062,
  [SMALL_STATE(1048)] = 61120,
  [SMALL_STATE(1049)] = 61178,
  [SMALL_STATE(1050)] = 61236,
  [SMALL_STATE(1051)] = 61320,
  [SMALL_STATE(1052)] = 61404,
  [SMALL_STATE(1053)] = 61488,
  [SMALL_STATE(1054)] = 61572,
  [SMALL_STATE(1055)] = 61656,
  [SMALL_STATE(1056)] = 61740,
  [SMALL_STATE(1057)] = 61824,
  [SMALL_STATE(1058)] = 61908,
  [SMALL_STATE(1059)] = 61992,
  [SMALL_STATE(1060)] = 62076,
  [SMALL_STATE(1061)] = 62134,
  [SMALL_STATE(1062)] = 62192,
  [SMALL_STATE(1063)] = 62250,
  [SMALL_STATE(1064)] = 62334,
  [SMALL_STATE(1065)] = 62418,
  [SMALL_STATE(1066)] = 62502,
  [SMALL_STATE(1067)] = 62560,
  [SMALL_STATE(1068)] = 62622,
  [SMALL_STATE(1069)] = 62680,
  [SMALL_STATE(1070)] = 62738,
  [SMALL_STATE(1071)] = 62796,
  [SMALL_STATE(1072)] = 62880,
  [SMALL_STATE(1073)] = 62938,
  [SMALL_STATE(1074)] = 63022,
  [SMALL_STATE(1075)] = 63106,
  [SMALL_STATE(1076)] = 63190,
  [SMALL_STATE(1077)] = 63248,
  [SMALL_STATE(1078)] = 63306,
  [SMALL_STATE(1079)] = 63364,
  [SMALL_STATE(1080)] = 63448,
  [SMALL_STATE(1081)] = 63506,
  [SMALL_STATE(1082)] = 63564,
  [SMALL_STATE(1083)] = 63648,
  [SMALL_STATE(1084)] = 63706,
  [SMALL_STATE(1085)] = 63790,
  [SMALL_STATE(1086)] = 63874,
  [SMALL_STATE(1087)] = 63958,
  [SMALL_STATE(1088)] = 64042,
  [SMALL_STATE(1089)] = 64100,
  [SMALL_STATE(1090)] = 64158,
  [SMALL_STATE(1091)] = 64216,
  [SMALL_STATE(1092)] = 64274,
  [SMALL_STATE(1093)] = 64332,
  [SMALL_STATE(1094)] = 64390,
  [SMALL_STATE(1095)] = 64448,
  [SMALL_STATE(1096)] = 64506,
  [SMALL_STATE(1097)] = 64564,
  [SMALL_STATE(1098)] = 64622,
  [SMALL_STATE(1099)] = 64680,
  [SMALL_STATE(1100)] = 64764,
  [SMALL_STATE(1101)] = 64822,
  [SMALL_STATE(1102)] = 64880,
  [SMALL_STATE(1103)] = 64938,
  [SMALL_STATE(1104)] = 65022,
  [SMALL_STATE(1105)] = 65080,
  [SMALL_STATE(1106)] = 65138,
  [SMALL_STATE(1107)] = 65222,
  [SMALL_STATE(1108)] = 65306,
  [SMALL_STATE(1109)] = 65390,
  [SMALL_STATE(1110)] = 65448,
  [SMALL_STATE(1111)] = 65506,
  [SMALL_STATE(1112)] = 65590,
  [SMALL_STATE(1113)] = 65674,
  [SMALL_STATE(1114)] = 65732,
  [SMALL_STATE(1115)] = 65816,
  [SMALL_STATE(1116)] = 65874,
  [SMALL_STATE(1117)] = 65932,
  [SMALL_STATE(1118)] = 66016,
  [SMALL_STATE(1119)] = 66074,
  [SMALL_STATE(1120)] = 66158,
  [SMALL_STATE(1121)] = 66216,
  [SMALL_STATE(1122)] = 66274,
  [SMALL_STATE(1123)] = 66332,
  [SMALL_STATE(1124)] = 66390,
  [SMALL_STATE(1125)] = 66448,
  [SMALL_STATE(1126)] = 66506,
  [SMALL_STATE(1127)] = 66564,
  [SMALL_STATE(1128)] = 66622,
  [SMALL_STATE(1129)] = 66706,
  [SMALL_STATE(1130)] = 66790,
  [SMALL_STATE(1131)] = 66874,
  [SMALL_STATE(1132)] = 66958,
  [SMALL_STATE(1133)] = 67042,
  [SMALL_STATE(1134)] = 67126,
  [SMALL_STATE(1135)] = 67210,
  [SMALL_STATE(1136)] = 67294,
  [SMALL_STATE(1137)] = 67378,
  [SMALL_STATE(1138)] = 67462,
  [SMALL_STATE(1139)] = 67546,
  [SMALL_STATE(1140)] = 67630,
  [SMALL_STATE(1141)] = 67714,
  [SMALL_STATE(1142)] = 67798,
  [SMALL_STATE(1143)] = 67882,
  [SMALL_STATE(1144)] = 67966,
  [SMALL_STATE(1145)] = 68022,
  [SMALL_STATE(1146)] = 68106,
  [SMALL_STATE(1147)] = 68162,
  [SMALL_STATE(1148)] = 68246,
  [SMALL_STATE(1149)] = 68330,
  [SMALL_STATE(1150)] = 68414,
  [SMALL_STATE(1151)] = 68498,
  [SMALL_STATE(1152)] = 68582,
  [SMALL_STATE(1153)] = 68666,
  [SMALL_STATE(1154)] = 68750,
  [SMALL_STATE(1155)] = 68834,
  [SMALL_STATE(1156)] = 68886,
  [SMALL_STATE(1157)] = 68942,
  [SMALL_STATE(1158)] = 68994,
  [SMALL_STATE(1159)] = 69050,
  [SMALL_STATE(1160)] = 69106,
  [SMALL_STATE(1161)] = 69164,
  [SMALL_STATE(1162)] = 69228,
  [SMALL_STATE(1163)] = 69290,
  [SMALL_STATE(1164)] = 69342,
  [SMALL_STATE(1165)] = 69426,
  [SMALL_STATE(1166)] = 69510,
  [SMALL_STATE(1167)] = 69594,
  [SMALL_STATE(1168)] = 69646,
  [SMALL_STATE(1169)] = 69730,
  [SMALL_STATE(1170)] = 69814,
  [SMALL_STATE(1171)] = 69898,
  [SMALL_STATE(1172)] = 69982,
  [SMALL_STATE(1173)] = 70034,
  [SMALL_STATE(1174)] = 70118,
  [SMALL_STATE(1175)] = 70202,
  [SMALL_STATE(1176)] = 70286,
  [SMALL_STATE(1177)] = 70342,
  [SMALL_STATE(1178)] = 70426,
  [SMALL_STATE(1179)] = 70478,
  [SMALL_STATE(1180)] = 70538,
  [SMALL_STATE(1181)] = 70596,
  [SMALL_STATE(1182)] = 70654,
  [SMALL_STATE(1183)] = 70706,
  [SMALL_STATE(1184)] = 70758,
  [SMALL_STATE(1185)] = 70816,
  [SMALL_STATE(1186)] = 70872,
  [SMALL_STATE(1187)] = 70928,
  [SMALL_STATE(1188)] = 71012,
  [SMALL_STATE(1189)] = 71070,
  [SMALL_STATE(1190)] = 71154,
  [SMALL_STATE(1191)] = 71238,
  [SMALL_STATE(1192)] = 71322,
  [SMALL_STATE(1193)] = 71406,
  [SMALL_STATE(1194)] = 71490,
  [SMALL_STATE(1195)] = 71542,
  [SMALL_STATE(1196)] = 71594,
  [SMALL_STATE(1197)] = 71678,
  [SMALL_STATE(1198)] = 71762,
  [SMALL_STATE(1199)] = 71846,
  [SMALL_STATE(1200)] = 71930,
  [SMALL_STATE(1201)] = 72014,
  [SMALL_STATE(1202)] = 72098,
  [SMALL_STATE(1203)] = 72182,
  [SMALL_STATE(1204)] = 72266,
  [SMALL_STATE(1205)] = 72326,
  [SMALL_STATE(1206)] = 72384,
  [SMALL_STATE(1207)] = 72442,
  [SMALL_STATE(1208)] = 72526,
  [SMALL_STATE(1209)] = 72610,
  [SMALL_STATE(1210)] = 72694,
  [SMALL_STATE(1211)] = 72778,
  [SMALL_STATE(1212)] = 72862,
  [SMALL_STATE(1213)] = 72946,
  [SMALL_STATE(1214)] = 73030,
  [SMALL_STATE(1215)] = 73114,
  [SMALL_STATE(1216)] = 73198,
  [SMALL_STATE(1217)] = 73282,
  [SMALL_STATE(1218)] = 73366,
  [SMALL_STATE(1219)] = 73450,
  [SMALL_STATE(1220)] = 73534,
  [SMALL_STATE(1221)] = 73618,
  [SMALL_STATE(1222)] = 73702,
  [SMALL_STATE(1223)] = 73786,
  [SMALL_STATE(1224)] = 73870,
  [SMALL_STATE(1225)] = 73954,
  [SMALL_STATE(1226)] = 74038,
  [SMALL_STATE(1227)] = 74122,
  [SMALL_STATE(1228)] = 74206,
  [SMALL_STATE(1229)] = 74290,
  [SMALL_STATE(1230)] = 74374,
  [SMALL_STATE(1231)] = 74458,
  [SMALL_STATE(1232)] = 74542,
  [SMALL_STATE(1233)] = 74626,
  [SMALL_STATE(1234)] = 74710,
  [SMALL_STATE(1235)] = 74794,
  [SMALL_STATE(1236)] = 74878,
  [SMALL_STATE(1237)] = 74962,
  [SMALL_STATE(1238)] = 75046,
  [SMALL_STATE(1239)] = 75130,
  [SMALL_STATE(1240)] = 75214,
  [SMALL_STATE(1241)] = 75298,
  [SMALL_STATE(1242)] = 75382,
  [SMALL_STATE(1243)] = 75466,
  [SMALL_STATE(1244)] = 75550,
  [SMALL_STATE(1245)] = 75634,
  [SMALL_STATE(1246)] = 75718,
  [SMALL_STATE(1247)] = 75802,
  [SMALL_STATE(1248)] = 75886,
  [SMALL_STATE(1249)] = 75944,
  [SMALL_STATE(1250)] = 76028,
  [SMALL_STATE(1251)] = 76112,
  [SMALL_STATE(1252)] = 76196,
  [SMALL_STATE(1253)] = 76280,
  [SMALL_STATE(1254)] = 76364,
  [SMALL_STATE(1255)] = 76448,
  [SMALL_STATE(1256)] = 76532,
  [SMALL_STATE(1257)] = 76616,
  [SMALL_STATE(1258)] = 76700,
  [SMALL_STATE(1259)] = 76784,
  [SMALL_STATE(1260)] = 76868,
  [SMALL_STATE(1261)] = 76952,
  [SMALL_STATE(1262)] = 77036,
  [SMALL_STATE(1263)] = 77120,
  [SMALL_STATE(1264)] = 77204,
  [SMALL_STATE(1265)] = 77288,
  [SMALL_STATE(1266)] = 77372,
  [SMALL_STATE(1267)] = 77456,
  [SMALL_STATE(1268)] = 77540,
  [SMALL_STATE(1269)] = 77624,
  [SMALL_STATE(1270)] = 77708,
  [SMALL_STATE(1271)] = 77792,
  [SMALL_STATE(1272)] = 77876,
  [SMALL_STATE(1273)] = 77960,
  [SMALL_STATE(1274)] = 78044,
  [SMALL_STATE(1275)] = 78128,
  [SMALL_STATE(1276)] = 78212,
  [SMALL_STATE(1277)] = 78296,
  [SMALL_STATE(1278)] = 78380,
  [SMALL_STATE(1279)] = 78464,
  [SMALL_STATE(1280)] = 78548,
  [SMALL_STATE(1281)] = 78632,
  [SMALL_STATE(1282)] = 78716,
  [SMALL_STATE(1283)] = 78800,
  [SMALL_STATE(1284)] = 78884,
  [SMALL_STATE(1285)] = 78968,
  [SMALL_STATE(1286)] = 79052,
  [SMALL_STATE(1287)] = 79136,
  [SMALL_STATE(1288)] = 79220,
  [SMALL_STATE(1289)] = 79304,
  [SMALL_STATE(1290)] = 79388,
  [SMALL_STATE(1291)] = 79472,
  [SMALL_STATE(1292)] = 79556,
  [SMALL_STATE(1293)] = 79640,
  [SMALL_STATE(1294)] = 79724,
  [SMALL_STATE(1295)] = 79808,
  [SMALL_STATE(1296)] = 79892,
  [SMALL_STATE(1297)] = 79976,
  [SMALL_STATE(1298)] = 80060,
  [SMALL_STATE(1299)] = 80144,
  [SMALL_STATE(1300)] = 80228,
  [SMALL_STATE(1301)] = 80312,
  [SMALL_STATE(1302)] = 80396,
  [SMALL_STATE(1303)] = 80480,
  [SMALL_STATE(1304)] = 80564,
  [SMALL_STATE(1305)] = 80648,
  [SMALL_STATE(1306)] = 80732,
  [SMALL_STATE(1307)] = 80816,
  [SMALL_STATE(1308)] = 80900,
  [SMALL_STATE(1309)] = 80984,
  [SMALL_STATE(1310)] = 81068,
  [SMALL_STATE(1311)] = 81152,
  [SMALL_STATE(1312)] = 81236,
  [SMALL_STATE(1313)] = 81320,
  [SMALL_STATE(1314)] = 81404,
  [SMALL_STATE(1315)] = 81488,
  [SMALL_STATE(1316)] = 81572,
  [SMALL_STATE(1317)] = 81656,
  [SMALL_STATE(1318)] = 81740,
  [SMALL_STATE(1319)] = 81824,
  [SMALL_STATE(1320)] = 81908,
  [SMALL_STATE(1321)] = 81992,
  [SMALL_STATE(1322)] = 82076,
  [SMALL_STATE(1323)] = 82160,
  [SMALL_STATE(1324)] = 82244,
  [SMALL_STATE(1325)] = 82328,
  [SMALL_STATE(1326)] = 82412,
  [SMALL_STATE(1327)] = 82496,
  [SMALL_STATE(1328)] = 82580,
  [SMALL_STATE(1329)] = 82664,
  [SMALL_STATE(1330)] = 82748,
  [SMALL_STATE(1331)] = 82832,
  [SMALL_STATE(1332)] = 82916,
  [SMALL_STATE(1333)] = 83000,
  [SMALL_STATE(1334)] = 83084,
  [SMALL_STATE(1335)] = 83168,
  [SMALL_STATE(1336)] = 83252,
  [SMALL_STATE(1337)] = 83336,
  [SMALL_STATE(1338)] = 83420,
  [SMALL_STATE(1339)] = 83504,
  [SMALL_STATE(1340)] = 83588,
  [SMALL_STATE(1341)] = 83652,
  [SMALL_STATE(1342)] = 83736,
  [SMALL_STATE(1343)] = 83791,
  [SMALL_STATE(1344)] = 83842,
  [SMALL_STATE(1345)] = 83893,
  [SMALL_STATE(1346)] = 83944,
  [SMALL_STATE(1347)] = 83995,
  [SMALL_STATE(1348)] = 84056,
  [SMALL_STATE(1349)] = 84119,
  [SMALL_STATE(1350)] = 84184,
  [SMALL_STATE(1351)] = 84235,
  [SMALL_STATE(1352)] = 84294,
  [SMALL_STATE(1353)] = 84351,
  [SMALL_STATE(1354)] = 84408,
  [SMALL_STATE(1355)] = 84465,
  [SMALL_STATE(1356)] = 84516,
  [SMALL_STATE(1357)] = 84567,
  [SMALL_STATE(1358)] = 84618,
  [SMALL_STATE(1359)] = 84675,
  [SMALL_STATE(1360)] = 84734,
  [SMALL_STATE(1361)] = 84797,
  [SMALL_STATE(1362)] = 84852,
  [SMALL_STATE(1363)] = 84907,
  [SMALL_STATE(1364)] = 84966,
  [SMALL_STATE(1365)] = 85023,
  [SMALL_STATE(1366)] = 85074,
  [SMALL_STATE(1367)] = 85125,
  [SMALL_STATE(1368)] = 85188,
  [SMALL_STATE(1369)] = 85245,
  [SMALL_STATE(1370)] = 85304,
  [SMALL_STATE(1371)] = 85359,
  [SMALL_STATE(1372)] = 85422,
  [SMALL_STATE(1373)] = 85485,
  [SMALL_STATE(1374)] = 85548,
  [SMALL_STATE(1375)] = 85599,
  [SMALL_STATE(1376)] = 85654,
  [SMALL_STATE(1377)] = 85711,
  [SMALL_STATE(1378)] = 85762,
  [SMALL_STATE(1379)] = 85817,
  [SMALL_STATE(1380)] = 85868,
  [SMALL_STATE(1381)] = 85925,
  [SMALL_STATE(1382)] = 85976,
  [SMALL_STATE(1383)] = 86043,
  [SMALL_STATE(1384)] = 86126,
  [SMALL_STATE(1385)] = 86191,
  [SMALL_STATE(1386)] = 86270,
  [SMALL_STATE(1387)] = 86347,
  [SMALL_STATE(1388)] = 86420,
  [SMALL_STATE(1389)] = 86489,
  [SMALL_STATE(1390)] = 86570,
  [SMALL_STATE(1391)] = 86645,
  [SMALL_STATE(1392)] = 86732,
  [SMALL_STATE(1393)] = 86783,
  [SMALL_STATE(1394)] = 86870,
  [SMALL_STATE(1395)] = 86957,
  [SMALL_STATE(1396)] = 87044,
  [SMALL_STATE(1397)] = 87131,
  [SMALL_STATE(1398)] = 87218,
  [SMALL_STATE(1399)] = 87273,
  [SMALL_STATE(1400)] = 87328,
  [SMALL_STATE(1401)] = 87383,
  [SMALL_STATE(1402)] = 87440,
  [SMALL_STATE(1403)] = 87499,
  [SMALL_STATE(1404)] = 87558,
  [SMALL_STATE(1405)] = 87621,
  [SMALL_STATE(1406)] = 87705,
  [SMALL_STATE(1407)] = 87761,
  [SMALL_STATE(1408)] = 87811,
  [SMALL_STATE(1409)] = 87861,
  [SMALL_STATE(1410)] = 87917,
  [SMALL_STATE(1411)] = 87973,
  [SMALL_STATE(1412)] = 88029,
  [SMALL_STATE(1413)] = 88085,
  [SMALL_STATE(1414)] = 88141,
  [SMALL_STATE(1415)] = 88197,
  [SMALL_STATE(1416)] = 88247,
  [SMALL_STATE(1417)] = 88297,
  [SMALL_STATE(1418)] = 88347,
  [SMALL_STATE(1419)] = 88413,
  [SMALL_STATE(1420)] = 88463,
  [SMALL_STATE(1421)] = 88517,
  [SMALL_STATE(1422)] = 88573,
  [SMALL_STATE(1423)] = 88629,
  [SMALL_STATE(1424)] = 88685,
  [SMALL_STATE(1425)] = 88741,
  [SMALL_STATE(1426)] = 88797,
  [SMALL_STATE(1427)] = 88853,
  [SMALL_STATE(1428)] = 88909,
  [SMALL_STATE(1429)] = 88969,
  [SMALL_STATE(1430)] = 89019,
  [SMALL_STATE(1431)] = 89075,
  [SMALL_STATE(1432)] = 89131,
  [SMALL_STATE(1433)] = 89191,
  [SMALL_STATE(1434)] = 89247,
  [SMALL_STATE(1435)] = 89303,
  [SMALL_STATE(1436)] = 89359,
  [SMALL_STATE(1437)] = 89415,
  [SMALL_STATE(1438)] = 89471,
  [SMALL_STATE(1439)] = 89527,
  [SMALL_STATE(1440)] = 89583,
  [SMALL_STATE(1441)] = 89639,
  [SMALL_STATE(1442)] = 89689,
  [SMALL_STATE(1443)] = 89739,
  [SMALL_STATE(1444)] = 89803,
  [SMALL_STATE(1445)] = 89859,
  [SMALL_STATE(1446)] = 89915,
  [SMALL_STATE(1447)] = 89965,
  [SMALL_STATE(1448)] = 90015,
  [SMALL_STATE(1449)] = 90095,
  [SMALL_STATE(1450)] = 90157,
  [SMALL_STATE(1451)] = 90233,
  [SMALL_STATE(1452)] = 90307,
  [SMALL_STATE(1453)] = 90377,
  [SMALL_STATE(1454)] = 90443,
  [SMALL_STATE(1455)] = 90499,
  [SMALL_STATE(1456)] = 90577,
  [SMALL_STATE(1457)] = 90627,
  [SMALL_STATE(1458)] = 90699,
  [SMALL_STATE(1459)] = 90755,
  [SMALL_STATE(1460)] = 90809,
  [SMALL_STATE(1461)] = 90893,
  [SMALL_STATE(1462)] = 90949,
  [SMALL_STATE(1463)] = 91005,
  [SMALL_STATE(1464)] = 91089,
  [SMALL_STATE(1465)] = 91145,
  [SMALL_STATE(1466)] = 91229,
  [SMALL_STATE(1467)] = 91285,
  [SMALL_STATE(1468)] = 91335,
  [SMALL_STATE(1469)] = 91391,
  [SMALL_STATE(1470)] = 91447,
  [SMALL_STATE(1471)] = 91503,
  [SMALL_STATE(1472)] = 91587,
  [SMALL_STATE(1473)] = 91637,
  [SMALL_STATE(1474)] = 91721,
  [SMALL_STATE(1475)] = 91777,
  [SMALL_STATE(1476)] = 91835,
  [SMALL_STATE(1477)] = 91891,
  [SMALL_STATE(1478)] = 91941,
  [SMALL_STATE(1479)] = 91991,
  [SMALL_STATE(1480)] = 92041,
  [SMALL_STATE(1481)] = 92097,
  [SMALL_STATE(1482)] = 92147,
  [SMALL_STATE(1483)] = 92203,
  [SMALL_STATE(1484)] = 92263,
  [SMALL_STATE(1485)] = 92313,
  [SMALL_STATE(1486)] = 92369,
  [SMALL_STATE(1487)] = 92425,
  [SMALL_STATE(1488)] = 92475,
  [SMALL_STATE(1489)] = 92525,
  [SMALL_STATE(1490)] = 92581,
  [SMALL_STATE(1491)] = 92637,
  [SMALL_STATE(1492)] = 92693,
  [SMALL_STATE(1493)] = 92749,
  [SMALL_STATE(1494)] = 92805,
  [SMALL_STATE(1495)] = 92855,
  [SMALL_STATE(1496)] = 92915,
  [SMALL_STATE(1497)] = 92975,
  [SMALL_STATE(1498)] = 93031,
  [SMALL_STATE(1499)] = 93081,
  [SMALL_STATE(1500)] = 93137,
  [SMALL_STATE(1501)] = 93193,
  [SMALL_STATE(1502)] = 93243,
  [SMALL_STATE(1503)] = 93293,
  [SMALL_STATE(1504)] = 93349,
  [SMALL_STATE(1505)] = 93405,
  [SMALL_STATE(1506)] = 93461,
  [SMALL_STATE(1507)] = 93511,
  [SMALL_STATE(1508)] = 93567,
  [SMALL_STATE(1509)] = 93617,
  [SMALL_STATE(1510)] = 93673,
  [SMALL_STATE(1511)] = 93723,
  [SMALL_STATE(1512)] = 93779,
  [SMALL_STATE(1513)] = 93829,
  [SMALL_STATE(1514)] = 93885,
  [SMALL_STATE(1515)] = 93941,
  [SMALL_STATE(1516)] = 93991,
  [SMALL_STATE(1517)] = 94041,
  [SMALL_STATE(1518)] = 94097,
  [SMALL_STATE(1519)] = 94151,
  [SMALL_STATE(1520)] = 94201,
  [SMALL_STATE(1521)] = 94257,
  [SMALL_STATE(1522)] = 94321,
  [SMALL_STATE(1523)] = 94377,
  [SMALL_STATE(1524)] = 94435,
  [SMALL_STATE(1525)] = 94491,
  [SMALL_STATE(1526)] = 94547,
  [SMALL_STATE(1527)] = 94597,
  [SMALL_STATE(1528)] = 94653,
  [SMALL_STATE(1529)] = 94709,
  [SMALL_STATE(1530)] = 94769,
  [SMALL_STATE(1531)] = 94825,
  [SMALL_STATE(1532)] = 94881,
  [SMALL_STATE(1533)] = 94937,
  [SMALL_STATE(1534)] = 94993,
  [SMALL_STATE(1535)] = 95049,
  [SMALL_STATE(1536)] = 95105,
  [SMALL_STATE(1537)] = 95161,
  [SMALL_STATE(1538)] = 95217,
  [SMALL_STATE(1539)] = 95273,
  [SMALL_STATE(1540)] = 95329,
  [SMALL_STATE(1541)] = 95379,
  [SMALL_STATE(1542)] = 95435,
  [SMALL_STATE(1543)] = 95491,
  [SMALL_STATE(1544)] = 95541,
  [SMALL_STATE(1545)] = 95597,
  [SMALL_STATE(1546)] = 95653,
  [SMALL_STATE(1547)] = 95709,
  [SMALL_STATE(1548)] = 95765,
  [SMALL_STATE(1549)] = 95821,
  [SMALL_STATE(1550)] = 95877,
  [SMALL_STATE(1551)] = 95933,
  [SMALL_STATE(1552)] = 95989,
  [SMALL_STATE(1553)] = 96045,
  [SMALL_STATE(1554)] = 96101,
  [SMALL_STATE(1555)] = 96157,
  [SMALL_STATE(1556)] = 96213,
  [SMALL_STATE(1557)] = 96269,
  [SMALL_STATE(1558)] = 96325,
  [SMALL_STATE(1559)] = 96375,
  [SMALL_STATE(1560)] = 96431,
  [SMALL_STATE(1561)] = 96481,
  [SMALL_STATE(1562)] = 96537,
  [SMALL_STATE(1563)] = 96587,
  [SMALL_STATE(1564)] = 96637,
  [SMALL_STATE(1565)] = 96693,
  [SMALL_STATE(1566)] = 96749,
  [SMALL_STATE(1567)] = 96807,
  [SMALL_STATE(1568)] = 96869,
  [SMALL_STATE(1569)] = 96925,
  [SMALL_STATE(1570)] = 96985,
  [SMALL_STATE(1571)] = 97034,
  [SMALL_STATE(1572)] = 97083,
  [SMALL_STATE(1573)] = 97132,
  [SMALL_STATE(1574)] = 97181,
  [SMALL_STATE(1575)] = 97230,
  [SMALL_STATE(1576)] = 97279,
  [SMALL_STATE(1577)] = 97328,
  [SMALL_STATE(1578)] = 97377,
  [SMALL_STATE(1579)] = 97426,
  [SMALL_STATE(1580)] = 97479,
  [SMALL_STATE(1581)] = 97528,
  [SMALL_STATE(1582)] = 97583,
  [SMALL_STATE(1583)] = 97632,
  [SMALL_STATE(1584)] = 97681,
  [SMALL_STATE(1585)] = 97730,
  [SMALL_STATE(1586)] = 97779,
  [SMALL_STATE(1587)] = 97828,
  [SMALL_STATE(1588)] = 97877,
  [SMALL_STATE(1589)] = 97932,
  [SMALL_STATE(1590)] = 97981,
  [SMALL_STATE(1591)] = 98030,
  [SMALL_STATE(1592)] = 98079,
  [SMALL_STATE(1593)] = 98128,
  [SMALL_STATE(1594)] = 98181,
  [SMALL_STATE(1595)] = 98234,
  [SMALL_STATE(1596)] = 98283,
  [SMALL_STATE(1597)] = 98332,
  [SMALL_STATE(1598)] = 98381,
  [SMALL_STATE(1599)] = 98430,
  [SMALL_STATE(1600)] = 98479,
  [SMALL_STATE(1601)] = 98528,
  [SMALL_STATE(1602)] = 98581,
  [SMALL_STATE(1603)] = 98634,
  [SMALL_STATE(1604)] = 98687,
  [SMALL_STATE(1605)] = 98736,
  [SMALL_STATE(1606)] = 98785,
  [SMALL_STATE(1607)] = 98834,
  [SMALL_STATE(1608)] = 98883,
  [SMALL_STATE(1609)] = 98932,
  [SMALL_STATE(1610)] = 98981,
  [SMALL_STATE(1611)] = 99030,
  [SMALL_STATE(1612)] = 99083,
  [SMALL_STATE(1613)] = 99136,
  [SMALL_STATE(1614)] = 99185,
  [SMALL_STATE(1615)] = 99234,
  [SMALL_STATE(1616)] = 99283,
  [SMALL_STATE(1617)] = 99332,
  [SMALL_STATE(1618)] = 99381,
  [SMALL_STATE(1619)] = 99430,
  [SMALL_STATE(1620)] = 99483,
  [SMALL_STATE(1621)] = 99532,
  [SMALL_STATE(1622)] = 99581,
  [SMALL_STATE(1623)] = 99630,
  [SMALL_STATE(1624)] = 99685,
  [SMALL_STATE(1625)] = 99734,
  [SMALL_STATE(1626)] = 99783,
  [SMALL_STATE(1627)] = 99832,
  [SMALL_STATE(1628)] = 99888,
  [SMALL_STATE(1629)] = 99950,
  [SMALL_STATE(1630)] = 100028,
  [SMALL_STATE(1631)] = 100088,
  [SMALL_STATE(1632)] = 100162,
  [SMALL_STATE(1633)] = 100244,
  [SMALL_STATE(1634)] = 100326,
  [SMALL_STATE(1635)] = 100398,
  [SMALL_STATE(1636)] = 100466,
  [SMALL_STATE(1637)] = 100524,
  [SMALL_STATE(1638)] = 100588,
  [SMALL_STATE(1639)] = 100646,
  [SMALL_STATE(1640)] = 100704,
  [SMALL_STATE(1641)] = 100778,
  [SMALL_STATE(1642)] = 100836,
  [SMALL_STATE(1643)] = 100894,
  [SMALL_STATE(1644)] = 100952,
  [SMALL_STATE(1645)] = 101006,
  [SMALL_STATE(1646)] = 101064,
  [SMALL_STATE(1647)] = 101120,
  [SMALL_STATE(1648)] = 101196,
  [SMALL_STATE(1649)] = 101266,
  [SMALL_STATE(1650)] = 101340,
  [SMALL_STATE(1651)] = 101422,
  [SMALL_STATE(1652)] = 101496,
  [SMALL_STATE(1653)] = 101558,
  [SMALL_STATE(1654)] = 101636,
  [SMALL_STATE(1655)] = 101696,
  [SMALL_STATE(1656)] = 101770,
  [SMALL_STATE(1657)] = 101842,
  [SMALL_STATE(1658)] = 101910,
  [SMALL_STATE(1659)] = 101974,
  [SMALL_STATE(1660)] = 102050,
  [SMALL_STATE(1661)] = 102120,
  [SMALL_STATE(1662)] = 102202,
  [SMALL_STATE(1663)] = 102284,
  [SMALL_STATE(1664)] = 102340,
  [SMALL_STATE(1665)] = 102422,
  [SMALL_STATE(1666)] = 102504,
  [SMALL_STATE(1667)] = 102586,
  [SMALL_STATE(1668)] = 102660,
  [SMALL_STATE(1669)] = 102734,
  [SMALL_STATE(1670)] = 102782,
  [SMALL_STATE(1671)] = 102856,
  [SMALL_STATE(1672)] = 102910,
  [SMALL_STATE(1673)] = 102964,
  [SMALL_STATE(1674)] = 103038,
  [SMALL_STATE(1675)] = 103086,
  [SMALL_STATE(1676)] = 103134,
  [SMALL_STATE(1677)] = 103190,
  [SMALL_STATE(1678)] = 103248,
  [SMALL_STATE(1679)] = 103308,
  [SMALL_STATE(1680)] = 103360,
  [SMALL_STATE(1681)] = 103420,
  [SMALL_STATE(1682)] = 103468,
  [SMALL_STATE(1683)] = 103542,
  [SMALL_STATE(1684)] = 103600,
  [SMALL_STATE(1685)] = 103658,
  [SMALL_STATE(1686)] = 103716,
  [SMALL_STATE(1687)] = 103798,
  [SMALL_STATE(1688)] = 103880,
  [SMALL_STATE(1689)] = 103962,
  [SMALL_STATE(1690)] = 104020,
  [SMALL_STATE(1691)] = 104074,
  [SMALL_STATE(1692)] = 104130,
  [SMALL_STATE(1693)] = 104204,
  [SMALL_STATE(1694)] = 104278,
  [SMALL_STATE(1695)] = 104336,
  [SMALL_STATE(1696)] = 104394,
  [SMALL_STATE(1697)] = 104452,
  [SMALL_STATE(1698)] = 104534,
  [SMALL_STATE(1699)] = 104585,
  [SMALL_STATE(1700)] = 104632,
  [SMALL_STATE(1701)] = 104683,
  [SMALL_STATE(1702)] = 104730,
  [SMALL_STATE(1703)] = 104777,
  [SMALL_STATE(1704)] = 104834,
  [SMALL_STATE(1705)] = 104881,
  [SMALL_STATE(1706)] = 104928,
  [SMALL_STATE(1707)] = 104975,
  [SMALL_STATE(1708)] = 105022,
  [SMALL_STATE(1709)] = 105069,
  [SMALL_STATE(1710)] = 105116,
  [SMALL_STATE(1711)] = 105163,
  [SMALL_STATE(1712)] = 105210,
  [SMALL_STATE(1713)] = 105257,
  [SMALL_STATE(1714)] = 105304,
  [SMALL_STATE(1715)] = 105351,
  [SMALL_STATE(1716)] = 105398,
  [SMALL_STATE(1717)] = 105445,
  [SMALL_STATE(1718)] = 105492,
  [SMALL_STATE(1719)] = 105539,
  [SMALL_STATE(1720)] = 105586,
  [SMALL_STATE(1721)] = 105633,
  [SMALL_STATE(1722)] = 105680,
  [SMALL_STATE(1723)] = 105733,
  [SMALL_STATE(1724)] = 105780,
  [SMALL_STATE(1725)] = 105827,
  [SMALL_STATE(1726)] = 105874,
  [SMALL_STATE(1727)] = 105921,
  [SMALL_STATE(1728)] = 105968,
  [SMALL_STATE(1729)] = 106023,
  [SMALL_STATE(1730)] = 106070,
  [SMALL_STATE(1731)] = 106117,
  [SMALL_STATE(1732)] = 106164,
  [SMALL_STATE(1733)] = 106211,
  [SMALL_STATE(1734)] = 106258,
  [SMALL_STATE(1735)] = 106305,
  [SMALL_STATE(1736)] = 106352,
  [SMALL_STATE(1737)] = 106399,
  [SMALL_STATE(1738)] = 106446,
  [SMALL_STATE(1739)] = 106497,
  [SMALL_STATE(1740)] = 106554,
  [SMALL_STATE(1741)] = 106613,
  [SMALL_STATE(1742)] = 106670,
  [SMALL_STATE(1743)] = 106717,
  [SMALL_STATE(1744)] = 106764,
  [SMALL_STATE(1745)] = 106811,
  [SMALL_STATE(1746)] = 106858,
  [SMALL_STATE(1747)] = 106905,
  [SMALL_STATE(1748)] = 106952,
  [SMALL_STATE(1749)] = 106999,
  [SMALL_STATE(1750)] = 107046,
  [SMALL_STATE(1751)] = 107093,
  [SMALL_STATE(1752)] = 107140,
  [SMALL_STATE(1753)] = 107193,
  [SMALL_STATE(1754)] = 107240,
  [SMALL_STATE(1755)] = 107287,
  [SMALL_STATE(1756)] = 107334,
  [SMALL_STATE(1757)] = 107381,
  [SMALL_STATE(1758)] = 107432,
  [SMALL_STATE(1759)] = 107479,
  [SMALL_STATE(1760)] = 107526,
  [SMALL_STATE(1761)] = 107581,
  [SMALL_STATE(1762)] = 107628,
  [SMALL_STATE(1763)] = 107675,
  [SMALL_STATE(1764)] = 107722,
  [SMALL_STATE(1765)] = 107769,
  [SMALL_STATE(1766)] = 107826,
  [SMALL_STATE(1767)] = 107873,
  [SMALL_STATE(1768)] = 107920,
  [SMALL_STATE(1769)] = 107967,
  [SMALL_STATE(1770)] = 108026,
  [SMALL_STATE(1771)] = 108077,
  [SMALL_STATE(1772)] = 108124,
  [SMALL_STATE(1773)] = 108171,
  [SMALL_STATE(1774)] = 108218,
  [SMALL_STATE(1775)] = 108265,
  [SMALL_STATE(1776)] = 108318,
  [SMALL_STATE(1777)] = 108370,
  [SMALL_STATE(1778)] = 108424,
  [SMALL_STATE(1779)] = 108476,
  [SMALL_STATE(1780)] = 108528,
  [SMALL_STATE(1781)] = 108580,
  [SMALL_STATE(1782)] = 108631,
  [SMALL_STATE(1783)] = 108682,
  [SMALL_STATE(1784)] = 108733,
  [SMALL_STATE(1785)] = 108784,
  [SMALL_STATE(1786)] = 108835,
  [SMALL_STATE(1787)] = 108886,
  [SMALL_STATE(1788)] = 108935,
  [SMALL_STATE(1789)] = 108986,
  [SMALL_STATE(1790)] = 109037,
  [SMALL_STATE(1791)] = 109088,
  [SMALL_STATE(1792)] = 109150,
  [SMALL_STATE(1793)] = 109198,
  [SMALL_STATE(1794)] = 109246,
  [SMALL_STATE(1795)] = 109294,
  [SMALL_STATE(1796)] = 109356,
  [SMALL_STATE(1797)] = 109404,
  [SMALL_STATE(1798)] = 109452,
  [SMALL_STATE(1799)] = 109514,
  [SMALL_STATE(1800)] = 109576,
  [SMALL_STATE(1801)] = 109626,
  [SMALL_STATE(1802)] = 109674,
  [SMALL_STATE(1803)] = 109717,
  [SMALL_STATE(1804)] = 109776,
  [SMALL_STATE(1805)] = 109819,
  [SMALL_STATE(1806)] = 109862,
  [SMALL_STATE(1807)] = 109919,
  [SMALL_STATE(1808)] = 109976,
  [SMALL_STATE(1809)] = 110019,
  [SMALL_STATE(1810)] = 110076,
  [SMALL_STATE(1811)] = 110119,
  [SMALL_STATE(1812)] = 110178,
  [SMALL_STATE(1813)] = 110233,
  [SMALL_STATE(1814)] = 110290,
  [SMALL_STATE(1815)] = 110349,
  [SMALL_STATE(1816)] = 110392,
  [SMALL_STATE(1817)] = 110451,
  [SMALL_STATE(1818)] = 110510,
  [SMALL_STATE(1819)] = 110565,
  [SMALL_STATE(1820)] = 110621,
  [SMALL_STATE(1821)] = 110675,
  [SMALL_STATE(1822)] = 110729,
  [SMALL_STATE(1823)] = 110783,
  [SMALL_STATE(1824)] = 110839,
  [SMALL_STATE(1825)] = 110893,
  [SMALL_STATE(1826)] = 110947,
  [SMALL_STATE(1827)] = 111001,
  [SMALL_STATE(1828)] = 111055,
  [SMALL_STATE(1829)] = 111109,
  [SMALL_STATE(1830)] = 111163,
  [SMALL_STATE(1831)] = 111217,
  [SMALL_STATE(1832)] = 111273,
  [SMALL_STATE(1833)] = 111329,
  [SMALL_STATE(1834)] = 111385,
  [SMALL_STATE(1835)] = 111441,
  [SMALL_STATE(1836)] = 111495,
  [SMALL_STATE(1837)] = 111551,
  [SMALL_STATE(1838)] = 111605,
  [SMALL_STATE(1839)] = 111659,
  [SMALL_STATE(1840)] = 111713,
  [SMALL_STATE(1841)] = 111767,
  [SMALL_STATE(1842)] = 111821,
  [SMALL_STATE(1843)] = 111875,
  [SMALL_STATE(1844)] = 111929,
  [SMALL_STATE(1845)] = 111985,
  [SMALL_STATE(1846)] = 112041,
  [SMALL_STATE(1847)] = 112095,
  [SMALL_STATE(1848)] = 112151,
  [SMALL_STATE(1849)] = 112207,
  [SMALL_STATE(1850)] = 112261,
  [SMALL_STATE(1851)] = 112315,
  [SMALL_STATE(1852)] = 112369,
  [SMALL_STATE(1853)] = 112423,
  [SMALL_STATE(1854)] = 112477,
  [SMALL_STATE(1855)] = 112531,
  [SMALL_STATE(1856)] = 112585,
  [SMALL_STATE(1857)] = 112641,
  [SMALL_STATE(1858)] = 112695,
  [SMALL_STATE(1859)] = 112749,
  [SMALL_STATE(1860)] = 112803,
  [SMALL_STATE(1861)] = 112857,
  [SMALL_STATE(1862)] = 112913,
  [SMALL_STATE(1863)] = 112967,
  [SMALL_STATE(1864)] = 113021,
  [SMALL_STATE(1865)] = 113077,
  [SMALL_STATE(1866)] = 113131,
  [SMALL_STATE(1867)] = 113187,
  [SMALL_STATE(1868)] = 113243,
  [SMALL_STATE(1869)] = 113297,
  [SMALL_STATE(1870)] = 113351,
  [SMALL_STATE(1871)] = 113405,
  [SMALL_STATE(1872)] = 113455,
  [SMALL_STATE(1873)] = 113511,
  [SMALL_STATE(1874)] = 113567,
  [SMALL_STATE(1875)] = 113623,
  [SMALL_STATE(1876)] = 113677,
  [SMALL_STATE(1877)] = 113733,
  [SMALL_STATE(1878)] = 113787,
  [SMALL_STATE(1879)] = 113849,
  [SMALL_STATE(1880)] = 113903,
  [SMALL_STATE(1881)] = 113957,
  [SMALL_STATE(1882)] = 114011,
  [SMALL_STATE(1883)] = 114067,
  [SMALL_STATE(1884)] = 114121,
  [SMALL_STATE(1885)] = 114177,
  [SMALL_STATE(1886)] = 114233,
  [SMALL_STATE(1887)] = 114287,
  [SMALL_STATE(1888)] = 114341,
  [SMALL_STATE(1889)] = 114395,
  [SMALL_STATE(1890)] = 114451,
  [SMALL_STATE(1891)] = 114509,
  [SMALL_STATE(1892)] = 114563,
  [SMALL_STATE(1893)] = 114617,
  [SMALL_STATE(1894)] = 114671,
  [SMALL_STATE(1895)] = 114727,
  [SMALL_STATE(1896)] = 114783,
  [SMALL_STATE(1897)] = 114837,
  [SMALL_STATE(1898)] = 114891,
  [SMALL_STATE(1899)] = 114945,
  [SMALL_STATE(1900)] = 115001,
  [SMALL_STATE(1901)] = 115055,
  [SMALL_STATE(1902)] = 115109,
  [SMALL_STATE(1903)] = 115163,
  [SMALL_STATE(1904)] = 115219,
  [SMALL_STATE(1905)] = 115273,
  [SMALL_STATE(1906)] = 115327,
  [SMALL_STATE(1907)] = 115381,
  [SMALL_STATE(1908)] = 115437,
  [SMALL_STATE(1909)] = 115491,
  [SMALL_STATE(1910)] = 115545,
  [SMALL_STATE(1911)] = 115599,
  [SMALL_STATE(1912)] = 115655,
  [SMALL_STATE(1913)] = 115709,
  [SMALL_STATE(1914)] = 115763,
  [SMALL_STATE(1915)] = 115817,
  [SMALL_STATE(1916)] = 115871,
  [SMALL_STATE(1917)] = 115927,
  [SMALL_STATE(1918)] = 115981,
  [SMALL_STATE(1919)] = 116037,
  [SMALL_STATE(1920)] = 116093,
  [SMALL_STATE(1921)] = 116149,
  [SMALL_STATE(1922)] = 116203,
  [SMALL_STATE(1923)] = 116244,
  [SMALL_STATE(1924)] = 116291,
  [SMALL_STATE(1925)] = 116332,
  [SMALL_STATE(1926)] = 116379,
  [SMALL_STATE(1927)] = 116426,
  [SMALL_STATE(1928)] = 116467,
  [SMALL_STATE(1929)] = 116518,
  [SMALL_STATE(1930)] = 116565,
  [SMALL_STATE(1931)] = 116612,
  [SMALL_STATE(1932)] = 116663,
  [SMALL_STATE(1933)] = 116710,
  [SMALL_STATE(1934)] = 116761,
  [SMALL_STATE(1935)] = 116808,
  [SMALL_STATE(1936)] = 116855,
  [SMALL_STATE(1937)] = 116902,
  [SMALL_STATE(1938)] = 116943,
  [SMALL_STATE(1939)] = 116992,
  [SMALL_STATE(1940)] = 117039,
  [SMALL_STATE(1941)] = 117080,
  [SMALL_STATE(1942)] = 117133,
  [SMALL_STATE(1943)] = 117174,
  [SMALL_STATE(1944)] = 117225,
  [SMALL_STATE(1945)] = 117272,
  [SMALL_STATE(1946)] = 117313,
  [SMALL_STATE(1947)] = 117358,
  [SMALL_STATE(1948)] = 117417,
  [SMALL_STATE(1949)] = 117466,
  [SMALL_STATE(1950)] = 117517,
  [SMALL_STATE(1951)] = 117568,
  [SMALL_STATE(1952)] = 117609,
  [SMALL_STATE(1953)] = 117662,
  [SMALL_STATE(1954)] = 117709,
  [SMALL_STATE(1955)] = 117750,
  [SMALL_STATE(1956)] = 117796,
  [SMALL_STATE(1957)] = 117878,
  [SMALL_STATE(1958)] = 117960,
  [SMALL_STATE(1959)] = 118006,
  [SMALL_STATE(1960)] = 118052,
  [SMALL_STATE(1961)] = 118100,
  [SMALL_STATE(1962)] = 118146,
  [SMALL_STATE(1963)] = 118194,
  [SMALL_STATE(1964)] = 118234,
  [SMALL_STATE(1965)] = 118282,
  [SMALL_STATE(1966)] = 118364,
  [SMALL_STATE(1967)] = 118410,
  [SMALL_STATE(1968)] = 118456,
  [SMALL_STATE(1969)] = 118508,
  [SMALL_STATE(1970)] = 118590,
  [SMALL_STATE(1971)] = 118672,
  [SMALL_STATE(1972)] = 118718,
  [SMALL_STATE(1973)] = 118758,
  [SMALL_STATE(1974)] = 118798,
  [SMALL_STATE(1975)] = 118838,
  [SMALL_STATE(1976)] = 118920,
  [SMALL_STATE(1977)] = 118968,
  [SMALL_STATE(1978)] = 119014,
  [SMALL_STATE(1979)] = 119062,
  [SMALL_STATE(1980)] = 119108,
  [SMALL_STATE(1981)] = 119160,
  [SMALL_STATE(1982)] = 119206,
  [SMALL_STATE(1983)] = 119254,
  [SMALL_STATE(1984)] = 119336,
  [SMALL_STATE(1985)] = 119418,
  [SMALL_STATE(1986)] = 119464,
  [SMALL_STATE(1987)] = 119510,
  [SMALL_STATE(1988)] = 119568,
  [SMALL_STATE(1989)] = 119647,
  [SMALL_STATE(1990)] = 119696,
  [SMALL_STATE(1991)] = 119745,
  [SMALL_STATE(1992)] = 119794,
  [SMALL_STATE(1993)] = 119839,
  [SMALL_STATE(1994)] = 119890,
  [SMALL_STATE(1995)] = 119943,
  [SMALL_STATE(1996)] = 119998,
  [SMALL_STATE(1997)] = 120053,
  [SMALL_STATE(1998)] = 120122,
  [SMALL_STATE(1999)] = 120175,
  [SMALL_STATE(2000)] = 120242,
  [SMALL_STATE(2001)] = 120307,
  [SMALL_STATE(2002)] = 120368,
  [SMALL_STATE(2003)] = 120425,
  [SMALL_STATE(2004)] = 120492,
  [SMALL_STATE(2005)] = 120555,
  [SMALL_STATE(2006)] = 120628,
  [SMALL_STATE(2007)] = 120675,
  [SMALL_STATE(2008)] = 120754,
  [SMALL_STATE(2009)] = 120833,
  [SMALL_STATE(2010)] = 120880,
  [SMALL_STATE(2011)] = 120951,
  [SMALL_STATE(2012)] = 121002,
  [SMALL_STATE(2013)] = 121069,
  [SMALL_STATE(2014)] = 121134,
  [SMALL_STATE(2015)] = 121195,
  [SMALL_STATE(2016)] = 121252,
  [SMALL_STATE(2017)] = 121303,
  [SMALL_STATE(2018)] = 121372,
  [SMALL_STATE(2019)] = 121435,
  [SMALL_STATE(2020)] = 121510,
  [SMALL_STATE(2021)] = 121589,
  [SMALL_STATE(2022)] = 121668,
  [SMALL_STATE(2023)] = 121747,
  [SMALL_STATE(2024)] = 121798,
  [SMALL_STATE(2025)] = 121877,
  [SMALL_STATE(2026)] = 121950,
  [SMALL_STATE(2027)] = 122025,
  [SMALL_STATE(2028)] = 122100,
  [SMALL_STATE(2029)] = 122175,
  [SMALL_STATE(2030)] = 122254,
  [SMALL_STATE(2031)] = 122293,
  [SMALL_STATE(2032)] = 122332,
  [SMALL_STATE(2033)] = 122405,
  [SMALL_STATE(2034)] = 122478,
  [SMALL_STATE(2035)] = 122517,
  [SMALL_STATE(2036)] = 122572,
  [SMALL_STATE(2037)] = 122611,
  [SMALL_STATE(2038)] = 122662,
  [SMALL_STATE(2039)] = 122709,
  [SMALL_STATE(2040)] = 122760,
  [SMALL_STATE(2041)] = 122835,
  [SMALL_STATE(2042)] = 122910,
  [SMALL_STATE(2043)] = 122949,
  [SMALL_STATE(2044)] = 123022,
  [SMALL_STATE(2045)] = 123095,
  [SMALL_STATE(2046)] = 123142,
  [SMALL_STATE(2047)] = 123181,
  [SMALL_STATE(2048)] = 123232,
  [SMALL_STATE(2049)] = 123279,
  [SMALL_STATE(2050)] = 123328,
  [SMALL_STATE(2051)] = 123379,
  [SMALL_STATE(2052)] = 123428,
  [SMALL_STATE(2053)] = 123473,
  [SMALL_STATE(2054)] = 123522,
  [SMALL_STATE(2055)] = 123571,
  [SMALL_STATE(2056)] = 123616,
  [SMALL_STATE(2057)] = 123655,
  [SMALL_STATE(2058)] = 123700,
  [SMALL_STATE(2059)] = 123739,
  [SMALL_STATE(2060)] = 123815,
  [SMALL_STATE(2061)] = 123859,
  [SMALL_STATE(2062)] = 123903,
  [SMALL_STATE(2063)] = 123947,
  [SMALL_STATE(2064)] = 123991,
  [SMALL_STATE(2065)] = 124067,
  [SMALL_STATE(2066)] = 124105,
  [SMALL_STATE(2067)] = 124143,
  [SMALL_STATE(2068)] = 124219,
  [SMALL_STATE(2069)] = 124263,
  [SMALL_STATE(2070)] = 124341,
  [SMALL_STATE(2071)] = 124379,
  [SMALL_STATE(2072)] = 124423,
  [SMALL_STATE(2073)] = 124467,
  [SMALL_STATE(2074)] = 124511,
  [SMALL_STATE(2075)] = 124563,
  [SMALL_STATE(2076)] = 124615,
  [SMALL_STATE(2077)] = 124659,
  [SMALL_STATE(2078)] = 124703,
  [SMALL_STATE(2079)] = 124747,
  [SMALL_STATE(2080)] = 124791,
  [SMALL_STATE(2081)] = 124835,
  [SMALL_STATE(2082)] = 124879,
  [SMALL_STATE(2083)] = 124925,
  [SMALL_STATE(2084)] = 124969,
  [SMALL_STATE(2085)] = 125013,
  [SMALL_STATE(2086)] = 125055,
  [SMALL_STATE(2087)] = 125099,
  [SMALL_STATE(2088)] = 125143,
  [SMALL_STATE(2089)] = 125187,
  [SMALL_STATE(2090)] = 125233,
  [SMALL_STATE(2091)] = 125271,
  [SMALL_STATE(2092)] = 125323,
  [SMALL_STATE(2093)] = 125375,
  [SMALL_STATE(2094)] = 125413,
  [SMALL_STATE(2095)] = 125457,
  [SMALL_STATE(2096)] = 125495,
  [SMALL_STATE(2097)] = 125539,
  [SMALL_STATE(2098)] = 125577,
  [SMALL_STATE(2099)] = 125615,
  [SMALL_STATE(2100)] = 125659,
  [SMALL_STATE(2101)] = 125697,
  [SMALL_STATE(2102)] = 125773,
  [SMALL_STATE(2103)] = 125813,
  [SMALL_STATE(2104)] = 125857,
  [SMALL_STATE(2105)] = 125901,
  [SMALL_STATE(2106)] = 125939,
  [SMALL_STATE(2107)] = 125983,
  [SMALL_STATE(2108)] = 126029,
  [SMALL_STATE(2109)] = 126073,
  [SMALL_STATE(2110)] = 126111,
  [SMALL_STATE(2111)] = 126155,
  [SMALL_STATE(2112)] = 126207,
  [SMALL_STATE(2113)] = 126251,
  [SMALL_STATE(2114)] = 126327,
  [SMALL_STATE(2115)] = 126365,
  [SMALL_STATE(2116)] = 126403,
  [SMALL_STATE(2117)] = 126447,
  [SMALL_STATE(2118)] = 126491,
  [SMALL_STATE(2119)] = 126565,
  [SMALL_STATE(2120)] = 126603,
  [SMALL_STATE(2121)] = 126657,
  [SMALL_STATE(2122)] = 126701,
  [SMALL_STATE(2123)] = 126757,
  [SMALL_STATE(2124)] = 126795,
  [SMALL_STATE(2125)] = 126839,
  [SMALL_STATE(2126)] = 126885,
  [SMALL_STATE(2127)] = 126937,
  [SMALL_STATE(2128)] = 126981,
  [SMALL_STATE(2129)] = 127059,
  [SMALL_STATE(2130)] = 127135,
  [SMALL_STATE(2131)] = 127173,
  [SMALL_STATE(2132)] = 127217,
  [SMALL_STATE(2133)] = 127269,
  [SMALL_STATE(2134)] = 127307,
  [SMALL_STATE(2135)] = 127345,
  [SMALL_STATE(2136)] = 127389,
  [SMALL_STATE(2137)] = 127431,
  [SMALL_STATE(2138)] = 127469,
  [SMALL_STATE(2139)] = 127513,
  [SMALL_STATE(2140)] = 127551,
  [SMALL_STATE(2141)] = 127629,
  [SMALL_STATE(2142)] = 127673,
  [SMALL_STATE(2143)] = 127717,
  [SMALL_STATE(2144)] = 127761,
  [SMALL_STATE(2145)] = 127805,
  [SMALL_STATE(2146)] = 127849,
  [SMALL_STATE(2147)] = 127893,
  [SMALL_STATE(2148)] = 127937,
  [SMALL_STATE(2149)] = 127981,
  [SMALL_STATE(2150)] = 128025,
  [SMALL_STATE(2151)] = 128063,
  [SMALL_STATE(2152)] = 128107,
  [SMALL_STATE(2153)] = 128159,
  [SMALL_STATE(2154)] = 128235,
  [SMALL_STATE(2155)] = 128279,
  [SMALL_STATE(2156)] = 128323,
  [SMALL_STATE(2157)] = 128361,
  [SMALL_STATE(2158)] = 128405,
  [SMALL_STATE(2159)] = 128449,
  [SMALL_STATE(2160)] = 128487,
  [SMALL_STATE(2161)] = 128533,
  [SMALL_STATE(2162)] = 128591,
  [SMALL_STATE(2163)] = 128637,
  [SMALL_STATE(2164)] = 128679,
  [SMALL_STATE(2165)] = 128717,
  [SMALL_STATE(2166)] = 128761,
  [SMALL_STATE(2167)] = 128803,
  [SMALL_STATE(2168)] = 128847,
  [SMALL_STATE(2169)] = 128885,
  [SMALL_STATE(2170)] = 128937,
  [SMALL_STATE(2171)] = 128989,
  [SMALL_STATE(2172)] = 129033,
  [SMALL_STATE(2173)] = 129077,
  [SMALL_STATE(2174)] = 129131,
  [SMALL_STATE(2175)] = 129205,
  [SMALL_STATE(2176)] = 129243,
  [SMALL_STATE(2177)] = 129295,
  [SMALL_STATE(2178)] = 129335,
  [SMALL_STATE(2179)] = 129387,
  [SMALL_STATE(2180)] = 129439,
  [SMALL_STATE(2181)] = 129491,
  [SMALL_STATE(2182)] = 129543,
  [SMALL_STATE(2183)] = 129591,
  [SMALL_STATE(2184)] = 129629,
  [SMALL_STATE(2185)] = 129667,
  [SMALL_STATE(2186)] = 129713,
  [SMALL_STATE(2187)] = 129751,
  [SMALL_STATE(2188)] = 129795,
  [SMALL_STATE(2189)] = 129839,
  [SMALL_STATE(2190)] = 129883,
  [SMALL_STATE(2191)] = 129927,
  [SMALL_STATE(2192)] = 129971,
  [SMALL_STATE(2193)] = 130015,
  [SMALL_STATE(2194)] = 130059,
  [SMALL_STATE(2195)] = 130103,
  [SMALL_STATE(2196)] = 130147,
  [SMALL_STATE(2197)] = 130191,
  [SMALL_STATE(2198)] = 130235,
  [SMALL_STATE(2199)] = 130279,
  [SMALL_STATE(2200)] = 130323,
  [SMALL_STATE(2201)] = 130367,
  [SMALL_STATE(2202)] = 130411,
  [SMALL_STATE(2203)] = 130449,
  [SMALL_STATE(2204)] = 130505,
  [SMALL_STATE(2205)] = 130549,
  [SMALL_STATE(2206)] = 130593,
  [SMALL_STATE(2207)] = 130637,
  [SMALL_STATE(2208)] = 130689,
  [SMALL_STATE(2209)] = 130733,
  [SMALL_STATE(2210)] = 130777,
  [SMALL_STATE(2211)] = 130851,
  [SMALL_STATE(2212)] = 130895,
  [SMALL_STATE(2213)] = 130937,
  [SMALL_STATE(2214)] = 130979,
  [SMALL_STATE(2215)] = 131023,
  [SMALL_STATE(2216)] = 131067,
  [SMALL_STATE(2217)] = 131111,
  [SMALL_STATE(2218)] = 131187,
  [SMALL_STATE(2219)] = 131225,
  [SMALL_STATE(2220)] = 131269,
  [SMALL_STATE(2221)] = 131313,
  [SMALL_STATE(2222)] = 131357,
  [SMALL_STATE(2223)] = 131401,
  [SMALL_STATE(2224)] = 131445,
  [SMALL_STATE(2225)] = 131497,
  [SMALL_STATE(2226)] = 131541,
  [SMALL_STATE(2227)] = 131585,
  [SMALL_STATE(2228)] = 131629,
  [SMALL_STATE(2229)] = 131673,
  [SMALL_STATE(2230)] = 131717,
  [SMALL_STATE(2231)] = 131761,
  [SMALL_STATE(2232)] = 131805,
  [SMALL_STATE(2233)] = 131849,
  [SMALL_STATE(2234)] = 131893,
  [SMALL_STATE(2235)] = 131937,
  [SMALL_STATE(2236)] = 132011,
  [SMALL_STATE(2237)] = 132055,
  [SMALL_STATE(2238)] = 132099,
  [SMALL_STATE(2239)] = 132141,
  [SMALL_STATE(2240)] = 132185,
  [SMALL_STATE(2241)] = 132229,
  [SMALL_STATE(2242)] = 132267,
  [SMALL_STATE(2243)] = 132311,
  [SMALL_STATE(2244)] = 132349,
  [SMALL_STATE(2245)] = 132395,
  [SMALL_STATE(2246)] = 132437,
  [SMALL_STATE(2247)] = 132515,
  [SMALL_STATE(2248)] = 132571,
  [SMALL_STATE(2249)] = 132615,
  [SMALL_STATE(2250)] = 132653,
  [SMALL_STATE(2251)] = 132695,
  [SMALL_STATE(2252)] = 132733,
  [SMALL_STATE(2253)] = 132777,
  [SMALL_STATE(2254)] = 132842,
  [SMALL_STATE(2255)] = 132889,
  [SMALL_STATE(2256)] = 132958,
  [SMALL_STATE(2257)] = 133007,
  [SMALL_STATE(2258)] = 133056,
  [SMALL_STATE(2259)] = 133129,
  [SMALL_STATE(2260)] = 133176,
  [SMALL_STATE(2261)] = 133225,
  [SMALL_STATE(2262)] = 133290,
  [SMALL_STATE(2263)] = 133353,
  [SMALL_STATE(2264)] = 133400,
  [SMALL_STATE(2265)] = 133459,
  [SMALL_STATE(2266)] = 133506,
  [SMALL_STATE(2267)] = 133553,
  [SMALL_STATE(2268)] = 133600,
  [SMALL_STATE(2269)] = 133649,
  [SMALL_STATE(2270)] = 133708,
  [SMALL_STATE(2271)] = 133777,
  [SMALL_STATE(2272)] = 133832,
  [SMALL_STATE(2273)] = 133899,
  [SMALL_STATE(2274)] = 133936,
  [SMALL_STATE(2275)] = 133997,
  [SMALL_STATE(2276)] = 134070,
  [SMALL_STATE(2277)] = 134115,
  [SMALL_STATE(2278)] = 134152,
  [SMALL_STATE(2279)] = 134225,
  [SMALL_STATE(2280)] = 134266,
  [SMALL_STATE(2281)] = 134339,
  [SMALL_STATE(2282)] = 134412,
  [SMALL_STATE(2283)] = 134485,
  [SMALL_STATE(2284)] = 134558,
  [SMALL_STATE(2285)] = 134631,
  [SMALL_STATE(2286)] = 134668,
  [SMALL_STATE(2287)] = 134729,
  [SMALL_STATE(2288)] = 134802,
  [SMALL_STATE(2289)] = 134843,
  [SMALL_STATE(2290)] = 134908,
  [SMALL_STATE(2291)] = 134945,
  [SMALL_STATE(2292)] = 135004,
  [SMALL_STATE(2293)] = 135077,
  [SMALL_STATE(2294)] = 135124,
  [SMALL_STATE(2295)] = 135195,
  [SMALL_STATE(2296)] = 135268,
  [SMALL_STATE(2297)] = 135341,
  [SMALL_STATE(2298)] = 135414,
  [SMALL_STATE(2299)] = 135459,
  [SMALL_STATE(2300)] = 135528,
  [SMALL_STATE(2301)] = 135597,
  [SMALL_STATE(2302)] = 135670,
  [SMALL_STATE(2303)] = 135719,
  [SMALL_STATE(2304)] = 135788,
  [SMALL_STATE(2305)] = 135861,
  [SMALL_STATE(2306)] = 135908,
  [SMALL_STATE(2307)] = 135981,
  [SMALL_STATE(2308)] = 136050,
  [SMALL_STATE(2309)] = 136113,
  [SMALL_STATE(2310)] = 136186,
  [SMALL_STATE(2311)] = 136243,
  [SMALL_STATE(2312)] = 136316,
  [SMALL_STATE(2313)] = 136389,
  [SMALL_STATE(2314)] = 136458,
  [SMALL_STATE(2315)] = 136509,
  [SMALL_STATE(2316)] = 136582,
  [SMALL_STATE(2317)] = 136651,
  [SMALL_STATE(2318)] = 136692,
  [SMALL_STATE(2319)] = 136755,
  [SMALL_STATE(2320)] = 136824,
  [SMALL_STATE(2321)] = 136873,
  [SMALL_STATE(2322)] = 136924,
  [SMALL_STATE(2323)] = 136991,
  [SMALL_STATE(2324)] = 137040,
  [SMALL_STATE(2325)] = 137103,
  [SMALL_STATE(2326)] = 137164,
  [SMALL_STATE(2327)] = 137221,
  [SMALL_STATE(2328)] = 137274,
  [SMALL_STATE(2329)] = 137339,
  [SMALL_STATE(2330)] = 137398,
  [SMALL_STATE(2331)] = 137469,
  [SMALL_STATE(2332)] = 137540,
  [SMALL_STATE(2333)] = 137611,
  [SMALL_STATE(2334)] = 137682,
  [SMALL_STATE(2335)] = 137753,
  [SMALL_STATE(2336)] = 137824,
  [SMALL_STATE(2337)] = 137889,
  [SMALL_STATE(2338)] = 137938,
  [SMALL_STATE(2339)] = 137999,
  [SMALL_STATE(2340)] = 138062,
  [SMALL_STATE(2341)] = 138135,
  [SMALL_STATE(2342)] = 138208,
  [SMALL_STATE(2343)] = 138281,
  [SMALL_STATE(2344)] = 138318,
  [SMALL_STATE(2345)] = 138389,
  [SMALL_STATE(2346)] = 138434,
  [SMALL_STATE(2347)] = 138489,
  [SMALL_STATE(2348)] = 138560,
  [SMALL_STATE(2349)] = 138607,
  [SMALL_STATE(2350)] = 138678,
  [SMALL_STATE(2351)] = 138727,
  [SMALL_STATE(2352)] = 138798,
  [SMALL_STATE(2353)] = 138839,
  [SMALL_STATE(2354)] = 138876,
  [SMALL_STATE(2355)] = 138921,
  [SMALL_STATE(2356)] = 138980,
  [SMALL_STATE(2357)] = 139033,
  [SMALL_STATE(2358)] = 139080,
  [SMALL_STATE(2359)] = 139127,
  [SMALL_STATE(2360)] = 139200,
  [SMALL_STATE(2361)] = 139273,
  [SMALL_STATE(2362)] = 139320,
  [SMALL_STATE(2363)] = 139393,
  [SMALL_STATE(2364)] = 139462,
  [SMALL_STATE(2365)] = 139531,
  [SMALL_STATE(2366)] = 139568,
  [SMALL_STATE(2367)] = 139641,
  [SMALL_STATE(2368)] = 139714,
  [SMALL_STATE(2369)] = 139761,
  [SMALL_STATE(2370)] = 139798,
  [SMALL_STATE(2371)] = 139839,
  [SMALL_STATE(2372)] = 139880,
  [SMALL_STATE(2373)] = 139921,
  [SMALL_STATE(2374)] = 139968,
  [SMALL_STATE(2375)] = 140041,
  [SMALL_STATE(2376)] = 140092,
  [SMALL_STATE(2377)] = 140139,
  [SMALL_STATE(2378)] = 140204,
  [SMALL_STATE(2379)] = 140241,
  [SMALL_STATE(2380)] = 140278,
  [SMALL_STATE(2381)] = 140327,
  [SMALL_STATE(2382)] = 140368,
  [SMALL_STATE(2383)] = 140415,
  [SMALL_STATE(2384)] = 140452,
  [SMALL_STATE(2385)] = 140497,
  [SMALL_STATE(2386)] = 140544,
  [SMALL_STATE(2387)] = 140589,
  [SMALL_STATE(2388)] = 140638,
  [SMALL_STATE(2389)] = 140701,
  [SMALL_STATE(2390)] = 140762,
  [SMALL_STATE(2391)] = 140819,
  [SMALL_STATE(2392)] = 140866,
  [SMALL_STATE(2393)] = 140913,
  [SMALL_STATE(2394)] = 140966,
  [SMALL_STATE(2395)] = 141013,
  [SMALL_STATE(2396)] = 141076,
  [SMALL_STATE(2397)] = 141117,
  [SMALL_STATE(2398)] = 141166,
  [SMALL_STATE(2399)] = 141207,
  [SMALL_STATE(2400)] = 141248,
  [SMALL_STATE(2401)] = 141321,
  [SMALL_STATE(2402)] = 141362,
  [SMALL_STATE(2403)] = 141407,
  [SMALL_STATE(2404)] = 141480,
  [SMALL_STATE(2405)] = 141527,
  [SMALL_STATE(2406)] = 141568,
  [SMALL_STATE(2407)] = 141639,
  [SMALL_STATE(2408)] = 141680,
  [SMALL_STATE(2409)] = 141733,
  [SMALL_STATE(2410)] = 141780,
  [SMALL_STATE(2411)] = 141821,
  [SMALL_STATE(2412)] = 141870,
  [SMALL_STATE(2413)] = 141937,
  [SMALL_STATE(2414)] = 141978,
  [SMALL_STATE(2415)] = 142051,
  [SMALL_STATE(2416)] = 142092,
  [SMALL_STATE(2417)] = 142143,
  [SMALL_STATE(2418)] = 142184,
  [SMALL_STATE(2419)] = 142237,
  [SMALL_STATE(2420)] = 142286,
  [SMALL_STATE(2421)] = 142359,
  [SMALL_STATE(2422)] = 142408,
  [SMALL_STATE(2423)] = 142445,
  [SMALL_STATE(2424)] = 142493,
  [SMALL_STATE(2425)] = 142529,
  [SMALL_STATE(2426)] = 142573,
  [SMALL_STATE(2427)] = 142619,
  [SMALL_STATE(2428)] = 142665,
  [SMALL_STATE(2429)] = 142713,
  [SMALL_STATE(2430)] = 142751,
  [SMALL_STATE(2431)] = 142797,
  [SMALL_STATE(2432)] = 142867,
  [SMALL_STATE(2433)] = 142937,
  [SMALL_STATE(2434)] = 143007,
  [SMALL_STATE(2435)] = 143047,
  [SMALL_STATE(2436)] = 143083,
  [SMALL_STATE(2437)] = 143119,
  [SMALL_STATE(2438)] = 143169,
  [SMALL_STATE(2439)] = 143233,
  [SMALL_STATE(2440)] = 143295,
  [SMALL_STATE(2441)] = 143355,
  [SMALL_STATE(2442)] = 143411,
  [SMALL_STATE(2443)] = 143463,
  [SMALL_STATE(2444)] = 143525,
  [SMALL_STATE(2445)] = 143583,
  [SMALL_STATE(2446)] = 143651,
  [SMALL_STATE(2447)] = 143719,
  [SMALL_STATE(2448)] = 143787,
  [SMALL_STATE(2449)] = 143855,
  [SMALL_STATE(2450)] = 143923,
  [SMALL_STATE(2451)] = 143991,
  [SMALL_STATE(2452)] = 144061,
  [SMALL_STATE(2453)] = 144129,
  [SMALL_STATE(2454)] = 144165,
  [SMALL_STATE(2455)] = 144201,
  [SMALL_STATE(2456)] = 144237,
  [SMALL_STATE(2457)] = 144307,
  [SMALL_STATE(2458)] = 144377,
  [SMALL_STATE(2459)] = 144447,
  [SMALL_STATE(2460)] = 144493,
  [SMALL_STATE(2461)] = 144563,
  [SMALL_STATE(2462)] = 144633,
  [SMALL_STATE(2463)] = 144701,
  [SMALL_STATE(2464)] = 144737,
  [SMALL_STATE(2465)] = 144773,
  [SMALL_STATE(2466)] = 144843,
  [SMALL_STATE(2467)] = 144879,
  [SMALL_STATE(2468)] = 144915,
  [SMALL_STATE(2469)] = 144985,
  [SMALL_STATE(2470)] = 145037,
  [SMALL_STATE(2471)] = 145103,
  [SMALL_STATE(2472)] = 145151,
  [SMALL_STATE(2473)] = 145215,
  [SMALL_STATE(2474)] = 145277,
  [SMALL_STATE(2475)] = 145335,
  [SMALL_STATE(2476)] = 145389,
  [SMALL_STATE(2477)] = 145435,
  [SMALL_STATE(2478)] = 145499,
  [SMALL_STATE(2479)] = 145559,
  [SMALL_STATE(2480)] = 145629,
  [SMALL_STATE(2481)] = 145699,
  [SMALL_STATE(2482)] = 145735,
  [SMALL_STATE(2483)] = 145771,
  [SMALL_STATE(2484)] = 145839,
  [SMALL_STATE(2485)] = 145875,
  [SMALL_STATE(2486)] = 145945,
  [SMALL_STATE(2487)] = 145981,
  [SMALL_STATE(2488)] = 146017,
  [SMALL_STATE(2489)] = 146063,
  [SMALL_STATE(2490)] = 146109,
  [SMALL_STATE(2491)] = 146147,
  [SMALL_STATE(2492)] = 146185,
  [SMALL_STATE(2493)] = 146255,
  [SMALL_STATE(2494)] = 146325,
  [SMALL_STATE(2495)] = 146395,
  [SMALL_STATE(2496)] = 146465,
  [SMALL_STATE(2497)] = 146535,
  [SMALL_STATE(2498)] = 146605,
  [SMALL_STATE(2499)] = 146675,
  [SMALL_STATE(2500)] = 146745,
  [SMALL_STATE(2501)] = 146781,
  [SMALL_STATE(2502)] = 146817,
  [SMALL_STATE(2503)] = 146865,
  [SMALL_STATE(2504)] = 146901,
  [SMALL_STATE(2505)] = 146937,
  [SMALL_STATE(2506)] = 147007,
  [SMALL_STATE(2507)] = 147043,
  [SMALL_STATE(2508)] = 147079,
  [SMALL_STATE(2509)] = 147149,
  [SMALL_STATE(2510)] = 147219,
  [SMALL_STATE(2511)] = 147289,
  [SMALL_STATE(2512)] = 147359,
  [SMALL_STATE(2513)] = 147399,
  [SMALL_STATE(2514)] = 147469,
  [SMALL_STATE(2515)] = 147539,
  [SMALL_STATE(2516)] = 147581,
  [SMALL_STATE(2517)] = 147617,
  [SMALL_STATE(2518)] = 147655,
  [SMALL_STATE(2519)] = 147725,
  [SMALL_STATE(2520)] = 147795,
  [SMALL_STATE(2521)] = 147863,
  [SMALL_STATE(2522)] = 147898,
  [SMALL_STATE(2523)] = 147933,
  [SMALL_STATE(2524)] = 147968,
  [SMALL_STATE(2525)] = 148035,
  [SMALL_STATE(2526)] = 148084,
  [SMALL_STATE(2527)] = 148145,
  [SMALL_STATE(2528)] = 148208,
  [SMALL_STATE(2529)] = 148255,
  [SMALL_STATE(2530)] = 148314,
  [SMALL_STATE(2531)] = 148371,
  [SMALL_STATE(2532)] = 148422,
  [SMALL_STATE(2533)] = 148467,
  [SMALL_STATE(2534)] = 148528,
  [SMALL_STATE(2535)] = 148583,
  [SMALL_STATE(2536)] = 148650,
  [SMALL_STATE(2537)] = 148717,
  [SMALL_STATE(2538)] = 148752,
  [SMALL_STATE(2539)] = 148787,
  [SMALL_STATE(2540)] = 148854,
  [SMALL_STATE(2541)] = 148921,
  [SMALL_STATE(2542)] = 148988,
  [SMALL_STATE(2543)] = 149023,
  [SMALL_STATE(2544)] = 149064,
  [SMALL_STATE(2545)] = 149099,
  [SMALL_STATE(2546)] = 149166,
  [SMALL_STATE(2547)] = 149233,
  [SMALL_STATE(2548)] = 149268,
  [SMALL_STATE(2549)] = 149303,
  [SMALL_STATE(2550)] = 149338,
  [SMALL_STATE(2551)] = 149405,
  [SMALL_STATE(2552)] = 149440,
  [SMALL_STATE(2553)] = 149475,
  [SMALL_STATE(2554)] = 149542,
  [SMALL_STATE(2555)] = 149609,
  [SMALL_STATE(2556)] = 149644,
  [SMALL_STATE(2557)] = 149679,
  [SMALL_STATE(2558)] = 149746,
  [SMALL_STATE(2559)] = 149781,
  [SMALL_STATE(2560)] = 149816,
  [SMALL_STATE(2561)] = 149851,
  [SMALL_STATE(2562)] = 149886,
  [SMALL_STATE(2563)] = 149953,
  [SMALL_STATE(2564)] = 149990,
  [SMALL_STATE(2565)] = 150025,
  [SMALL_STATE(2566)] = 150060,
  [SMALL_STATE(2567)] = 150127,
  [SMALL_STATE(2568)] = 150162,
  [SMALL_STATE(2569)] = 150197,
  [SMALL_STATE(2570)] = 150232,
  [SMALL_STATE(2571)] = 150267,
  [SMALL_STATE(2572)] = 150302,
  [SMALL_STATE(2573)] = 150369,
  [SMALL_STATE(2574)] = 150436,
  [SMALL_STATE(2575)] = 150503,
  [SMALL_STATE(2576)] = 150538,
  [SMALL_STATE(2577)] = 150605,
  [SMALL_STATE(2578)] = 150640,
  [SMALL_STATE(2579)] = 150707,
  [SMALL_STATE(2580)] = 150742,
  [SMALL_STATE(2581)] = 150777,
  [SMALL_STATE(2582)] = 150812,
  [SMALL_STATE(2583)] = 150847,
  [SMALL_STATE(2584)] = 150914,
  [SMALL_STATE(2585)] = 150949,
  [SMALL_STATE(2586)] = 150990,
  [SMALL_STATE(2587)] = 151031,
  [SMALL_STATE(2588)] = 151098,
  [SMALL_STATE(2589)] = 151139,
  [SMALL_STATE(2590)] = 151184,
  [SMALL_STATE(2591)] = 151251,
  [SMALL_STATE(2592)] = 151318,
  [SMALL_STATE(2593)] = 151363,
  [SMALL_STATE(2594)] = 151406,
  [SMALL_STATE(2595)] = 151445,
  [SMALL_STATE(2596)] = 151480,
  [SMALL_STATE(2597)] = 151547,
  [SMALL_STATE(2598)] = 151582,
  [SMALL_STATE(2599)] = 151617,
  [SMALL_STATE(2600)] = 151684,
  [SMALL_STATE(2601)] = 151751,
  [SMALL_STATE(2602)] = 151786,
  [SMALL_STATE(2603)] = 151821,
  [SMALL_STATE(2604)] = 151856,
  [SMALL_STATE(2605)] = 151891,
  [SMALL_STATE(2606)] = 151926,
  [SMALL_STATE(2607)] = 151961,
  [SMALL_STATE(2608)] = 151996,
  [SMALL_STATE(2609)] = 152031,
  [SMALL_STATE(2610)] = 152066,
  [SMALL_STATE(2611)] = 152101,
  [SMALL_STATE(2612)] = 152136,
  [SMALL_STATE(2613)] = 152203,
  [SMALL_STATE(2614)] = 152270,
  [SMALL_STATE(2615)] = 152309,
  [SMALL_STATE(2616)] = 152346,
  [SMALL_STATE(2617)] = 152381,
  [SMALL_STATE(2618)] = 152448,
  [SMALL_STATE(2619)] = 152482,
  [SMALL_STATE(2620)] = 152516,
  [SMALL_STATE(2621)] = 152550,
  [SMALL_STATE(2622)] = 152584,
  [SMALL_STATE(2623)] = 152618,
  [SMALL_STATE(2624)] = 152652,
  [SMALL_STATE(2625)] = 152686,
  [SMALL_STATE(2626)] = 152720,
  [SMALL_STATE(2627)] = 152754,
  [SMALL_STATE(2628)] = 152788,
  [SMALL_STATE(2629)] = 152822,
  [SMALL_STATE(2630)] = 152886,
  [SMALL_STATE(2631)] = 152920,
  [SMALL_STATE(2632)] = 152954,
  [SMALL_STATE(2633)] = 152988,
  [SMALL_STATE(2634)] = 153022,
  [SMALL_STATE(2635)] = 153056,
  [SMALL_STATE(2636)] = 153090,
  [SMALL_STATE(2637)] = 153124,
  [SMALL_STATE(2638)] = 153158,
  [SMALL_STATE(2639)] = 153192,
  [SMALL_STATE(2640)] = 153226,
  [SMALL_STATE(2641)] = 153260,
  [SMALL_STATE(2642)] = 153324,
  [SMALL_STATE(2643)] = 153358,
  [SMALL_STATE(2644)] = 153392,
  [SMALL_STATE(2645)] = 153426,
  [SMALL_STATE(2646)] = 153460,
  [SMALL_STATE(2647)] = 153494,
  [SMALL_STATE(2648)] = 153530,
  [SMALL_STATE(2649)] = 153564,
  [SMALL_STATE(2650)] = 153598,
  [SMALL_STATE(2651)] = 153632,
  [SMALL_STATE(2652)] = 153668,
  [SMALL_STATE(2653)] = 153732,
  [SMALL_STATE(2654)] = 153766,
  [SMALL_STATE(2655)] = 153800,
  [SMALL_STATE(2656)] = 153834,
  [SMALL_STATE(2657)] = 153898,
  [SMALL_STATE(2658)] = 153932,
  [SMALL_STATE(2659)] = 153966,
  [SMALL_STATE(2660)] = 154000,
  [SMALL_STATE(2661)] = 154034,
  [SMALL_STATE(2662)] = 154098,
  [SMALL_STATE(2663)] = 154132,
  [SMALL_STATE(2664)] = 154166,
  [SMALL_STATE(2665)] = 154200,
  [SMALL_STATE(2666)] = 154264,
  [SMALL_STATE(2667)] = 154298,
  [SMALL_STATE(2668)] = 154332,
  [SMALL_STATE(2669)] = 154366,
  [SMALL_STATE(2670)] = 154400,
  [SMALL_STATE(2671)] = 154434,
  [SMALL_STATE(2672)] = 154468,
  [SMALL_STATE(2673)] = 154502,
  [SMALL_STATE(2674)] = 154536,
  [SMALL_STATE(2675)] = 154570,
  [SMALL_STATE(2676)] = 154604,
  [SMALL_STATE(2677)] = 154638,
  [SMALL_STATE(2678)] = 154672,
  [SMALL_STATE(2679)] = 154710,
  [SMALL_STATE(2680)] = 154744,
  [SMALL_STATE(2681)] = 154778,
  [SMALL_STATE(2682)] = 154812,
  [SMALL_STATE(2683)] = 154846,
  [SMALL_STATE(2684)] = 154880,
  [SMALL_STATE(2685)] = 154914,
  [SMALL_STATE(2686)] = 154948,
  [SMALL_STATE(2687)] = 154982,
  [SMALL_STATE(2688)] = 155044,
  [SMALL_STATE(2689)] = 155108,
  [SMALL_STATE(2690)] = 155142,
  [SMALL_STATE(2691)] = 155176,
  [SMALL_STATE(2692)] = 155210,
  [SMALL_STATE(2693)] = 155244,
  [SMALL_STATE(2694)] = 155278,
  [SMALL_STATE(2695)] = 155312,
  [SMALL_STATE(2696)] = 155346,
  [SMALL_STATE(2697)] = 155380,
  [SMALL_STATE(2698)] = 155414,
  [SMALL_STATE(2699)] = 155448,
  [SMALL_STATE(2700)] = 155482,
  [SMALL_STATE(2701)] = 155541,
  [SMALL_STATE(2702)] = 155600,
  [SMALL_STATE(2703)] = 155635,
  [SMALL_STATE(2704)] = 155691,
  [SMALL_STATE(2705)] = 155761,
  [SMALL_STATE(2706)] = 155817,
  [SMALL_STATE(2707)] = 155853,
  [SMALL_STATE(2708)] = 155889,
  [SMALL_STATE(2709)] = 155923,
  [SMALL_STATE(2710)] = 155978,
  [SMALL_STATE(2711)] = 156031,
  [SMALL_STATE(2712)] = 156086,
  [SMALL_STATE(2713)] = 156139,
  [SMALL_STATE(2714)] = 156189,
  [SMALL_STATE(2715)] = 156219,
  [SMALL_STATE(2716)] = 156266,
  [SMALL_STATE(2717)] = 156313,
  [SMALL_STATE(2718)] = 156365,
  [SMALL_STATE(2719)] = 156417,
  [SMALL_STATE(2720)] = 156469,
  [SMALL_STATE(2721)] = 156521,
  [SMALL_STATE(2722)] = 156573,
  [SMALL_STATE(2723)] = 156625,
  [SMALL_STATE(2724)] = 156677,
  [SMALL_STATE(2725)] = 156729,
  [SMALL_STATE(2726)] = 156781,
  [SMALL_STATE(2727)] = 156833,
  [SMALL_STATE(2728)] = 156885,
  [SMALL_STATE(2729)] = 156933,
  [SMALL_STATE(2730)] = 156981,
  [SMALL_STATE(2731)] = 157023,
  [SMALL_STATE(2732)] = 157071,
  [SMALL_STATE(2733)] = 157119,
  [SMALL_STATE(2734)] = 157167,
  [SMALL_STATE(2735)] = 157215,
  [SMALL_STATE(2736)] = 157263,
  [SMALL_STATE(2737)] = 157315,
  [SMALL_STATE(2738)] = 157363,
  [SMALL_STATE(2739)] = 157411,
  [SMALL_STATE(2740)] = 157459,
  [SMALL_STATE(2741)] = 157507,
  [SMALL_STATE(2742)] = 157555,
  [SMALL_STATE(2743)] = 157603,
  [SMALL_STATE(2744)] = 157651,
  [SMALL_STATE(2745)] = 157699,
  [SMALL_STATE(2746)] = 157747,
  [SMALL_STATE(2747)] = 157795,
  [SMALL_STATE(2748)] = 157843,
  [SMALL_STATE(2749)] = 157891,
  [SMALL_STATE(2750)] = 157939,
  [SMALL_STATE(2751)] = 157987,
  [SMALL_STATE(2752)] = 158039,
  [SMALL_STATE(2753)] = 158087,
  [SMALL_STATE(2754)] = 158135,
  [SMALL_STATE(2755)] = 158183,
  [SMALL_STATE(2756)] = 158231,
  [SMALL_STATE(2757)] = 158279,
  [SMALL_STATE(2758)] = 158327,
  [SMALL_STATE(2759)] = 158375,
  [SMALL_STATE(2760)] = 158423,
  [SMALL_STATE(2761)] = 158471,
  [SMALL_STATE(2762)] = 158519,
  [SMALL_STATE(2763)] = 158567,
  [SMALL_STATE(2764)] = 158615,
  [SMALL_STATE(2765)] = 158663,
  [SMALL_STATE(2766)] = 158711,
  [SMALL_STATE(2767)] = 158759,
  [SMALL_STATE(2768)] = 158807,
  [SMALL_STATE(2769)] = 158855,
  [SMALL_STATE(2770)] = 158903,
  [SMALL_STATE(2771)] = 158951,
  [SMALL_STATE(2772)] = 159003,
  [SMALL_STATE(2773)] = 159051,
  [SMALL_STATE(2774)] = 159103,
  [SMALL_STATE(2775)] = 159151,
  [SMALL_STATE(2776)] = 159199,
  [SMALL_STATE(2777)] = 159247,
  [SMALL_STATE(2778)] = 159295,
  [SMALL_STATE(2779)] = 159343,
  [SMALL_STATE(2780)] = 159391,
  [SMALL_STATE(2781)] = 159439,
  [SMALL_STATE(2782)] = 159487,
  [SMALL_STATE(2783)] = 159535,
  [SMALL_STATE(2784)] = 159583,
  [SMALL_STATE(2785)] = 159631,
  [SMALL_STATE(2786)] = 159679,
  [SMALL_STATE(2787)] = 159731,
  [SMALL_STATE(2788)] = 159779,
  [SMALL_STATE(2789)] = 159812,
  [SMALL_STATE(2790)] = 159861,
  [SMALL_STATE(2791)] = 159910,
  [SMALL_STATE(2792)] = 159945,
  [SMALL_STATE(2793)] = 159994,
  [SMALL_STATE(2794)] = 160043,
  [SMALL_STATE(2795)] = 160092,
  [SMALL_STATE(2796)] = 160132,
  [SMALL_STATE(2797)] = 160172,
  [SMALL_STATE(2798)] = 160212,
  [SMALL_STATE(2799)] = 160252,
  [SMALL_STATE(2800)] = 160292,
  [SMALL_STATE(2801)] = 160332,
  [SMALL_STATE(2802)] = 160372,
  [SMALL_STATE(2803)] = 160412,
  [SMALL_STATE(2804)] = 160436,
  [SMALL_STATE(2805)] = 160481,
  [SMALL_STATE(2806)] = 160504,
  [SMALL_STATE(2807)] = 160527,
  [SMALL_STATE(2808)] = 160554,
  [SMALL_STATE(2809)] = 160579,
  [SMALL_STATE(2810)] = 160610,
  [SMALL_STATE(2811)] = 160639,
  [SMALL_STATE(2812)] = 160668,
  [SMALL_STATE(2813)] = 160697,
  [SMALL_STATE(2814)] = 160726,
  [SMALL_STATE(2815)] = 160749,
  [SMALL_STATE(2816)] = 160777,
  [SMALL_STATE(2817)] = 160817,
  [SMALL_STATE(2818)] = 160845,
  [SMALL_STATE(2819)] = 160873,
  [SMALL_STATE(2820)] = 160909,
  [SMALL_STATE(2821)] = 160949,
  [SMALL_STATE(2822)] = 160985,
  [SMALL_STATE(2823)] = 161021,
  [SMALL_STATE(2824)] = 161047,
  [SMALL_STATE(2825)] = 161083,
  [SMALL_STATE(2826)] = 161119,
  [SMALL_STATE(2827)] = 161147,
  [SMALL_STATE(2828)] = 161183,
  [SMALL_STATE(2829)] = 161219,
  [SMALL_STATE(2830)] = 161255,
  [SMALL_STATE(2831)] = 161291,
  [SMALL_STATE(2832)] = 161327,
  [SMALL_STATE(2833)] = 161363,
  [SMALL_STATE(2834)] = 161399,
  [SMALL_STATE(2835)] = 161427,
  [SMALL_STATE(2836)] = 161463,
  [SMALL_STATE(2837)] = 161499,
  [SMALL_STATE(2838)] = 161535,
  [SMALL_STATE(2839)] = 161561,
  [SMALL_STATE(2840)] = 161583,
  [SMALL_STATE(2841)] = 161619,
  [SMALL_STATE(2842)] = 161642,
  [SMALL_STATE(2843)] = 161677,
  [SMALL_STATE(2844)] = 161700,
  [SMALL_STATE(2845)] = 161737,
  [SMALL_STATE(2846)] = 161760,
  [SMALL_STATE(2847)] = 161783,
  [SMALL_STATE(2848)] = 161820,
  [SMALL_STATE(2849)] = 161843,
  [SMALL_STATE(2850)] = 161878,
  [SMALL_STATE(2851)] = 161901,
  [SMALL_STATE(2852)] = 161924,
  [SMALL_STATE(2853)] = 161953,
  [SMALL_STATE(2854)] = 161976,
  [SMALL_STATE(2855)] = 161999,
  [SMALL_STATE(2856)] = 162022,
  [SMALL_STATE(2857)] = 162045,
  [SMALL_STATE(2858)] = 162068,
  [SMALL_STATE(2859)] = 162101,
  [SMALL_STATE(2860)] = 162126,
  [SMALL_STATE(2861)] = 162149,
  [SMALL_STATE(2862)] = 162172,
  [SMALL_STATE(2863)] = 162195,
  [SMALL_STATE(2864)] = 162232,
  [SMALL_STATE(2865)] = 162255,
  [SMALL_STATE(2866)] = 162280,
  [SMALL_STATE(2867)] = 162307,
  [SMALL_STATE(2868)] = 162332,
  [SMALL_STATE(2869)] = 162365,
  [SMALL_STATE(2870)] = 162398,
  [SMALL_STATE(2871)] = 162421,
  [SMALL_STATE(2872)] = 162444,
  [SMALL_STATE(2873)] = 162467,
  [SMALL_STATE(2874)] = 162490,
  [SMALL_STATE(2875)] = 162513,
  [SMALL_STATE(2876)] = 162536,
  [SMALL_STATE(2877)] = 162561,
  [SMALL_STATE(2878)] = 162584,
  [SMALL_STATE(2879)] = 162607,
  [SMALL_STATE(2880)] = 162640,
  [SMALL_STATE(2881)] = 162674,
  [SMALL_STATE(2882)] = 162700,
  [SMALL_STATE(2883)] = 162726,
  [SMALL_STATE(2884)] = 162752,
  [SMALL_STATE(2885)] = 162778,
  [SMALL_STATE(2886)] = 162810,
  [SMALL_STATE(2887)] = 162836,
  [SMALL_STATE(2888)] = 162862,
  [SMALL_STATE(2889)] = 162894,
  [SMALL_STATE(2890)] = 162920,
  [SMALL_STATE(2891)] = 162952,
  [SMALL_STATE(2892)] = 162986,
  [SMALL_STATE(2893)] = 163018,
  [SMALL_STATE(2894)] = 163050,
  [SMALL_STATE(2895)] = 163082,
  [SMALL_STATE(2896)] = 163116,
  [SMALL_STATE(2897)] = 163150,
  [SMALL_STATE(2898)] = 163182,
  [SMALL_STATE(2899)] = 163216,
  [SMALL_STATE(2900)] = 163248,
  [SMALL_STATE(2901)] = 163280,
  [SMALL_STATE(2902)] = 163300,
  [SMALL_STATE(2903)] = 163320,
  [SMALL_STATE(2904)] = 163352,
  [SMALL_STATE(2905)] = 163372,
  [SMALL_STATE(2906)] = 163392,
  [SMALL_STATE(2907)] = 163412,
  [SMALL_STATE(2908)] = 163446,
  [SMALL_STATE(2909)] = 163472,
  [SMALL_STATE(2910)] = 163506,
  [SMALL_STATE(2911)] = 163538,
  [SMALL_STATE(2912)] = 163564,
  [SMALL_STATE(2913)] = 163596,
  [SMALL_STATE(2914)] = 163628,
  [SMALL_STATE(2915)] = 163660,
  [SMALL_STATE(2916)] = 163694,
  [SMALL_STATE(2917)] = 163728,
  [SMALL_STATE(2918)] = 163766,
  [SMALL_STATE(2919)] = 163800,
  [SMALL_STATE(2920)] = 163832,
  [SMALL_STATE(2921)] = 163858,
  [SMALL_STATE(2922)] = 163890,
  [SMALL_STATE(2923)] = 163922,
  [SMALL_STATE(2924)] = 163954,
  [SMALL_STATE(2925)] = 163986,
  [SMALL_STATE(2926)] = 164020,
  [SMALL_STATE(2927)] = 164052,
  [SMALL_STATE(2928)] = 164084,
  [SMALL_STATE(2929)] = 164116,
  [SMALL_STATE(2930)] = 164150,
  [SMALL_STATE(2931)] = 164182,
  [SMALL_STATE(2932)] = 164216,
  [SMALL_STATE(2933)] = 164248,
  [SMALL_STATE(2934)] = 164280,
  [SMALL_STATE(2935)] = 164312,
  [SMALL_STATE(2936)] = 164346,
  [SMALL_STATE(2937)] = 164378,
  [SMALL_STATE(2938)] = 164410,
  [SMALL_STATE(2939)] = 164444,
  [SMALL_STATE(2940)] = 164470,
  [SMALL_STATE(2941)] = 164502,
  [SMALL_STATE(2942)] = 164534,
  [SMALL_STATE(2943)] = 164566,
  [SMALL_STATE(2944)] = 164600,
  [SMALL_STATE(2945)] = 164632,
  [SMALL_STATE(2946)] = 164664,
  [SMALL_STATE(2947)] = 164684,
  [SMALL_STATE(2948)] = 164718,
  [SMALL_STATE(2949)] = 164744,
  [SMALL_STATE(2950)] = 164776,
  [SMALL_STATE(2951)] = 164808,
  [SMALL_STATE(2952)] = 164842,
  [SMALL_STATE(2953)] = 164874,
  [SMALL_STATE(2954)] = 164906,
  [SMALL_STATE(2955)] = 164935,
  [SMALL_STATE(2956)] = 164964,
  [SMALL_STATE(2957)] = 164993,
  [SMALL_STATE(2958)] = 165022,
  [SMALL_STATE(2959)] = 165051,
  [SMALL_STATE(2960)] = 165080,
  [SMALL_STATE(2961)] = 165109,
  [SMALL_STATE(2962)] = 165138,
  [SMALL_STATE(2963)] = 165169,
  [SMALL_STATE(2964)] = 165198,
  [SMALL_STATE(2965)] = 165227,
  [SMALL_STATE(2966)] = 165258,
  [SMALL_STATE(2967)] = 165287,
  [SMALL_STATE(2968)] = 165318,
  [SMALL_STATE(2969)] = 165347,
  [SMALL_STATE(2970)] = 165376,
  [SMALL_STATE(2971)] = 165405,
  [SMALL_STATE(2972)] = 165436,
  [SMALL_STATE(2973)] = 165465,
  [SMALL_STATE(2974)] = 165490,
  [SMALL_STATE(2975)] = 165521,
  [SMALL_STATE(2976)] = 165550,
  [SMALL_STATE(2977)] = 165579,
  [SMALL_STATE(2978)] = 165608,
  [SMALL_STATE(2979)] = 165639,
  [SMALL_STATE(2980)] = 165668,
  [SMALL_STATE(2981)] = 165697,
  [SMALL_STATE(2982)] = 165728,
  [SMALL_STATE(2983)] = 165759,
  [SMALL_STATE(2984)] = 165788,
  [SMALL_STATE(2985)] = 165811,
  [SMALL_STATE(2986)] = 165836,
  [SMALL_STATE(2987)] = 165865,
  [SMALL_STATE(2988)] = 165894,
  [SMALL_STATE(2989)] = 165925,
  [SMALL_STATE(2990)] = 165954,
  [SMALL_STATE(2991)] = 165985,
  [SMALL_STATE(2992)] = 166014,
  [SMALL_STATE(2993)] = 166043,
  [SMALL_STATE(2994)] = 166070,
  [SMALL_STATE(2995)] = 166099,
  [SMALL_STATE(2996)] = 166130,
  [SMALL_STATE(2997)] = 166161,
  [SMALL_STATE(2998)] = 166190,
  [SMALL_STATE(2999)] = 166219,
  [SMALL_STATE(3000)] = 166250,
  [SMALL_STATE(3001)] = 166279,
  [SMALL_STATE(3002)] = 166310,
  [SMALL_STATE(3003)] = 166341,
  [SMALL_STATE(3004)] = 166370,
  [SMALL_STATE(3005)] = 166399,
  [SMALL_STATE(3006)] = 166428,
  [SMALL_STATE(3007)] = 166457,
  [SMALL_STATE(3008)] = 166488,
  [SMALL_STATE(3009)] = 166513,
  [SMALL_STATE(3010)] = 166538,
  [SMALL_STATE(3011)] = 166565,
  [SMALL_STATE(3012)] = 166590,
  [SMALL_STATE(3013)] = 166615,
  [SMALL_STATE(3014)] = 166646,
  [SMALL_STATE(3015)] = 166677,
  [SMALL_STATE(3016)] = 166706,
  [SMALL_STATE(3017)] = 166735,
  [SMALL_STATE(3018)] = 166759,
  [SMALL_STATE(3019)] = 166783,
  [SMALL_STATE(3020)] = 166801,
  [SMALL_STATE(3021)] = 166819,
  [SMALL_STATE(3022)] = 166843,
  [SMALL_STATE(3023)] = 166861,
  [SMALL_STATE(3024)] = 166879,
  [SMALL_STATE(3025)] = 166903,
  [SMALL_STATE(3026)] = 166927,
  [SMALL_STATE(3027)] = 166951,
  [SMALL_STATE(3028)] = 166975,
  [SMALL_STATE(3029)] = 166999,
  [SMALL_STATE(3030)] = 167023,
  [SMALL_STATE(3031)] = 167047,
  [SMALL_STATE(3032)] = 167069,
  [SMALL_STATE(3033)] = 167093,
  [SMALL_STATE(3034)] = 167119,
  [SMALL_STATE(3035)] = 167145,
  [SMALL_STATE(3036)] = 167163,
  [SMALL_STATE(3037)] = 167191,
  [SMALL_STATE(3038)] = 167215,
  [SMALL_STATE(3039)] = 167239,
  [SMALL_STATE(3040)] = 167263,
  [SMALL_STATE(3041)] = 167281,
  [SMALL_STATE(3042)] = 167307,
  [SMALL_STATE(3043)] = 167333,
  [SMALL_STATE(3044)] = 167361,
  [SMALL_STATE(3045)] = 167386,
  [SMALL_STATE(3046)] = 167409,
  [SMALL_STATE(3047)] = 167438,
  [SMALL_STATE(3048)] = 167461,
  [SMALL_STATE(3049)] = 167484,
  [SMALL_STATE(3050)] = 167507,
  [SMALL_STATE(3051)] = 167530,
  [SMALL_STATE(3052)] = 167547,
  [SMALL_STATE(3053)] = 167576,
  [SMALL_STATE(3054)] = 167593,
  [SMALL_STATE(3055)] = 167616,
  [SMALL_STATE(3056)] = 167633,
  [SMALL_STATE(3057)] = 167656,
  [SMALL_STATE(3058)] = 167681,
  [SMALL_STATE(3059)] = 167704,
  [SMALL_STATE(3060)] = 167727,
  [SMALL_STATE(3061)] = 167750,
  [SMALL_STATE(3062)] = 167775,
  [SMALL_STATE(3063)] = 167798,
  [SMALL_STATE(3064)] = 167824,
  [SMALL_STATE(3065)] = 167850,
  [SMALL_STATE(3066)] = 167874,
  [SMALL_STATE(3067)] = 167894,
  [SMALL_STATE(3068)] = 167916,
  [SMALL_STATE(3069)] = 167938,
  [SMALL_STATE(3070)] = 167960,
  [SMALL_STATE(3071)] = 167986,
  [SMALL_STATE(3072)] = 168008,
  [SMALL_STATE(3073)] = 168030,
  [SMALL_STATE(3074)] = 168048,
  [SMALL_STATE(3075)] = 168070,
  [SMALL_STATE(3076)] = 168092,
  [SMALL_STATE(3077)] = 168114,
  [SMALL_STATE(3078)] = 168136,
  [SMALL_STATE(3079)] = 168158,
  [SMALL_STATE(3080)] = 168180,
  [SMALL_STATE(3081)] = 168202,
  [SMALL_STATE(3082)] = 168228,
  [SMALL_STATE(3083)] = 168250,
  [SMALL_STATE(3084)] = 168272,
  [SMALL_STATE(3085)] = 168294,
  [SMALL_STATE(3086)] = 168316,
  [SMALL_STATE(3087)] = 168342,
  [SMALL_STATE(3088)] = 168362,
  [SMALL_STATE(3089)] = 168384,
  [SMALL_STATE(3090)] = 168406,
  [SMALL_STATE(3091)] = 168422,
  [SMALL_STATE(3092)] = 168444,
  [SMALL_STATE(3093)] = 168460,
  [SMALL_STATE(3094)] = 168482,
  [SMALL_STATE(3095)] = 168504,
  [SMALL_STATE(3096)] = 168530,
  [SMALL_STATE(3097)] = 168552,
  [SMALL_STATE(3098)] = 168568,
  [SMALL_STATE(3099)] = 168590,
  [SMALL_STATE(3100)] = 168612,
  [SMALL_STATE(3101)] = 168632,
  [SMALL_STATE(3102)] = 168654,
  [SMALL_STATE(3103)] = 168676,
  [SMALL_STATE(3104)] = 168698,
  [SMALL_STATE(3105)] = 168720,
  [SMALL_STATE(3106)] = 168746,
  [SMALL_STATE(3107)] = 168772,
  [SMALL_STATE(3108)] = 168794,
  [SMALL_STATE(3109)] = 168816,
  [SMALL_STATE(3110)] = 168842,
  [SMALL_STATE(3111)] = 168868,
  [SMALL_STATE(3112)] = 168890,
  [SMALL_STATE(3113)] = 168912,
  [SMALL_STATE(3114)] = 168934,
  [SMALL_STATE(3115)] = 168950,
  [SMALL_STATE(3116)] = 168972,
  [SMALL_STATE(3117)] = 168994,
  [SMALL_STATE(3118)] = 169016,
  [SMALL_STATE(3119)] = 169042,
  [SMALL_STATE(3120)] = 169064,
  [SMALL_STATE(3121)] = 169086,
  [SMALL_STATE(3122)] = 169108,
  [SMALL_STATE(3123)] = 169124,
  [SMALL_STATE(3124)] = 169146,
  [SMALL_STATE(3125)] = 169168,
  [SMALL_STATE(3126)] = 169194,
  [SMALL_STATE(3127)] = 169220,
  [SMALL_STATE(3128)] = 169246,
  [SMALL_STATE(3129)] = 169268,
  [SMALL_STATE(3130)] = 169290,
  [SMALL_STATE(3131)] = 169312,
  [SMALL_STATE(3132)] = 169338,
  [SMALL_STATE(3133)] = 169354,
  [SMALL_STATE(3134)] = 169376,
  [SMALL_STATE(3135)] = 169398,
  [SMALL_STATE(3136)] = 169418,
  [SMALL_STATE(3137)] = 169444,
  [SMALL_STATE(3138)] = 169470,
  [SMALL_STATE(3139)] = 169496,
  [SMALL_STATE(3140)] = 169522,
  [SMALL_STATE(3141)] = 169544,
  [SMALL_STATE(3142)] = 169562,
  [SMALL_STATE(3143)] = 169584,
  [SMALL_STATE(3144)] = 169610,
  [SMALL_STATE(3145)] = 169634,
  [SMALL_STATE(3146)] = 169656,
  [SMALL_STATE(3147)] = 169682,
  [SMALL_STATE(3148)] = 169708,
  [SMALL_STATE(3149)] = 169734,
  [SMALL_STATE(3150)] = 169753,
  [SMALL_STATE(3151)] = 169778,
  [SMALL_STATE(3152)] = 169797,
  [SMALL_STATE(3153)] = 169816,
  [SMALL_STATE(3154)] = 169831,
  [SMALL_STATE(3155)] = 169850,
  [SMALL_STATE(3156)] = 169869,
  [SMALL_STATE(3157)] = 169888,
  [SMALL_STATE(3158)] = 169907,
  [SMALL_STATE(3159)] = 169920,
  [SMALL_STATE(3160)] = 169937,
  [SMALL_STATE(3161)] = 169952,
  [SMALL_STATE(3162)] = 169971,
  [SMALL_STATE(3163)] = 169986,
  [SMALL_STATE(3164)] = 169999,
  [SMALL_STATE(3165)] = 170012,
  [SMALL_STATE(3166)] = 170031,
  [SMALL_STATE(3167)] = 170046,
  [SMALL_STATE(3168)] = 170069,
  [SMALL_STATE(3169)] = 170088,
  [SMALL_STATE(3170)] = 170113,
  [SMALL_STATE(3171)] = 170136,
  [SMALL_STATE(3172)] = 170155,
  [SMALL_STATE(3173)] = 170180,
  [SMALL_STATE(3174)] = 170205,
  [SMALL_STATE(3175)] = 170230,
  [SMALL_STATE(3176)] = 170255,
  [SMALL_STATE(3177)] = 170280,
  [SMALL_STATE(3178)] = 170305,
  [SMALL_STATE(3179)] = 170330,
  [SMALL_STATE(3180)] = 170355,
  [SMALL_STATE(3181)] = 170380,
  [SMALL_STATE(3182)] = 170399,
  [SMALL_STATE(3183)] = 170418,
  [SMALL_STATE(3184)] = 170437,
  [SMALL_STATE(3185)] = 170456,
  [SMALL_STATE(3186)] = 170471,
  [SMALL_STATE(3187)] = 170490,
  [SMALL_STATE(3188)] = 170509,
  [SMALL_STATE(3189)] = 170528,
  [SMALL_STATE(3190)] = 170547,
  [SMALL_STATE(3191)] = 170566,
  [SMALL_STATE(3192)] = 170585,
  [SMALL_STATE(3193)] = 170600,
  [SMALL_STATE(3194)] = 170619,
  [SMALL_STATE(3195)] = 170638,
  [SMALL_STATE(3196)] = 170657,
  [SMALL_STATE(3197)] = 170682,
  [SMALL_STATE(3198)] = 170707,
  [SMALL_STATE(3199)] = 170732,
  [SMALL_STATE(3200)] = 170757,
  [SMALL_STATE(3201)] = 170782,
  [SMALL_STATE(3202)] = 170807,
  [SMALL_STATE(3203)] = 170832,
  [SMALL_STATE(3204)] = 170857,
  [SMALL_STATE(3205)] = 170882,
  [SMALL_STATE(3206)] = 170907,
  [SMALL_STATE(3207)] = 170926,
  [SMALL_STATE(3208)] = 170945,
  [SMALL_STATE(3209)] = 170970,
  [SMALL_STATE(3210)] = 170995,
  [SMALL_STATE(3211)] = 171020,
  [SMALL_STATE(3212)] = 171039,
  [SMALL_STATE(3213)] = 171064,
  [SMALL_STATE(3214)] = 171089,
  [SMALL_STATE(3215)] = 171114,
  [SMALL_STATE(3216)] = 171139,
  [SMALL_STATE(3217)] = 171164,
  [SMALL_STATE(3218)] = 171189,
  [SMALL_STATE(3219)] = 171214,
  [SMALL_STATE(3220)] = 171239,
  [SMALL_STATE(3221)] = 171264,
  [SMALL_STATE(3222)] = 171289,
  [SMALL_STATE(3223)] = 171314,
  [SMALL_STATE(3224)] = 171333,
  [SMALL_STATE(3225)] = 171356,
  [SMALL_STATE(3226)] = 171377,
  [SMALL_STATE(3227)] = 171402,
  [SMALL_STATE(3228)] = 171415,
  [SMALL_STATE(3229)] = 171434,
  [SMALL_STATE(3230)] = 171453,
  [SMALL_STATE(3231)] = 171472,
  [SMALL_STATE(3232)] = 171491,
  [SMALL_STATE(3233)] = 171512,
  [SMALL_STATE(3234)] = 171531,
  [SMALL_STATE(3235)] = 171556,
  [SMALL_STATE(3236)] = 171577,
  [SMALL_STATE(3237)] = 171602,
  [SMALL_STATE(3238)] = 171627,
  [SMALL_STATE(3239)] = 171652,
  [SMALL_STATE(3240)] = 171677,
  [SMALL_STATE(3241)] = 171702,
  [SMALL_STATE(3242)] = 171727,
  [SMALL_STATE(3243)] = 171752,
  [SMALL_STATE(3244)] = 171777,
  [SMALL_STATE(3245)] = 171800,
  [SMALL_STATE(3246)] = 171821,
  [SMALL_STATE(3247)] = 171842,
  [SMALL_STATE(3248)] = 171861,
  [SMALL_STATE(3249)] = 171880,
  [SMALL_STATE(3250)] = 171905,
  [SMALL_STATE(3251)] = 171924,
  [SMALL_STATE(3252)] = 171937,
  [SMALL_STATE(3253)] = 171956,
  [SMALL_STATE(3254)] = 171975,
  [SMALL_STATE(3255)] = 172000,
  [SMALL_STATE(3256)] = 172019,
  [SMALL_STATE(3257)] = 172040,
  [SMALL_STATE(3258)] = 172065,
  [SMALL_STATE(3259)] = 172090,
  [SMALL_STATE(3260)] = 172115,
  [SMALL_STATE(3261)] = 172140,
  [SMALL_STATE(3262)] = 172165,
  [SMALL_STATE(3263)] = 172190,
  [SMALL_STATE(3264)] = 172215,
  [SMALL_STATE(3265)] = 172240,
  [SMALL_STATE(3266)] = 172259,
  [SMALL_STATE(3267)] = 172278,
  [SMALL_STATE(3268)] = 172297,
  [SMALL_STATE(3269)] = 172316,
  [SMALL_STATE(3270)] = 172335,
  [SMALL_STATE(3271)] = 172354,
  [SMALL_STATE(3272)] = 172371,
  [SMALL_STATE(3273)] = 172390,
  [SMALL_STATE(3274)] = 172415,
  [SMALL_STATE(3275)] = 172434,
  [SMALL_STATE(3276)] = 172453,
  [SMALL_STATE(3277)] = 172472,
  [SMALL_STATE(3278)] = 172493,
  [SMALL_STATE(3279)] = 172514,
  [SMALL_STATE(3280)] = 172533,
  [SMALL_STATE(3281)] = 172554,
  [SMALL_STATE(3282)] = 172575,
  [SMALL_STATE(3283)] = 172596,
  [SMALL_STATE(3284)] = 172615,
  [SMALL_STATE(3285)] = 172636,
  [SMALL_STATE(3286)] = 172657,
  [SMALL_STATE(3287)] = 172682,
  [SMALL_STATE(3288)] = 172701,
  [SMALL_STATE(3289)] = 172722,
  [SMALL_STATE(3290)] = 172745,
  [SMALL_STATE(3291)] = 172770,
  [SMALL_STATE(3292)] = 172789,
  [SMALL_STATE(3293)] = 172810,
  [SMALL_STATE(3294)] = 172829,
  [SMALL_STATE(3295)] = 172842,
  [SMALL_STATE(3296)] = 172861,
  [SMALL_STATE(3297)] = 172882,
  [SMALL_STATE(3298)] = 172901,
  [SMALL_STATE(3299)] = 172926,
  [SMALL_STATE(3300)] = 172945,
  [SMALL_STATE(3301)] = 172964,
  [SMALL_STATE(3302)] = 172983,
  [SMALL_STATE(3303)] = 173002,
  [SMALL_STATE(3304)] = 173021,
  [SMALL_STATE(3305)] = 173046,
  [SMALL_STATE(3306)] = 173065,
  [SMALL_STATE(3307)] = 173084,
  [SMALL_STATE(3308)] = 173107,
  [SMALL_STATE(3309)] = 173126,
  [SMALL_STATE(3310)] = 173145,
  [SMALL_STATE(3311)] = 173164,
  [SMALL_STATE(3312)] = 173189,
  [SMALL_STATE(3313)] = 173208,
  [SMALL_STATE(3314)] = 173227,
  [SMALL_STATE(3315)] = 173248,
  [SMALL_STATE(3316)] = 173273,
  [SMALL_STATE(3317)] = 173294,
  [SMALL_STATE(3318)] = 173315,
  [SMALL_STATE(3319)] = 173336,
  [SMALL_STATE(3320)] = 173355,
  [SMALL_STATE(3321)] = 173380,
  [SMALL_STATE(3322)] = 173395,
  [SMALL_STATE(3323)] = 173414,
  [SMALL_STATE(3324)] = 173435,
  [SMALL_STATE(3325)] = 173450,
  [SMALL_STATE(3326)] = 173469,
  [SMALL_STATE(3327)] = 173488,
  [SMALL_STATE(3328)] = 173513,
  [SMALL_STATE(3329)] = 173528,
  [SMALL_STATE(3330)] = 173547,
  [SMALL_STATE(3331)] = 173572,
  [SMALL_STATE(3332)] = 173597,
  [SMALL_STATE(3333)] = 173620,
  [SMALL_STATE(3334)] = 173645,
  [SMALL_STATE(3335)] = 173670,
  [SMALL_STATE(3336)] = 173695,
  [SMALL_STATE(3337)] = 173720,
  [SMALL_STATE(3338)] = 173745,
  [SMALL_STATE(3339)] = 173770,
  [SMALL_STATE(3340)] = 173789,
  [SMALL_STATE(3341)] = 173808,
  [SMALL_STATE(3342)] = 173823,
  [SMALL_STATE(3343)] = 173844,
  [SMALL_STATE(3344)] = 173867,
  [SMALL_STATE(3345)] = 173888,
  [SMALL_STATE(3346)] = 173907,
  [SMALL_STATE(3347)] = 173932,
  [SMALL_STATE(3348)] = 173951,
  [SMALL_STATE(3349)] = 173971,
  [SMALL_STATE(3350)] = 173993,
  [SMALL_STATE(3351)] = 174015,
  [SMALL_STATE(3352)] = 174037,
  [SMALL_STATE(3353)] = 174059,
  [SMALL_STATE(3354)] = 174081,
  [SMALL_STATE(3355)] = 174097,
  [SMALL_STATE(3356)] = 174119,
  [SMALL_STATE(3357)] = 174141,
  [SMALL_STATE(3358)] = 174155,
  [SMALL_STATE(3359)] = 174175,
  [SMALL_STATE(3360)] = 174197,
  [SMALL_STATE(3361)] = 174219,
  [SMALL_STATE(3362)] = 174241,
  [SMALL_STATE(3363)] = 174261,
  [SMALL_STATE(3364)] = 174281,
  [SMALL_STATE(3365)] = 174301,
  [SMALL_STATE(3366)] = 174321,
  [SMALL_STATE(3367)] = 174337,
  [SMALL_STATE(3368)] = 174353,
  [SMALL_STATE(3369)] = 174375,
  [SMALL_STATE(3370)] = 174397,
  [SMALL_STATE(3371)] = 174415,
  [SMALL_STATE(3372)] = 174435,
  [SMALL_STATE(3373)] = 174457,
  [SMALL_STATE(3374)] = 174477,
  [SMALL_STATE(3375)] = 174497,
  [SMALL_STATE(3376)] = 174517,
  [SMALL_STATE(3377)] = 174539,
  [SMALL_STATE(3378)] = 174561,
  [SMALL_STATE(3379)] = 174579,
  [SMALL_STATE(3380)] = 174595,
  [SMALL_STATE(3381)] = 174617,
  [SMALL_STATE(3382)] = 174639,
  [SMALL_STATE(3383)] = 174661,
  [SMALL_STATE(3384)] = 174683,
  [SMALL_STATE(3385)] = 174697,
  [SMALL_STATE(3386)] = 174717,
  [SMALL_STATE(3387)] = 174737,
  [SMALL_STATE(3388)] = 174757,
  [SMALL_STATE(3389)] = 174777,
  [SMALL_STATE(3390)] = 174797,
  [SMALL_STATE(3391)] = 174819,
  [SMALL_STATE(3392)] = 174835,
  [SMALL_STATE(3393)] = 174857,
  [SMALL_STATE(3394)] = 174875,
  [SMALL_STATE(3395)] = 174897,
  [SMALL_STATE(3396)] = 174917,
  [SMALL_STATE(3397)] = 174939,
  [SMALL_STATE(3398)] = 174961,
  [SMALL_STATE(3399)] = 174983,
  [SMALL_STATE(3400)] = 175001,
  [SMALL_STATE(3401)] = 175023,
  [SMALL_STATE(3402)] = 175043,
  [SMALL_STATE(3403)] = 175065,
  [SMALL_STATE(3404)] = 175087,
  [SMALL_STATE(3405)] = 175109,
  [SMALL_STATE(3406)] = 175131,
  [SMALL_STATE(3407)] = 175153,
  [SMALL_STATE(3408)] = 175173,
  [SMALL_STATE(3409)] = 175187,
  [SMALL_STATE(3410)] = 175203,
  [SMALL_STATE(3411)] = 175223,
  [SMALL_STATE(3412)] = 175243,
  [SMALL_STATE(3413)] = 175265,
  [SMALL_STATE(3414)] = 175285,
  [SMALL_STATE(3415)] = 175307,
  [SMALL_STATE(3416)] = 175329,
  [SMALL_STATE(3417)] = 175343,
  [SMALL_STATE(3418)] = 175365,
  [SMALL_STATE(3419)] = 175387,
  [SMALL_STATE(3420)] = 175407,
  [SMALL_STATE(3421)] = 175429,
  [SMALL_STATE(3422)] = 175451,
  [SMALL_STATE(3423)] = 175473,
  [SMALL_STATE(3424)] = 175489,
  [SMALL_STATE(3425)] = 175509,
  [SMALL_STATE(3426)] = 175531,
  [SMALL_STATE(3427)] = 175553,
  [SMALL_STATE(3428)] = 175567,
  [SMALL_STATE(3429)] = 175589,
  [SMALL_STATE(3430)] = 175611,
  [SMALL_STATE(3431)] = 175629,
  [SMALL_STATE(3432)] = 175647,
  [SMALL_STATE(3433)] = 175669,
  [SMALL_STATE(3434)] = 175691,
  [SMALL_STATE(3435)] = 175709,
  [SMALL_STATE(3436)] = 175731,
  [SMALL_STATE(3437)] = 175753,
  [SMALL_STATE(3438)] = 175775,
  [SMALL_STATE(3439)] = 175797,
  [SMALL_STATE(3440)] = 175811,
  [SMALL_STATE(3441)] = 175833,
  [SMALL_STATE(3442)] = 175855,
  [SMALL_STATE(3443)] = 175877,
  [SMALL_STATE(3444)] = 175899,
  [SMALL_STATE(3445)] = 175921,
  [SMALL_STATE(3446)] = 175935,
  [SMALL_STATE(3447)] = 175955,
  [SMALL_STATE(3448)] = 175977,
  [SMALL_STATE(3449)] = 175997,
  [SMALL_STATE(3450)] = 176016,
  [SMALL_STATE(3451)] = 176033,
  [SMALL_STATE(3452)] = 176050,
  [SMALL_STATE(3453)] = 176067,
  [SMALL_STATE(3454)] = 176080,
  [SMALL_STATE(3455)] = 176093,
  [SMALL_STATE(3456)] = 176106,
  [SMALL_STATE(3457)] = 176117,
  [SMALL_STATE(3458)] = 176134,
  [SMALL_STATE(3459)] = 176151,
  [SMALL_STATE(3460)] = 176168,
  [SMALL_STATE(3461)] = 176187,
  [SMALL_STATE(3462)] = 176206,
  [SMALL_STATE(3463)] = 176225,
  [SMALL_STATE(3464)] = 176242,
  [SMALL_STATE(3465)] = 176255,
  [SMALL_STATE(3466)] = 176268,
  [SMALL_STATE(3467)] = 176285,
  [SMALL_STATE(3468)] = 176298,
  [SMALL_STATE(3469)] = 176315,
  [SMALL_STATE(3470)] = 176334,
  [SMALL_STATE(3471)] = 176345,
  [SMALL_STATE(3472)] = 176362,
  [SMALL_STATE(3473)] = 176373,
  [SMALL_STATE(3474)] = 176384,
  [SMALL_STATE(3475)] = 176401,
  [SMALL_STATE(3476)] = 176412,
  [SMALL_STATE(3477)] = 176431,
  [SMALL_STATE(3478)] = 176448,
  [SMALL_STATE(3479)] = 176467,
  [SMALL_STATE(3480)] = 176478,
  [SMALL_STATE(3481)] = 176495,
  [SMALL_STATE(3482)] = 176506,
  [SMALL_STATE(3483)] = 176517,
  [SMALL_STATE(3484)] = 176536,
  [SMALL_STATE(3485)] = 176549,
  [SMALL_STATE(3486)] = 176568,
  [SMALL_STATE(3487)] = 176587,
  [SMALL_STATE(3488)] = 176598,
  [SMALL_STATE(3489)] = 176617,
  [SMALL_STATE(3490)] = 176630,
  [SMALL_STATE(3491)] = 176647,
  [SMALL_STATE(3492)] = 176660,
  [SMALL_STATE(3493)] = 176679,
  [SMALL_STATE(3494)] = 176698,
  [SMALL_STATE(3495)] = 176715,
  [SMALL_STATE(3496)] = 176730,
  [SMALL_STATE(3497)] = 176743,
  [SMALL_STATE(3498)] = 176762,
  [SMALL_STATE(3499)] = 176775,
  [SMALL_STATE(3500)] = 176786,
  [SMALL_STATE(3501)] = 176803,
  [SMALL_STATE(3502)] = 176820,
  [SMALL_STATE(3503)] = 176831,
  [SMALL_STATE(3504)] = 176850,
  [SMALL_STATE(3505)] = 176867,
  [SMALL_STATE(3506)] = 176886,
  [SMALL_STATE(3507)] = 176903,
  [SMALL_STATE(3508)] = 176920,
  [SMALL_STATE(3509)] = 176933,
  [SMALL_STATE(3510)] = 176952,
  [SMALL_STATE(3511)] = 176971,
  [SMALL_STATE(3512)] = 176988,
  [SMALL_STATE(3513)] = 177007,
  [SMALL_STATE(3514)] = 177018,
  [SMALL_STATE(3515)] = 177029,
  [SMALL_STATE(3516)] = 177040,
  [SMALL_STATE(3517)] = 177057,
  [SMALL_STATE(3518)] = 177074,
  [SMALL_STATE(3519)] = 177091,
  [SMALL_STATE(3520)] = 177102,
  [SMALL_STATE(3521)] = 177113,
  [SMALL_STATE(3522)] = 177132,
  [SMALL_STATE(3523)] = 177143,
  [SMALL_STATE(3524)] = 177162,
  [SMALL_STATE(3525)] = 177181,
  [SMALL_STATE(3526)] = 177192,
  [SMALL_STATE(3527)] = 177211,
  [SMALL_STATE(3528)] = 177230,
  [SMALL_STATE(3529)] = 177249,
  [SMALL_STATE(3530)] = 177268,
  [SMALL_STATE(3531)] = 177287,
  [SMALL_STATE(3532)] = 177298,
  [SMALL_STATE(3533)] = 177309,
  [SMALL_STATE(3534)] = 177328,
  [SMALL_STATE(3535)] = 177347,
  [SMALL_STATE(3536)] = 177366,
  [SMALL_STATE(3537)] = 177383,
  [SMALL_STATE(3538)] = 177396,
  [SMALL_STATE(3539)] = 177407,
  [SMALL_STATE(3540)] = 177426,
  [SMALL_STATE(3541)] = 177445,
  [SMALL_STATE(3542)] = 177456,
  [SMALL_STATE(3543)] = 177475,
  [SMALL_STATE(3544)] = 177494,
  [SMALL_STATE(3545)] = 177513,
  [SMALL_STATE(3546)] = 177532,
  [SMALL_STATE(3547)] = 177549,
  [SMALL_STATE(3548)] = 177560,
  [SMALL_STATE(3549)] = 177573,
  [SMALL_STATE(3550)] = 177592,
  [SMALL_STATE(3551)] = 177603,
  [SMALL_STATE(3552)] = 177614,
  [SMALL_STATE(3553)] = 177627,
  [SMALL_STATE(3554)] = 177644,
  [SMALL_STATE(3555)] = 177657,
  [SMALL_STATE(3556)] = 177676,
  [SMALL_STATE(3557)] = 177689,
  [SMALL_STATE(3558)] = 177708,
  [SMALL_STATE(3559)] = 177725,
  [SMALL_STATE(3560)] = 177742,
  [SMALL_STATE(3561)] = 177759,
  [SMALL_STATE(3562)] = 177770,
  [SMALL_STATE(3563)] = 177781,
  [SMALL_STATE(3564)] = 177798,
  [SMALL_STATE(3565)] = 177815,
  [SMALL_STATE(3566)] = 177832,
  [SMALL_STATE(3567)] = 177843,
  [SMALL_STATE(3568)] = 177856,
  [SMALL_STATE(3569)] = 177875,
  [SMALL_STATE(3570)] = 177894,
  [SMALL_STATE(3571)] = 177905,
  [SMALL_STATE(3572)] = 177918,
  [SMALL_STATE(3573)] = 177931,
  [SMALL_STATE(3574)] = 177948,
  [SMALL_STATE(3575)] = 177961,
  [SMALL_STATE(3576)] = 177974,
  [SMALL_STATE(3577)] = 177987,
  [SMALL_STATE(3578)] = 178000,
  [SMALL_STATE(3579)] = 178013,
  [SMALL_STATE(3580)] = 178026,
  [SMALL_STATE(3581)] = 178043,
  [SMALL_STATE(3582)] = 178062,
  [SMALL_STATE(3583)] = 178081,
  [SMALL_STATE(3584)] = 178100,
  [SMALL_STATE(3585)] = 178119,
  [SMALL_STATE(3586)] = 178130,
  [SMALL_STATE(3587)] = 178149,
  [SMALL_STATE(3588)] = 178168,
  [SMALL_STATE(3589)] = 178185,
  [SMALL_STATE(3590)] = 178204,
  [SMALL_STATE(3591)] = 178223,
  [SMALL_STATE(3592)] = 178242,
  [SMALL_STATE(3593)] = 178261,
  [SMALL_STATE(3594)] = 178280,
  [SMALL_STATE(3595)] = 178299,
  [SMALL_STATE(3596)] = 178318,
  [SMALL_STATE(3597)] = 178337,
  [SMALL_STATE(3598)] = 178350,
  [SMALL_STATE(3599)] = 178366,
  [SMALL_STATE(3600)] = 178382,
  [SMALL_STATE(3601)] = 178396,
  [SMALL_STATE(3602)] = 178410,
  [SMALL_STATE(3603)] = 178426,
  [SMALL_STATE(3604)] = 178440,
  [SMALL_STATE(3605)] = 178456,
  [SMALL_STATE(3606)] = 178466,
  [SMALL_STATE(3607)] = 178482,
  [SMALL_STATE(3608)] = 178496,
  [SMALL_STATE(3609)] = 178510,
  [SMALL_STATE(3610)] = 178520,
  [SMALL_STATE(3611)] = 178534,
  [SMALL_STATE(3612)] = 178548,
  [SMALL_STATE(3613)] = 178558,
  [SMALL_STATE(3614)] = 178568,
  [SMALL_STATE(3615)] = 178582,
  [SMALL_STATE(3616)] = 178596,
  [SMALL_STATE(3617)] = 178610,
  [SMALL_STATE(3618)] = 178624,
  [SMALL_STATE(3619)] = 178638,
  [SMALL_STATE(3620)] = 178648,
  [SMALL_STATE(3621)] = 178658,
  [SMALL_STATE(3622)] = 178668,
  [SMALL_STATE(3623)] = 178678,
  [SMALL_STATE(3624)] = 178692,
  [SMALL_STATE(3625)] = 178702,
  [SMALL_STATE(3626)] = 178712,
  [SMALL_STATE(3627)] = 178728,
  [SMALL_STATE(3628)] = 178738,
  [SMALL_STATE(3629)] = 178748,
  [SMALL_STATE(3630)] = 178758,
  [SMALL_STATE(3631)] = 178772,
  [SMALL_STATE(3632)] = 178786,
  [SMALL_STATE(3633)] = 178796,
  [SMALL_STATE(3634)] = 178810,
  [SMALL_STATE(3635)] = 178824,
  [SMALL_STATE(3636)] = 178838,
  [SMALL_STATE(3637)] = 178852,
  [SMALL_STATE(3638)] = 178862,
  [SMALL_STATE(3639)] = 178876,
  [SMALL_STATE(3640)] = 178890,
  [SMALL_STATE(3641)] = 178906,
  [SMALL_STATE(3642)] = 178916,
  [SMALL_STATE(3643)] = 178930,
  [SMALL_STATE(3644)] = 178944,
  [SMALL_STATE(3645)] = 178958,
  [SMALL_STATE(3646)] = 178968,
  [SMALL_STATE(3647)] = 178982,
  [SMALL_STATE(3648)] = 178996,
  [SMALL_STATE(3649)] = 179010,
  [SMALL_STATE(3650)] = 179020,
  [SMALL_STATE(3651)] = 179036,
  [SMALL_STATE(3652)] = 179046,
  [SMALL_STATE(3653)] = 179060,
  [SMALL_STATE(3654)] = 179074,
  [SMALL_STATE(3655)] = 179088,
  [SMALL_STATE(3656)] = 179104,
  [SMALL_STATE(3657)] = 179120,
  [SMALL_STATE(3658)] = 179136,
  [SMALL_STATE(3659)] = 179152,
  [SMALL_STATE(3660)] = 179166,
  [SMALL_STATE(3661)] = 179180,
  [SMALL_STATE(3662)] = 179190,
  [SMALL_STATE(3663)] = 179204,
  [SMALL_STATE(3664)] = 179218,
  [SMALL_STATE(3665)] = 179232,
  [SMALL_STATE(3666)] = 179246,
  [SMALL_STATE(3667)] = 179260,
  [SMALL_STATE(3668)] = 179274,
  [SMALL_STATE(3669)] = 179288,
  [SMALL_STATE(3670)] = 179302,
  [SMALL_STATE(3671)] = 179312,
  [SMALL_STATE(3672)] = 179326,
  [SMALL_STATE(3673)] = 179340,
  [SMALL_STATE(3674)] = 179350,
  [SMALL_STATE(3675)] = 179364,
  [SMALL_STATE(3676)] = 179378,
  [SMALL_STATE(3677)] = 179392,
  [SMALL_STATE(3678)] = 179406,
  [SMALL_STATE(3679)] = 179420,
  [SMALL_STATE(3680)] = 179436,
  [SMALL_STATE(3681)] = 179446,
  [SMALL_STATE(3682)] = 179462,
  [SMALL_STATE(3683)] = 179476,
  [SMALL_STATE(3684)] = 179490,
  [SMALL_STATE(3685)] = 179500,
  [SMALL_STATE(3686)] = 179510,
  [SMALL_STATE(3687)] = 179520,
  [SMALL_STATE(3688)] = 179532,
  [SMALL_STATE(3689)] = 179546,
  [SMALL_STATE(3690)] = 179560,
  [SMALL_STATE(3691)] = 179574,
  [SMALL_STATE(3692)] = 179588,
  [SMALL_STATE(3693)] = 179602,
  [SMALL_STATE(3694)] = 179616,
  [SMALL_STATE(3695)] = 179630,
  [SMALL_STATE(3696)] = 179640,
  [SMALL_STATE(3697)] = 179656,
  [SMALL_STATE(3698)] = 179672,
  [SMALL_STATE(3699)] = 179688,
  [SMALL_STATE(3700)] = 179704,
  [SMALL_STATE(3701)] = 179714,
  [SMALL_STATE(3702)] = 179728,
  [SMALL_STATE(3703)] = 179742,
  [SMALL_STATE(3704)] = 179756,
  [SMALL_STATE(3705)] = 179770,
  [SMALL_STATE(3706)] = 179784,
  [SMALL_STATE(3707)] = 179798,
  [SMALL_STATE(3708)] = 179808,
  [SMALL_STATE(3709)] = 179824,
  [SMALL_STATE(3710)] = 179838,
  [SMALL_STATE(3711)] = 179852,
  [SMALL_STATE(3712)] = 179862,
  [SMALL_STATE(3713)] = 179876,
  [SMALL_STATE(3714)] = 179890,
  [SMALL_STATE(3715)] = 179900,
  [SMALL_STATE(3716)] = 179913,
  [SMALL_STATE(3717)] = 179926,
  [SMALL_STATE(3718)] = 179939,
  [SMALL_STATE(3719)] = 179952,
  [SMALL_STATE(3720)] = 179965,
  [SMALL_STATE(3721)] = 179978,
  [SMALL_STATE(3722)] = 179991,
  [SMALL_STATE(3723)] = 180004,
  [SMALL_STATE(3724)] = 180017,
  [SMALL_STATE(3725)] = 180030,
  [SMALL_STATE(3726)] = 180043,
  [SMALL_STATE(3727)] = 180056,
  [SMALL_STATE(3728)] = 180069,
  [SMALL_STATE(3729)] = 180082,
  [SMALL_STATE(3730)] = 180095,
  [SMALL_STATE(3731)] = 180108,
  [SMALL_STATE(3732)] = 180121,
  [SMALL_STATE(3733)] = 180134,
  [SMALL_STATE(3734)] = 180147,
  [SMALL_STATE(3735)] = 180158,
  [SMALL_STATE(3736)] = 180171,
  [SMALL_STATE(3737)] = 180184,
  [SMALL_STATE(3738)] = 180197,
  [SMALL_STATE(3739)] = 180210,
  [SMALL_STATE(3740)] = 180223,
  [SMALL_STATE(3741)] = 180236,
  [SMALL_STATE(3742)] = 180247,
  [SMALL_STATE(3743)] = 180260,
  [SMALL_STATE(3744)] = 180273,
  [SMALL_STATE(3745)] = 180286,
  [SMALL_STATE(3746)] = 180299,
  [SMALL_STATE(3747)] = 180312,
  [SMALL_STATE(3748)] = 180325,
  [SMALL_STATE(3749)] = 180338,
  [SMALL_STATE(3750)] = 180351,
  [SMALL_STATE(3751)] = 180364,
  [SMALL_STATE(3752)] = 180377,
  [SMALL_STATE(3753)] = 180390,
  [SMALL_STATE(3754)] = 180403,
  [SMALL_STATE(3755)] = 180416,
  [SMALL_STATE(3756)] = 180429,
  [SMALL_STATE(3757)] = 180438,
  [SMALL_STATE(3758)] = 180451,
  [SMALL_STATE(3759)] = 180464,
  [SMALL_STATE(3760)] = 180473,
  [SMALL_STATE(3761)] = 180486,
  [SMALL_STATE(3762)] = 180499,
  [SMALL_STATE(3763)] = 180512,
  [SMALL_STATE(3764)] = 180525,
  [SMALL_STATE(3765)] = 180538,
  [SMALL_STATE(3766)] = 180551,
  [SMALL_STATE(3767)] = 180564,
  [SMALL_STATE(3768)] = 180577,
  [SMALL_STATE(3769)] = 180590,
  [SMALL_STATE(3770)] = 180603,
  [SMALL_STATE(3771)] = 180616,
  [SMALL_STATE(3772)] = 180629,
  [SMALL_STATE(3773)] = 180642,
  [SMALL_STATE(3774)] = 180655,
  [SMALL_STATE(3775)] = 180668,
  [SMALL_STATE(3776)] = 180681,
  [SMALL_STATE(3777)] = 180694,
  [SMALL_STATE(3778)] = 180707,
  [SMALL_STATE(3779)] = 180720,
  [SMALL_STATE(3780)] = 180733,
  [SMALL_STATE(3781)] = 180746,
  [SMALL_STATE(3782)] = 180759,
  [SMALL_STATE(3783)] = 180772,
  [SMALL_STATE(3784)] = 180785,
  [SMALL_STATE(3785)] = 180798,
  [SMALL_STATE(3786)] = 180811,
  [SMALL_STATE(3787)] = 180824,
  [SMALL_STATE(3788)] = 180837,
  [SMALL_STATE(3789)] = 180850,
  [SMALL_STATE(3790)] = 180863,
  [SMALL_STATE(3791)] = 180876,
  [SMALL_STATE(3792)] = 180889,
  [SMALL_STATE(3793)] = 180902,
  [SMALL_STATE(3794)] = 180915,
  [SMALL_STATE(3795)] = 180928,
  [SMALL_STATE(3796)] = 180941,
  [SMALL_STATE(3797)] = 180954,
  [SMALL_STATE(3798)] = 180967,
  [SMALL_STATE(3799)] = 180980,
  [SMALL_STATE(3800)] = 180993,
  [SMALL_STATE(3801)] = 181006,
  [SMALL_STATE(3802)] = 181019,
  [SMALL_STATE(3803)] = 181032,
  [SMALL_STATE(3804)] = 181045,
  [SMALL_STATE(3805)] = 181058,
  [SMALL_STATE(3806)] = 181071,
  [SMALL_STATE(3807)] = 181084,
  [SMALL_STATE(3808)] = 181097,
  [SMALL_STATE(3809)] = 181110,
  [SMALL_STATE(3810)] = 181123,
  [SMALL_STATE(3811)] = 181136,
  [SMALL_STATE(3812)] = 181149,
  [SMALL_STATE(3813)] = 181162,
  [SMALL_STATE(3814)] = 181175,
  [SMALL_STATE(3815)] = 181188,
  [SMALL_STATE(3816)] = 181201,
  [SMALL_STATE(3817)] = 181214,
  [SMALL_STATE(3818)] = 181227,
  [SMALL_STATE(3819)] = 181240,
  [SMALL_STATE(3820)] = 181249,
  [SMALL_STATE(3821)] = 181260,
  [SMALL_STATE(3822)] = 181273,
  [SMALL_STATE(3823)] = 181286,
  [SMALL_STATE(3824)] = 181299,
  [SMALL_STATE(3825)] = 181312,
  [SMALL_STATE(3826)] = 181325,
  [SMALL_STATE(3827)] = 181338,
  [SMALL_STATE(3828)] = 181351,
  [SMALL_STATE(3829)] = 181364,
  [SMALL_STATE(3830)] = 181377,
  [SMALL_STATE(3831)] = 181386,
  [SMALL_STATE(3832)] = 181397,
  [SMALL_STATE(3833)] = 181410,
  [SMALL_STATE(3834)] = 181423,
  [SMALL_STATE(3835)] = 181436,
  [SMALL_STATE(3836)] = 181449,
  [SMALL_STATE(3837)] = 181462,
  [SMALL_STATE(3838)] = 181475,
  [SMALL_STATE(3839)] = 181488,
  [SMALL_STATE(3840)] = 181501,
  [SMALL_STATE(3841)] = 181514,
  [SMALL_STATE(3842)] = 181527,
  [SMALL_STATE(3843)] = 181540,
  [SMALL_STATE(3844)] = 181553,
  [SMALL_STATE(3845)] = 181566,
  [SMALL_STATE(3846)] = 181579,
  [SMALL_STATE(3847)] = 181592,
  [SMALL_STATE(3848)] = 181605,
  [SMALL_STATE(3849)] = 181618,
  [SMALL_STATE(3850)] = 181631,
  [SMALL_STATE(3851)] = 181644,
  [SMALL_STATE(3852)] = 181653,
  [SMALL_STATE(3853)] = 181664,
  [SMALL_STATE(3854)] = 181677,
  [SMALL_STATE(3855)] = 181690,
  [SMALL_STATE(3856)] = 181703,
  [SMALL_STATE(3857)] = 181716,
  [SMALL_STATE(3858)] = 181729,
  [SMALL_STATE(3859)] = 181742,
  [SMALL_STATE(3860)] = 181755,
  [SMALL_STATE(3861)] = 181766,
  [SMALL_STATE(3862)] = 181779,
  [SMALL_STATE(3863)] = 181792,
  [SMALL_STATE(3864)] = 181805,
  [SMALL_STATE(3865)] = 181818,
  [SMALL_STATE(3866)] = 181831,
  [SMALL_STATE(3867)] = 181844,
  [SMALL_STATE(3868)] = 181855,
  [SMALL_STATE(3869)] = 181868,
  [SMALL_STATE(3870)] = 181881,
  [SMALL_STATE(3871)] = 181894,
  [SMALL_STATE(3872)] = 181907,
  [SMALL_STATE(3873)] = 181920,
  [SMALL_STATE(3874)] = 181933,
  [SMALL_STATE(3875)] = 181946,
  [SMALL_STATE(3876)] = 181959,
  [SMALL_STATE(3877)] = 181972,
  [SMALL_STATE(3878)] = 181985,
  [SMALL_STATE(3879)] = 181998,
  [SMALL_STATE(3880)] = 182011,
  [SMALL_STATE(3881)] = 182024,
  [SMALL_STATE(3882)] = 182037,
  [SMALL_STATE(3883)] = 182050,
  [SMALL_STATE(3884)] = 182063,
  [SMALL_STATE(3885)] = 182076,
  [SMALL_STATE(3886)] = 182089,
  [SMALL_STATE(3887)] = 182100,
  [SMALL_STATE(3888)] = 182113,
  [SMALL_STATE(3889)] = 182126,
  [SMALL_STATE(3890)] = 182139,
  [SMALL_STATE(3891)] = 182152,
  [SMALL_STATE(3892)] = 182165,
  [SMALL_STATE(3893)] = 182178,
  [SMALL_STATE(3894)] = 182189,
  [SMALL_STATE(3895)] = 182202,
  [SMALL_STATE(3896)] = 182213,
  [SMALL_STATE(3897)] = 182226,
  [SMALL_STATE(3898)] = 182239,
  [SMALL_STATE(3899)] = 182252,
  [SMALL_STATE(3900)] = 182265,
  [SMALL_STATE(3901)] = 182278,
  [SMALL_STATE(3902)] = 182291,
  [SMALL_STATE(3903)] = 182304,
  [SMALL_STATE(3904)] = 182317,
  [SMALL_STATE(3905)] = 182330,
  [SMALL_STATE(3906)] = 182343,
  [SMALL_STATE(3907)] = 182356,
  [SMALL_STATE(3908)] = 182369,
  [SMALL_STATE(3909)] = 182382,
  [SMALL_STATE(3910)] = 182395,
  [SMALL_STATE(3911)] = 182408,
  [SMALL_STATE(3912)] = 182421,
  [SMALL_STATE(3913)] = 182434,
  [SMALL_STATE(3914)] = 182447,
  [SMALL_STATE(3915)] = 182460,
  [SMALL_STATE(3916)] = 182473,
  [SMALL_STATE(3917)] = 182484,
  [SMALL_STATE(3918)] = 182497,
  [SMALL_STATE(3919)] = 182510,
  [SMALL_STATE(3920)] = 182523,
  [SMALL_STATE(3921)] = 182536,
  [SMALL_STATE(3922)] = 182549,
  [SMALL_STATE(3923)] = 182562,
  [SMALL_STATE(3924)] = 182575,
  [SMALL_STATE(3925)] = 182588,
  [SMALL_STATE(3926)] = 182601,
  [SMALL_STATE(3927)] = 182614,
  [SMALL_STATE(3928)] = 182627,
  [SMALL_STATE(3929)] = 182640,
  [SMALL_STATE(3930)] = 182653,
  [SMALL_STATE(3931)] = 182666,
  [SMALL_STATE(3932)] = 182679,
  [SMALL_STATE(3933)] = 182692,
  [SMALL_STATE(3934)] = 182703,
  [SMALL_STATE(3935)] = 182716,
  [SMALL_STATE(3936)] = 182729,
  [SMALL_STATE(3937)] = 182742,
  [SMALL_STATE(3938)] = 182755,
  [SMALL_STATE(3939)] = 182766,
  [SMALL_STATE(3940)] = 182779,
  [SMALL_STATE(3941)] = 182792,
  [SMALL_STATE(3942)] = 182805,
  [SMALL_STATE(3943)] = 182818,
  [SMALL_STATE(3944)] = 182829,
  [SMALL_STATE(3945)] = 182842,
  [SMALL_STATE(3946)] = 182855,
  [SMALL_STATE(3947)] = 182868,
  [SMALL_STATE(3948)] = 182879,
  [SMALL_STATE(3949)] = 182892,
  [SMALL_STATE(3950)] = 182903,
  [SMALL_STATE(3951)] = 182916,
  [SMALL_STATE(3952)] = 182929,
  [SMALL_STATE(3953)] = 182942,
  [SMALL_STATE(3954)] = 182955,
  [SMALL_STATE(3955)] = 182968,
  [SMALL_STATE(3956)] = 182981,
  [SMALL_STATE(3957)] = 182994,
  [SMALL_STATE(3958)] = 183007,
  [SMALL_STATE(3959)] = 183017,
  [SMALL_STATE(3960)] = 183027,
  [SMALL_STATE(3961)] = 183037,
  [SMALL_STATE(3962)] = 183045,
  [SMALL_STATE(3963)] = 183055,
  [SMALL_STATE(3964)] = 183065,
  [SMALL_STATE(3965)] = 183075,
  [SMALL_STATE(3966)] = 183085,
  [SMALL_STATE(3967)] = 183093,
  [SMALL_STATE(3968)] = 183103,
  [SMALL_STATE(3969)] = 183113,
  [SMALL_STATE(3970)] = 183123,
  [SMALL_STATE(3971)] = 183131,
  [SMALL_STATE(3972)] = 183141,
  [SMALL_STATE(3973)] = 183151,
  [SMALL_STATE(3974)] = 183161,
  [SMALL_STATE(3975)] = 183171,
  [SMALL_STATE(3976)] = 183181,
  [SMALL_STATE(3977)] = 183191,
  [SMALL_STATE(3978)] = 183201,
  [SMALL_STATE(3979)] = 183211,
  [SMALL_STATE(3980)] = 183221,
  [SMALL_STATE(3981)] = 183231,
  [SMALL_STATE(3982)] = 183239,
  [SMALL_STATE(3983)] = 183249,
  [SMALL_STATE(3984)] = 183259,
  [SMALL_STATE(3985)] = 183269,
  [SMALL_STATE(3986)] = 183277,
  [SMALL_STATE(3987)] = 183285,
  [SMALL_STATE(3988)] = 183295,
  [SMALL_STATE(3989)] = 183305,
  [SMALL_STATE(3990)] = 183315,
  [SMALL_STATE(3991)] = 183325,
  [SMALL_STATE(3992)] = 183333,
  [SMALL_STATE(3993)] = 183341,
  [SMALL_STATE(3994)] = 183351,
  [SMALL_STATE(3995)] = 183361,
  [SMALL_STATE(3996)] = 183371,
  [SMALL_STATE(3997)] = 183381,
  [SMALL_STATE(3998)] = 183391,
  [SMALL_STATE(3999)] = 183401,
  [SMALL_STATE(4000)] = 183409,
  [SMALL_STATE(4001)] = 183419,
  [SMALL_STATE(4002)] = 183429,
  [SMALL_STATE(4003)] = 183439,
  [SMALL_STATE(4004)] = 183449,
  [SMALL_STATE(4005)] = 183459,
  [SMALL_STATE(4006)] = 183469,
  [SMALL_STATE(4007)] = 183479,
  [SMALL_STATE(4008)] = 183487,
  [SMALL_STATE(4009)] = 183495,
  [SMALL_STATE(4010)] = 183505,
  [SMALL_STATE(4011)] = 183515,
  [SMALL_STATE(4012)] = 183525,
  [SMALL_STATE(4013)] = 183535,
  [SMALL_STATE(4014)] = 183543,
  [SMALL_STATE(4015)] = 183553,
  [SMALL_STATE(4016)] = 183563,
  [SMALL_STATE(4017)] = 183571,
  [SMALL_STATE(4018)] = 183581,
  [SMALL_STATE(4019)] = 183591,
  [SMALL_STATE(4020)] = 183601,
  [SMALL_STATE(4021)] = 183611,
  [SMALL_STATE(4022)] = 183621,
  [SMALL_STATE(4023)] = 183629,
  [SMALL_STATE(4024)] = 183639,
  [SMALL_STATE(4025)] = 183649,
  [SMALL_STATE(4026)] = 183657,
  [SMALL_STATE(4027)] = 183667,
  [SMALL_STATE(4028)] = 183677,
  [SMALL_STATE(4029)] = 183687,
  [SMALL_STATE(4030)] = 183695,
  [SMALL_STATE(4031)] = 183705,
  [SMALL_STATE(4032)] = 183713,
  [SMALL_STATE(4033)] = 183721,
  [SMALL_STATE(4034)] = 183731,
  [SMALL_STATE(4035)] = 183739,
  [SMALL_STATE(4036)] = 183749,
  [SMALL_STATE(4037)] = 183759,
  [SMALL_STATE(4038)] = 183767,
  [SMALL_STATE(4039)] = 183777,
  [SMALL_STATE(4040)] = 183785,
  [SMALL_STATE(4041)] = 183795,
  [SMALL_STATE(4042)] = 183805,
  [SMALL_STATE(4043)] = 183815,
  [SMALL_STATE(4044)] = 183825,
  [SMALL_STATE(4045)] = 183835,
  [SMALL_STATE(4046)] = 183845,
  [SMALL_STATE(4047)] = 183855,
  [SMALL_STATE(4048)] = 183865,
  [SMALL_STATE(4049)] = 183875,
  [SMALL_STATE(4050)] = 183883,
  [SMALL_STATE(4051)] = 183893,
  [SMALL_STATE(4052)] = 183903,
  [SMALL_STATE(4053)] = 183911,
  [SMALL_STATE(4054)] = 183921,
  [SMALL_STATE(4055)] = 183931,
  [SMALL_STATE(4056)] = 183941,
  [SMALL_STATE(4057)] = 183951,
  [SMALL_STATE(4058)] = 183961,
  [SMALL_STATE(4059)] = 183969,
  [SMALL_STATE(4060)] = 183979,
  [SMALL_STATE(4061)] = 183987,
  [SMALL_STATE(4062)] = 183995,
  [SMALL_STATE(4063)] = 184005,
  [SMALL_STATE(4064)] = 184013,
  [SMALL_STATE(4065)] = 184023,
  [SMALL_STATE(4066)] = 184031,
  [SMALL_STATE(4067)] = 184039,
  [SMALL_STATE(4068)] = 184049,
  [SMALL_STATE(4069)] = 184059,
  [SMALL_STATE(4070)] = 184069,
  [SMALL_STATE(4071)] = 184079,
  [SMALL_STATE(4072)] = 184089,
  [SMALL_STATE(4073)] = 184097,
  [SMALL_STATE(4074)] = 184107,
  [SMALL_STATE(4075)] = 184117,
  [SMALL_STATE(4076)] = 184125,
  [SMALL_STATE(4077)] = 184135,
  [SMALL_STATE(4078)] = 184143,
  [SMALL_STATE(4079)] = 184153,
  [SMALL_STATE(4080)] = 184163,
  [SMALL_STATE(4081)] = 184171,
  [SMALL_STATE(4082)] = 184181,
  [SMALL_STATE(4083)] = 184191,
  [SMALL_STATE(4084)] = 184201,
  [SMALL_STATE(4085)] = 184209,
  [SMALL_STATE(4086)] = 184219,
  [SMALL_STATE(4087)] = 184227,
  [SMALL_STATE(4088)] = 184237,
  [SMALL_STATE(4089)] = 184247,
  [SMALL_STATE(4090)] = 184257,
  [SMALL_STATE(4091)] = 184267,
  [SMALL_STATE(4092)] = 184277,
  [SMALL_STATE(4093)] = 184287,
  [SMALL_STATE(4094)] = 184297,
  [SMALL_STATE(4095)] = 184307,
  [SMALL_STATE(4096)] = 184317,
  [SMALL_STATE(4097)] = 184327,
  [SMALL_STATE(4098)] = 184337,
  [SMALL_STATE(4099)] = 184347,
  [SMALL_STATE(4100)] = 184357,
  [SMALL_STATE(4101)] = 184367,
  [SMALL_STATE(4102)] = 184375,
  [SMALL_STATE(4103)] = 184382,
  [SMALL_STATE(4104)] = 184389,
  [SMALL_STATE(4105)] = 184396,
  [SMALL_STATE(4106)] = 184403,
  [SMALL_STATE(4107)] = 184410,
  [SMALL_STATE(4108)] = 184417,
  [SMALL_STATE(4109)] = 184424,
  [SMALL_STATE(4110)] = 184431,
  [SMALL_STATE(4111)] = 184438,
  [SMALL_STATE(4112)] = 184445,
  [SMALL_STATE(4113)] = 184452,
  [SMALL_STATE(4114)] = 184459,
  [SMALL_STATE(4115)] = 184466,
  [SMALL_STATE(4116)] = 184473,
  [SMALL_STATE(4117)] = 184480,
  [SMALL_STATE(4118)] = 184487,
  [SMALL_STATE(4119)] = 184494,
  [SMALL_STATE(4120)] = 184501,
  [SMALL_STATE(4121)] = 184508,
  [SMALL_STATE(4122)] = 184515,
  [SMALL_STATE(4123)] = 184522,
  [SMALL_STATE(4124)] = 184529,
  [SMALL_STATE(4125)] = 184536,
  [SMALL_STATE(4126)] = 184543,
  [SMALL_STATE(4127)] = 184550,
  [SMALL_STATE(4128)] = 184557,
  [SMALL_STATE(4129)] = 184564,
  [SMALL_STATE(4130)] = 184571,
  [SMALL_STATE(4131)] = 184578,
  [SMALL_STATE(4132)] = 184585,
  [SMALL_STATE(4133)] = 184592,
  [SMALL_STATE(4134)] = 184599,
  [SMALL_STATE(4135)] = 184606,
  [SMALL_STATE(4136)] = 184613,
  [SMALL_STATE(4137)] = 184620,
  [SMALL_STATE(4138)] = 184627,
  [SMALL_STATE(4139)] = 184634,
  [SMALL_STATE(4140)] = 184641,
  [SMALL_STATE(4141)] = 184648,
  [SMALL_STATE(4142)] = 184655,
  [SMALL_STATE(4143)] = 184662,
  [SMALL_STATE(4144)] = 184669,
  [SMALL_STATE(4145)] = 184676,
  [SMALL_STATE(4146)] = 184683,
  [SMALL_STATE(4147)] = 184690,
  [SMALL_STATE(4148)] = 184697,
  [SMALL_STATE(4149)] = 184704,
  [SMALL_STATE(4150)] = 184711,
  [SMALL_STATE(4151)] = 184718,
  [SMALL_STATE(4152)] = 184725,
  [SMALL_STATE(4153)] = 184732,
  [SMALL_STATE(4154)] = 184739,
  [SMALL_STATE(4155)] = 184746,
  [SMALL_STATE(4156)] = 184753,
  [SMALL_STATE(4157)] = 184760,
  [SMALL_STATE(4158)] = 184767,
  [SMALL_STATE(4159)] = 184774,
  [SMALL_STATE(4160)] = 184781,
  [SMALL_STATE(4161)] = 184788,
  [SMALL_STATE(4162)] = 184795,
  [SMALL_STATE(4163)] = 184802,
  [SMALL_STATE(4164)] = 184809,
  [SMALL_STATE(4165)] = 184816,
  [SMALL_STATE(4166)] = 184823,
  [SMALL_STATE(4167)] = 184830,
  [SMALL_STATE(4168)] = 184837,
  [SMALL_STATE(4169)] = 184844,
  [SMALL_STATE(4170)] = 184851,
  [SMALL_STATE(4171)] = 184858,
  [SMALL_STATE(4172)] = 184865,
  [SMALL_STATE(4173)] = 184872,
  [SMALL_STATE(4174)] = 184879,
  [SMALL_STATE(4175)] = 184886,
  [SMALL_STATE(4176)] = 184893,
  [SMALL_STATE(4177)] = 184900,
  [SMALL_STATE(4178)] = 184907,
  [SMALL_STATE(4179)] = 184914,
  [SMALL_STATE(4180)] = 184921,
  [SMALL_STATE(4181)] = 184928,
  [SMALL_STATE(4182)] = 184935,
  [SMALL_STATE(4183)] = 184942,
  [SMALL_STATE(4184)] = 184949,
  [SMALL_STATE(4185)] = 184956,
  [SMALL_STATE(4186)] = 184963,
  [SMALL_STATE(4187)] = 184970,
  [SMALL_STATE(4188)] = 184977,
  [SMALL_STATE(4189)] = 184984,
  [SMALL_STATE(4190)] = 184991,
  [SMALL_STATE(4191)] = 184998,
  [SMALL_STATE(4192)] = 185005,
  [SMALL_STATE(4193)] = 185012,
  [SMALL_STATE(4194)] = 185019,
  [SMALL_STATE(4195)] = 185026,
  [SMALL_STATE(4196)] = 185033,
  [SMALL_STATE(4197)] = 185040,
  [SMALL_STATE(4198)] = 185047,
  [SMALL_STATE(4199)] = 185054,
  [SMALL_STATE(4200)] = 185061,
  [SMALL_STATE(4201)] = 185068,
  [SMALL_STATE(4202)] = 185075,
  [SMALL_STATE(4203)] = 185082,
  [SMALL_STATE(4204)] = 185089,
  [SMALL_STATE(4205)] = 185096,
  [SMALL_STATE(4206)] = 185103,
  [SMALL_STATE(4207)] = 185110,
  [SMALL_STATE(4208)] = 185117,
  [SMALL_STATE(4209)] = 185124,
  [SMALL_STATE(4210)] = 185131,
  [SMALL_STATE(4211)] = 185138,
  [SMALL_STATE(4212)] = 185145,
  [SMALL_STATE(4213)] = 185152,
  [SMALL_STATE(4214)] = 185159,
  [SMALL_STATE(4215)] = 185166,
  [SMALL_STATE(4216)] = 185173,
  [SMALL_STATE(4217)] = 185180,
  [SMALL_STATE(4218)] = 185187,
  [SMALL_STATE(4219)] = 185194,
  [SMALL_STATE(4220)] = 185201,
  [SMALL_STATE(4221)] = 185208,
  [SMALL_STATE(4222)] = 185215,
  [SMALL_STATE(4223)] = 185222,
  [SMALL_STATE(4224)] = 185229,
  [SMALL_STATE(4225)] = 185236,
  [SMALL_STATE(4226)] = 185243,
  [SMALL_STATE(4227)] = 185250,
  [SMALL_STATE(4228)] = 185257,
  [SMALL_STATE(4229)] = 185264,
  [SMALL_STATE(4230)] = 185271,
  [SMALL_STATE(4231)] = 185278,
  [SMALL_STATE(4232)] = 185285,
  [SMALL_STATE(4233)] = 185292,
  [SMALL_STATE(4234)] = 185299,
  [SMALL_STATE(4235)] = 185306,
  [SMALL_STATE(4236)] = 185313,
  [SMALL_STATE(4237)] = 185320,
  [SMALL_STATE(4238)] = 185327,
  [SMALL_STATE(4239)] = 185334,
  [SMALL_STATE(4240)] = 185341,
  [SMALL_STATE(4241)] = 185348,
  [SMALL_STATE(4242)] = 185355,
  [SMALL_STATE(4243)] = 185362,
  [SMALL_STATE(4244)] = 185369,
  [SMALL_STATE(4245)] = 185376,
  [SMALL_STATE(4246)] = 185383,
  [SMALL_STATE(4247)] = 185390,
  [SMALL_STATE(4248)] = 185397,
  [SMALL_STATE(4249)] = 185404,
  [SMALL_STATE(4250)] = 185411,
  [SMALL_STATE(4251)] = 185418,
  [SMALL_STATE(4252)] = 185425,
  [SMALL_STATE(4253)] = 185432,
  [SMALL_STATE(4254)] = 185439,
  [SMALL_STATE(4255)] = 185446,
  [SMALL_STATE(4256)] = 185453,
  [SMALL_STATE(4257)] = 185460,
  [SMALL_STATE(4258)] = 185467,
  [SMALL_STATE(4259)] = 185474,
  [SMALL_STATE(4260)] = 185481,
  [SMALL_STATE(4261)] = 185488,
  [SMALL_STATE(4262)] = 185495,
  [SMALL_STATE(4263)] = 185502,
  [SMALL_STATE(4264)] = 185509,
  [SMALL_STATE(4265)] = 185516,
  [SMALL_STATE(4266)] = 185523,
  [SMALL_STATE(4267)] = 185530,
  [SMALL_STATE(4268)] = 185537,
  [SMALL_STATE(4269)] = 185544,
  [SMALL_STATE(4270)] = 185551,
  [SMALL_STATE(4271)] = 185558,
  [SMALL_STATE(4272)] = 185565,
  [SMALL_STATE(4273)] = 185572,
  [SMALL_STATE(4274)] = 185579,
  [SMALL_STATE(4275)] = 185586,
  [SMALL_STATE(4276)] = 185593,
  [SMALL_STATE(4277)] = 185600,
  [SMALL_STATE(4278)] = 185607,
  [SMALL_STATE(4279)] = 185614,
  [SMALL_STATE(4280)] = 185621,
  [SMALL_STATE(4281)] = 185628,
  [SMALL_STATE(4282)] = 185635,
  [SMALL_STATE(4283)] = 185642,
  [SMALL_STATE(4284)] = 185649,
  [SMALL_STATE(4285)] = 185656,
  [SMALL_STATE(4286)] = 185663,
  [SMALL_STATE(4287)] = 185670,
  [SMALL_STATE(4288)] = 185677,
  [SMALL_STATE(4289)] = 185684,
  [SMALL_STATE(4290)] = 185691,
  [SMALL_STATE(4291)] = 185698,
  [SMALL_STATE(4292)] = 185705,
  [SMALL_STATE(4293)] = 185712,
  [SMALL_STATE(4294)] = 185719,
  [SMALL_STATE(4295)] = 185726,
  [SMALL_STATE(4296)] = 185733,
  [SMALL_STATE(4297)] = 185740,
  [SMALL_STATE(4298)] = 185747,
  [SMALL_STATE(4299)] = 185754,
  [SMALL_STATE(4300)] = 185761,
  [SMALL_STATE(4301)] = 185768,
  [SMALL_STATE(4302)] = 185775,
  [SMALL_STATE(4303)] = 185782,
  [SMALL_STATE(4304)] = 185789,
  [SMALL_STATE(4305)] = 185796,
  [SMALL_STATE(4306)] = 185803,
  [SMALL_STATE(4307)] = 185810,
  [SMALL_STATE(4308)] = 185817,
  [SMALL_STATE(4309)] = 185824,
  [SMALL_STATE(4310)] = 185831,
  [SMALL_STATE(4311)] = 185838,
  [SMALL_STATE(4312)] = 185845,
  [SMALL_STATE(4313)] = 185852,
  [SMALL_STATE(4314)] = 185859,
  [SMALL_STATE(4315)] = 185866,
  [SMALL_STATE(4316)] = 185873,
  [SMALL_STATE(4317)] = 185880,
  [SMALL_STATE(4318)] = 185887,
  [SMALL_STATE(4319)] = 185894,
  [SMALL_STATE(4320)] = 185901,
  [SMALL_STATE(4321)] = 185908,
  [SMALL_STATE(4322)] = 185915,
  [SMALL_STATE(4323)] = 185922,
  [SMALL_STATE(4324)] = 185929,
  [SMALL_STATE(4325)] = 185936,
  [SMALL_STATE(4326)] = 185943,
  [SMALL_STATE(4327)] = 185950,
  [SMALL_STATE(4328)] = 185957,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3565),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4082),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4014),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3997),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4005),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3630),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3925),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3927),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3930),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4033),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4125),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4131),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3564),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(332),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4274),
  [45] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(2268),
  [48] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(228),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [53] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 1, 0, 0),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 1, 0, 0),
  [57] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(160),
  [60] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [62] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [64] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(161),
  [67] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(2611),
  [70] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(3942),
  [73] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 1, 0, 0), SHIFT(4298),
  [76] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4025),
  [78] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3156),
  [80] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [82] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [84] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [86] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2602),
  [88] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [90] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [92] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3444),
  [94] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3126),
  [96] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [98] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 32),
  [114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 32),
  [116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3942),
  [126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4298),
  [128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3194),
  [132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(706),
  [136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3359),
  [140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3360),
  [144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3148),
  [146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2616),
  [180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3403),
  [186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3118),
  [188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3693),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4266),
  [196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(232),
  [203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2652),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2652),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2317),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2302),
  [233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 1, 0, 0), SHIFT(224),
  [236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2661),
  [240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2661),
  [242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2594),
  [246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3958),
  [252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4096),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4097),
  [256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3703),
  [258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3963),
  [286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4064),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(329),
  [296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 6, 0, 85),
  [300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 6, 0, 85),
  [304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1225),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3397),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3398),
  [324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3143),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4118),
  [330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 4, 0, 67),
  [332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 4, 0, 67),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 67),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 67),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 85),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 5, 0, 85),
  [342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4055),
  [344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4056),
  [346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3617),
  [350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4068),
  [356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4100),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3959),
  [360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3689),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1486),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4035),
  [382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3646),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3420),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3422),
  [390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3095),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4249),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 2, 0, 3),
  [408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1770),
  [410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1244),
  [416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1247),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3447),
  [430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3349),
  [434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3064),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1331),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1246),
  [452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3709),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3406),
  [464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4249),
  [472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1980),
  [479] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(215),
  [482] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(216),
  [485] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [491] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(161),
  [494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2611),
  [497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3650),
  [500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3833),
  [503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1792),
  [506] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(4298),
  [509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3156),
  [515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(5),
  [518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2109),
  [521] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2587),
  [524] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2602),
  [527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3443),
  [530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2117),
  [533] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3444),
  [536] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3126),
  [539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1952),
  [542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2587),
  [545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(3712),
  [548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(4303),
  [551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(2288),
  [554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2416),
  [556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2708),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2708),
  [562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2035),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [566] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1226),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3987),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3648),
  [588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2803),
  [590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4023),
  [592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4024),
  [594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4028),
  [596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3141),
  [598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2797),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4157),
  [604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1521),
  [610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2798),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4271),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1203),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4275),
  [638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1475),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2520),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2513),
  [688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2462),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2465),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2344),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2480),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2497),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2497),
  [742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2294),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2351),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2468),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2307),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2456),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2313),
  [768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2316),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2303),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2433),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2452),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2452),
  [788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2457),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2458),
  [796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2406),
  [802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2460),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2524),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2535),
  [816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2536),
  [820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2539),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2495),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2496),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2496),
  [836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2505),
  [838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2505),
  [840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2508),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2508),
  [844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2451),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2518),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1646),
  [868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1328),
  [872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1330),
  [880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3643),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1588),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1289),
  [898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2403),
  [902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2420),
  [908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1627),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4047),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2258),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2376),
  [944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2592),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2593),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(712),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2525),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2286),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2526),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2527),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2528),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2529),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2530),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2531),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2532),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [1006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2533),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [1010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2534),
  [1012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [1014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [1018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [1024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [1026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [1028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [1030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2553),
  [1032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [1034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [1036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2289),
  [1040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2554),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1690),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1082),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [1056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [1058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2268),
  [1060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [1064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [1066] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [1068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2409),
  [1070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [1076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2291),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [1080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2590),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [1084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2591),
  [1086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [1088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2314),
  [1090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2314),
  [1092] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1980),
  [1096] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(215),
  [1100] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(216),
  [1104] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(160),
  [1108] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(160),
  [1112] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(161),
  [1116] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2611),
  [1120] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3833),
  [1124] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(4298),
  [1128] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(4025),
  [1132] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3156),
  [1136] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(5),
  [1140] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2109),
  [1144] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2652),
  [1148] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2602),
  [1152] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3443),
  [1156] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2117),
  [1160] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3444),
  [1164] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3126),
  [1168] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(1952),
  [1172] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2652),
  [1176] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(3712),
  [1180] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(4303),
  [1184] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), REDUCE(sym_memory_space, 4, 0, 61), SHIFT(2288),
  [1188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2318),
  [1190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [1192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [1194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [1196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [1200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2337),
  [1202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [1204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2338),
  [1206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [1212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2361),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [1220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2540),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [1224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2541),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [1228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2308),
  [1232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2310),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [1236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(682),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1246] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(1980),
  [1249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(215),
  [1252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(216),
  [1255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(160),
  [1258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(160),
  [1261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(161),
  [1264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2611),
  [1267] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3833),
  [1270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(4298),
  [1273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(4025),
  [1276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3156),
  [1279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(5),
  [1282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2109),
  [1285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2652),
  [1288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2602),
  [1291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3443),
  [1294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2117),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3444),
  [1300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3126),
  [1303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(1952),
  [1306] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2652),
  [1309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(3712),
  [1312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(4303),
  [1315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 29), SHIFT(2288),
  [1318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1980),
  [1321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(215),
  [1324] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(216),
  [1327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(160),
  [1330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(160),
  [1333] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(161),
  [1336] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2611),
  [1339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3833),
  [1342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(4298),
  [1345] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(4025),
  [1348] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3156),
  [1351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(5),
  [1354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2109),
  [1357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2652),
  [1360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2602),
  [1363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3443),
  [1366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2117),
  [1369] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3444),
  [1372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3126),
  [1375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(1952),
  [1378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2652),
  [1381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(3712),
  [1384] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(4303),
  [1387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 30), SHIFT(2288),
  [1390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1325),
  [1396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [1398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [1400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [1402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2408),
  [1404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [1406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [1408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2253),
  [1410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2412),
  [1412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2412),
  [1414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [1418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [1424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [1426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2336),
  [1428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [1430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4029),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [1440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [1442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 1, 0, 0),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3565),
  [1451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4022),
  [1454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0),
  [1456] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4082),
  [1459] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4055),
  [1462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4056),
  [1465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4057),
  [1468] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3617),
  [1471] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3963),
  [1474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3925),
  [1477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(2704),
  [1480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3927),
  [1483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3930),
  [1486] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4033),
  [1489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4125),
  [1492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4131),
  [1495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(3564),
  [1498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(261),
  [1501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(334),
  [1504] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat2, 2, 0, 0), SHIFT_REPEAT(4274),
  [1507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0),
  [1509] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3565),
  [1512] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4022),
  [1515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4082),
  [1518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4014),
  [1521] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3997),
  [1524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4005),
  [1527] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3630),
  [1530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3974),
  [1533] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3925),
  [1536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(2704),
  [1539] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3927),
  [1542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3930),
  [1545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4033),
  [1548] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4125),
  [1551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4131),
  [1554] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(3564),
  [1557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(262),
  [1560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(332),
  [1563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_script_repeat1, 2, 0, 0), SHIFT_REPEAT(4274),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(318),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(341),
  [1574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(334),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2707),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(336),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [1612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [1614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [1622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3993),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 7, 0, 0),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0),
  [1629] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3788),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [1634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3212),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(394),
  [1642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(444),
  [1644] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3993),
  [1647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 5, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0),
  [1651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3788),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(414),
  [1660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3209),
  [1662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(380),
  [1664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3993),
  [1667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 3, 0, 0),
  [1669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0),
  [1671] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3788),
  [1674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [1676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [1680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3205),
  [1682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [1684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3993),
  [1687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 6, 0, 0),
  [1689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0),
  [1691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3788),
  [1694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [1700] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3210),
  [1702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(388),
  [1704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3993),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 4, 0, 0),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0),
  [1711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3788),
  [1714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [1718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(434),
  [1720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3208),
  [1722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [1728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(349),
  [1730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(344),
  [1732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(347),
  [1734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4091),
  [1738] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3804),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [1747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3199),
  [1751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(491),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4039),
  [1757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4061),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [1761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3804),
  [1764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [1766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [1768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(502),
  [1770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3200),
  [1772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(499),
  [1774] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3804),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(483),
  [1783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3198),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(484),
  [1787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3804),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [1794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(509),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3201),
  [1798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [1800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3804),
  [1803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3197),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4053),
  [1817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3795),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [1826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [1828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3330),
  [1830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [1832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(784),
  [1834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3795),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [1839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [1841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3335),
  [1845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(652),
  [1847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3795),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [1854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [1856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3333),
  [1858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(633),
  [1860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3795),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3331),
  [1871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(624),
  [1873] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3795),
  [1876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1586),
  [1878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [1880] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [1882] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3334),
  [1884] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [1886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_text_expansion, 2, 0, 26),
  [1890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_text_expansion, 2, 0, 26),
  [1892] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3787),
  [1894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_text_expansion, 2, 0, 0),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_text_expansion, 2, 0, 0),
  [1898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_text_expansion, 3, 0, 26),
  [1900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_text_expansion, 3, 0, 26),
  [1902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(355),
  [1905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0),
  [1907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0),
  [1909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3787),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [1914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [1916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(309),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [1922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [1924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro, 2, 0, 7),
  [1926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro, 2, 0, 7),
  [1928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro, 4, 0, 35),
  [1930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro, 4, 0, 35),
  [1932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4040),
  [1934] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3784),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3149),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(987),
  [1945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3273),
  [1947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [1949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3645),
  [1955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2056),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3482),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [1973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [1975] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__address_expression, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [1978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__address_expression, 1, 0, 0), REDUCE(sym__expression, 1, 0, 0),
  [1981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_expression, 1, 0, 0),
  [1983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_expression, 1, 0, 0),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [1987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 1, 0, 26),
  [1989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 1, 0, 26),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3975),
  [1993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3814),
  [1996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [1998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [2004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3258),
  [2006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [2008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [2016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [2018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2732),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [2024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3684),
  [2026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [2036] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 3, 0, 0), SHIFT(3784),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1750),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [2043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [2045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3180),
  [2047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(952),
  [2049] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3814),
  [2052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3259),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [2062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 5, 0, 0), SHIFT(3814),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [2069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [2071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3260),
  [2073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [2075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 4, 0, 0), SHIFT(3784),
  [2078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [2080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [2082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3226),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 2, 0, 0),
  [2102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(310),
  [2110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3784),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [2117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3290),
  [2121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [2123] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3784),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3304),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [2136] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 6, 0, 0), SHIFT(3814),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1469),
  [2143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [2145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3261),
  [2147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [2149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 7, 0, 0), SHIFT(3814),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [2156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [2158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3262),
  [2160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(891),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(651),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [2184] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(4054),
  [2187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3787),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(321),
  [2196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3404),
  [2198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(674),
  [2200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 6, 0, 0),
  [2203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 6, 0, 0),
  [2206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3788),
  [2208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(845),
  [2211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3210),
  [2214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3404),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [2219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [2221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 7, 0, 0),
  [2224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 7, 0, 0),
  [2227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1034),
  [2230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3212),
  [2233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3993),
  [2236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3788),
  [2239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3204),
  [2241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3993),
  [2244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 8, 0, 0),
  [2246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0),
  [2248] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3788),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [2253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 8, 0, 0),
  [2256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 8, 0, 0),
  [2259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(957),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3213),
  [2264] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3213),
  [2267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 9, 0, 0),
  [2269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [2273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3993),
  [2276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3788),
  [2279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 9, 0, 0),
  [2282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 9, 0, 0),
  [2285] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(854),
  [2288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3222),
  [2290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 10, 0, 0),
  [2292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3993),
  [2299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3788),
  [2302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 10, 0, 0),
  [2305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 10, 0, 0),
  [2308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(904),
  [2311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 11, 0, 0),
  [2313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [2317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3993),
  [2320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3788),
  [2323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 11, 0, 0),
  [2326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 11, 0, 0),
  [2329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1021),
  [2332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 12, 0, 0),
  [2334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 12, 0, 0),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [2350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 4, 0, 0),
  [2361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 4, 0, 0),
  [2364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(888),
  [2367] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3208),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [2378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(311),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2756),
  [2386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 5, 0, 0),
  [2389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), REDUCE(sym_symbol, 5, 0, 0),
  [2392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1002),
  [2395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3209),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [2404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3993),
  [2407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0),
  [2409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0),
  [2411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3788),
  [2414] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_identifier, 1, 0, 9), REDUCE(sym__expression, 1, 0, 0),
  [2417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4183),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [2421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 3, 0, 0),
  [2423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 3, 0, 0),
  [2425] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(674),
  [2428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3788),
  [2431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [2439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3803),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [2446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(324),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3803),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(330),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [2460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(4020),
  [2463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 1, 0, 0),
  [2465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0),
  [2467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(3790),
  [2470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3421),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3790),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3804),
  [2480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1501),
  [2483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3201),
  [2486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3196),
  [2488] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(4020),
  [2491] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3790),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [2496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3432),
  [2498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1488),
  [2501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3198),
  [2504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3432),
  [2507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(320),
  [2509] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1494),
  [2512] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3199),
  [2515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1498),
  [2518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3200),
  [2521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integer, 1, 0, 0),
  [2523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integer, 1, 0, 0),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [2527] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3804),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [2532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1506),
  [2535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3202),
  [2537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3202),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [2542] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3804),
  [2545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1508),
  [2548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3203),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [2552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3804),
  [2555] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1510),
  [2558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [2560] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3804),
  [2563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1512),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [2568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 1, 0, 12),
  [2570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 1, 0, 12),
  [2572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [2578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0),
  [2580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0),
  [2582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [2585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__literal, 1, 0, 0), REDUCE(sym__address_expression, 1, 0, 0),
  [2588] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_binary_expression, 3, 0, 38),
  [2590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_binary_expression, 3, 0, 38),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [2598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integer, 2, 0, 0),
  [2600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integer, 2, 0, 0),
  [2602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [2604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [2606] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(765),
  [2609] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3790),
  [2612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3804),
  [2615] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(770),
  [2618] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3803),
  [2621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 2, 0, 25),
  [2623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 2, 0, 25),
  [2625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [2633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_handle, 2, 0, 0),
  [2635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_handle, 2, 0, 0),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [2639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 13, 0, 0),
  [2641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 13, 0, 0),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [2645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 27),
  [2647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 27),
  [2649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_call_expression, 2, 0, 27),
  [2651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_call_expression, 2, 0, 27),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [2661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3794),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [2668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3794),
  [2674] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1646),
  [2677] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(84),
  [2680] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1328),
  [2683] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1328),
  [2686] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1329),
  [2689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1246),
  [2692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3650),
  [2695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1330),
  [2698] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(4041),
  [2701] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3643),
  [2704] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3405),
  [2707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1545),
  [2710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3406),
  [2713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3086),
  [2716] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(1161),
  [2719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(4186),
  [2722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 2, 0, 31),
  [2724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 2, 0, 31),
  [2726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [2728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_address, 3, 0, 43),
  [2730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_address, 2, 0, 31), REDUCE(sym_address, 3, 0, 43),
  [2733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_address, 3, 0, 43),
  [2735] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_address, 2, 0, 31), REDUCE(sym_address, 3, 0, 43),
  [2738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0),
  [2740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0),
  [2742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(3787),
  [2745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(570),
  [2748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [2750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [2752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1691),
  [2754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_address_expression, 3, 0, 0),
  [2758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_address_expression, 3, 0, 0),
  [2760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [2762] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [2764] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_var_call_expression_argument_list, 3, 0, 0),
  [2766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_var_call_expression_argument_list, 3, 0, 0),
  [2768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [2770] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [2772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3404),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [2777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__address_expression, 1, 0, 11),
  [2779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__address_expression, 1, 0, 11),
  [2781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3845),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4053),
  [2787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3795),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [2792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3795),
  [2794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3327),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [2798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3858),
  [2800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3661),
  [2802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [2804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3412),
  [2806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1598),
  [2809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3331),
  [2812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3412),
  [2815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [2817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1608),
  [2820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3333),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [2831] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1586),
  [2834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3334),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3864),
  [2841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(327),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3742),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [2851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [2853] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1580),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [2860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(364),
  [2862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3335),
  [2865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__path_expression, 1, 0, 0),
  [2867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__path_expression, 1, 0, 0),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [2875] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3795),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [2880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1589),
  [2883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3337),
  [2885] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3804),
  [2888] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(966),
  [2891] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3794),
  [2894] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3337),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [2899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3795),
  [2902] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1624),
  [2905] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(928),
  [2908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3804),
  [2911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3338),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [2915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3795),
  [2918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1617),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [2923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3795),
  [2926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unary_expression, 2, 0, 24),
  [2928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_expression, 2, 0, 24),
  [2930] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1604),
  [2933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 24),
  [2935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__prefix_postfix_expression, 2, 0, 24),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [2939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [2941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3829),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4093),
  [2973] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(3805),
  [2976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3435),
  [2978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0),
  [2980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0),
  [2982] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(3989),
  [2985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0),
  [2987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0),
  [2989] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(3802),
  [2992] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [2994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [2996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [2998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [3000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [3002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [3004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [3006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [3008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [3010] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 38),
  [3012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 38),
  [3014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3771),
  [3016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [3018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3832),
  [3020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1472),
  [3022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [3024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 3, 0, 38),
  [3026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38),
  [3028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [3030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(4064),
  [3033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [3035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [3037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [3039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3861),
  [3041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2739),
  [3045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3805),
  [3051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [3053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3904),
  [3055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(350),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2752),
  [3063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3844),
  [3065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [3067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3849),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [3071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [3073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__and_expression, 4, 0, 53),
  [3075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__and_expression, 4, 0, 53),
  [3077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 4, 0, 52),
  [3079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 52),
  [3081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 4, 0, 53),
  [3083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 4, 0, 53),
  [3085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 5, 0, 72),
  [3087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 5, 0, 72),
  [3089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [3097] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3421),
  [3100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3541),
  [3102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [3104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [3106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [3108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [3110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__path_expression, 2, 0, 0),
  [3112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__path_expression, 2, 0, 0),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [3118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [3120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [3122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [3124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3783),
  [3126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [3128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1178),
  [3131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3805),
  [3134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [3136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [3138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3796),
  [3140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3380),
  [3142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [3144] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3813),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [3151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [3159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3813),
  [3161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3805),
  [3164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [3166] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3795),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [3175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [3187] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3783),
  [3190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [3192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [3194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [3196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [3198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [3200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1163),
  [3203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3795),
  [3206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [3208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [3210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [3212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [3214] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(3294),
  [3217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [3219] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [3221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(4023),
  [3224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(4024),
  [3227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(4028),
  [3230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(3141),
  [3233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT(2801),
  [3236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1370),
  [3239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4074),
  [3243] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(3796),
  [3246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [3248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3784),
  [3250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [3252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3381),
  [3254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [3256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3814),
  [3258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [3260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4040),
  [3262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3784),
  [3265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3286),
  [3267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [3269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3441),
  [3271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1771),
  [3274] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3259),
  [3277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3441),
  [3280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__special_command_operator, 1, 0, 0),
  [3282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__special_command_operator, 1, 0, 0),
  [3284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(371),
  [3286] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1644),
  [3289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(82),
  [3292] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1325),
  [3295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1325),
  [3298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1326),
  [3301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1246),
  [3304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1327),
  [3307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(4041),
  [3310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3643),
  [3313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3405),
  [3316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1545),
  [3319] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3406),
  [3322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3086),
  [3325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(1161),
  [3328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(4186),
  [3331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1701),
  [3334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3260),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [3339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1706),
  [3342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3261),
  [3345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [3347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_expression, 3, 0, 0),
  [3349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_expression, 3, 0, 0),
  [3351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character, 3, 0, 0),
  [3353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character, 3, 0, 0),
  [3355] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1710),
  [3358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3262),
  [3361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3814),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [3366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1711),
  [3369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3263),
  [3371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3263),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [3378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3814),
  [3381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1712),
  [3384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3264),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [3388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3814),
  [3391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1714),
  [3394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [3396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3814),
  [3399] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1715),
  [3402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [3404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [3406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bitmask, 1, 0, 0),
  [3408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bitmask, 1, 0, 0),
  [3410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3432),
  [3413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [3415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [3417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [3419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1343),
  [3422] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3796),
  [3425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [3427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [3429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [3431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [3433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 9),
  [3435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 2, 0, 9),
  [3437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [3439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1761),
  [3442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3226),
  [3445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 1, 0, 10),
  [3447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 1, 0, 10),
  [3449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 1, 0, 11),
  [3451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 1, 0, 11),
  [3453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3381),
  [3456] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3796),
  [3459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [3461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [3463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1766),
  [3466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3273),
  [3469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1748),
  [3472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3290),
  [3475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [3477] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1732),
  [3480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3304),
  [3483] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 8, 0, 0), SHIFT(3784),
  [3486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [3488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1764),
  [3491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3311),
  [3493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3311),
  [3496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [3498] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1355),
  [3501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3813),
  [3504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 9, 0, 0), SHIFT(3784),
  [3507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1699),
  [3510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3315),
  [3512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [3514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 10, 0, 0), SHIFT(3784),
  [3517] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1704),
  [3520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [3522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 11, 0, 0), SHIFT(3784),
  [3525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(1705),
  [3528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 2, 0, 0), SHIFT(3814),
  [3531] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1379),
  [3534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3783),
  [3537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3257),
  [3539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbol, 14, 0, 0),
  [3541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbol, 14, 0, 0),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [3545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3786),
  [3547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3433),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [3553] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3412),
  [3556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1407),
  [3559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3784),
  [3562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [3564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(3815),
  [3567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3442),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [3571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3815),
  [3573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3435),
  [3576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3814),
  [3579] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1429),
  [3582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3814),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [3587] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3784),
  [3590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [3592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [3594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [3596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [3598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [3602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [3604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [3606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [3610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [3612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_symbol, 1, 0, 0), SHIFT(3786),
  [3615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_unary_expression, 2, 0, 24),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [3619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_unary_expression, 2, 0, 24),
  [3621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3968),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [3627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_update_expression, 2, 0, 24),
  [3629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_update_expression, 2, 0, 24),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [3633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sizeof_expression, 2, 0, 33),
  [3635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sizeof_expression, 2, 0, 33),
  [3637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [3639] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3815),
  [3642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_expression, 2, 0, 24),
  [3644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_pointer_expression, 2, 0, 24),
  [3646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3786),
  [3649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1615),
  [3652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3815),
  [3655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_binary_expression, 3, 0, 38),
  [3657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_binary_expression, 3, 0, 38),
  [3659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 5, 0, 78),
  [3661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 5, 0, 78),
  [3663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 5, 0, 82),
  [3665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 5, 0, 82),
  [3667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 6, 0, 96),
  [3669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 6, 0, 96),
  [3671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0),
  [3673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [3676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0),
  [3678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [3683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1251),
  [3685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [3687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [3689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [3693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1255),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [3699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [3701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 3, 0, 38),
  [3703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 3, 0, 38),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [3707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [3709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_conditional_expression, 4, 0, 68),
  [3711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_conditional_expression, 4, 0, 68),
  [3713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 4, 0, 52),
  [3715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 4, 0, 52),
  [3717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 4, 0, 53),
  [3719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 4, 0, 53),
  [3721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_conditional_expression, 5, 0, 86),
  [3723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_conditional_expression, 5, 0, 86),
  [3725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_assignment_expression, 5, 0, 72),
  [3727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_assignment_expression, 5, 0, 72),
  [3729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3380),
  [3732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1574),
  [3735] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3786),
  [3738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_cast_expression, 4, 0, 64),
  [3740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_cast_expression, 4, 0, 64),
  [3742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [3744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1341),
  [3746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [3750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1208),
  [3752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [3754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1210),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [3758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1212),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [3762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [3774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_expression, 2, 0, 0),
  [3776] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_expression, 2, 0, 0),
  [3778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_string_literal, 2, 0, 0),
  [3780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_string_literal, 2, 0, 0),
  [3782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_option_value, 1, 0, 0),
  [3784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 22),
  [3787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [3789] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 22),
  [3792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_assignment_left_expression, 1, 0, 0),
  [3794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_type_identifier, 1, 0, 22),
  [3796] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__hll_expression, 1, 0, 0), REDUCE(sym__hll_assignment_left_expression, 1, 0, 0), REDUCE(sym__hll_type_identifier, 1, 0, 22),
  [3800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_update_expression, 2, 0, 32),
  [3802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_update_expression, 2, 0, 32),
  [3804] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3441),
  [3807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_char_literal, 3, 0, 0),
  [3809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_char_literal, 3, 0, 0),
  [3811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_string_literal, 3, 0, 0),
  [3813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_string_literal, 3, 0, 0),
  [3815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_call_expression, 2, 0, 27),
  [3817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_call_expression, 2, 0, 27),
  [3819] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3381),
  [3822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 3, 0, 0),
  [3824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 3, 0, 0),
  [3826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 2, 0, 0),
  [3828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 2, 0, 0),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [3832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_field_identifier, 1, 0, 46),
  [3834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_field_identifier, 1, 0, 46),
  [3836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_field_expression, 3, 0, 47),
  [3838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_field_expression, 3, 0, 47),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [3842] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 4, 0, 0),
  [3844] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 4, 0, 0),
  [3846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 3, 0, 0),
  [3848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 3, 0, 0),
  [3850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_subscript_expression, 4, 0, 69),
  [3852] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_subscript_expression, 4, 0, 69),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [3856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [3858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_expression, 5, 0, 0),
  [3860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_expression, 5, 0, 0),
  [3862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 4, 0, 0),
  [3864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 4, 0, 0),
  [3866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 5, 0, 0),
  [3868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 5, 0, 0),
  [3870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_argument_list, 6, 0, 0),
  [3872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_argument_list, 6, 0, 0),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [3876] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3442),
  [3879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3433),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [3884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [3888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [3890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1057),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4000),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [3896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1050),
  [3898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1053),
  [3900] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [3904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [3908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1059),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [3916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [3920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4021),
  [3922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [3924] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_option_value, 1, 0, 0),
  [3926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4081),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3799),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2220),
  [3934] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1833),
  [3936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3173),
  [3938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1834),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4046),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [3950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [3952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1920),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3320),
  [3956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [3958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [3960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1916),
  [3966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3174),
  [3968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1919),
  [3970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [3972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1316),
  [3974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [3976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [3978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [3980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1314),
  [3982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [3988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [3990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [3992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [3994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [3998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1844),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3175),
  [4002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1845),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [4006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [4008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1847),
  [4010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3336),
  [4012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1831),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [4018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1874),
  [4020] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3176),
  [4022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1866),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [4028] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1882),
  [4030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3177),
  [4032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [4038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1885),
  [4040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3254),
  [4042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1867),
  [4044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [4046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2196),
  [4048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1899),
  [4050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3298),
  [4052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1894),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [4058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [4060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3169),
  [4062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [4064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 3, 0, 0),
  [4066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 3, 0, 0),
  [4068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0),
  [4070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0),
  [4072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1801),
  [4075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1770),
  [4078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 3, 0, 0),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [4082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 2, 0, 0),
  [4084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [4086] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 1, 0, 0),
  [4088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 1, 0, 0),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [4092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 1, 0, 0),
  [4094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [4100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1808),
  [4103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3798),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3934),
  [4110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1787),
  [4113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(1804),
  [4116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3934),
  [4119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [4121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [4123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1651),
  [4125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [4127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat1, 4, 0, 0),
  [4129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat1, 4, 0, 0),
  [4131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [4133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [4135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1649),
  [4137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [4139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [4141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [4143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1668),
  [4145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [4147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [4149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [4151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [4153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [4155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [4157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [4159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1640),
  [4161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [4163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [4165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [4167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [4169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [4171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4092),
  [4173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [4175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [4177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [4179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2608),
  [4182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3254),
  [4185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [4187] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2568),
  [4190] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3417),
  [4193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [4195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3417),
  [4197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [4199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2569),
  [4202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2556),
  [4205] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3175),
  [4208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [4210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3350),
  [4212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [4214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2551),
  [4217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3174),
  [4220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2603),
  [4223] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3336),
  [4226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2610),
  [4229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3320),
  [4232] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3350),
  [4235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [4237] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2561),
  [4240] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3176),
  [4243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [4245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3150),
  [4247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1682),
  [4249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2564),
  [4252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2538),
  [4255] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0),
  [4257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0),
  [4259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(2056),
  [4262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(3511),
  [4265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3177),
  [4268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [4270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2565),
  [4273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__option_value, 1, 0, 0),
  [4275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__option_value, 1, 0, 0),
  [4277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3178),
  [4279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3178),
  [4282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [4284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3298),
  [4287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3172),
  [4289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [4291] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2559),
  [4294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3346),
  [4296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2567),
  [4299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3346),
  [4302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [4304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2575),
  [4307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3234),
  [4309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [4311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2579),
  [4314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [4316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(2580),
  [4319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [4321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [4325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 3, 0, 0),
  [4327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 3, 0, 0),
  [4329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4299),
  [4331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(2042),
  [4334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3799),
  [4337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [4339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [4341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3426),
  [4343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(2030),
  [4346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3729),
  [4349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4050),
  [4351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [4353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3351),
  [4355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0),
  [4357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat2, 2, 0, 0),
  [4359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1946),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [4366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(2123),
  [4369] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3751),
  [4372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [4380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [4382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [4388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [4390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [4392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [4394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [4396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [4398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [4400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [4402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2609),
  [4404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 4, 0, 0),
  [4406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [4408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 2, 0, 0),
  [4410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [4412] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 62), REDUCE(sym_memory_space, 6, 0, 91),
  [4416] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 62), REDUCE(sym_memory_space, 6, 0, 91),
  [4420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4165),
  [4422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1949),
  [4424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [4426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 1, 0, 0),
  [4428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1943),
  [4430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 3, 0, 0),
  [4432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [4434] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 60),
  [4437] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 60),
  [4440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 28),
  [4442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 28),
  [4444] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 62),
  [4447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_memory_space, 2, 0, 28), REDUCE(sym_memory_space, 4, 0, 62),
  [4450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 3, 0, 0),
  [4452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [4454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [4456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 5, 0, 0),
  [4458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [4460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1978),
  [4462] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(2159),
  [4465] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3800),
  [4468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [4470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [4472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [4474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [4478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [4480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [4482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [4484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [4486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [4488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [4490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [4492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [4494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [4496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [4498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [4500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [4502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [4504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [4506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [4508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3476),
  [4510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [4512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [4514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [4516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [4518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [4520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [4522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [4524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(3768),
  [4527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(2052),
  [4530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3768),
  [4532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [4534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_type_qualifier, 1, 0, 0),
  [4536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_qualifier, 1, 0, 0),
  [4538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(3801),
  [4541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(2057),
  [4544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [4546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [4550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [4552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [4556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [4558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [4560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [4562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [4564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34),
  [4566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34),
  [4568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3608),
  [4570] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3125),
  [4573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3523),
  [4576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [4578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [4580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3691),
  [4583] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3138),
  [4586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3583),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [4591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [4595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [4597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(197),
  [4599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [4601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [4603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [4605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 3, 0, 0),
  [4607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [4609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(196),
  [4611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [4613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [4615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [4617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [4619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [4621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [4623] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(3802),
  [4626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34),
  [4628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34),
  [4630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3691),
  [4633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3137),
  [4636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3581),
  [4639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [4641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [4643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [4645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34),
  [4647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34),
  [4649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3691),
  [4652] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3139),
  [4655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3586),
  [4658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [4660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [4662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3131),
  [4665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3485),
  [4668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [4670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [4672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3623),
  [4674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3109),
  [4677] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3540),
  [4680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1290),
  [4682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [4684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [4686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [4688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [4690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [4692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [4694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [4696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [4698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [4700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [4702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [4704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [4706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2136),
  [4708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3110),
  [4711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3544),
  [4714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3705),
  [4717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3146),
  [4720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3590),
  [4723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3705),
  [4726] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3147),
  [4729] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 6, 0, 34), SHIFT(3592),
  [4732] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3705),
  [4735] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3127),
  [4738] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3595),
  [4741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [4743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3105),
  [4746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 7, 0, 34), SHIFT(3528),
  [4749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 2, 0, 0),
  [4751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [4753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3350),
  [4756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [4758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [4760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3106),
  [4763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_if_block, 5, 0, 34), SHIFT(3535),
  [4766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [4768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [4770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [4772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3417),
  [4775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [4779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [4781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [4783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [4785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [4787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [4789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [4791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [4793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(208),
  [4795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [4797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [4801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2436),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [4807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [4809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [4811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [4813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [4815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [4817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [4819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [4821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [4823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1137),
  [4825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 2, 0, 8),
  [4827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 2, 0, 8),
  [4829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [4831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2586),
  [4833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [4835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [4837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [4839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(205),
  [4841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [4843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [4847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [4849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [4851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [4855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(213),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [4869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [4871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [4873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [4875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [4877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [4883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1231),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [4889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1237),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [4899] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(4042),
  [4902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [4904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [4906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [4908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3940),
  [4910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [4912] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(4076),
  [4915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_argument, 1, 0, 0),
  [4917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__command_argument, 1, 0, 0), SHIFT(3940),
  [4920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_comma_expression, 3, 0, 63),
  [4922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [4924] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3351),
  [4927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0),
  [4929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0),
  [4931] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3980),
  [4934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3167),
  [4937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3697),
  [4940] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3426),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [4945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(4018),
  [4948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__path_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(3976),
  [4951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3414),
  [4953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2588),
  [4955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [4957] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4078),
  [4960] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3332),
  [4963] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3696),
  [4966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [4968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [4970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [4972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [4974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [4976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [4978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1168),
  [4980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [4982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [4984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [4986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [4988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [4990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [4992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [4994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [4996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_option_value, 2, 0, 0),
  [4998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_option_value, 2, 0, 0),
  [5000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [5002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [5004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1273),
  [5006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [5008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [5010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [5012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [5014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [5016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [5018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [5020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [5022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [5024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 3, 0, 0),
  [5026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 3, 0, 0), SHIFT(3908),
  [5029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [5031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [5033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [5035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2663),
  [5037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 4, 0, 0),
  [5039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 4, 0, 0), SHIFT(3908),
  [5042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [5044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [5046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [5048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [5050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [5052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [5054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [5056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [5058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [5060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [5062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_labeled_statement, 1, 0, 0),
  [5064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__non_labeled_statement, 1, 0, 0),
  [5066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [5068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3770),
  [5070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [5072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [5074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT(3908),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 3, 0, 0),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 3, 0, 0),
  [5081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 4, 0, 0),
  [5083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 4, 0, 0),
  [5085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [5087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [5089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [5091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [5093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [5095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [5097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [5099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [5101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [5103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [5105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [5107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [5109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [5111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4001),
  [5113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__binary_expression, 3, 0, 38), SHIFT(4001),
  [5116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [5118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3),
  [5120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3),
  [5122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3), SHIFT(3979),
  [5125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 3, 0, 3), SHIFT(3647),
  [5128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [5130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [5132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [5134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [5136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [5138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [5140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [5142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [5144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [5146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 5, 0, 72),
  [5148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [5150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [5152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [5154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [5156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3),
  [5158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3),
  [5160] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3), SHIFT(4011),
  [5163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 3), SHIFT(3600),
  [5166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 3, 0, 8),
  [5168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 3, 0, 8),
  [5170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2614),
  [5172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__command_argument, 1, 0, 0), SHIFT(3948),
  [5175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [5177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 3, 0, 38),
  [5179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 4, 0, 52),
  [5181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_range_expression, 4, 0, 53),
  [5183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0),
  [5185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat1, 2, 0, 0),
  [5187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [5189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [5191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2614),
  [5194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_macro_expansion, 2, 0, 0),
  [5196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_macro_expansion, 2, 0, 0),
  [5198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [5200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [5202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 5, 0, 53),
  [5204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 5, 0, 53),
  [5206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 16),
  [5208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 3, 0, 16),
  [5210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 7, 0, 0),
  [5212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 7, 0, 0),
  [5214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_block, 5, 0, 34),
  [5216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_block, 5, 0, 34),
  [5218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition, 3, 0, 16),
  [5220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_definition, 3, 0, 16),
  [5222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 34),
  [5224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 4, 0, 34),
  [5226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 4, 0, 36),
  [5228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 4, 0, 36),
  [5230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition, 4, 0, 36),
  [5232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_definition, 4, 0, 36),
  [5234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 4, 0, 37),
  [5236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 4, 0, 37),
  [5238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_block, 3, 0, 3),
  [5240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_block, 3, 0, 3),
  [5242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_block_repeat1, 3, 0, 0),
  [5244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_block_repeat1, 3, 0, 0),
  [5246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 8, 0, 34),
  [5248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 8, 0, 34),
  [5250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 5, 0, 34),
  [5252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 5, 0, 34),
  [5254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 5, 0, 48),
  [5256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 5, 0, 48),
  [5258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 5, 0, 49),
  [5260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 5, 0, 49),
  [5262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 5, 0, 52),
  [5264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 5, 0, 52),
  [5266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_expression, 4, 0, 8),
  [5268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_expression, 4, 0, 8),
  [5270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 4, 0, 38),
  [5272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 4, 0, 38),
  [5274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 8, 1, 99),
  [5276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 8, 1, 99),
  [5278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 6, 0, 0),
  [5280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 6, 0, 0),
  [5282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_block, 6, 0, 37),
  [5284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_block, 6, 0, 37),
  [5286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 4, 0, 0),
  [5288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 4, 0, 0),
  [5290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_block, 4, 0, 3),
  [5292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_block, 4, 0, 3),
  [5294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 9, 1, 109),
  [5296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 9, 1, 109),
  [5298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_block, 6, 0, 34),
  [5300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_block, 6, 0, 34),
  [5302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 5, 0, 0),
  [5304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 5, 0, 0),
  [5306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_block, 5, 0, 37),
  [5308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_block, 5, 0, 37),
  [5310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 10, 0, 34),
  [5312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 10, 0, 34),
  [5314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_pre_condition_format, 6, 0, 34),
  [5316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_pre_condition_format, 6, 0, 34),
  [5318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 6, 0, 70),
  [5320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_declaration, 6, 0, 70),
  [5322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 6, 0, 71),
  [5324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 6, 0, 71),
  [5326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__repeat_block_post_condition_format, 7, 1, 87),
  [5328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__repeat_block_post_condition_format, 7, 1, 87),
  [5330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_assignment_expression, 6, 0, 72),
  [5332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_assignment_expression, 6, 0, 72),
  [5334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 2, 0, 4),
  [5336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 2, 0, 4),
  [5338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subroutine_call_expression, 7, 0, 88),
  [5340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subroutine_call_expression, 7, 0, 88),
  [5342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 3, 0, 13),
  [5344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 3, 0, 13),
  [5346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_block, 7, 0, 123),
  [5348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_block, 7, 0, 123),
  [5350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 2, 0, 5),
  [5352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 2, 0, 5),
  [5354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2901),
  [5356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4070),
  [5358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3982),
  [5360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4048),
  [5362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2859),
  [5364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2908),
  [5366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [5368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__statement, 2, 0, 0),
  [5370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__statement, 2, 0, 0),
  [5372] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_repeat_block, 1, 0, 2),
  [5374] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_repeat_block, 1, 0, 2),
  [5376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_command_expression, 3, 0, 14),
  [5378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command_expression, 3, 0, 14),
  [5380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_block, 8, 0, 123),
  [5382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elif_block, 8, 0, 123),
  [5384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_block, 9, 0, 34),
  [5386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_block, 9, 0, 34),
  [5388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4302),
  [5390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 2, 0, 0),
  [5392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [5394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [5396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [5398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3369),
  [5400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3312),
  [5402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3372),
  [5404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3081),
  [5406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3036),
  [5408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [5410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 1, 0, 0),
  [5412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2700),
  [5414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [5416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2818),
  [5418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3824),
  [5420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3838),
  [5422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4051),
  [5424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3477),
  [5426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3574),
  [5428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2706),
  [5431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0),
  [5433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0),
  [5435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2707),
  [5438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_declaration, 1, 0, 76),
  [5440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2709),
  [5442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3294),
  [5444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2801),
  [5446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [5448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__label, 2, 0, 6),
  [5450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__label, 2, 0, 6),
  [5452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2826),
  [5454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2948),
  [5456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79),
  [5458] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(2760),
  [5461] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(366),
  [5464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 79), SHIFT(2746),
  [5467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0),
  [5469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(2760),
  [5472] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(366),
  [5475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 2, 0, 0), SHIFT(2742),
  [5478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0),
  [5480] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(2760),
  [5483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(366),
  [5486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 0), SHIFT(2753),
  [5489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92),
  [5491] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(2760),
  [5494] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(366),
  [5497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 92), SHIFT(2758),
  [5500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93),
  [5502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(2760),
  [5505] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(366),
  [5508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 93), SHIFT(2761),
  [5511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79),
  [5513] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(2760),
  [5516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(366),
  [5519] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 79), SHIFT(2757),
  [5522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104),
  [5524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(2760),
  [5527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(366),
  [5530] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 104), SHIFT(2770),
  [5533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0),
  [5535] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(2760),
  [5538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(366),
  [5541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 0), SHIFT(2765),
  [5544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93),
  [5546] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(2760),
  [5549] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(366),
  [5552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 93), SHIFT(2767),
  [5555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92),
  [5557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(2760),
  [5560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(366),
  [5563] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 92), SHIFT(2766),
  [5566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104),
  [5568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(2760),
  [5571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(366),
  [5574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 104), SHIFT(2768),
  [5577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4133),
  [5579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2740),
  [5581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [5583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [5585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3129),
  [5587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3394),
  [5589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3070),
  [5591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2999),
  [5593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2800),
  [5595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [5597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [5599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [5601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [5603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [5605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3964),
  [5607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3807),
  [5609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [5611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3552),
  [5613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3083),
  [5615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2895),
  [5617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3215),
  [5619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2896),
  [5621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3010),
  [5623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2742),
  [5625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [5627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2731),
  [5629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2753),
  [5631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [5633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [5635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [5637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [5639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3484),
  [5641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3068),
  [5643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2907),
  [5645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3216),
  [5647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2909),
  [5649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [5651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [5653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [5655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [5657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [5659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2767),
  [5661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2768),
  [5663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [5665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [5667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [5669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2935),
  [5671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3219),
  [5673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2931),
  [5675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3548),
  [5677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3099),
  [5679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2916),
  [5681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3217),
  [5683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2918),
  [5685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [5687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2782),
  [5689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [5691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [5693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [5695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [5697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [5699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [5701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3075),
  [5703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2929),
  [5705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3218),
  [5707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2925),
  [5709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [5711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4043),
  [5713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [5715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4032),
  [5717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [5719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [5721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3969),
  [5723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3810),
  [5725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [5727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [5729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3189),
  [5731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2995),
  [5733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3237),
  [5735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2996),
  [5737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3034),
  [5739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3680),
  [5741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [5743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2971),
  [5745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3241),
  [5747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2967),
  [5749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0),
  [5751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0),
  [5753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2839),
  [5755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0), SHIFT(3424),
  [5758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [5760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [5762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3001),
  [5764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3238),
  [5766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3002),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3673),
  [5770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [5772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3013),
  [5774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3239),
  [5776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2982),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3637),
  [5780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [5782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2965),
  [5784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3240),
  [5786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2962),
  [5788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 41),
  [5790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [5794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [5796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [5798] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 41), SHIFT(2824),
  [5801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 23),
  [5803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 23), SHIFT(2829),
  [5806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 23),
  [5808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 23), SHIFT(2827),
  [5811] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 23), REDUCE(sym_hll_type_descriptor, 2, 0, 41),
  [5814] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 1, 0, 23), REDUCE(sym_hll_type_descriptor, 2, 0, 41), SHIFT(2833),
  [5818] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 23), REDUCE(sym_hll_type_descriptor, 3, 0, 41),
  [5821] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 23), REDUCE(sym_hll_type_descriptor, 3, 0, 41), SHIFT(2822),
  [5825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 67),
  [5827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 67), SHIFT(2825),
  [5830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 41),
  [5832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 41), SHIFT(2835),
  [5835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 67),
  [5837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 67), SHIFT(2831),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [5842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [5846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [5848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [5850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [5852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [5854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0),
  [5856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0),
  [5858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 1, 0, 0),
  [5860] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 3, 0, 0), SHIFT(3672),
  [5863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0),
  [5865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0),
  [5867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 4, 0, 0), SHIFT(3672),
  [5870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0),
  [5872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0),
  [5874] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 2, 0, 0), SHIFT(3672),
  [5877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 23),
  [5879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 23),
  [5881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3434),
  [5883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3067),
  [5885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [5887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2773),
  [5889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0),
  [5891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0),
  [5893] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat2, 2, 0, 0), SHIFT_REPEAT(3434),
  [5896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 23),
  [5898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 23),
  [5900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [5902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [5904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3134),
  [5906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [5908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2751),
  [5910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [5912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3031),
  [5914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0),
  [5916] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0), SHIFT_REPEAT(2803),
  [5919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat1, 2, 0, 0),
  [5921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41),
  [5923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41),
  [5925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [5927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41),
  [5929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41),
  [5931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [5933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat1, 2, 0, 0),
  [5935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__hll_declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2803),
  [5938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [5940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3040),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3806),
  [5946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [5948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [5950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [5954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2793),
  [5956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [5958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [5960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [5962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [5964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [5966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2792),
  [5968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [5970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3579),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [5974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2736),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2860),
  [5980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [5982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [5984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [5986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [5988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [5990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [5994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2862),
  [5996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [5998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [6000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [6002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [6004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [6006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [6008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [6010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [6012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0),
  [6014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0),
  [6016] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 1, 0, 0), SHIFT(3271),
  [6019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [6021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [6023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [6025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [6027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [6029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [6031] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0),
  [6033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0),
  [6035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 0), SHIFT(3271),
  [6038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2867),
  [6041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1963),
  [6043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [6045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [6047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [6049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [6051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [6053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [6055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [6057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [6059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [6061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [6063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [6065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3964),
  [6067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3035),
  [6069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3809),
  [6071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3040),
  [6074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3806),
  [6077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [6079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [6081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3035),
  [6084] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3809),
  [6087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2927),
  [6089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3436),
  [6091] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3484),
  [6094] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3216),
  [6097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3214),
  [6099] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3436),
  [6102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_type_identifier, 1, 0, 22),
  [6104] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_struct_specifier, 3, 0, 55),
  [6106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_struct_specifier, 3, 0, 55),
  [6108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2786),
  [6110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_union_specifier, 3, 0, 55),
  [6112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_union_specifier, 3, 0, 55),
  [6114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_enum_specifier, 3, 0, 55),
  [6116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_enum_specifier, 3, 0, 55),
  [6118] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 1, 0, 23), SHIFT(3434),
  [6121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3548),
  [6124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3217),
  [6127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 3, 0, 41), SHIFT(3434),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3357),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3225),
  [6134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [6136] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3597),
  [6139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3218),
  [6142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2771),
  [6144] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3491),
  [6147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3219),
  [6150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [6152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3508),
  [6155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3220),
  [6157] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3220),
  [6160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3537),
  [6162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 23), SHIFT(3434),
  [6165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3537),
  [6168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3221),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3554),
  [6172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3554),
  [6175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3577),
  [6177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 41),
  [6179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_sized_type_specifier, 2, 0, 41),
  [6181] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_declaration_specifiers, 2, 0, 41), SHIFT(3434),
  [6184] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3577),
  [6187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [6189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3967),
  [6191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3686),
  [6193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [6195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2789),
  [6197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3090),
  [6199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3695),
  [6201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3438),
  [6203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3637),
  [6206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3240),
  [6209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3092),
  [6211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3808),
  [6213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3437),
  [6215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3438),
  [6218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2790),
  [6220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [6222] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3680),
  [6225] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3241),
  [6228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [6230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3628),
  [6233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3242),
  [6235] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3242),
  [6238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3695),
  [6241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3243),
  [6243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [6245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3707),
  [6248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3612),
  [6250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3624),
  [6252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2984),
  [6255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3053),
  [6258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3807),
  [6261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3236),
  [6263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3687),
  [6265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4179),
  [6267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3995),
  [6269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4015),
  [6271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3831),
  [6273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4122),
  [6275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [6277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3609),
  [6280] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3238),
  [6283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [6285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2794),
  [6287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3673),
  [6290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3239),
  [6293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT(3612),
  [6296] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3090),
  [6299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3810),
  [6302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(2803),
  [6305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_descriptor_repeat2, 2, 0, 0), SHIFT_REPEAT(3507),
  [6308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3092),
  [6311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3808),
  [6314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3031),
  [6317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__hll_pointer_declarator_specifier, 1, 0, 0), SHIFT(3395),
  [6320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [6322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3811),
  [6324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3440),
  [6326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [6328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3185),
  [6330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [6332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [6334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_expression, 2, 0, 33),
  [6336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_expression, 2, 0, 33),
  [6338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [6340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3289),
  [6342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [6344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [6346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 33),
  [6348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 33),
  [6350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3185),
  [6353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3792),
  [6356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3341),
  [6359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_macro_text_expansion_repeat1, 2, 0, 0), SHIFT_REPEAT(3811),
  [6362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3784),
  [6364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [6366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [6370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 1, 0, 0),
  [6372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3112),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [6376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3313),
  [6378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2988),
  [6380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3814),
  [6382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [6384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [6386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3795),
  [6388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [6390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [6392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3608),
  [6394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [6396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3469),
  [6398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [6400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3539),
  [6402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3543),
  [6404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3545),
  [6406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [6408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [6410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3455),
  [6412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3510),
  [6414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [6416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [6418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [6420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3596),
  [6422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [6424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3486),
  [6426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3436),
  [6429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3563),
  [6431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [6433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3582),
  [6435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3584),
  [6437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3587),
  [6439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [6441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [6443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [6445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3591),
  [6447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3594),
  [6449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3993),
  [6451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [6453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [6455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [6457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [6459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [6461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [6463] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [6465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [6467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2865),
  [6469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2369),
  [6471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3161),
  [6473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3438),
  [6476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2379),
  [6478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3326),
  [6480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [6482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3626),
  [6484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3307),
  [6486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3854),
  [6488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [6490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [6492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1918),
  [6494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1823),
  [6496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [6498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2290),
  [6500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1613),
  [6502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(684),
  [6504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3276),
  [6506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [6508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(512),
  [6510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(516),
  [6512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(519),
  [6514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [6516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1374),
  [6518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3211),
  [6520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [6522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [6524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [6526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3324),
  [6528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2938),
  [6530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2943),
  [6532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2947),
  [6534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [6536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 2, 0, 58),
  [6538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2703),
  [6540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [6542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [6544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [6546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_pattern, 1, 0, 0),
  [6548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_type_pattern, 1, 0, 0),
  [6550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [6552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [6554] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subroutine_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3231),
  [6557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [6559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 100),
  [6561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3698),
  [6563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [6565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1911),
  [6567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 101),
  [6569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3384),
  [6571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2974),
  [6573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2978),
  [6575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2981),
  [6577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_pointer_declarator, 3, 0, 75),
  [6579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 102),
  [6581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 5, 0, 103),
  [6583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [6585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat2, 2, 0, 0),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [6589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3416),
  [6591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3255),
  [6593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3445),
  [6595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 8, 0, 122),
  [6597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [6599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [6601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [6603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [6605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3321),
  [6607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [6609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3162),
  [6611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [6613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3272),
  [6615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_sized_type_specifier_repeat1, 2, 0, 0),
  [6617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [6619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [6621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 110),
  [6623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 111),
  [6625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 112),
  [6627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 4, 0, 89),
  [6629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 113),
  [6631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 6, 0, 114),
  [6633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0),
  [6635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0),
  [6637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3943),
  [6639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [6641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_declaration, 2, 0, 40),
  [6643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3560),
  [6645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_argument_list_default_format, 1, 0, 0),
  [6647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3136),
  [6649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 4, 0, 90),
  [6651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3357),
  [6654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3296),
  [6657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0),
  [6659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0),
  [6661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3916),
  [6663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1903),
  [6665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [6667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1015),
  [6669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3073),
  [6671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [6673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3605),
  [6675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 118),
  [6677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [6679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 119),
  [6681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 7, 0, 120),
  [6683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_array_declarator, 3, 0, 75),
  [6685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_declarator, 3, 0, 75),
  [6687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3879),
  [6690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [6692] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3326),
  [6695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [6697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4078),
  [6699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3699),
  [6701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [6703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [6705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [6707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [6709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3186),
  [6711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_pointer_declarator, 2, 0, 58),
  [6713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_declaration, 2, 0, 40),
  [6715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_declaration, 3, 0, 59),
  [6717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3437),
  [6720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1907),
  [6722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [6724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [6726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [6728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [6730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4050),
  [6732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [6734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [6736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 66),
  [6738] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 81), REDUCE(sym_hll_type_descriptor, 5, 0, 97),
  [6741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3354),
  [6744] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 65), REDUCE(sym_hll_type_descriptor, 4, 0, 83),
  [6747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 1, 0, 51),
  [6749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 1, 0, 51),
  [6751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4054),
  [6753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [6755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [6757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [6759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [6761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [6763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [6765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat1, 2, 0, 0),
  [6767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [6769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [6771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3967),
  [6773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3130),
  [6775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [6777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3650),
  [6780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3329),
  [6782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [6784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3613),
  [6787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3468),
  [6790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 5, 0, 97),
  [6792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [6794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [6796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_hll_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4004),
  [6799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4074),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [6803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [6805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [6807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [6809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 5, 0, 98),
  [6811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4092),
  [6813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [6815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [6817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3962),
  [6819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [6821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [6823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74), SHIFT_REPEAT(3679),
  [6826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74),
  [6828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74),
  [6830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3115),
  [6832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [6834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 3, 0, 65),
  [6836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4089),
  [6838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [6840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [6842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [6844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [6846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [6848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_format_expression, 3, 0, 54),
  [6850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_format_expression, 3, 0, 54),
  [6852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 45), REDUCE(sym_hll_type_descriptor, 3, 0, 66),
  [6855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 83),
  [6857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [6859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [6863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3973),
  [6865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3813),
  [6867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [6869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1549),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [6875] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_symbol_repeat1, 2, 0, 0), SHIFT_REPEAT(3440),
  [6878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [6880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [6882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 84),
  [6884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [6886] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4036),
  [6888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [6890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [6894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4020),
  [6896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [6898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [6900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [6902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [6904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [6906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [6908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 2, 0, 45),
  [6910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4085),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [6916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 4, 0, 81),
  [6918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_type_descriptor, 6, 0, 108),
  [6920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [6922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3998),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [6928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [6930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4093),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3805),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [6940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3965),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3439),
  [6944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3042),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3034),
  [6948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3971),
  [6950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3571),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [6956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3977),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [6960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [6964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4079),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [6974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3983),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3783),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [6980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [6982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3567),
  [6984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [6986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3355),
  [6988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 6, 0, 0),
  [6990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3249),
  [6992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 5, 0, 0),
  [6994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 5, 0, 0),
  [6996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 8, 0, 121),
  [6998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 5, 0, 0),
  [7000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [7002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [7004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [7008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [7010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 4, 0, 0),
  [7012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 4, 0, 0),
  [7014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_function_declarator, 2, 0, 57),
  [7016] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_function_declarator, 2, 0, 57),
  [7018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [7020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [7022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 5, 0, 0),
  [7024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 17),
  [7026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 17), SHIFT_REPEAT(3606),
  [7029] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 94),
  [7031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 105),
  [7033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4132),
  [7036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0),
  [7038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 0),
  [7040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 106),
  [7042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [7044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_with_default_format, 1, 0, 0),
  [7046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_command_with_default_format, 1, 0, 0),
  [7048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [7050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 80),
  [7052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0), SHIFT_REPEAT(4113),
  [7055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3650),
  [7058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 107),
  [7060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 5, 0, 95),
  [7062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [7064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_function_declarator, 3, 0, 77),
  [7066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2696),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2698),
  [7070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3606),
  [7072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 7, 0, 0),
  [7074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3725),
  [7076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [7078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [7080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3613),
  [7083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_type_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(3494),
  [7086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 4, 0, 0),
  [7088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 4, 0, 0),
  [7090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [7092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 3, 0, 0),
  [7094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 3, 0, 0),
  [7096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parameter_list, 2, 0, 0),
  [7098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [7100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_with_default_format, 2, 0, 0),
  [7102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_var_command_with_default_format, 2, 0, 0),
  [7104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_identifier, 2, 0, 1),
  [7106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__command_identifier, 2, 0, 1),
  [7108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_function_declarator, 2, 0, 57),
  [7110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3812),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3536),
  [7114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2644),
  [7118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [7122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 105),
  [7124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 106),
  [7126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 115),
  [7128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [7130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [7132] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3517),
  [7135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 107),
  [7137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 116),
  [7139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [7141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [7143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 117),
  [7145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [7147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [7149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [7151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [7153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [7155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 6, 0, 95),
  [7157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 4, 0, 0),
  [7159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [7161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3625),
  [7163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(3812),
  [7166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_file_handle_repeat1, 2, 0, 0), SHIFT_REPEAT(3536),
  [7169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 94),
  [7171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2626),
  [7173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [7175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 80),
  [7177] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(93),
  [7180] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3921),
  [7183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 4, 0, 95),
  [7185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_parenthesized_declarator, 3, 0, 0),
  [7187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_argument_list_default_format, 2, 0, 0),
  [7189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2630),
  [7191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [7193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [7195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_arguments, 4, 0, 0),
  [7197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0), SHIFT_REPEAT(3560),
  [7200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0),
  [7202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat1, 2, 0, 0),
  [7204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 115),
  [7206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 116),
  [7208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0),
  [7210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0),
  [7212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2993),
  [7214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__command_identifier, 1, 0, 1),
  [7216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__command_identifier, 1, 0, 1),
  [7218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 117),
  [7220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_parenthesized_declarator, 3, 0, 0),
  [7222] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parenthesized_declarator, 3, 0, 0),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [7226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [7228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 7, 0, 121),
  [7230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__host_command_argument_list_default_format_repeat2, 2, 0, 0), SHIFT_REPEAT(3136),
  [7233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_parameter_list, 2, 0, 0),
  [7235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_function_declarator, 3, 0, 77),
  [7237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_function_declarator, 3, 0, 77),
  [7239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_abstract_array_declarator, 3, 0, 80),
  [7241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__command_arguments_repeat3, 2, 0, 0), SHIFT_REPEAT(3355),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [7248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [7250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [7256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3990),
  [7258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [7260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [7264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3607),
  [7266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2455),
  [7268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [7270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [7272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3954),
  [7274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 4, 0, 0),
  [7276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3881),
  [7278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [7280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [7282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__var_command_argument_list_non_hll_format_repeat1, 2, 0, 0),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [7286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [7292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3926),
  [7294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [7296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(97),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [7300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3688),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [7304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_format_expression_repeat1, 2, 0, 74), SHIFT_REPEAT(3599),
  [7307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_default_format_var_command, 1, 0, 3),
  [7309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(361),
  [7311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0),
  [7313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(3640),
  [7316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_labeled_expression_repeat1, 2, 0, 0),
  [7318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2503),
  [7322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3644),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2507),
  [7326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [7328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [7334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3692),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [7338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2901),
  [7340] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 4, 0, 0),
  [7342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [7344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [7346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [7348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [7350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_expression, 2, 0, 39),
  [7352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_option_expression, 2, 0, 39), SHIFT(35),
  [7355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2636),
  [7357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [7359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_option_expression, 2, 0, 39),
  [7361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [7363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 1, 0, 3),
  [7365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [7367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 6, 0, 0),
  [7369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 2, 0, 0),
  [7371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_pointer_declarator_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2803),
  [7374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [7376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_string_literal_repeat1, 2, 0, 0),
  [7378] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(3677),
  [7381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4031),
  [7383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [7385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [7387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3144),
  [7389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [7391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_hll_var_command, 1, 0, 3),
  [7393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3063),
  [7395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 20),
  [7397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__command_identifier_repeat1, 2, 0, 20),
  [7399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [7401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [7403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(130),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [7407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [7409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [7411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_default_format, 5, 0, 0),
  [7413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_argument_list_non_hll_format, 2, 0, 0),
  [7415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3616),
  [7417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_argument_list_non_hll_format, 1, 0, 0),
  [7419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [7421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [7423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [7425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [7427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [7429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1745),
  [7431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [7433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [7435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [7437] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_hll_option_expression, 2, 0, 39), SHIFT(525),
  [7440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [7442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [7444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [7446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [7448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [7450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [7452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [7454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [7456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [7458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [7460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [7462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3752),
  [7464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [7466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [7468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3606),
  [7470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [7472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3562),
  [7474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [7476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [7478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4169),
  [7480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [7482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [7484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [7486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3736),
  [7488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [7490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [7492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [7494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [7498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [7502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [7506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 15),
  [7508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_macro_definition_repeat1, 2, 0, 15),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3566),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [7514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [7516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [7518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3748),
  [7522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [7524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [7526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [7528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [7530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [7532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [7538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [7540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [7542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [7546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [7548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3760),
  [7550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [7554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [7556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [7558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3765),
  [7560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_hll_parameter_list_repeat1, 2, 0, 0),
  [7562] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2712),
  [7565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [7567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [7569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [7571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [7573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [7575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [7577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [7579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4178),
  [7581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [7583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [7585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [7587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [7589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [7591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [7593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [7595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [7597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [7599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3780),
  [7601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [7603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [7605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [7607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3782),
  [7609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [7611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [7613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4181),
  [7615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4182),
  [7617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [7619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4184),
  [7621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4185),
  [7623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [7625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2712),
  [7627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [7629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4187),
  [7631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4188),
  [7633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [7635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4189),
  [7637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4190),
  [7639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [7641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [7643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4192),
  [7645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [7647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [7649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [7651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4193),
  [7653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [7655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [7657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3153),
  [7659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4195),
  [7661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4196),
  [7663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [7665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4197),
  [7667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4198),
  [7669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [7671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4199),
  [7673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4200),
  [7675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [7677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4201),
  [7679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4202),
  [7681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2466),
  [7683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4204),
  [7687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4206),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [7695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [7697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4208),
  [7699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [7701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [7703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [7705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [7707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4211),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4212),
  [7711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4225),
  [7713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4213),
  [7715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4214),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [7719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [7721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4216),
  [7723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [7725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4217),
  [7727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4218),
  [7729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [7731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4219),
  [7733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4220),
  [7735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [7737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4221),
  [7739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4222),
  [7741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [7743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4223),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4224),
  [7747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3097),
  [7749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4102),
  [7751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4328),
  [7753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [7755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4228),
  [7759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3122),
  [7761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4229),
  [7763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [7765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3160),
  [7767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4231),
  [7769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4232),
  [7771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3756),
  [7773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4233),
  [7775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [7777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [7779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4235),
  [7781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4236),
  [7783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [7785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4237),
  [7787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4238),
  [7789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [7791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4239),
  [7793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4240),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [7797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4149),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [7803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_identifier, 2, 0, 9),
  [7805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4183),
  [7807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_definition_command_argument_list_format, 1, 0, 0),
  [7809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 3, 0, 0),
  [7811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3851),
  [7813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [7815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3917),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [7819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [7821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [7825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [7827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [7829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command_with_non_hll_format, 3, 0, 0),
  [7831] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__var_command_with_non_hll_format, 3, 0, 0),
  [7833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [7835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [7837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4151),
  [7839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4152),
  [7841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [7843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [7845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3465),
  [7847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3557),
  [7849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [7851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [7853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3868),
  [7857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3869),
  [7861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__command_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(4109),
  [7864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2787),
  [7866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2763),
  [7868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [7870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [7872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [7874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [7876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2769),
  [7878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [7880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3855),
  [7882] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_pattern_command_argument_list_format_repeat2, 2, 0, 0),
  [7884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 2, 0, 0),
  [7886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [7888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [7890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [7892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3857),
  [7894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [7896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [7898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [7900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_pattern_command_argument_list_format, 1, 0, 0),
  [7902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [7904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [7906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [7908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [7910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [7912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_expression, 4, 0, 73),
  [7914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_expression, 4, 0, 73),
  [7916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [7918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [7920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3874),
  [7924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [7926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [7928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [7930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [7932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [7934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [7936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [7938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4158),
  [7940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4159),
  [7942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat3, 2, 0, 0),
  [7944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [7946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__hll_var_command_argument_list_default_format_repeat3, 2, 0, 0), SHIFT_REPEAT(4113),
  [7949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [7951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [7953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3931),
  [7955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [7957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3859),
  [7959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [7961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 0),
  [7963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4183),
  [7966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hll_option_expression, 4, 0, 73),
  [7968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hll_option_expression, 4, 0, 73),
  [7970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3898),
  [7974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_parenthesized_option_value, 3, 0, 0),
  [7976] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__hll_parenthesized_option_value, 3, 0, 0),
  [7978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1723),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3902),
  [7988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [7990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3903),
  [7992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [7998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [8000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2774),
  [8002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3907),
  [8006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [8010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [8012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4135),
  [8014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [8016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [8030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_hll_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(739),
  [8033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [8035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4244),
  [8037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4267),
  [8039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [8041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [8043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [8045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [8047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [8049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [8051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [8053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [8055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4145),
  [8057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1802),
  [8059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4163),
  [8061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4164),
  [8063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [8065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1800),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3770),
  [8069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [8071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [8073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command, 3, 0, 21),
  [8075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [8077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [8081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4116),
  [8083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [8085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3620),
  [8087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [8089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [8091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_option_value, 3, 0, 0),
  [8093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_option_value, 3, 0, 0),
  [8095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3561),
  [8097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [8101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [8103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [8105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [8109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3731),
  [8111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [8113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [8117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2660),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4313),
  [8121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [8123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2653),
  [8125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [8131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [8135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3954),
  [8137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__other_command, 3, 0, 21),
  [8139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [8141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [8143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4153),
  [8145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command, 1, 0, 4),
  [8147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4161),
  [8149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4161),
  [8151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [8155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2680),
  [8157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [8159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2804),
  [8161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [8163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [8165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [8167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [8169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [8171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [8173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [8175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4127),
  [8177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [8179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [8181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [8183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [8185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_non_default_format_var_command, 5, 0, 50),
  [8187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [8189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2692),
  [8191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [8193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [8195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [8197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [8199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command, 1, 0, 4),
  [8201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [8203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [8205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3367),
  [8207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_option_expression, 2, 0, 39), SHIFT(34),
  [8210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [8212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [8214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [8216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [8218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4110),
  [8220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_hll_option_expression, 2, 0, 39), SHIFT(557),
  [8223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4256),
  [8225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [8227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [8229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [8231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2679),
  [8233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [8235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [8237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4325),
  [8239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4325),
  [8241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4170),
  [8243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4170),
  [8245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [8247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4280),
  [8249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4280),
  [8251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [8253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(199),
  [8255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4258),
  [8257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4258),
  [8259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [8261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4262),
  [8263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4262),
  [8265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4111),
  [8267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4111),
  [8269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [8271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command, 3, 0, 21),
  [8273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [8275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2657),
  [8277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [8279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [8283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command, 5, 0, 56),
  [8285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [8287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 7, 0, 0),
  [8289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [8291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2685),
  [8293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2686),
  [8295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__var_command, 1, 0, 5),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [8299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(179),
  [8301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3170),
  [8303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [8305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [8307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [8309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3708),
  [8311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [8313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_identifier_repeat1, 2, 0, 44),
  [8315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [8317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_command_argument_list_non_default_format, 6, 0, 0),
  [8319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [8321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [8323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [8325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [8327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [8329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4294),
  [8331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_default_format_var_command, 3, 0, 21),
  [8333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2857),
  [8335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2676),
  [8337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [8339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [8341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [8343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [8345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [8347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [8349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [8351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__non_hll_var_command, 3, 0, 21),
  [8353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4315),
  [8355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [8357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [8359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [8361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3132),
  [8363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [8365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [8367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [8369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [8371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [8373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [8375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [8377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4306),
  [8379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [8381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [8383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3759),
  [8385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_definition_command_expression, 3, 0, 0),
  [8387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [8389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_definition_command, 1, 0, 0),
  [8391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [8393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [8395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [8397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4246),
  [8399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3687),
  [8401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [8403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4310),
  [8405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4314),
  [8407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [8409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [8411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [8413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1357),
  [8415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [8417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [8419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4141),
  [8421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [8423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [8425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [8427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [8429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [8431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [8433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4269),
  [8435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [8439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [8441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4241),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4242),
  [8447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4254),
  [8449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [8451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__host_command_with_default_format, 3, 0, 18),
  [8453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4248),
  [8455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4252),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3667),
  [8459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [8463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [8465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [8467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [8469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [8471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [8473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [8475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4143),
  [8477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4243),
  [8479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4245),
  [8481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_if_command, 3, 0, 19),
  [8483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3961),
  [8485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [8487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [8489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [8491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4284),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4286),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [8497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [8499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [8501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4296),
  [8503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [8505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4305),
  [8507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4307),
  [8509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4311),
  [8511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [8513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4316),
  [8515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4317),
  [8517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4259),
  [8519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4276),
  [8521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [8523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4250),
  [8525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4319),
  [8527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [8529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4166),
  [8531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [8533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4260),
  [8535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4272),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4323),
  [8539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [8541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [8543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4156),
  [8545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4171),
  [8547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4175),
  [8549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4251),
  [8551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4264),
  [8555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4265),
  [8557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4279),
  [8559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4281),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4283),
  [8563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4285),
  [8565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4295),
  [8567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4301),
  [8569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [8571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4308),
  [8573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4321),
  [8575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [8577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4326),
  [8579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4107),
  [8581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [8583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [8585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4119),
  [8587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [8589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [8591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [8593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4128),
  [8595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [8597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4138),
  [8599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [8601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3572),
  [8603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [8605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4226),
  [8607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4162),
  [8609] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [8611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [8617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [8619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [8625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [8627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [8629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [8631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [8633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [8635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [8637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [8639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [8641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [8643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [8645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [8649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [8651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [8653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [8655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [8657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4293),
  [8659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [8661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__hll_var_call_expression_function, 3, 0, 42),
  [8663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [8665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3020),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4287),
  [8671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [8675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3632),
  [8677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [8679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3055),
  [8681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [8683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [8685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [8687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [8689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3114),
  [8691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3192),
  [8693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [8695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1729),
  [8697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [8699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4318),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_label_identifier = 0,
  ts_external_token__and_operator_pre_hook = 1,
  ts_external_token__decimal_number = 2,
  ts_external_token__decimal_number_pre_hook = 3,
  ts_external_token_hll_number_literal = 4,
  ts_external_token__hll_number_literal_pre_hook = 5,
  ts_external_token_path = 6,
  ts_external_token_AMP_AMP = 7,
  ts_external_token_AMP = 8,
  ts_external_token__ampersand_char = 9,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_label_identifier] = sym_label_identifier,
  [ts_external_token__and_operator_pre_hook] = sym__and_operator_pre_hook,
  [ts_external_token__decimal_number] = sym__decimal_number,
  [ts_external_token__decimal_number_pre_hook] = sym__decimal_number_pre_hook,
  [ts_external_token_hll_number_literal] = sym_hll_number_literal,
  [ts_external_token__hll_number_literal_pre_hook] = sym__hll_number_literal_pre_hook,
  [ts_external_token_path] = sym_path,
  [ts_external_token_AMP_AMP] = anon_sym_AMP_AMP,
  [ts_external_token_AMP] = anon_sym_AMP,
  [ts_external_token__ampersand_char] = sym__ampersand_char,
};

static const bool ts_external_scanner_states[21][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_hll_number_literal] = true,
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
    [ts_external_token__ampersand_char] = true,
  },
  [2] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [3] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [4] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
  },
  [5] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [6] = {
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [7] = {
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
  },
  [8] = {
    [ts_external_token__hll_number_literal_pre_hook] = true,
    [ts_external_token_AMP] = true,
  },
  [9] = {
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [10] = {
    [ts_external_token_label_identifier] = true,
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP_AMP] = true,
    [ts_external_token_AMP] = true,
  },
  [11] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_AMP] = true,
  },
  [12] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_path] = true,
    [ts_external_token_AMP] = true,
  },
  [13] = {
    [ts_external_token__and_operator_pre_hook] = true,
  },
  [14] = {
    [ts_external_token__and_operator_pre_hook] = true,
    [ts_external_token_path] = true,
  },
  [15] = {
    [ts_external_token_AMP] = true,
  },
  [16] = {
    [ts_external_token__decimal_number_pre_hook] = true,
    [ts_external_token_hll_number_literal] = true,
  },
  [17] = {
    [ts_external_token_path] = true,
  },
  [18] = {
    [ts_external_token_AMP] = true,
    [ts_external_token__ampersand_char] = true,
  },
  [19] = {
    [ts_external_token__decimal_number] = true,
  },
  [20] = {
    [ts_external_token_hll_number_literal] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_t32_external_scanner_create(void);
void tree_sitter_t32_external_scanner_destroy(void *);
bool tree_sitter_t32_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_t32_external_scanner_serialize(void *, char *);
void tree_sitter_t32_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_t32(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_t32_external_scanner_create,
      tree_sitter_t32_external_scanner_destroy,
      tree_sitter_t32_external_scanner_scan,
      tree_sitter_t32_external_scanner_serialize,
      tree_sitter_t32_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "t32",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 7,
      .minor_version = 1,
      .patch_version = 4,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
